(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.4' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     11816,        310]
NotebookOptionsPosition[     10248,        253]
NotebookOutlinePosition[     10633,        270]
CellTagsIndexPosition[     10590,        267]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Exercises - Graph", "Title",
 CellChangeTimes->{{3.676110727751924*^9, 3.676110731104054*^9}, {
  3.676202750271039*^9, 3.676202750855156*^9}}],

Cell[CellGroupData[{

Cell["To be or not to be lists", "Section",
 CellChangeTimes->{{3.6761107633014383`*^9, 3.676110769096087*^9}, {
  3.6761156799717283`*^9, 3.676115682532858*^9}, {3.6761157161495457`*^9, 
  3.676115721492573*^9}, {3.676116110625745*^9, 3.676116114387026*^9}, {
  3.676202752888332*^9, 3.676202757098895*^9}, {3.67628141267354*^9, 
  3.676281425259199*^9}}],

Cell["\<\
In this exercise you are tasked with visualising the concordance network for \
the \[OpenCurlyDoubleQuote]To or not to be\[CloseCurlyDoubleQuote] extract \
imported from Princeton:\
\>", "Text",
 CellChangeTimes->{{3.676280875033128*^9, 3.6762809250297832`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"toBeOrNotToBe", "=", 
  RowBox[{
  "Import", "[", 
   "\"\<http://www.cs.princeton.edu/courses/archive/spring07/cos116/lab12/\
shakespeare.txt\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.676280851812958*^9, 3.676280861927535*^9}, {
  3.6762824843906393`*^9, 3.6762824867303658`*^9}}],

Cell[BoxData["\<\"To be, or not to be--that is the question: \\nWhether 'tis \
nobler in the mind to suffer \\nThe slings and arrows of outrageous fortune \
\\nOr to take arms against a sea of troubles \\nAnd by opposing end them. To \
die, to sleep-- \\nNo more--and by a sleep to say we end \\nThe heartache, \
and the thousand natural shocks \\nThat flesh is heir to. 'Tis a consummation \
\\nDevoutly to be wished. To die, to sleep-- \\nTo sleep--perchance to dream: \
ay, there's the rub, \\nFor in that sleep of death what dreams may come \
\\nWhen we have shuffled off this mortal coil, \\nMust give us pause. There's \
the respect \\nThat makes calamity of so long life. \\nFor who would bear the \
whips and scorns of time, \\nTh' oppressor's wrong, the proud man's contumely \
\\nThe pangs of despised love, the law's delay, \\nThe insolence of office, \
and the spurns \\nThat patient merit of th' unworthy takes, \\nWhen he \
himself might his quietus make \\nWith a bare bodkin? Who would fardels bear, \
\\nTo grunt and sweat under a weary life, \\nBut that the dread of something \
after death, \\nThe undiscovered country, from whose bourn \\nNo traveller \
returns, puzzles the will, \\nAnd makes us rather bear those ills we have \
\\nThan fly to others that we know not of? \\nThus conscience does make \
cowards of us all, \\nAnd thus the native hue of resolution \\nIs sicklied \
o'er with the pale cast of thought, \\nAnd enterprise of great pitch and \
moment \\nWith this regard their currents turn awry \\nAnd lose the name of \
action. -- Soft you now, \\nThe fair Ophelia! -- Nymph, in thy orisons \\nBe \
all my sins remembered. \\n\"\>"], "Output",
 CellChangeTimes->{3.676658669583563*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Use TextWords to drop punctuation marks and ToLowerCase to remove potential \
duplication of words. You will need to ensure that the output of this step is \
a flat list, which will pass this predicate test:\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676281066152912*^9, 3.676281150933772*^9}, {
  3.676281643177724*^9, 3.6762816966843557`*^9}, {3.67628247963334*^9, 
  3.6762824810935917`*^9}, {3.676283587228643*^9, 3.676283600212089*^9}}],

Cell["\<\
Partition the output from step 2 into lists containing two elements, note \
that the partitions must overset by 1 (as the words \
\[OpenCurlyDoubleQuote]nobler\[CloseCurlyDoubleQuote],\[CloseCurlyDoubleQuote]\
mind\[CloseCurlyDoubleQuote],\[CloseCurlyDoubleQuote]suffer\
\[CloseCurlyDoubleQuote] are all connected to one another)\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676281173289214*^9, 3.676281197364092*^9}, {
  3.676281286107692*^9, 3.676281322736557*^9}}],

Cell["\<\
Convert the output of step 3 into a list of UndirectedEdges and create a \
Graph from the output:\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676281329949398*^9, 3.676281392803528*^9}}],

Cell["\<\
Count the number of edges and vertices in the graph, consult the \
documentation on Graph Measures to see if there are interesting measures that \
might facilitate your analysis of this data.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.67628222783044*^9, 3.67628230176499*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Subgraphing", "Section",
 CellChangeTimes->{{3.6761107633014383`*^9, 3.676110769096087*^9}, {
  3.6761156799717283`*^9, 3.676115682532858*^9}, {3.6761157161495457`*^9, 
  3.676115721492573*^9}, {3.676116110625745*^9, 3.676116114387026*^9}, {
  3.676202752888332*^9, 3.676202757098895*^9}, {3.67628141267354*^9, 
  3.676281445860187*^9}, {3.676282130414431*^9, 3.676282135318386*^9}}],

Cell["\<\
Extracting parts of graph is fairly simple when using the Subgraph function:\
\>", "Text",
 CellChangeTimes->{{3.6762821376132927`*^9, 3.67628215444317*^9}}],

Cell[CellGroupData[{

Cell["\<\
Investigate the function VertexLabels in the documentation for a method to \
add labels to the vertices as tooltips (shown when the cursor hovers over a \
tooltip)\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676281449590415*^9, 3.6762815073087482`*^9}}],

Cell["Calculate the DegreeCentrality of the Graph", "ItemNumbered",
 CellChangeTimes->{{3.676281757546769*^9, 3.676281779991562*^9}}],

Cell["\<\
Use the function Pick to find those vertices where the DegreeCentrality is \
greater than 2\[LineSeparator]\[LineSeparator]As you have not used Pick \
before, here is a template.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.67628178327747*^9, 3.676281798655952*^9}, {
  3.676281842239648*^9, 3.676281887902157*^9}, {3.676282192099884*^9, 
  3.6762821929761267`*^9}, {3.676282340603826*^9, 3.676282340634357*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pick", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\"\<apples\>\"", ",", "\"\<oranges\>\"", ",", "\"\<fruits\>\""}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "1"}], "}"}], ",", 
   RowBox[{"q_", "/;", 
    RowBox[{"q", ">", "1"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.676281799947177*^9, 3.676281831068059*^9}, {
  3.676281865214621*^9, 3.676281873503606*^9}}],

Cell[BoxData[
 RowBox[{"{", "\<\"oranges\"\>", "}"}]], "Output",
 CellChangeTimes->{3.676281831584815*^9, 3.676281873811645*^9}]
}, Open  ]],

Cell["Your pick statement is correct if the following yields true:", "Text",
 CellChangeTimes->{{3.6762821960695972`*^9, 3.676282213384268*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Length", "[", "yourSymbol", "]"}], "==", "34"}]], "Input",
 CellChangeTimes->{{3.676282169875874*^9, 3.676282187466092*^9}, {
  3.676283658465938*^9, 3.676283658485468*^9}}],

Cell["\<\
Provide this list of vertices to Subgraph, use VertexLabels to label the \
vertices:\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676282310169447*^9, 3.676282338149255*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Always question whether...", "Section",
 CellChangeTimes->{{3.6761107633014383`*^9, 3.676110769096087*^9}, {
  3.6761156799717283`*^9, 3.676115682532858*^9}, {3.6761157161495457`*^9, 
  3.676115721492573*^9}, {3.676116110625745*^9, 3.676116114387026*^9}, {
  3.676202752888332*^9, 3.676202757098895*^9}, {3.67628141267354*^9, 
  3.676281445860187*^9}, {3.676282130414431*^9, 3.676282135318386*^9}, {
  3.676282366838748*^9, 3.67628236971758*^9}, {3.676283524025569*^9, 
  3.6762835341709843`*^9}}],

Cell["\<\
When we created our concordances the line breaks were not taken into account, \
which is why \[OpenCurlyDoubleQuote]question whether\[CloseCurlyDoubleQuote] \
are connected. Let\[CloseCurlyQuote]s correct for this by formalising our \
concordance processing.\
\>", "Text",
 CellChangeTimes->{{3.676283537253255*^9, 3.676283561869718*^9}, {
  3.676283727812211*^9, 3.6762837457987823`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Split the imported string at line breaks (represented by EndOfLine)\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676282512887595*^9, 3.676282549012657*^9}}],

Cell["\<\
Write your steps for partitioning strings into three word concordances into a \
function.\[LineSeparator]\[LineSeparator]Applying your function to the string \
below should provide the output shown:\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676282831821476*^9, 3.676282862623252*^9}, {
  3.676283148463279*^9, 3.676283164423374*^9}, {3.676283210818132*^9, 
  3.676283236236271*^9}}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "testString", "=", "\"\<Or to take arms against a sea of troubles\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"yourFunction", "[", "testString", "]"}], "==", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"\"\<Or\>\"", "\[UndirectedEdge]", "\"\<to\>\""}], ",", 
    RowBox[{"\"\<to\>\"", "\[UndirectedEdge]", "\"\<take\>\""}], ",", 
    RowBox[{"\"\<take\>\"", "\[UndirectedEdge]", "\"\<arms\>\""}], ",", 
    RowBox[{"\"\<arms\>\"", "\[UndirectedEdge]", "\"\<against\>\""}], ",", 
    RowBox[{"\"\<against\>\"", "\[UndirectedEdge]", "\"\<a\>\""}], ",", 
    RowBox[{"\"\<a\>\"", "\[UndirectedEdge]", "\"\<sea\>\""}], ",", 
    RowBox[{"\"\<sea\>\"", "\[UndirectedEdge]", "\"\<of\>\""}], ",", 
    RowBox[{"\"\<of\>\"", "\[UndirectedEdge]", "\"\<troubles\>\""}]}], 
   "}"}]}]}], "Input",
 CellChangeTimes->{{3.676283237918741*^9, 3.676283249091297*^9}, {
  3.6762837976494007`*^9, 3.6762838044718847`*^9}}],

Cell["\<\
Map your function across the split strings from step 1 and generate the \
resultant graph.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676283278937501*^9, 3.676283305648048*^9}, {
  3.676283343200768*^9, 3.676283344053247*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1680, 1001},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification:>1.5 Inherited,
FrontEndVersion->"10.4 for Mac OS X x86 (32-bit, 64-bit Kernel) (April 11, \
2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 149, 2, 137, "Title"],
Cell[CellGroupData[{
Cell[754, 28, 356, 5, 95, "Section"],
Cell[1113, 35, 272, 5, 46, "Text"],
Cell[CellGroupData[{
Cell[1410, 44, 310, 7, 43, "Input"],
Cell[1723, 53, 1719, 22, 919, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3479, 80, 452, 7, 72, "ItemNumbered"],
Cell[3934, 89, 476, 8, 72, "ItemNumbered"],
Cell[4413, 99, 195, 4, 44, "ItemNumbered"],
Cell[4611, 105, 287, 5, 72, "ItemNumbered"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4947, 116, 389, 5, 95, "Section"],
Cell[5339, 123, 167, 3, 46, "Text"],
Cell[CellGroupData[{
Cell[5531, 130, 263, 5, 72, "ItemNumbered"],
Cell[5797, 137, 133, 1, 44, "ItemNumbered"],
Cell[5933, 140, 421, 7, 99, "ItemNumbered"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6391, 152, 419, 11, 44, "Input"],
Cell[6813, 165, 128, 2, 43, "Output"]
}, Open  ]],
Cell[6956, 170, 144, 1, 46, "Text"],
Cell[7103, 173, 208, 4, 43, "Input"],
Cell[7314, 179, 182, 4, 44, "ItemNumbered"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7533, 188, 503, 7, 95, "Section"],
Cell[8039, 197, 399, 7, 76, "Text"],
Cell[CellGroupData[{
Cell[8463, 208, 165, 3, 44, "ItemNumbered"],
Cell[8631, 213, 394, 7, 99, "ItemNumbered"]
}, Open  ]],
Cell[9040, 223, 940, 19, 94, "Input"],
Cell[9983, 244, 237, 5, 45, "ItemNumbered"]
}, Open  ]]
}, Open  ]]
}
]
*)

