(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.4' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     10425,        275]
NotebookOptionsPosition[      9515,        241]
NotebookOutlinePosition[      9869,        257]
CellTagsIndexPosition[      9826,        254]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Exercises - Text Analysis", "Title",
 CellChangeTimes->{{3.676110727751924*^9, 3.676110731104054*^9}}],

Cell[CellGroupData[{

Cell["ListPlot", "Section",
 CellChangeTimes->{{3.6761107575081167`*^9, 3.6761107597580442`*^9}}],

Cell["\<\
The Wolfram Language integrates a connection to the Wikipedia API, allowing \
raw data content from Wikipedia pages to be returned, for instance:\
\>", "Text",
 CellChangeTimes->{{3.676111946940352*^9, 3.676111977349062*^9}}],

Cell[BoxData[
 RowBox[{"WikipediaData", "[", "\"\<Digital Humanities\>\"", "]"}]], "Input"],

Cell["Split the article into TextSentences", "ItemNumbered",
 CellChangeTimes->{{3.676111993629017*^9, 3.676112008985784*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"digH$Senteces", "=", 
   RowBox[{"TextSentences", "[", 
    RowBox[{"WikipediaData", "[", "\"\<Digital Humanities\>\"", "]"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.676111583381814*^9, 3.6761115849901447`*^9}, {
  3.676111627817505*^9, 3.676111639076825*^9}, {3.67611177188824*^9, 
  3.676111808168098*^9}}],

Cell["\<\
Use Map to calculate the number of words per sentence and total length of \
each sentence\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676111993629017*^9, 3.676112015419999*^9}, {
  3.676112317973572*^9, 3.6761123515666323`*^9}, {3.676112545329803*^9, 
  3.67611254977351*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"plotData", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"WordCount", "[", "#", "]"}], ",", 
        RowBox[{"StringLength", "[", "#", "]"}]}], "}"}], "&"}], ",", 
     "digH$Senteces"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.676112647356571*^9, 3.676112675055571*^9}}],

Cell["\<\
One of the sentences has 1311 character in it, which seems suspicious - \
remove this data point using Cases, DeleteCases, Select or any function you \
see fit.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676111993629017*^9, 3.676112015419999*^9}, {
  3.676112317973572*^9, 3.6761123515666323`*^9}, {3.676112545329803*^9, 
  3.676112556208243*^9}, {3.676112596023409*^9, 3.676112634779952*^9}}],

Cell[BoxData[
 RowBox[{"plotData", "=", 
  RowBox[{"Select", "[", 
   RowBox[{"plotData", ",", 
    RowBox[{
     RowBox[{
      RowBox[{"Last", "[", "#", "]"}], "<", "1000"}], "&"}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.67611267834519*^9, 3.676112716074622*^9}}],

Cell["\<\
Display the data from Step 3 using ListPlot - as shown below:\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676112743727592*^9, 3.676112760782566*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.011000000000000001`],
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxdk1lKQ0EURBtX4AL8iCAifsV51iZOKIIYP5SI+szgGE2iQb/EXspbgkvo
pbylOPSpB92CFPVup7rurb7jzV69M2KMOf79/8PwN2//wV0HNFsBsy7fjwIW
n9TX4Q/wnYD2Bb5MvQVfROcSPgbfhs/xe9Wn4afwWVD1KniFjsXvc+yv0o3v
z+VnFX9P8IOA3+/x/eYMnAjo5QffFd23gN+bWD9r4++Q70NwLfHDvPJb+Cb6
mu8kOnX4Puff4PTr1S952iz246XPvE0DXfLLBzEv+vBd9F7hNfobJP5bcd33
Yr9O59Ez6JXzxo/ZCzg6TPT0vujHan7k11d+U9Qb8XnXTvzofvIo5z1D/RzO
fPNHvpN/of60L3fwDc5xXv1W6d+ecP4rue8CrOFH74s8HHmYJepNOHk65S0/
6kf5q76C/w6cffJJv+V7Qa+AO/LR/FKu/XDaL/yW71H7iT/th/ugzjv3mo/8
Kj/2rZCe3m+Sh1Me2rd7+wMjRYfp
      "]]}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"Word Count\"", TraditionalForm], 
    FormBox["\"Sentence Length (Characters)\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{626.7890625, Automatic},
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Part[{{Identity, Identity}, {Identity, Identity}}, 1, 2][#]& )[
         Part[#, 1]], 
        (Part[{{Identity, Identity}, {Identity, Identity}}, 2, 2][#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 72.}, {0, 508.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.676112058283832*^9, 3.6761121037758083`*^9}, 
   3.676112513588904*^9, 3.67611295574671*^9}],

Cell["\<\
OPTIONAL (Advanced): It is fairly simple to create a linear model of this \
data, i.e. fit a straight line this data using the function LinearModelFit - \
consult the documentation for LinearModelFit to \
\>", "ItemNumbered",
 CellChangeTimes->{{3.676112129408249*^9, 3.6761121982224493`*^9}, {
  3.676112290028624*^9, 3.676112304090582*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"model", "=", 
   RowBox[{"LinearModelFit", "[", 
    RowBox[{"data", ",", "x"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"model", "[", "x", "]"}]}], "Input",
 CellChangeTimes->{{3.67611219908638*^9, 3.676112240393539*^9}}],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV0fk71AkAx3GNakjkSCmPjCuRRoz7mk+EoTAzX5mU+6hsCCslpW9TJsXD
etKTip7syjrKORVGGbJFIjepkW0Vii3l8dCOte0P7+f1B7x1wo5xIykyMjJe
P/pfyfUMqX1gg5OvDFtkMK4rjvVkt9BM85gNgyOvGrN0xTzOMHWaXsKk3Ytc
IGx1xR2++WU99DrmtH+KJT9LR5zm929KK72NeaG2uHLUhiYO41WOP6IPM492
fnc31dQU9wxRrzfQJ5mmN/ZtUotVFstpWHyroy8waWZ9665WfWNuFqzlqzPk
Ea7y4ev6fCNk5fSPWdWpQvqkZGd1vjWo3pzfDOs0MMMx9Lq0eRdSzCo3uNtp
Q+nKu9S7r9zAUOtRvVmsi1XPlk78arUXW3VEX41mDaBRLHPCVZYD9UNSvYMm
RuiJvxVUIiHQxJDTmzM1wbzVdOmcwA8fci+cKko0Ra1+BaMhyh8RTe99RmGG
EQWaTpRmAPpeWmSImsxhKN0hEjQFYYVxY4J+sAUEa4bbs7pCkNm2bVfzO0tU
qM1OdOmHYbCqUzQlsIae2e47HdfCcctiS3C4ni2Mifd1y7KRaJUSU8pFdpiI
D0ot4R1CiVKLtqerAz4Xqfyl2HYYHyPUHR8+d0RFf/7ihHYUPq0sXF0Vx0S9
Rlhlau5PsKRFS09fBHihx0V7KdHQC/k+KWLtQmlxSHI2LwazrUXl2OwMDxnB
YFZ7LGY6mkPfSpzhU96ccE4lDiW3Le4WF7igZf9hg6GGOLjcePKiNmY3ApTL
DDMS4rHW6o+xEVNXcJ4O8xe1EnB//t1zd4obogVFO54OJUArzc9D0u2Gbta1
8/SsnyG87yDKzHFHtnySOccmEcYKTFl+GAuJ/bM7e78k4iVF6JRj4AFhgX+6
YsFxMNpSldrHPeAYNXl53DUJSTWRQjehJ6ad1ks2LSVh0qnJa/T4HsyrmqTL
l5yA7ReLRyL3H19nx/i80JOod9Gi1Sp4obrz3GCwUjIWIg5u7OvwQtpdjwHZ
umRsKL8/bpPvjbNXK/RWx51C+BX+nbogH/SfXn7eopkCVrflliYNNnxiZ5ol
Ayl47DjAsCLZWB9GicjNPI090h0uDWNsMHxlg1dZnwGrM9cx1IODZHZhaf/n
Mwj4LDRTL+dAY892r6D8VLAXlo9J1nBBYb25ed71LGrV/K+3JXCh6mNsR106
Czp5tFHcx4WTcU2eri+J2cTg+vgBLir4F6du7yMhjCIe6A5xof06wE6bR8Ke
sK+6MMLFikzqG80DJFhbFYpYf3LROhOgrR5CIvxFWUb331x4VlOLqdEk8jQ+
HhiTJ+BnE1g7fZ7EQcVRXo4Cgae/mK88mkZiC6XX11mRgPUUdd+UgMSdT/Xe
RcoENt2omX9/iUTN40vORzYSePMP1e5tNokXEUbGX/QJhDbViHtuksj21zIs
3Eqgd2O6CruABNdbRZ+7jYBzXGBY1y0Sr6wXtYTbCejryK3sKCTxYU27yklz
AhP8QPfW30mULTcqGVkQ2P/aPM+5lETMXJXCiCWBdobclLiMxJwkb5WDLYGy
8ZrLj+6ReNibSZmxI6DpmP7avpLEqWfkcoEDgYyrgSYNVSScGhOl3k4ElmbM
z9jUkFhRfWRxmUkgxk2u60Etif8AXD8peQ==
       "]]}}, {}}, {{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxdk0lOAzEURC1OwAFYBAkhxCrMM1hhEogFhAUoCGg6CWMgCUSwAeFDcIA+
Akfoo/RRGPyqJRsJlaq/U67/y3807dbbQ8aYw9//P/R/s/Yf3KVHs+Ex6fD9
wGPxQX0Vfgff8mif4IvUm/B5dM7hI/BN+Ay/V30SfgyfBlWvghfoWPw+hv4q
nfD+TH6W8fcA3/P4/Rreb07AMY+5/OC7ovvm8HsV6ict/O3zfQCuRH6YV3YN
X0df8x1Hpw7f5fwLnH5z9UueNgn95NJn3qaBLvll/ZAXPfg2es/wGv31I//N
sJ53Q79O59Ez6JXzxo/Z8Tg8iPT0vujHan7k11N+E9Qb4XnXivzofvIo5z1F
/RTOfLN7vpN/of60LzfwNc5xXv1W6d8ecf4zuu8MrOFH74s8HHmYBeopnDyd
8pYf9aP8VV/CfxvOPuVRv+V7Qa+AO/LR/GKu/XDaL/yW71H7iT/th3ujzjvP
NR/5VX7sWyE9vd8oD0ceRerx/Yu69u/W/gDK1Yq8
       "]]}, {}}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"Word Count\"", TraditionalForm], 
    FormBox["\"Sentence Length (Characters)\"", TraditionalForm]},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->{490.76171875, Automatic},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 77}, {-9.445600369945318, 534.4642601629727}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.676112397612186*^9, 3.6761125085959253`*^9}, {
  3.6761129637177057`*^9, 3.676112996586808*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1054, 851},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"10.4 for Mac OS X x86 (32-bit, 64-bit Kernel) (April 11, \
2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 108, 1, 92, "Title"],
Cell[CellGroupData[{
Cell[713, 27, 97, 1, 64, "Section"],
Cell[813, 30, 235, 4, 30, "Text"],
Cell[1051, 36, 91, 1, 28, "Input"],
Cell[1145, 39, 126, 1, 30, "ItemNumbered"],
Cell[1274, 42, 357, 8, 28, "Input"],
Cell[1634, 52, 286, 6, 30, "ItemNumbered"],
Cell[1923, 60, 377, 11, 28, "Input"],
Cell[2303, 73, 404, 7, 49, "ItemNumbered"],
Cell[2710, 82, 273, 8, 28, "Input"],
Cell[2986, 92, 159, 3, 30, "ItemNumbered"],
Cell[3148, 97, 2084, 47, 358, "Output"],
Cell[5235, 146, 352, 6, 49, "ItemNumbered"],
Cell[CellGroupData[{
Cell[5612, 156, 267, 6, 46, "Input"],
Cell[5882, 164, 3593, 72, 264, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

