(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.4' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    290009,       6366]
NotebookOptionsPosition[    286968,       6263]
NotebookOutlinePosition[    287322,       6279]
CellTagsIndexPosition[    287279,       6276]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Exercises - Graph", "Title",
 CellChangeTimes->{{3.676110727751924*^9, 3.676110731104054*^9}, {
  3.676202750271039*^9, 3.676202750855156*^9}}],

Cell[CellGroupData[{

Cell["To be or not to be lists", "Section",
 CellChangeTimes->{{3.6761107633014383`*^9, 3.676110769096087*^9}, {
  3.6761156799717283`*^9, 3.676115682532858*^9}, {3.6761157161495457`*^9, 
  3.676115721492573*^9}, {3.676116110625745*^9, 3.676116114387026*^9}, {
  3.676202752888332*^9, 3.676202757098895*^9}, {3.67628141267354*^9, 
  3.676281425259199*^9}}],

Cell["\<\
In this exercise you are tasked with visualising the concordance network for \
the \[OpenCurlyDoubleQuote]To or not to be\[CloseCurlyDoubleQuote] extract \
imported from Princeton:\
\>", "Text",
 CellChangeTimes->{{3.676280875033128*^9, 3.6762809250297832`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"toBeOrNotToBe", "=", 
  RowBox[{
  "Import", "[", 
   "\"\<http://www.cs.princeton.edu/courses/archive/spring07/cos116/lab12/\
shakespeare.txt\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.676280851812958*^9, 3.676280861927535*^9}, {
  3.6762824843906393`*^9, 3.6762824867303658`*^9}}],

Cell[BoxData["\<\"To be, or not to be--that is the question: \\nWhether 'tis \
nobler in the mind to suffer \\nThe slings and arrows of outrageous fortune \
\\nOr to take arms against a sea of troubles \\nAnd by opposing end them. To \
die, to sleep-- \\nNo more--and by a sleep to say we end \\nThe heartache, \
and the thousand natural shocks \\nThat flesh is heir to. 'Tis a consummation \
\\nDevoutly to be wished. To die, to sleep-- \\nTo sleep--perchance to dream: \
ay, there's the rub, \\nFor in that sleep of death what dreams may come \
\\nWhen we have shuffled off this mortal coil, \\nMust give us pause. There's \
the respect \\nThat makes calamity of so long life. \\nFor who would bear the \
whips and scorns of time, \\nTh' oppressor's wrong, the proud man's contumely \
\\nThe pangs of despised love, the law's delay, \\nThe insolence of office, \
and the spurns \\nThat patient merit of th' unworthy takes, \\nWhen he \
himself might his quietus make \\nWith a bare bodkin? Who would fardels bear, \
\\nTo grunt and sweat under a weary life, \\nBut that the dread of something \
after death, \\nThe undiscovered country, from whose bourn \\nNo traveller \
returns, puzzles the will, \\nAnd makes us rather bear those ills we have \
\\nThan fly to others that we know not of? \\nThus conscience does make \
cowards of us all, \\nAnd thus the native hue of resolution \\nIs sicklied \
o'er with the pale cast of thought, \\nAnd enterprise of great pitch and \
moment \\nWith this regard their currents turn awry \\nAnd lose the name of \
action. -- Soft you now, \\nThe fair Ophelia! -- Nymph, in thy orisons \\nBe \
all my sins remembered. \\n\"\>"], "Output",
 CellChangeTimes->{3.676724999702114*^9, 3.676805632654099*^9}]
}, Open  ]],

Cell["\<\
Use TextWords to drop punctuation marks and ToLowerCase to remove potential \
duplication of words. You will need to ensure that the output of this step is \
a flat list, which will pass this predicate test:\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676281066152912*^9, 3.676281150933772*^9}, {
   3.676281643177724*^9, 3.6762816966843557`*^9}, {3.67628247963334*^9, 
   3.6762824810935917`*^9}, 3.676283610303768*^9}],

Cell["\<\
The question was written to trip you up in two different ways. \
\>", "Text",
 CellChangeTimes->{{3.676805651308219*^9, 3.676805798269312*^9}, {
  3.6768060394304323`*^9, 3.676806115295024*^9}}],

Cell[CellGroupData[{

Cell["\<\
The check that your symbol is 125 elements long is because this analysis \
should really be performed on non-stop words, if stop words are removed then \
there are 125 words touching one another.\
\>", "Item",
 CellChangeTimes->{{3.676805651308219*^9, 3.676805798269312*^9}, {
  3.6768060394304323`*^9, 3.6768061105831137`*^9}}],

Cell["\<\
You were asked to remove duplicates (which can be achieved using \
DeleteDuplicates or Union) but this doesn't make sense! If the text contained \
the following sentence \"evil umbrellas and very evil fish\" you are \
interested to note that both umbrellas and fish are described as evil - \
removing duplicates would obliterate this useful information!\
\>", "Item",
 CellChangeTimes->{{3.676805651308219*^9, 3.676805798269312*^9}, {
  3.6768060394304323`*^9, 3.676806144213428*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"toBeOrNotToBe$Words", "=", 
  RowBox[{"Flatten", "@", 
   RowBox[{"ToLowerCase", "[", 
    RowBox[{"TextWords", "[", "toBeOrNotToBe", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.67628108204801*^9, 3.676281089623889*^9}, {
   3.676281119896688*^9, 3.676281163344379*^9}, 3.676281723216466*^9, {
   3.6762820217365227`*^9, 3.6762820236636553`*^9}, {3.676282449043976*^9, 
   3.6762824498311653`*^9}, {3.676283619212508*^9, 3.676283622451449*^9}, {
   3.676806158191105*^9, 3.6768061627766447`*^9}, 3.6768062811034203`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"to\"\>", ",", "\<\"be\"\>", ",", "\<\"or\"\>", 
   ",", "\<\"not\"\>", ",", "\<\"to\"\>", ",", "\<\"be\"\>", 
   ",", "\<\"that\"\>", ",", "\<\"is\"\>", ",", "\<\"the\"\>", 
   ",", "\<\"question\"\>", ",", "\<\"whether\"\>", ",", "\<\"tis\"\>", 
   ",", "\<\"nobler\"\>", ",", "\<\"in\"\>", ",", "\<\"the\"\>", 
   ",", "\<\"mind\"\>", ",", "\<\"to\"\>", ",", "\<\"suffer\"\>", 
   ",", "\<\"the\"\>", ",", "\<\"slings\"\>", ",", "\<\"and\"\>", 
   ",", "\<\"arrows\"\>", ",", "\<\"of\"\>", ",", "\<\"outrageous\"\>", 
   ",", "\<\"fortune\"\>", ",", "\<\"or\"\>", ",", "\<\"to\"\>", 
   ",", "\<\"take\"\>", ",", "\<\"arms\"\>", ",", "\<\"against\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"sea\"\>", ",", "\<\"of\"\>", 
   ",", "\<\"troubles\"\>", ",", "\<\"and\"\>", ",", "\<\"by\"\>", 
   ",", "\<\"opposing\"\>", ",", "\<\"end\"\>", ",", "\<\"them\"\>", 
   ",", "\<\"to\"\>", ",", "\<\"die\"\>", ",", "\<\"to\"\>", 
   ",", "\<\"sleep\"\>", ",", "\<\"no\"\>", ",", "\<\"more\"\>", 
   ",", "\<\"and\"\>", ",", "\<\"by\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"sleep\"\>", ",", "\<\"to\"\>", ",", "\<\"say\"\>", 
   ",", "\<\"we\"\>", ",", "\<\"end\"\>", ",", "\<\"the\"\>", 
   ",", "\<\"heartache\"\>", ",", "\<\"and\"\>", ",", "\<\"the\"\>", 
   ",", "\<\"thousand\"\>", ",", "\<\"natural\"\>", ",", "\<\"shocks\"\>", 
   ",", "\<\"that\"\>", ",", "\<\"flesh\"\>", ",", "\<\"is\"\>", 
   ",", "\<\"heir\"\>", ",", "\<\"to\"\>", ",", "\<\"tis\"\>", 
   ",", "\<\"a\"\>", ",", "\<\"consummation\"\>", ",", "\<\"devoutly\"\>", 
   ",", "\<\"to\"\>", ",", "\<\"be\"\>", ",", "\<\"wished\"\>", 
   ",", "\<\"to\"\>", ",", "\<\"die\"\>", ",", "\<\"to\"\>", 
   ",", "\<\"sleep\"\>", ",", "\<\"to\"\>", ",", "\<\"sleep\"\>", 
   ",", "\<\"perchance\"\>", ",", "\<\"to\"\>", ",", "\<\"dream\"\>", 
   ",", "\<\"ay\"\>", ",", "\<\"there's\"\>", ",", "\<\"the\"\>", 
   ",", "\<\"rub\"\>", ",", "\<\"for\"\>", ",", "\<\"in\"\>", 
   ",", "\<\"that\"\>", ",", "\<\"sleep\"\>", ",", "\<\"of\"\>", 
   ",", "\<\"death\"\>", ",", "\<\"what\"\>", ",", "\<\"dreams\"\>", 
   ",", "\<\"may\"\>", ",", "\<\"come\"\>", ",", "\<\"when\"\>", 
   ",", "\<\"we\"\>", ",", "\<\"have\"\>", ",", "\<\"shuffled\"\>", 
   ",", "\<\"off\"\>", ",", "\<\"this\"\>", ",", "\<\"mortal\"\>", 
   ",", "\<\"coil\"\>", ",", "\<\"must\"\>", ",", "\<\"give\"\>", 
   ",", "\<\"us\"\>", ",", "\<\"pause\"\>", ",", "\<\"there's\"\>", 
   ",", "\<\"the\"\>", ",", "\<\"respect\"\>", ",", "\<\"that\"\>", 
   ",", "\<\"makes\"\>", ",", "\<\"calamity\"\>", ",", "\<\"of\"\>", 
   ",", "\<\"so\"\>", ",", "\<\"long\"\>", ",", "\<\"life\"\>", 
   ",", "\<\"for\"\>", ",", "\<\"who\"\>", ",", "\<\"would\"\>", 
   ",", "\<\"bear\"\>", ",", "\<\"the\"\>", ",", "\<\"whips\"\>", 
   ",", "\<\"and\"\>", ",", "\<\"scorns\"\>", ",", "\<\"of\"\>", 
   ",", "\<\"time\"\>", ",", "\<\"th\"\>", ",", "\<\"oppressor's\"\>", 
   ",", "\<\"wrong\"\>", ",", "\<\"the\"\>", ",", "\<\"proud\"\>", 
   ",", "\<\"man's\"\>", ",", "\<\"contumely\"\>", ",", "\<\"the\"\>", 
   ",", "\<\"pangs\"\>", ",", "\<\"of\"\>", ",", "\<\"despised\"\>", 
   ",", "\<\"love\"\>", ",", "\<\"the\"\>", ",", "\<\"law's\"\>", 
   ",", "\<\"delay\"\>", ",", "\<\"the\"\>", ",", "\<\"insolence\"\>", 
   ",", "\<\"of\"\>", ",", "\<\"office\"\>", ",", "\<\"and\"\>", 
   ",", "\<\"the\"\>", ",", "\<\"spurns\"\>", ",", "\<\"that\"\>", 
   ",", "\<\"patient\"\>", ",", "\<\"merit\"\>", ",", "\<\"of\"\>", 
   ",", "\<\"th\"\>", ",", "\<\"unworthy\"\>", ",", "\<\"takes\"\>", 
   ",", "\<\"when\"\>", ",", "\<\"he\"\>", ",", "\<\"himself\"\>", 
   ",", "\<\"might\"\>", ",", "\<\"his\"\>", ",", "\<\"quietus\"\>", 
   ",", "\<\"make\"\>", ",", "\<\"with\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"bare\"\>", ",", "\<\"bodkin\"\>", ",", "\<\"who\"\>", 
   ",", "\<\"would\"\>", ",", "\<\"fardels\"\>", ",", "\<\"bear\"\>", 
   ",", "\<\"to\"\>", ",", "\<\"grunt\"\>", ",", "\<\"and\"\>", 
   ",", "\<\"sweat\"\>", ",", "\<\"under\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"weary\"\>", ",", "\<\"life\"\>", ",", "\<\"but\"\>", 
   ",", "\<\"that\"\>", ",", "\<\"the\"\>", ",", "\<\"dread\"\>", 
   ",", "\<\"of\"\>", ",", "\<\"something\"\>", ",", "\<\"after\"\>", 
   ",", "\<\"death\"\>", ",", "\<\"the\"\>", ",", "\<\"undiscovered\"\>", 
   ",", "\<\"country\"\>", ",", "\<\"from\"\>", ",", "\<\"whose\"\>", 
   ",", "\<\"bourn\"\>", ",", "\<\"no\"\>", ",", "\<\"traveller\"\>", 
   ",", "\<\"returns\"\>", ",", "\<\"puzzles\"\>", ",", "\<\"the\"\>", 
   ",", "\<\"will\"\>", ",", "\<\"and\"\>", ",", "\<\"makes\"\>", 
   ",", "\<\"us\"\>", ",", "\<\"rather\"\>", ",", "\<\"bear\"\>", 
   ",", "\<\"those\"\>", ",", "\<\"ills\"\>", ",", "\<\"we\"\>", 
   ",", "\<\"have\"\>", ",", "\<\"than\"\>", ",", "\<\"fly\"\>", 
   ",", "\<\"to\"\>", ",", "\<\"others\"\>", ",", "\<\"that\"\>", 
   ",", "\<\"we\"\>", ",", "\<\"know\"\>", ",", "\<\"not\"\>", 
   ",", "\<\"of\"\>", ",", "\<\"thus\"\>", ",", "\<\"conscience\"\>", 
   ",", "\<\"does\"\>", ",", "\<\"make\"\>", ",", "\<\"cowards\"\>", 
   ",", "\<\"of\"\>", ",", "\<\"us\"\>", ",", "\<\"all\"\>", 
   ",", "\<\"and\"\>", ",", "\<\"thus\"\>", ",", "\<\"the\"\>", 
   ",", "\<\"native\"\>", ",", "\<\"hue\"\>", ",", "\<\"of\"\>", 
   ",", "\<\"resolution\"\>", ",", "\<\"is\"\>", ",", "\<\"sicklied\"\>", 
   ",", "\<\"o'er\"\>", ",", "\<\"with\"\>", ",", "\<\"the\"\>", 
   ",", "\<\"pale\"\>", ",", "\<\"cast\"\>", ",", "\<\"of\"\>", 
   ",", "\<\"thought\"\>", ",", "\<\"and\"\>", ",", "\<\"enterprise\"\>", 
   ",", "\<\"of\"\>", ",", "\<\"great\"\>", ",", "\<\"pitch\"\>", 
   ",", "\<\"and\"\>", ",", "\<\"moment\"\>", ",", "\<\"with\"\>", 
   ",", "\<\"this\"\>", ",", "\<\"regard\"\>", ",", "\<\"their\"\>", 
   ",", "\<\"currents\"\>", ",", "\<\"turn\"\>", ",", "\<\"awry\"\>", 
   ",", "\<\"and\"\>", ",", "\<\"lose\"\>", ",", "\<\"the\"\>", 
   ",", "\<\"name\"\>", ",", "\<\"of\"\>", ",", "\<\"action\"\>", 
   ",", "\<\"soft\"\>", ",", "\<\"you\"\>", ",", "\<\"now\"\>", 
   ",", "\<\"the\"\>", ",", "\<\"fair\"\>", ",", "\<\"ophelia\"\>", 
   ",", "\<\"nymph\"\>", ",", "\<\"in\"\>", ",", "\<\"thy\"\>", 
   ",", "\<\"orisons\"\>", ",", "\<\"be\"\>", ",", "\<\"all\"\>", 
   ",", "\<\"my\"\>", ",", "\<\"sins\"\>", ",", "\<\"remembered\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.676806163348523*^9, 3.676806281574747*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Length", "[", "toBeOrNotToBe$Words", "]"}], "==", "125"}]], "Input",\

 CellChangeTimes->{{3.676281698832514*^9, 3.676281715612265*^9}, 
   3.6768061681349983`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.676281163965769*^9, 3.676281724129806*^9, {3.676282024562805*^9, 
   3.6762820428712683`*^9}, 3.6762824507658854`*^9, 3.676282487849474*^9, 
   3.676283623045459*^9, 3.6767250022369137`*^9, 3.676805673430554*^9, 
   3.676806168737915*^9}]
}, Open  ]],

Cell["\<\
Partition the output from step 2 into lists containing two elements, note \
that the partitions must overset by 1 (as the words \
\[OpenCurlyDoubleQuote]nobler\[CloseCurlyDoubleQuote],\[CloseCurlyDoubleQuote]\
mind\[CloseCurlyDoubleQuote],\[CloseCurlyDoubleQuote]suffer\
\[CloseCurlyDoubleQuote] are all connected to one another)\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676281173289214*^9, 3.676281197364092*^9}, {
  3.676281286107692*^9, 3.676281322736557*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"partitions", "=", 
  RowBox[{"Partition", "[", 
   RowBox[{"toBeOrNotToBe$Words", ",", "2", ",", "1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.676281200128747*^9, 3.676281207782803*^9}, {
   3.6762812649027576`*^9, 3.676281264955187*^9}, 3.676282454787818*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"to\"\>", ",", "\<\"be\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"be\"\>", ",", "\<\"or\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"or\"\>", ",", "\<\"not\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"not\"\>", ",", "\<\"to\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"to\"\>", ",", "\<\"be\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"be\"\>", ",", "\<\"that\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"that\"\>", ",", "\<\"is\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"is\"\>", ",", "\<\"the\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"the\"\>", ",", "\<\"question\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"question\"\>", ",", "\<\"whether\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"whether\"\>", ",", "\<\"tis\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"tis\"\>", ",", "\<\"nobler\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"nobler\"\>", ",", "\<\"in\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"in\"\>", ",", "\<\"the\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"the\"\>", ",", "\<\"mind\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"mind\"\>", ",", "\<\"to\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"to\"\>", ",", "\<\"suffer\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"suffer\"\>", ",", "\<\"the\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"the\"\>", ",", "\<\"slings\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"slings\"\>", ",", "\<\"and\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"and\"\>", ",", "\<\"arrows\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"arrows\"\>", ",", "\<\"of\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"of\"\>", ",", "\<\"outrageous\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"outrageous\"\>", ",", "\<\"fortune\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"fortune\"\>", ",", "\<\"or\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"or\"\>", ",", "\<\"to\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"to\"\>", ",", "\<\"take\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"take\"\>", ",", "\<\"arms\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"arms\"\>", ",", "\<\"against\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"against\"\>", ",", "\<\"a\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"a\"\>", ",", "\<\"sea\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"sea\"\>", ",", "\<\"of\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"of\"\>", ",", "\<\"troubles\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"troubles\"\>", ",", "\<\"and\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"and\"\>", ",", "\<\"by\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"by\"\>", ",", "\<\"opposing\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"opposing\"\>", ",", "\<\"end\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"end\"\>", ",", "\<\"them\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"them\"\>", ",", "\<\"to\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"to\"\>", ",", "\<\"die\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"die\"\>", ",", "\<\"to\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"to\"\>", ",", "\<\"sleep\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"sleep\"\>", ",", "\<\"no\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"no\"\>", ",", "\<\"more\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"more\"\>", ",", "\<\"and\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"and\"\>", ",", "\<\"by\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"by\"\>", ",", "\<\"a\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"a\"\>", ",", "\<\"sleep\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"sleep\"\>", ",", "\<\"to\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"to\"\>", ",", "\<\"say\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"say\"\>", ",", "\<\"we\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"we\"\>", ",", "\<\"end\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"end\"\>", ",", "\<\"the\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"the\"\>", ",", "\<\"heartache\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"heartache\"\>", ",", "\<\"and\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"and\"\>", ",", "\<\"the\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"the\"\>", ",", "\<\"thousand\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"thousand\"\>", ",", "\<\"natural\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"natural\"\>", ",", "\<\"shocks\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"shocks\"\>", ",", "\<\"that\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"that\"\>", ",", "\<\"flesh\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"flesh\"\>", ",", "\<\"is\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"is\"\>", ",", "\<\"heir\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"heir\"\>", ",", "\<\"to\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"to\"\>", ",", "\<\"tis\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"tis\"\>", ",", "\<\"a\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"a\"\>", ",", "\<\"consummation\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"consummation\"\>", ",", "\<\"devoutly\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"devoutly\"\>", ",", "\<\"to\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"to\"\>", ",", "\<\"be\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"be\"\>", ",", "\<\"wished\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"wished\"\>", ",", "\<\"to\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"to\"\>", ",", "\<\"die\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"die\"\>", ",", "\<\"to\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"to\"\>", ",", "\<\"sleep\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"sleep\"\>", ",", "\<\"to\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"to\"\>", ",", "\<\"sleep\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"sleep\"\>", ",", "\<\"perchance\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"perchance\"\>", ",", "\<\"to\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"to\"\>", ",", "\<\"dream\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"dream\"\>", ",", "\<\"ay\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"ay\"\>", ",", "\<\"there's\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"there's\"\>", ",", "\<\"the\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"the\"\>", ",", "\<\"rub\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"rub\"\>", ",", "\<\"for\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"for\"\>", ",", "\<\"in\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"in\"\>", ",", "\<\"that\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"that\"\>", ",", "\<\"sleep\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"sleep\"\>", ",", "\<\"of\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"of\"\>", ",", "\<\"death\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"death\"\>", ",", "\<\"what\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"what\"\>", ",", "\<\"dreams\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"dreams\"\>", ",", "\<\"may\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"may\"\>", ",", "\<\"come\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"come\"\>", ",", "\<\"when\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"when\"\>", ",", "\<\"we\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"we\"\>", ",", "\<\"have\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"have\"\>", ",", "\<\"shuffled\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"shuffled\"\>", ",", "\<\"off\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"off\"\>", ",", "\<\"this\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"this\"\>", ",", "\<\"mortal\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"mortal\"\>", ",", "\<\"coil\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"coil\"\>", ",", "\<\"must\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"must\"\>", ",", "\<\"give\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"give\"\>", ",", "\<\"us\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"us\"\>", ",", "\<\"pause\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"pause\"\>", ",", "\<\"there's\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"there's\"\>", ",", "\<\"the\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"the\"\>", ",", "\<\"respect\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"respect\"\>", ",", "\<\"that\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"that\"\>", ",", "\<\"makes\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"makes\"\>", ",", "\<\"calamity\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"calamity\"\>", ",", "\<\"of\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"of\"\>", ",", "\<\"so\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"so\"\>", ",", "\<\"long\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"long\"\>", ",", "\<\"life\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"life\"\>", ",", "\<\"for\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"for\"\>", ",", "\<\"who\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"who\"\>", ",", "\<\"would\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"would\"\>", ",", "\<\"bear\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"bear\"\>", ",", "\<\"the\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"the\"\>", ",", "\<\"whips\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"whips\"\>", ",", "\<\"and\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"and\"\>", ",", "\<\"scorns\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"scorns\"\>", ",", "\<\"of\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"of\"\>", ",", "\<\"time\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"time\"\>", ",", "\<\"th\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"th\"\>", ",", "\<\"oppressor's\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"oppressor's\"\>", ",", "\<\"wrong\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"wrong\"\>", ",", "\<\"the\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"the\"\>", ",", "\<\"proud\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"proud\"\>", ",", "\<\"man's\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"man's\"\>", ",", "\<\"contumely\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"contumely\"\>", ",", "\<\"the\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"the\"\>", ",", "\<\"pangs\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"pangs\"\>", ",", "\<\"of\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"of\"\>", ",", "\<\"despised\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"despised\"\>", ",", "\<\"love\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"love\"\>", ",", "\<\"the\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"the\"\>", ",", "\<\"law's\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"law's\"\>", ",", "\<\"delay\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"delay\"\>", ",", "\<\"the\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"the\"\>", ",", "\<\"insolence\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"insolence\"\>", ",", "\<\"of\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"of\"\>", ",", "\<\"office\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"office\"\>", ",", "\<\"and\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"and\"\>", ",", "\<\"the\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"the\"\>", ",", "\<\"spurns\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"spurns\"\>", ",", "\<\"that\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"that\"\>", ",", "\<\"patient\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"patient\"\>", ",", "\<\"merit\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"merit\"\>", ",", "\<\"of\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"of\"\>", ",", "\<\"th\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"th\"\>", ",", "\<\"unworthy\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"unworthy\"\>", ",", "\<\"takes\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"takes\"\>", ",", "\<\"when\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"when\"\>", ",", "\<\"he\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"he\"\>", ",", "\<\"himself\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"himself\"\>", ",", "\<\"might\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"might\"\>", ",", "\<\"his\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"his\"\>", ",", "\<\"quietus\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"quietus\"\>", ",", "\<\"make\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"make\"\>", ",", "\<\"with\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"with\"\>", ",", "\<\"a\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"a\"\>", ",", "\<\"bare\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"bare\"\>", ",", "\<\"bodkin\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"bodkin\"\>", ",", "\<\"who\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"who\"\>", ",", "\<\"would\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"would\"\>", ",", "\<\"fardels\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"fardels\"\>", ",", "\<\"bear\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"bear\"\>", ",", "\<\"to\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"to\"\>", ",", "\<\"grunt\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"grunt\"\>", ",", "\<\"and\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"and\"\>", ",", "\<\"sweat\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"sweat\"\>", ",", "\<\"under\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"under\"\>", ",", "\<\"a\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"a\"\>", ",", "\<\"weary\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"weary\"\>", ",", "\<\"life\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"life\"\>", ",", "\<\"but\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"but\"\>", ",", "\<\"that\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"that\"\>", ",", "\<\"the\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"the\"\>", ",", "\<\"dread\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"dread\"\>", ",", "\<\"of\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"of\"\>", ",", "\<\"something\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"something\"\>", ",", "\<\"after\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"after\"\>", ",", "\<\"death\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"death\"\>", ",", "\<\"the\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"the\"\>", ",", "\<\"undiscovered\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"undiscovered\"\>", ",", "\<\"country\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"country\"\>", ",", "\<\"from\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"from\"\>", ",", "\<\"whose\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"whose\"\>", ",", "\<\"bourn\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"bourn\"\>", ",", "\<\"no\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"no\"\>", ",", "\<\"traveller\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"traveller\"\>", ",", "\<\"returns\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"returns\"\>", ",", "\<\"puzzles\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"puzzles\"\>", ",", "\<\"the\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"the\"\>", ",", "\<\"will\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"will\"\>", ",", "\<\"and\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"and\"\>", ",", "\<\"makes\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"makes\"\>", ",", "\<\"us\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"us\"\>", ",", "\<\"rather\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"rather\"\>", ",", "\<\"bear\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"bear\"\>", ",", "\<\"those\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"those\"\>", ",", "\<\"ills\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"ills\"\>", ",", "\<\"we\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"we\"\>", ",", "\<\"have\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"have\"\>", ",", "\<\"than\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"than\"\>", ",", "\<\"fly\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"fly\"\>", ",", "\<\"to\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"to\"\>", ",", "\<\"others\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"others\"\>", ",", "\<\"that\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"that\"\>", ",", "\<\"we\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"we\"\>", ",", "\<\"know\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"know\"\>", ",", "\<\"not\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"not\"\>", ",", "\<\"of\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"of\"\>", ",", "\<\"thus\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"thus\"\>", ",", "\<\"conscience\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"conscience\"\>", ",", "\<\"does\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"does\"\>", ",", "\<\"make\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"make\"\>", ",", "\<\"cowards\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"cowards\"\>", ",", "\<\"of\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"of\"\>", ",", "\<\"us\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"us\"\>", ",", "\<\"all\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"all\"\>", ",", "\<\"and\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"and\"\>", ",", "\<\"thus\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"thus\"\>", ",", "\<\"the\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"the\"\>", ",", "\<\"native\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"native\"\>", ",", "\<\"hue\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"hue\"\>", ",", "\<\"of\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"of\"\>", ",", "\<\"resolution\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"resolution\"\>", ",", "\<\"is\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"is\"\>", ",", "\<\"sicklied\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"sicklied\"\>", ",", "\<\"o'er\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"o'er\"\>", ",", "\<\"with\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"with\"\>", ",", "\<\"the\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"the\"\>", ",", "\<\"pale\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"pale\"\>", ",", "\<\"cast\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"cast\"\>", ",", "\<\"of\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"of\"\>", ",", "\<\"thought\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"thought\"\>", ",", "\<\"and\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"and\"\>", ",", "\<\"enterprise\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"enterprise\"\>", ",", "\<\"of\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"of\"\>", ",", "\<\"great\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"great\"\>", ",", "\<\"pitch\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"pitch\"\>", ",", "\<\"and\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"and\"\>", ",", "\<\"moment\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"moment\"\>", ",", "\<\"with\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"with\"\>", ",", "\<\"this\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"this\"\>", ",", "\<\"regard\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"regard\"\>", ",", "\<\"their\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"their\"\>", ",", "\<\"currents\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"currents\"\>", ",", "\<\"turn\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"turn\"\>", ",", "\<\"awry\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"awry\"\>", ",", "\<\"and\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"and\"\>", ",", "\<\"lose\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"lose\"\>", ",", "\<\"the\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"the\"\>", ",", "\<\"name\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"name\"\>", ",", "\<\"of\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"of\"\>", ",", "\<\"action\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"action\"\>", ",", "\<\"soft\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"soft\"\>", ",", "\<\"you\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"you\"\>", ",", "\<\"now\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"now\"\>", ",", "\<\"the\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"the\"\>", ",", "\<\"fair\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"fair\"\>", ",", "\<\"ophelia\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"ophelia\"\>", ",", "\<\"nymph\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"nymph\"\>", ",", "\<\"in\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"in\"\>", ",", "\<\"thy\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"thy\"\>", ",", "\<\"orisons\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"orisons\"\>", ",", "\<\"be\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"be\"\>", ",", "\<\"all\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"all\"\>", ",", "\<\"my\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"my\"\>", ",", "\<\"sins\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"sins\"\>", ",", "\<\"remembered\"\>"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.676806178095963*^9, 3.676806284472083*^9}]
}, Open  ]],

Cell["\<\
Convert the output of step 3 into a list of UndirectedEdges and create a \
Graph from the output:\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676281329949398*^9, 3.676281392803528*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{"UndirectedEdge", "@@@", "partitions"}], "]"}]], "Input",
 CellChangeTimes->{{3.6762813669506073`*^9, 3.676281371815393*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "to", "be", "or", "not", "that", "is", "the", "question", "whether", 
       "tis", "nobler", "in", "mind", "suffer", "slings", "and", "arrows", 
       "of", "outrageous", "fortune", "take", "arms", "against", "a", "sea", 
       "troubles", "by", "opposing", "end", "them", "die", "sleep", "no", 
       "more", "say", "we", "heartache", "thousand", "natural", "shocks", 
       "flesh", "heir", "consummation", "devoutly", "wished", "perchance", 
       "dream", "ay", "there's", "rub", "for", "death", "what", "dreams", 
       "may", "come", "when", "have", "shuffled", "off", "this", "mortal", 
       "coil", "must", "give", "us", "pause", "respect", "makes", "calamity", 
       "so", "long", "life", "who", "would", "bear", "whips", "scorns", 
       "time", "th", "oppressor's", "wrong", "proud", "man's", "contumely", 
       "pangs", "despised", "love", "law's", "delay", "insolence", "office", 
       "spurns", "patient", "merit", "unworthy", "takes", "he", "himself", 
       "might", "his", "quietus", "make", "with", "bare", "bodkin", "fardels",
        "grunt", "sweat", "under", "weary", "but", "dread", "something", 
       "after", "undiscovered", "country", "from", "whose", "bourn", 
       "traveller", "returns", "puzzles", "will", "rather", "those", "ills", 
       "than", "fly", "others", "know", "thus", "conscience", "does", 
       "cowards", "all", "native", "hue", "resolution", "sicklied", "o'er", 
       "pale", "cast", "thought", "enterprise", "great", "pitch", "moment", 
       "regard", "their", "currents", "turn", "awry", "lose", "name", 
       "action", "soft", "you", "now", "fair", "ophelia", "nymph", "thy", 
       "orisons", "my", "sins", "remembered"}, {Null, CompressedData["
1:eJw1T1VTalEYZQObTxF1+1nHQEGP3YKBioGioqiI3YoBJna3qNjdnfdv3nse
7sOaNbNmVqltTqtNLBKJ/IlIJDARiyUSqZT8Y0plMgAPD09PudzLS6EA8PYm
xMcHwNeXMT8/RH//gACJhJDAwKCg4GCOCwlBDA1lLCwsPFypjIggJDKSEJVK
rY6KElSOU6kIiY7meaUSICaGMYDY2Li4+HhKExJkssREQuRyjktKSk4WFqSk
/E8QkJpKSFpaenpGBkBmpkajUFCqUiFqtVlZ2dk5Obm5Oh3P5+Xl5xcU6PWF
hUVFxcUlJQZDaangKCuj1GgsL0esqKisNJk0mqqq6mqzGaCmhrHaWsS6Ooul
vt5qBWhoaGxsagJobkZsaWltBWhra28H6OhA7OwUVnd1Udrd3dODaLH09vb1
6XQ2W3//wMDg4NCQ3e5wcNzw8MiI0DA6ajYTMjbG2Pj4xATHOZ0m0+QkpQBT
U4jT0zMzWi3A7Ozc3Pz8wsLiolq9tLS8vLICsLrKmNFoMKytmc3r6xsbwrfN
za0tQra3KeX5nR2pFNHl2t3d27Pb9/cRDQa3mzGXC+Dg4PAQ8ehIJjs+Pjlx
OABOT8/OEM/PGbu4QLy8vLpi7Pra4dDrb25ub+/u7u8fHhh7fAR4ekJ8fn55
eX19ewN4f//4+PxUKL6+vr/FYrf75+f3989fQ/WDmw==
       "]}]]}, 
    TagBox[GraphicsGroupBox[GraphicsComplexBox[CompressedData["
1:eJw9V3k4VW/UNV3D5XIH955zXIkiSUKDynRXESIloZAKFUqlUolUiFBSQjKU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       "], {
        {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
         {Arrowheads[0.], 
          ArrowBox[BezierCurveBox[{
           1, {6.383146141202031, 4.6898891030332965`}, 2}], 
           0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{1, 2}, 0.0671614011006787]}, 
         {Arrowheads[0.], 
          ArrowBox[BezierCurveBox[{
           1, {6.303976288051561, 4.562332781688794}, 2}], 
           0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{1, 3}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{1, 4}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{1, 10}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{1, 13}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{1, 14}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{1, 21}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{1, 30}, 0.0671614011006787]}, 
         {Arrowheads[0.], 
          ArrowBox[BezierCurveBox[{
           1, {5.946755111300448, 5.2718713320991455`}, 31}], 
           0.0671614011006787]}, 
         {Arrowheads[0.], 
          ArrowBox[BezierCurveBox[{
           1, {6.063732336974264, 5.277815383259082}, 31}], 
           0.0671614011006787]}, 
         {Arrowheads[0.], 
          ArrowBox[BezierCurveBox[{
           1, {6.181238826735102, 5.283786328655707}, 31}], 
           0.0671614011006787]}, 
         {Arrowheads[0.], 
          ArrowBox[BezierCurveBox[{
           1, {6.298216052408921, 5.289730379907348}, 31}], 
           0.0671614011006787]}, 
         {Arrowheads[0.], 
          ArrowBox[BezierCurveBox[{
           1, {6.473284668357846, 4.159379071486712}, 32}], 
           0.0671614011006787]}, 
         {Arrowheads[0.], 
          ArrowBox[BezierCurveBox[{
           1, {6.370630916974096, 4.140053710726705}, 32}], 
           0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{1, 32}, 0.0671614011006787]}, 
         {Arrowheads[0.], 
          ArrowBox[BezierCurveBox[{
           1, {6.164282131584931, 4.101206959624035}, 32}], 
           0.0671614011006787]}, 
         {Arrowheads[0.], 
          ArrowBox[BezierCurveBox[{
           1, {6.0616283802011965`, 4.081881598831284}, 32}], 
           0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{1, 35}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{1, 42}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{1, 44}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{1, 45}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{1, 46}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{1, 47}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{1, 76}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{1, 108}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{1, 129}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{1, 130}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{2, 3}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{2, 5}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{2, 45}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{2, 136}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{2, 164}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{3, 4}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{3, 20}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{4, 18}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{4, 131}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{5, 6}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{5, 7}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{5, 12}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{5, 32}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{5, 36}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{5, 40}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{5, 41}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{5, 68}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{5, 69}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{5, 93}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{5, 94}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{5, 112}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{5, 130}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{6, 7}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{6, 41}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{6, 42}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{6, 139}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{6, 140}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 8}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 12}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 13}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 14}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 15}, 0.0671614011006787]}, 
         {Arrowheads[0.], 
          ArrowBox[BezierCurveBox[{
           7, {6.045394665908441, 2.5569222034444676`}, 16}], 
           0.0671614011006787]}, 
         {Arrowheads[0.], 
          ArrowBox[BezierCurveBox[{
           7, {5.955447462035541, 2.726694194912868}, 16}], 
           0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 29}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 37}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 38}, 0.0671614011006787]}, 
         {Arrowheads[0.], 
          ArrowBox[BezierCurveBox[{
           7, {6.582089374481275, 3.268416358306339}, 49}], 
           0.0671614011006787]}, 
         {Arrowheads[0.], 
          ArrowBox[BezierCurveBox[{
           7, {6.809688822413031, 2.9807352168938057`}, 49}], 
           0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 50}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 52}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 68}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 76}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 77}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 82}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 83}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 85}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 86}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 88}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 89}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 90}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 91}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 93}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 104}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 113}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 116}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 123}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 124}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 132}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 137}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 142}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 154}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 155}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 159}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{7, 160}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{8, 9}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{9, 10}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{10, 11}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{10, 24}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{11, 12}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{12, 51}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{12, 162}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{12, 163}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{15, 16}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{16, 17}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{16, 26}, 0.0671614011006787]}, 
         {Arrowheads[0.], 
          ArrowBox[BezierCurveBox[{
           16, {5.648721016772845, 3.0916068233593434`}, 27}], 
           0.0671614011006787]}, 
         {Arrowheads[0.], 
          ArrowBox[BezierCurveBox[{
           16, {6.015142835522975, 3.032660750728503}, 27}], 
           0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{16, 34}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{16, 37}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{16, 69}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{16, 77}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{16, 78}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{16, 92}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{16, 108}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{16, 109}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{16, 124}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{16, 132}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{16, 136}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{16, 144}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{16, 145}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{16, 147}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{16, 148}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{16, 153}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{16, 154}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{17, 18}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 19}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 25}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 26}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 32}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 52}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 66}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 70}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 71}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 78}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 79}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 80}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 86}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 87}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 91}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 92}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 95}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 113}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 114}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 132}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 135}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 138}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 139}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 143}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 144}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 145}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 146}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 155}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{18, 156}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{19, 20}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{21, 22}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{22, 23}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{23, 24}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{24, 25}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{24, 27}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{24, 32}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{24, 43}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{24, 104}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{24, 105}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{24, 110}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{24, 111}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{27, 28}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{28, 29}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{29, 30}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{29, 36}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{32, 33}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{32, 46}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{33, 34}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{33, 120}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{33, 121}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{35, 36}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{36, 57}, 0.0671614011006787]}, 
         {Arrowheads[0.], 
          ArrowBox[BezierCurveBox[{
           36, {3.711645777275047, 4.994541033547671}, 58}], 
           0.0671614011006787]}, 
         {Arrowheads[0.], 
          ArrowBox[BezierCurveBox[{
           36, {4.089095522967298, 5.173155233923852}, 58}], 
           0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{36, 127}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{36, 131}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{38, 39}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{39, 40}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{43, 44}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{47, 48}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{48, 49}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{49, 67}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{50, 51}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{51, 73}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{51, 74}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{52, 53}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{52, 115}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{53, 54}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{54, 55}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{55, 56}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{56, 57}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{57, 97}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{57, 98}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{58, 59}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{58, 128}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{59, 60}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{60, 61}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{61, 62}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{61, 104}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{61, 149}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{62, 63}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{63, 64}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{64, 65}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{65, 66}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{66, 67}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{66, 69}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{66, 125}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{66, 136}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{69, 70}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{71, 72}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{72, 73}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{73, 111}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{73, 112}, 0.0671614011006787]}, 
         {Arrowheads[0.], 
          ArrowBox[BezierCurveBox[{
           74, {6.644805823134304, 5.8234174977751785`}, 75}], 
           0.0671614011006787]}, 
         {Arrowheads[0.], 
          ArrowBox[BezierCurveBox[{
           74, {6.568719559177796, 6.047319331662888}, 75}], 
           0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{74, 106}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{75, 76}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{75, 107}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{76, 107}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{76, 125}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{76, 126}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{79, 80}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{80, 81}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{80, 96}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{81, 82}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{83, 84}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{84, 85}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{87, 88}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{89, 90}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{94, 95}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{96, 97}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{98, 99}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{99, 100}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{100, 101}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{101, 102}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{102, 103}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{103, 104}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{103, 134}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{103, 135}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{104, 141}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{104, 148}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{105, 106}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{109, 110}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{114, 115}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{116, 117}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{117, 118}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{118, 119}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{119, 120}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{121, 122}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{122, 123}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{126, 127}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{128, 129}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{132, 133}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{133, 134}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{136, 165}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{137, 138}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{140, 141}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{142, 143}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{146, 147}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{149, 150}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{150, 151}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{151, 152}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{152, 153}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{156, 157}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{157, 158}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{158, 159}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{160, 161}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{161, 162}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{163, 164}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{165, 166}, 0.0671614011006787]}, 
         {Arrowheads[0.], ArrowBox[{166, 167}, 0.0671614011006787]}}, 
        {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
         DiskBox[1, 0.0671614011006787], DiskBox[2, 0.0671614011006787], 
         DiskBox[3, 0.0671614011006787], DiskBox[4, 0.0671614011006787], 
         DiskBox[5, 0.0671614011006787], DiskBox[6, 0.0671614011006787], 
         DiskBox[7, 0.0671614011006787], DiskBox[8, 0.0671614011006787], 
         DiskBox[9, 0.0671614011006787], DiskBox[10, 0.0671614011006787], 
         DiskBox[11, 0.0671614011006787], DiskBox[12, 0.0671614011006787], 
         DiskBox[13, 0.0671614011006787], DiskBox[14, 0.0671614011006787], 
         DiskBox[15, 0.0671614011006787], DiskBox[16, 0.0671614011006787], 
         DiskBox[17, 0.0671614011006787], DiskBox[18, 0.0671614011006787], 
         DiskBox[19, 0.0671614011006787], DiskBox[20, 0.0671614011006787], 
         DiskBox[21, 0.0671614011006787], DiskBox[22, 0.0671614011006787], 
         DiskBox[23, 0.0671614011006787], DiskBox[24, 0.0671614011006787], 
         DiskBox[25, 0.0671614011006787], DiskBox[26, 0.0671614011006787], 
         DiskBox[27, 0.0671614011006787], DiskBox[28, 0.0671614011006787], 
         DiskBox[29, 0.0671614011006787], DiskBox[30, 0.0671614011006787], 
         DiskBox[31, 0.0671614011006787], DiskBox[32, 0.0671614011006787], 
         DiskBox[33, 0.0671614011006787], DiskBox[34, 0.0671614011006787], 
         DiskBox[35, 0.0671614011006787], DiskBox[36, 0.0671614011006787], 
         DiskBox[37, 0.0671614011006787], DiskBox[38, 0.0671614011006787], 
         DiskBox[39, 0.0671614011006787], DiskBox[40, 0.0671614011006787], 
         DiskBox[41, 0.0671614011006787], DiskBox[42, 0.0671614011006787], 
         DiskBox[43, 0.0671614011006787], DiskBox[44, 0.0671614011006787], 
         DiskBox[45, 0.0671614011006787], DiskBox[46, 0.0671614011006787], 
         DiskBox[47, 0.0671614011006787], DiskBox[48, 0.0671614011006787], 
         DiskBox[49, 0.0671614011006787], DiskBox[50, 0.0671614011006787], 
         DiskBox[51, 0.0671614011006787], DiskBox[52, 0.0671614011006787], 
         DiskBox[53, 0.0671614011006787], DiskBox[54, 0.0671614011006787], 
         DiskBox[55, 0.0671614011006787], DiskBox[56, 0.0671614011006787], 
         DiskBox[57, 0.0671614011006787], DiskBox[58, 0.0671614011006787], 
         DiskBox[59, 0.0671614011006787], DiskBox[60, 0.0671614011006787], 
         DiskBox[61, 0.0671614011006787], DiskBox[62, 0.0671614011006787], 
         DiskBox[63, 0.0671614011006787], DiskBox[64, 0.0671614011006787], 
         DiskBox[65, 0.0671614011006787], DiskBox[66, 0.0671614011006787], 
         DiskBox[67, 0.0671614011006787], DiskBox[68, 0.0671614011006787], 
         DiskBox[69, 0.0671614011006787], DiskBox[70, 0.0671614011006787], 
         DiskBox[71, 0.0671614011006787], DiskBox[72, 0.0671614011006787], 
         DiskBox[73, 0.0671614011006787], DiskBox[74, 0.0671614011006787], 
         DiskBox[75, 0.0671614011006787], DiskBox[76, 0.0671614011006787], 
         DiskBox[77, 0.0671614011006787], DiskBox[78, 0.0671614011006787], 
         DiskBox[79, 0.0671614011006787], DiskBox[80, 0.0671614011006787], 
         DiskBox[81, 0.0671614011006787], DiskBox[82, 0.0671614011006787], 
         DiskBox[83, 0.0671614011006787], DiskBox[84, 0.0671614011006787], 
         DiskBox[85, 0.0671614011006787], DiskBox[86, 0.0671614011006787], 
         DiskBox[87, 0.0671614011006787], DiskBox[88, 0.0671614011006787], 
         DiskBox[89, 0.0671614011006787], DiskBox[90, 0.0671614011006787], 
         DiskBox[91, 0.0671614011006787], DiskBox[92, 0.0671614011006787], 
         DiskBox[93, 0.0671614011006787], DiskBox[94, 0.0671614011006787], 
         DiskBox[95, 0.0671614011006787], DiskBox[96, 0.0671614011006787], 
         DiskBox[97, 0.0671614011006787], DiskBox[98, 0.0671614011006787], 
         DiskBox[99, 0.0671614011006787], DiskBox[100, 0.0671614011006787], 
         DiskBox[101, 0.0671614011006787], DiskBox[102, 0.0671614011006787], 
         DiskBox[103, 0.0671614011006787], DiskBox[104, 0.0671614011006787], 
         DiskBox[105, 0.0671614011006787], DiskBox[106, 0.0671614011006787], 
         DiskBox[107, 0.0671614011006787], DiskBox[108, 0.0671614011006787], 
         DiskBox[109, 0.0671614011006787], DiskBox[110, 0.0671614011006787], 
         DiskBox[111, 0.0671614011006787], DiskBox[112, 0.0671614011006787], 
         DiskBox[113, 0.0671614011006787], DiskBox[114, 0.0671614011006787], 
         DiskBox[115, 0.0671614011006787], DiskBox[116, 0.0671614011006787], 
         DiskBox[117, 0.0671614011006787], DiskBox[118, 0.0671614011006787], 
         DiskBox[119, 0.0671614011006787], DiskBox[120, 0.0671614011006787], 
         DiskBox[121, 0.0671614011006787], DiskBox[122, 0.0671614011006787], 
         DiskBox[123, 0.0671614011006787], DiskBox[124, 0.0671614011006787], 
         DiskBox[125, 0.0671614011006787], DiskBox[126, 0.0671614011006787], 
         DiskBox[127, 0.0671614011006787], DiskBox[128, 0.0671614011006787], 
         DiskBox[129, 0.0671614011006787], DiskBox[130, 0.0671614011006787], 
         DiskBox[131, 0.0671614011006787], DiskBox[132, 0.0671614011006787], 
         DiskBox[133, 0.0671614011006787], DiskBox[134, 0.0671614011006787], 
         DiskBox[135, 0.0671614011006787], DiskBox[136, 0.0671614011006787], 
         DiskBox[137, 0.0671614011006787], DiskBox[138, 0.0671614011006787], 
         DiskBox[139, 0.0671614011006787], DiskBox[140, 0.0671614011006787], 
         DiskBox[141, 0.0671614011006787], DiskBox[142, 0.0671614011006787], 
         DiskBox[143, 0.0671614011006787], DiskBox[144, 0.0671614011006787], 
         DiskBox[145, 0.0671614011006787], DiskBox[146, 0.0671614011006787], 
         DiskBox[147, 0.0671614011006787], DiskBox[148, 0.0671614011006787], 
         DiskBox[149, 0.0671614011006787], DiskBox[150, 0.0671614011006787], 
         DiskBox[151, 0.0671614011006787], DiskBox[152, 0.0671614011006787], 
         DiskBox[153, 0.0671614011006787], DiskBox[154, 0.0671614011006787], 
         DiskBox[155, 0.0671614011006787], DiskBox[156, 0.0671614011006787], 
         DiskBox[157, 0.0671614011006787], DiskBox[158, 0.0671614011006787], 
         DiskBox[159, 0.0671614011006787], DiskBox[160, 0.0671614011006787], 
         DiskBox[161, 0.0671614011006787], DiskBox[162, 0.0671614011006787], 
         DiskBox[163, 0.0671614011006787], DiskBox[164, 0.0671614011006787], 
         DiskBox[165, 0.0671614011006787], DiskBox[166, 0.0671614011006787], 
         DiskBox[167, 0.0671614011006787]}}]],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{{3.676281372261116*^9, 3.676281394724989*^9}, 
   3.676281731422598*^9, 3.6762820511192636`*^9, 3.676282494711528*^9, 
   3.676283629957041*^9, 3.676725024406567*^9, 3.6768061890685577`*^9, 
   3.676806287945207*^9}]
}, Open  ]],

Cell["\<\
Count the number of edges and vertices in the graph, consult the \
documentation on Graph Measures to see if there are interesting measures that \
might facilitate your analysis of this data.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.67628222783044*^9, 3.67628230176499*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Subgraphing", "Section",
 CellChangeTimes->{{3.6761107633014383`*^9, 3.676110769096087*^9}, {
  3.6761156799717283`*^9, 3.676115682532858*^9}, {3.6761157161495457`*^9, 
  3.676115721492573*^9}, {3.676116110625745*^9, 3.676116114387026*^9}, {
  3.676202752888332*^9, 3.676202757098895*^9}, {3.67628141267354*^9, 
  3.676281445860187*^9}, {3.676282130414431*^9, 3.676282135318386*^9}}],

Cell["\<\
Extracting parts of graph is fairly simple when using the Subgraph function:\
\>", "Text",
 CellChangeTimes->{{3.6762821376132927`*^9, 3.67628215444317*^9}}],

Cell["\<\
Investigate the function VertexLabels in the documentation for a method to \
add labels to the vertices as tooltips (shown when the cursor hovers over a \
tooltip)\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676281449590415*^9, 3.6762815073087482`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"graph", "=", 
  RowBox[{"Graph", "[", 
   RowBox[{
    RowBox[{"UndirectedEdge", "@@@", "partitions"}], ",", 
    RowBox[{"VertexLabels", "\[Rule]", 
     RowBox[{"Placed", "[", 
      RowBox[{"\"\<Name\>\"", ",", "Tooltip"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.676281514012226*^9, 3.676281520573228*^9}, {
  3.67628180573354*^9, 3.676281807542902*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "to", "be", "or", "not", "that", "is", "the", "question", "whether", 
       "tis", "nobler", "in", "mind", "suffer", "slings", "and", "arrows", 
       "of", "outrageous", "fortune", "take", "arms", "against", "a", "sea", 
       "troubles", "by", "opposing", "end", "them", "die", "sleep", "no", 
       "more", "say", "we", "heartache", "thousand", "natural", "shocks", 
       "flesh", "heir", "consummation", "devoutly", "wished", "perchance", 
       "dream", "ay", "there's", "rub", "for", "death", "what", "dreams", 
       "may", "come", "when", "have", "shuffled", "off", "this", "mortal", 
       "coil", "must", "give", "us", "pause", "respect", "makes", "calamity", 
       "so", "long", "life", "who", "would", "bear", "whips", "scorns", 
       "time", "th", "oppressor's", "wrong", "proud", "man's", "contumely", 
       "pangs", "despised", "love", "law's", "delay", "insolence", "office", 
       "spurns", "patient", "merit", "unworthy", "takes", "he", "himself", 
       "might", "his", "quietus", "make", "with", "bare", "bodkin", "fardels",
        "grunt", "sweat", "under", "weary", "but", "dread", "something", 
       "after", "undiscovered", "country", "from", "whose", "bourn", 
       "traveller", "returns", "puzzles", "will", "rather", "those", "ills", 
       "than", "fly", "others", "know", "thus", "conscience", "does", 
       "cowards", "all", "native", "hue", "resolution", "sicklied", "o'er", 
       "pale", "cast", "thought", "enterprise", "great", "pitch", "moment", 
       "regard", "their", "currents", "turn", "awry", "lose", "name", 
       "action", "soft", "you", "now", "fair", "ophelia", "nymph", "thy", 
       "orisons", "my", "sins", "remembered"}, {Null, CompressedData["
1:eJw1T1VTalEYZQObTxF1+1nHQEGP3YKBioGioqiI3YoBJna3qNjdnfdv3nse
7sOaNbNmVqltTqtNLBKJ/IlIJDARiyUSqZT8Y0plMgAPD09PudzLS6EA8PYm
xMcHwNeXMT8/RH//gACJhJDAwKCg4GCOCwlBDA1lLCwsPFypjIggJDKSEJVK
rY6KElSOU6kIiY7meaUSICaGMYDY2Li4+HhKExJkssREQuRyjktKSk4WFqSk
/E8QkJpKSFpaenpGBkBmpkajUFCqUiFqtVlZ2dk5Obm5Oh3P5+Xl5xcU6PWF
hUVFxcUlJQZDaangKCuj1GgsL0esqKisNJk0mqqq6mqzGaCmhrHaWsS6Ooul
vt5qBWhoaGxsagJobkZsaWltBWhra28H6OhA7OwUVnd1Udrd3dODaLH09vb1
6XQ2W3//wMDg4NCQ3e5wcNzw8MiI0DA6ajYTMjbG2Pj4xATHOZ0m0+QkpQBT
U4jT0zMzWi3A7Ozc3Pz8wsLiolq9tLS8vLICsLrKmNFoMKytmc3r6xsbwrfN
za0tQra3KeX5nR2pFNHl2t3d27Pb9/cRDQa3mzGXC+Dg4PAQ8ehIJjs+Pjlx
OABOT8/OEM/PGbu4QLy8vLpi7Pra4dDrb25ub+/u7u8fHhh7fAR4ekJ8fn55
eX19ewN4f//4+PxUKL6+vr/FYrf75+f3989fQ/WDmw==
       "]}, {VertexLabels -> {
         Placed["Name", Tooltip]}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{6.149636771561795, 4.746473222647219}, {
          6.383146141202031, 4.6898891030332965`}, {6.537485657691795, 
          4.505748662261141}}], 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.149636771561795, 4.746473222647219}, {6.537485657691795,
           4.505748662261141}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{6.149636771561795, 4.746473222647219}, {
          6.303976288051561, 4.562332781688794}, {6.537485657691795, 
          4.505748662261141}}], 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.149636771561795, 4.746473222647219}, {5.667872044263135,
           4.421154812506112}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.149636771561795, 4.746473222647219}, {5.310926506998834,
           3.824270196546829}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.149636771561795, 4.746473222647219}, {
          7.0849210092275365`, 4.6136396835144415`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.149636771561795, 4.746473222647219}, {6.362053751333953,
           3.8563569466851764`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.149636771561795, 4.746473222647219}, {
          6.5116673105508305`, 3.8371094483660664`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.149636771561795, 4.746473222647219}, {6.899865126434051,
           5.752288811798297}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.149636771561795, 4.746473222647219}, {
          5.4363061182430785`, 4.901002135422442}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{6.149636771561795, 4.746473222647219}, {
          5.946755111300448, 5.2718713320991455`}, {6.095334392147575, 
          5.815128489450103}}], 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{6.149636771561795, 4.746473222647219}, {
          6.063732336974264, 5.277815383259082}, {6.095334392147575, 
          5.815128489450103}}], 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{6.149636771561795, 4.746473222647219}, {
          6.181238826735102, 5.283786328655707}, {6.095334392147575, 
          5.815128489450103}}], 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{6.149636771561795, 4.746473222647219}, {
          6.298216052408921, 5.289730379907348}, {6.095334392147575, 
          5.815128489450103}}], 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{6.149636771561795, 4.746473222647219}, {
          6.473284668357846, 4.159379071486712}, {6.385276276997234, 
          3.494787447654268}}], 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{6.149636771561795, 4.746473222647219}, {
          6.370630916974096, 4.140053710726705}, {6.385276276997234, 
          3.494787447654268}}], 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.149636771561795, 4.746473222647219}, {6.385276276997234,
           3.494787447654268}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{6.149636771561795, 4.746473222647219}, {
          6.164282131584931, 4.101206959624035}, {6.385276276997234, 
          3.494787447654268}}], 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{6.149636771561795, 4.746473222647219}, {
          6.0616283802011965`, 4.081881598831284}, {6.385276276997234, 
          3.494787447654268}}], 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.149636771561795, 4.746473222647219}, {5.002585135615827,
           5.03940703938859}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.149636771561795, 4.746473222647219}, {5.43605233459265, 
          4.530633579453884}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.149636771561795, 4.746473222647219}, {6.438485841445654,
           5.692617584447861}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.149636771561795, 4.746473222647219}, {6.695298718201588,
           5.159422605706}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.149636771561795, 4.746473222647219}, {6.680466111177356,
           4.323724513250884}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.149636771561795, 4.746473222647219}, {7.206798706605325,
           4.90774208128364}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.149636771561795, 4.746473222647219}, {5.89930780378373, 
          4.701592886595449}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.149636771561795, 4.746473222647219}, {6.068823382809269,
           3.6725455438520997`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.149636771561795, 4.746473222647219}, {5.254529667273825,
           5.803055430296668}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.149636771561795, 4.746473222647219}, {5.7802121303291, 
          4.832266414015245}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.537485657691795, 4.505748662261141}, {5.667872044263135,
           4.421154812506112}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.537485657691795, 4.505748662261141}, {5.654444276220448,
           3.9313309674609833`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.537485657691795, 4.505748662261141}, {6.695298718201588,
           5.159422605706}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.537485657691795, 4.505748662261141}, {6.75890206431565, 
          3.4994116561945963`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.537485657691795, 4.505748662261141}, {7.504760351940558,
           5.020384341959129}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.667872044263135, 4.421154812506112}, {5.310926506998834,
           3.824270196546829}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.667872044263135, 4.421154812506112}, {4.809133697616101,
           3.9892595152109918`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.310926506998834, 3.824270196546829}, {5.205755396461726,
           2.2615298763791567`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.310926506998834, 3.824270196546829}, {
          4.5145469846148725`, 4.468921966786718}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.654444276220448, 3.9313309674609833`}, {
          5.193736397207274, 3.59275287946243}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.654444276220448, 3.9313309674609833`}, {
          6.2585261783873944`, 2.778555333708617}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.654444276220448, 3.9313309674609833`}, {
          7.069460972093033, 4.0661826374359435`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.654444276220448, 3.9313309674609833`}, {
          6.385276276997234, 3.494787447654268}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.654444276220448, 3.9313309674609833`}, {
          4.171918614028064, 4.5100096050305405`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.654444276220448, 3.9313309674609833`}, {
          4.837614827213826, 4.352198553196063}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.654444276220448, 3.9313309674609833`}, {
          5.028837574843454, 4.159474086797631}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.654444276220448, 3.9313309674609833`}, {
          5.963610244309773, 3.245357425500012}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.654444276220448, 3.9313309674609833`}, {
          5.312192751389908, 3.0435685384444895`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.654444276220448, 3.9313309674609833`}, {
          6.130726954147874, 3.3336715680211895`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.654444276220448, 3.9313309674609833`}, {
          4.7749747634798165`, 3.3918375125656066`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.654444276220448, 3.9313309674609833`}, {
          5.621638801045103, 4.980415389376189}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.654444276220448, 3.9313309674609833`}, {5.7802121303291,
           4.832266414015245}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.193736397207274, 3.59275287946243}, {
          6.2585261783873944`, 2.778555333708617}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.193736397207274, 3.59275287946243}, {5.028837574843454, 
          4.159474086797631}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.193736397207274, 3.59275287946243}, {5.43605233459265, 
          4.530633579453884}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.193736397207274, 3.59275287946243}, {
          4.7712508277371315`, 2.8425805800823154`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.193736397207274, 3.59275287946243}, {4.171046249811952, 
          3.785676689398237}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          7.357065363495607, 3.285149502354225}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          7.069460972093033, 4.0661826374359435`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          6.362053751333953, 3.8563569466851764`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          6.5116673105508305`, 3.8371094483660664`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          6.2569337566552115`, 2.2389366899546213`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{6.2585261783873944`, 2.778555333708617}, {
          6.045394665908441, 2.5569222034444676`}, {5.742315949556571, 
          2.50506106475853}}], 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{6.2585261783873944`, 2.778555333708617}, {
          5.955447462035541, 2.726694194912868}, {5.742315949556571, 
          2.50506106475853}}], 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          5.331827425726174, 4.017866612783906}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          6.4942988125515315`, 2.3818484062957475`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          5.380082737974588, 3.2586069186096647`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{6.2585261783873944`, 2.778555333708617}, {
          6.582089374481275, 3.268416358306339}, {7.13325201850692, 
          3.4705962415449187`}}], 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{6.2585261783873944`, 2.778555333708617}, {
          6.809688822413031, 2.9807352168938057`}, {7.13325201850692, 
          3.4705962415449187`}}], 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          6.925422516164995, 3.8582226359729974`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          4.796026848482926, 1.7062555617036526`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          5.963610244309773, 3.245357425500012}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          5.89930780378373, 4.701592886595449}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          6.464544283974497, 2.1945822199367875`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          5.33083723607252, 1.8884017019808517`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          7.0695677079762005`, 1.8146192212669432`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          7.172374012041844, 1.9319868236665776`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          5.7620041263555235`, 2.1625496290693884`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          6.341914635783516, 1.659046465587535}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          7.102680457458591, 2.3536134892290037`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          7.159022836775451, 2.5419960638956365`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          5.69083098185932, 2.339703306228457}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          6.130726954147874, 3.3336715680211895`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          4.546289871923202, 3.61732029546917}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          5.918983033092864, 2.0674227999199486`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          7.654148716612581, 1.8965499836353763`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          7.504009024452078, 2.1629783429699647`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          6.32019301572723, 2.069203564747613}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          5.0514551585248615`, 2.271331776722116}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          6.14323322020688, 1.6792235001437081`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          6.504020633767987, 1.758921236664134}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          6.322028968285791, 2.4358715017978447`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          5.906965752060233, 2.2798688490971397`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          6.599188488022773, 1.3221725309520966`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2585261783873944`, 2.778555333708617}, {
          7.578582817936315, 2.9278725667145253`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.357065363495607, 3.285149502354225}, {7.767930127232537,
           4.061610917172849}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.767930127232537, 4.061610917172849}, {
          7.0849210092275365`, 4.6136396835144415`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.0849210092275365`, 4.6136396835144415`}, {
          7.67042706936055, 4.634360395233147}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.0849210092275365`, 4.6136396835144415`}, {
          6.187397086229029, 4.5018969095708945`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.67042706936055, 4.634360395233147}, {7.069460972093033, 
          4.0661826374359435`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.069460972093033, 4.0661826374359435`}, {
          6.891140571291999, 4.968355810483028}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.069460972093033, 4.0661826374359435`}, {
          8.142266809902143, 3.8948361677230077`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.069460972093033, 4.0661826374359435`}, {
          7.876964262235069, 4.724566396534053}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.2569337566552115`, 2.2389366899546213`}, {
          5.742315949556571, 2.50506106475853}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.742315949556571, 2.50506106475853}, {5.006640342329984, 
          1.996758017840263}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.742315949556571, 2.50506106475853}, {5.163397074762742, 
          1.924833110543265}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{5.742315949556571, 2.50506106475853}, {
          5.648721016772845, 3.0916068233593434`}, {5.921547902739249, 
          3.619206509324367}}], 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{5.742315949556571, 2.50506106475853}, {
          6.015142835522975, 3.032660750728503}, {5.921547902739249, 
          3.619206509324367}}], 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.742315949556571, 2.50506106475853}, {6.933144562322129, 
          2.270567594676393}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.742315949556571, 2.50506106475853}, {
          6.4942988125515315`, 2.3818484062957475`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.742315949556571, 2.50506106475853}, {5.312192751389908, 
          3.0435685384444895`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.742315949556571, 2.50506106475853}, {6.464544283974497, 
          2.1945822199367875`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.742315949556571, 2.50506106475853}, {5.220139122449318, 
          1.7409562234406712`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.742315949556571, 2.50506106475853}, {5.617187236769821, 
          1.7671687549154562`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.742315949556571, 2.50506106475853}, {6.068823382809269, 
          3.6725455438520997`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.742315949556571, 2.50506106475853}, {
          6.5517742323912715`, 3.0801036532119843`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.742315949556571, 2.50506106475853}, {6.32019301572723, 
          2.069203564747613}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.742315949556571, 2.50506106475853}, {
          5.0514551585248615`, 2.271331776722116}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.742315949556571, 2.50506106475853}, {6.75890206431565, 
          3.4994116561945963`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.742315949556571, 2.50506106475853}, {5.512943286562156, 
          1.9101442465280285`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.742315949556571, 2.50506106475853}, {5.420572132419822, 
          1.700317648612181}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.742315949556571, 2.50506106475853}, {5.390105874726696, 
          1.426263137849097}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.742315949556571, 2.50506106475853}, {4.933116858618527, 
          2.922537675268689}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.742315949556571, 2.50506106475853}, {4.100507303107535, 
          2.6738460598170963`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.742315949556571, 2.50506106475853}, {6.322028968285791, 
          2.4358715017978447`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.006640342329984, 1.996758017840263}, {5.205755396461726,
           2.2615298763791567`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          4.5948434733987416`, 3.0838132699487937`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          5.689057346846456, 3.3614209303777516`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          5.163397074762742, 1.924833110543265}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          6.385276276997234, 3.494787447654268}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          4.796026848482926, 1.7062555617036526`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          5.449561272304643, 3.520266952943572}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          4.753617205980725, 2.4729716342105608`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          5.002298394063732, 3.4098321596759864`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          5.220139122449318, 1.7409562234406712`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          4.396302111625927, 1.6373636934441265`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          4.013040421168215, 1.748199624349427}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          5.7620041263555235`, 2.1625496290693884`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          5.758984688507607, 1.3264778022381596`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          5.69083098185932, 2.339703306228457}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          5.617187236769821, 1.7671687549154562`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          4.490754035169181, 2.6627511962915187`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          5.918983033092864, 2.0674227999199486`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          4.704383287221359, 1.2115043203915121`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          5.0514551585248615`, 2.271331776722116}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          3.9893420353129723`, 2.2858336966018897`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          5.5657947394892116`, 1.298438916823582}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          4.7712508277371315`, 2.8425805800823154`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          5.887731672061396, 1.4668978567571904`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          5.512943286562156, 1.9101442465280285`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          5.420572132419822, 1.700317648612181}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          5.014240377922645, 1.2421150035079034`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          5.906965752060233, 2.2798688490971397`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.205755396461726, 2.2615298763791567`}, {
          5.507814314892514, 0.8432205496601535}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.5948434733987416`, 3.0838132699487937`}, {
          4.809133697616101, 3.9892595152109918`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.899865126434051, 5.752288811798297}, {7.378875927829059,
           6.222314993004501}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.378875927829059, 6.222314993004501}, {
          6.9859487057321745`, 5.527189543765115}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.9859487057321745`, 5.527189543765115}, {
          6.187397086229029, 4.5018969095708945`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.187397086229029, 4.5018969095708945`}, {
          5.689057346846456, 3.3614209303777516`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.187397086229029, 4.5018969095708945`}, {
          5.921547902739249, 3.619206509324367}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.187397086229029, 4.5018969095708945`}, {
          6.385276276997234, 3.494787447654268}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.187397086229029, 4.5018969095708945`}, {
          6.543956849617926, 5.425568630656395}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.187397086229029, 4.5018969095708945`}, {
          4.546289871923202, 3.61732029546917}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.187397086229029, 4.5018969095708945`}, {
          6.682925364129103, 5.772427006331156}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.187397086229029, 4.5018969095708945`}, {
          6.765110864774691, 3.949728756954839}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.187397086229029, 4.5018969095708945`}, {
          6.230480715045088, 5.381379358396403}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.921547902739249, 3.619206509324367}, {5.801565237840344,
           4.1705527147121995`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.801565237840344, 4.1705527147121995`}, {
          5.331827425726174, 4.017866612783906}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.331827425726174, 4.017866612783906}, {
          5.4363061182430785`, 4.901002135422442}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.331827425726174, 4.017866612783906}, {4.171918614028064,
           4.5100096050305405`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.385276276997234, 3.494787447654268}, {7.811990351809001,
           2.510615613250353}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.385276276997234, 3.494787447654268}, {6.680466111177356,
           4.323724513250884}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.811990351809001, 2.510615613250353}, {6.933144562322129,
           2.270567594676393}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.811990351809001, 2.510615613250353}, {8.98931890052565, 
          1.9002202282593583`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.811990351809001, 2.510615613250353}, {8.621552133939062,
           2.068374644058318}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.002585135615827, 5.03940703938859}, {4.171918614028064, 
          4.5100096050305405`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.171918614028064, 4.5100096050305405`}, {
          2.45407440591467, 3.5443193983421604`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{4.171918614028064, 4.5100096050305405`}, {
          3.711645777275047, 4.994541033547671}, {3.6288226862142787`, 
          5.657686662444817}}], 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{4.171918614028064, 4.5100096050305405`}, {
          4.089095522967298, 5.173155233923852}, {3.6288226862142787`, 
          5.657686662444817}}], 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.171918614028064, 4.5100096050305405`}, {
          4.246031895088816, 5.424214591161256}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.171918614028064, 4.5100096050305405`}, {
          4.5145469846148725`, 4.468921966786718}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.380082737974588, 3.2586069186096647`}, {
          4.653319530703822, 3.8526274461150694`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.653319530703822, 3.8526274461150694`}, {
          4.837614827213826, 4.352198553196063}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.543956849617926, 5.425568630656395}, {6.438485841445654,
           5.692617584447861}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.206798706605325, 4.90774208128364}, {7.675345357070372, 
          4.293765451513408}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.675345357070372, 4.293765451513408}, {7.13325201850692, 
          3.4705962415449187`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.13325201850692, 3.4705962415449187`}, {
          6.471200009198261, 3.3870320741437476`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.925422516164995, 3.8582226359729974`}, {
          6.891140571291999, 4.968355810483028}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.891140571291999, 4.968355810483028}, {5.977546584833777,
           5.197029475364527}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.891140571291999, 4.968355810483028}, {6.947161646168591,
           6.051042700403976}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.796026848482926, 1.7062555617036526`}, {
          3.446321277322538, 1.2174262978896673`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.796026848482926, 1.7062555617036526`}, {
          4.428536643552565, 0.8200590954572822}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.446321277322538, 1.2174262978896673`}, {
          2.3160526084108604`, 1.1980820422353382`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.3160526084108604`, 1.1980820422353382`}, {
          1.6154733953574305`, 1.7591322299095886`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.6154733953574305`, 1.7591322299095886`}, {
          1.6931406440614536`, 2.695751802275926}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.6931406440614536`, 2.695751802275926}, {
          2.45407440591467, 3.5443193983421604`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.45407440591467, 3.5443193983421604`}, {
          2.2770615669776326`, 2.658373552073426}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.45407440591467, 3.5443193983421604`}, {
          1.1825030013764017`, 3.3663151869656325`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.6288226862142787`, 5.657686662444817}, {
          2.8079812768542913`, 5.989046134050012}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.6288226862142787`, 5.657686662444817}, {
          4.303963659925611, 6.196843253483276}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.8079812768542913`, 5.989046134050012}, {
          2.5187514305719745`, 5.415251232349086}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.5187514305719745`, 5.415251232349086}, {
          2.9299990400042604`, 4.510512987538155}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.9299990400042604`, 4.510512987538155}, {
          2.1529574440084636`, 5.023240898193836}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.9299990400042604`, 4.510512987538155}, {
          4.546289871923202, 3.61732029546917}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.9299990400042604`, 4.510512987538155}, {
          1.8626026195938934`, 4.490116957521179}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.1529574440084636`, 5.023240898193836}, {
          2.169495017650989, 5.396620499412995}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.169495017650989, 5.396620499412995}, {2.980731030250757,
           4.986759551041008}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.980731030250757, 4.986759551041008}, {4.060621435050115,
           4.31500895867023}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.060621435050115, 4.31500895867023}, {5.449561272304643, 
          3.520266952943572}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.449561272304643, 3.520266952943572}, {6.471200009198261,
           3.3870320741437476`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.449561272304643, 3.520266952943572}, {5.312192751389908,
           3.0435685384444895`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.449561272304643, 3.520266952943572}, {5.44190814843869, 
          4.342511074435499}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.449561272304643, 3.520266952943572}, {6.75890206431565, 
          3.4994116561945963`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.312192751389908, 3.0435685384444895`}, {
          4.753617205980725, 2.4729716342105608`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.002298394063732, 3.4098321596759864`}, {
          5.202651453608485, 4.567954790128944}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.202651453608485, 4.567954790128944}, {5.977546584833777,
           5.197029475364527}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.977546584833777, 5.197029475364527}, {6.230480715045088,
           5.381379358396403}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.977546584833777, 5.197029475364527}, {5.621638801045103,
           4.980415389376189}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{6.947161646168591, 6.051042700403976}, {
          6.644805823134304, 5.8234174977751785`}, {6.26636373614346, 
          5.819694128776073}}], 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{6.947161646168591, 6.051042700403976}, {
          6.568719559177796, 6.047319331662888}, {6.26636373614346, 
          5.819694128776073}}], 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.947161646168591, 6.051042700403976}, {7.04409477511401, 
          6.578491632123912}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.26636373614346, 5.819694128776073}, {5.89930780378373, 
          4.701592886595449}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.26636373614346, 5.819694128776073}, {5.868024869497765, 
          5.739404949223662}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.89930780378373, 4.701592886595449}, {5.868024869497765, 
          5.739404949223662}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.89930780378373, 4.701592886595449}, {5.44190814843869, 
          4.342511074435499}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.89930780378373, 4.701592886595449}, {5.023254778929178, 
          5.493756404508913}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.396302111625927, 1.6373636934441265`}, {
          4.013040421168215, 1.748199624349427}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.013040421168215, 1.748199624349427}, {4.452798597957239,
           1.309594443009607}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.013040421168215, 1.748199624349427}, {
          2.8639000019213623`, 1.954244002756251}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.452798597957239, 1.309594443009607}, {5.33083723607252, 
          1.8884017019808517`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.0695677079762005`, 1.8146192212669432`}, {
          7.596775138087475, 1.3322534760009694`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.596775138087475, 1.3322534760009694`}, {
          7.172374012041844, 1.9319868236665776`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.758984688507607, 1.3264778022381596`}, {
          6.341914635783516, 1.659046465587535}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.102680457458591, 2.3536134892290037`}, {
          7.159022836775451, 2.5419960638956365`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.7749747634798165`, 3.3918375125656066`}, {
          4.490754035169181, 2.6627511962915187`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.8639000019213623`, 1.954244002756251}, {
          2.2770615669776326`, 2.658373552073426}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.1825030013764017`, 3.3663151869656325`}, {
          0.27735827627303067`, 3.088035942564272}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{0.27735827627303067`, 3.088035942564272}, {0., 
          2.6107904872897985`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{0., 2.6107904872897985`}, {0.7247469291682034, 
          2.430154449302191}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{0.7247469291682034, 2.430154449302191}, {
          1.8363303510303703`, 2.4826883950104817`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.8363303510303703`, 2.4826883950104817`}, {
          3.222968733438419, 2.7214091399641176`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.222968733438419, 2.7214091399641176`}, {
          4.546289871923202, 3.61732029546917}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.222968733438419, 2.7214091399641176`}, {
          3.1174788294414415`, 1.9844497854644132`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.222968733438419, 2.7214091399641176`}, {
          3.9893420353129723`, 2.2858336966018897`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.546289871923202, 3.61732029546917}, {
          3.7296983794714667`, 3.8439652480265396`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.546289871923202, 3.61732029546917}, {4.933116858618527, 
          2.922537675268689}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.682925364129103, 5.772427006331156}, {7.04409477511401, 
          6.578491632123912}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.5517742323912715`, 3.0801036532119843`}, {
          6.765110864774691, 3.949728756954839}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.704383287221359, 1.2115043203915121`}, {
          4.428536643552565, 0.8200590954572822}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.654148716612581, 1.8965499836353763`}, {
          8.76445164424874, 1.2502946328805375`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.76445164424874, 1.2502946328805375`}, {9.58940249658448,
           0.9387965175642434}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.58940249658448, 0.9387965175642434}, {9.734166520490977,
           1.3643779960224809`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.734166520490977, 1.3643779960224809`}, {
          8.98931890052565, 1.9002202282593583`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.621552133939062, 2.068374644058318}, {8.38120966975411, 
          1.752782755925895}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.38120966975411, 1.752782755925895}, {7.504009024452078, 
          2.1629783429699647`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.023254778929178, 5.493756404508913}, {4.246031895088816,
           5.424214591161256}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.303963659925611, 6.196843253483276}, {5.254529667273825,
           5.803055430296668}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.0514551585248615`, 2.271331776722116}, {
          3.880365913277923, 1.832430416818754}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.880365913277923, 1.832430416818754}, {
          3.1174788294414415`, 1.9844497854644132`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.75890206431565, 3.4994116561945963`}, {
          8.361609050118435, 3.743269980721996}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.14323322020688, 1.6792235001437081`}, {
          5.5657947394892116`, 1.298438916823582}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.171046249811952, 3.785676689398237}, {
          3.7296983794714667`, 3.8439652480265396`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.504020633767987, 1.758921236664134}, {5.887731672061396,
           1.4668978567571904`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.014240377922645, 1.2421150035079034`}, {
          5.390105874726696, 1.426263137849097}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.8626026195938934`, 4.490116957521179}, {
          1.2931691969646906`, 4.093548710508397}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.2931691969646906`, 4.093548710508397}, {
          1.7745054969335254`, 3.490314717872141}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.7745054969335254`, 3.490314717872141}, {
          2.7684549403471252`, 3.010887525480971}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.7684549403471252`, 3.010887525480971}, {
          4.100507303107535, 2.6738460598170963`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.507814314892514, 0.8432205496601535}, {
          5.989414885145423, 0.}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.989414885145423, 0.}, {6.5648934906022, 
          0.2678740952569121}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.5648934906022, 0.2678740952569121}, {6.599188488022773, 
          1.3221725309520966`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.578582817936315, 2.9278725667145253`}, {
          8.437977541817116, 3.2958624084846737`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.437977541817116, 3.2958624084846737`}, {
          8.142266809902143, 3.8948361677230077`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.876964262235069, 4.724566396534053}, {7.504760351940558,
           5.020384341959129}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.361609050118435, 3.743269980721996}, {9.595931415834253,
           3.9606124169870194`}}, 0.0671614011006787]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.595931415834253, 3.9606124169870194`}, {
          10.44333446695205, 4.109398184268213}}, 0.0671614011006787]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
        TagBox[
         TooltipBox[
          DiskBox[{6.149636771561795, 4.746473222647219}, 0.0671614011006787],
          
          "\"to\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "to", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.537485657691795, 4.505748662261141}, 0.0671614011006787],
          
          "\"be\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "be", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.667872044263135, 4.421154812506112}, 0.0671614011006787],
          
          "\"or\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "or", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.310926506998834, 3.824270196546829}, 0.0671614011006787],
          
          "\"not\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "not", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.654444276220448, 3.9313309674609833`}, 
           0.0671614011006787],
          "\"that\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "that", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.193736397207274, 3.59275287946243}, 0.0671614011006787],
          "\"is\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "is", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.2585261783873944`, 2.778555333708617}, 
           0.0671614011006787],
          "\"the\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "the", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.357065363495607, 3.285149502354225}, 0.0671614011006787],
          
          "\"question\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "question", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.767930127232537, 4.061610917172849}, 0.0671614011006787],
          
          "\"whether\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "whether", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.0849210092275365`, 4.6136396835144415`}, 
           0.0671614011006787],
          "\"tis\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "tis", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.67042706936055, 4.634360395233147}, 0.0671614011006787],
          "\"nobler\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "nobler", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.069460972093033, 4.0661826374359435`}, 
           0.0671614011006787],
          "\"in\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "in", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.362053751333953, 3.8563569466851764`}, 
           0.0671614011006787],
          "\"mind\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "mind", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.5116673105508305`, 3.8371094483660664`}, 
           0.0671614011006787],
          "\"suffer\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "suffer", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.2569337566552115`, 2.2389366899546213`}, 
           0.0671614011006787],
          "\"slings\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "slings", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.742315949556571, 2.50506106475853}, 0.0671614011006787],
          "\"and\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "and", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.006640342329984, 1.996758017840263}, 0.0671614011006787],
          
          "\"arrows\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "arrows", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.205755396461726, 2.2615298763791567`}, 
           0.0671614011006787],
          "\"of\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "of", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.5948434733987416`, 3.0838132699487937`}, 
           0.0671614011006787],
          "\"outrageous\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "outrageous", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.809133697616101, 3.9892595152109918`}, 
           0.0671614011006787],
          "\"fortune\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "fortune", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.899865126434051, 5.752288811798297}, 0.0671614011006787],
          
          "\"take\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "take", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.378875927829059, 6.222314993004501}, 0.0671614011006787],
          
          "\"arms\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "arms", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.9859487057321745`, 5.527189543765115}, 
           0.0671614011006787],
          "\"against\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "against", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.187397086229029, 4.5018969095708945`}, 
           0.0671614011006787],
          "\"a\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "a", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.689057346846456, 3.3614209303777516`}, 
           0.0671614011006787],
          "\"sea\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "sea", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.163397074762742, 1.924833110543265}, 0.0671614011006787],
          
          "\"troubles\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "troubles", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.921547902739249, 3.619206509324367}, 0.0671614011006787],
          
          "\"by\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "by", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.801565237840344, 4.1705527147121995`}, 
           0.0671614011006787],
          "\"opposing\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "opposing", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.331827425726174, 4.017866612783906}, 0.0671614011006787],
          
          "\"end\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "end", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.4363061182430785`, 4.901002135422442}, 
           0.0671614011006787],
          "\"them\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "them", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.095334392147575, 5.815128489450103}, 0.0671614011006787],
          
          "\"die\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "die", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.385276276997234, 3.494787447654268}, 0.0671614011006787],
          
          "\"sleep\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "sleep", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.811990351809001, 2.510615613250353}, 0.0671614011006787],
          
          "\"no\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "no", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.933144562322129, 2.270567594676393}, 0.0671614011006787],
          
          "\"more\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "more", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.002585135615827, 5.03940703938859}, 0.0671614011006787],
          "\"say\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "say", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.171918614028064, 4.5100096050305405`}, 
           0.0671614011006787],
          "\"we\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "we", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.4942988125515315`, 2.3818484062957475`}, 
           0.0671614011006787],
          "\"heartache\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "heartache", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.380082737974588, 3.2586069186096647`}, 
           0.0671614011006787],
          "\"thousand\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "thousand", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.653319530703822, 3.8526274461150694`}, 
           0.0671614011006787],
          "\"natural\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "natural", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.837614827213826, 4.352198553196063}, 0.0671614011006787],
          
          "\"shocks\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "shocks", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.028837574843454, 4.159474086797631}, 0.0671614011006787],
          
          "\"flesh\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "flesh", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.43605233459265, 4.530633579453884}, 0.0671614011006787],
          "\"heir\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "heir", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.543956849617926, 5.425568630656395}, 0.0671614011006787],
          
          "\"consummation\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "consummation", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.438485841445654, 5.692617584447861}, 0.0671614011006787],
          
          "\"devoutly\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "devoutly", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.695298718201588, 5.159422605706}, 0.0671614011006787],
          "\"wished\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "wished", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.680466111177356, 4.323724513250884}, 0.0671614011006787],
          
          "\"perchance\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "perchance", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.206798706605325, 4.90774208128364}, 0.0671614011006787],
          "\"dream\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "dream", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.675345357070372, 4.293765451513408}, 0.0671614011006787],
          
          "\"ay\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ay", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.13325201850692, 3.4705962415449187`}, 0.0671614011006787],
          "\"there's\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "there's", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.925422516164995, 3.8582226359729974`}, 
           0.0671614011006787],
          "\"rub\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "rub", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.891140571291999, 4.968355810483028}, 0.0671614011006787],
          
          "\"for\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "for", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.796026848482926, 1.7062555617036526`}, 
           0.0671614011006787],
          "\"death\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "death", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.446321277322538, 1.2174262978896673`}, 
           0.0671614011006787],
          "\"what\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "what", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3160526084108604`, 1.1980820422353382`}, 
           0.0671614011006787],
          "\"dreams\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "dreams", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.6154733953574305`, 1.7591322299095886`}, 
           0.0671614011006787],
          "\"may\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "may", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.6931406440614536`, 2.695751802275926}, 
           0.0671614011006787],
          "\"come\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "come", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.45407440591467, 3.5443193983421604`}, 0.0671614011006787],
          "\"when\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "when", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6288226862142787`, 5.657686662444817}, 
           0.0671614011006787],
          "\"have\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "have", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8079812768542913`, 5.989046134050012}, 
           0.0671614011006787],
          "\"shuffled\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "shuffled", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.5187514305719745`, 5.415251232349086}, 
           0.0671614011006787],
          "\"off\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "off", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9299990400042604`, 4.510512987538155}, 
           0.0671614011006787],
          "\"this\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "this", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.1529574440084636`, 5.023240898193836}, 
           0.0671614011006787],
          "\"mortal\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "mortal", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.169495017650989, 5.396620499412995}, 0.0671614011006787],
          
          "\"coil\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "coil", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.980731030250757, 4.986759551041008}, 0.0671614011006787],
          
          "\"must\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "must", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.060621435050115, 4.31500895867023}, 0.0671614011006787],
          "\"give\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "give", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.449561272304643, 3.520266952943572}, 0.0671614011006787],
          
          "\"us\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "us", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.471200009198261, 3.3870320741437476`}, 
           0.0671614011006787],
          "\"pause\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "pause", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.963610244309773, 3.245357425500012}, 0.0671614011006787],
          
          "\"respect\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "respect", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.312192751389908, 3.0435685384444895`}, 
           0.0671614011006787],
          "\"makes\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "makes", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.753617205980725, 2.4729716342105608`}, 
           0.0671614011006787],
          "\"calamity\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "calamity", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.002298394063732, 3.4098321596759864`}, 
           0.0671614011006787],
          "\"so\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "so", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.202651453608485, 4.567954790128944}, 0.0671614011006787],
          
          "\"long\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "long", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.977546584833777, 5.197029475364527}, 0.0671614011006787],
          
          "\"life\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "life", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.947161646168591, 6.051042700403976}, 0.0671614011006787],
          
          "\"who\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "who", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.26636373614346, 5.819694128776073}, 0.0671614011006787],
          "\"would\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "would", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.89930780378373, 4.701592886595449}, 0.0671614011006787],
          "\"bear\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "bear", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.464544283974497, 2.1945822199367875`}, 
           0.0671614011006787],
          "\"whips\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "whips", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.220139122449318, 1.7409562234406712`}, 
           0.0671614011006787],
          "\"scorns\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "scorns", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.396302111625927, 1.6373636934441265`}, 
           0.0671614011006787],
          "\"time\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "time", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.013040421168215, 1.748199624349427}, 0.0671614011006787],
          
          "\"th\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "th", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.452798597957239, 1.309594443009607}, 0.0671614011006787],
          
          "\"oppressor's\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "oppressor's", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.33083723607252, 1.8884017019808517`}, 0.0671614011006787],
          "\"wrong\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "wrong", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.0695677079762005`, 1.8146192212669432`}, 
           0.0671614011006787],
          "\"proud\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "proud", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.596775138087475, 1.3322534760009694`}, 
           0.0671614011006787],
          "\"man's\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "man's", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.172374012041844, 1.9319868236665776`}, 
           0.0671614011006787],
          "\"contumely\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "contumely", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.7620041263555235`, 2.1625496290693884`}, 
           0.0671614011006787],
          "\"pangs\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "pangs", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.758984688507607, 1.3264778022381596`}, 
           0.0671614011006787],
          "\"despised\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "despised", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.341914635783516, 1.659046465587535}, 0.0671614011006787],
          
          "\"love\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "love", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.102680457458591, 2.3536134892290037`}, 
           0.0671614011006787],
          "\"law's\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "law's", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.159022836775451, 2.5419960638956365`}, 
           0.0671614011006787],
          "\"delay\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "delay", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.69083098185932, 2.339703306228457}, 0.0671614011006787],
          "\"insolence\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "insolence", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.617187236769821, 1.7671687549154562`}, 
           0.0671614011006787],
          "\"office\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "office", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.130726954147874, 3.3336715680211895`}, 
           0.0671614011006787],
          "\"spurns\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "spurns", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.7749747634798165`, 3.3918375125656066`}, 
           0.0671614011006787],
          "\"patient\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "patient", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.490754035169181, 2.6627511962915187`}, 
           0.0671614011006787],
          "\"merit\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "merit", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8639000019213623`, 1.954244002756251}, 
           0.0671614011006787],
          "\"unworthy\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "unworthy", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2770615669776326`, 2.658373552073426}, 
           0.0671614011006787],
          "\"takes\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "takes", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1825030013764017`, 3.3663151869656325`}, 
           0.0671614011006787],
          "\"he\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "he", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.27735827627303067`, 3.088035942564272}, 
           0.0671614011006787],
          "\"himself\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "himself", "Tooltip"]& ], 
        TagBox[
         TooltipBox[DiskBox[{0., 2.6107904872897985`}, 0.0671614011006787],
          "\"might\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "might", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.7247469291682034, 2.430154449302191}, 0.0671614011006787],
          "\"his\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "his", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8363303510303703`, 2.4826883950104817`}, 
           0.0671614011006787],
          "\"quietus\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "quietus", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.222968733438419, 2.7214091399641176`}, 
           0.0671614011006787],
          "\"make\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "make", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.546289871923202, 3.61732029546917}, 0.0671614011006787],
          "\"with\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "with", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.682925364129103, 5.772427006331156}, 0.0671614011006787],
          
          "\"bare\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "bare", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.04409477511401, 6.578491632123912}, 0.0671614011006787],
          "\"bodkin\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "bodkin", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.868024869497765, 5.739404949223662}, 0.0671614011006787],
          
          "\"fardels\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "fardels", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.068823382809269, 3.6725455438520997`}, 
           0.0671614011006787],
          "\"grunt\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "grunt", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.5517742323912715`, 3.0801036532119843`}, 
           0.0671614011006787],
          "\"sweat\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "sweat", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.765110864774691, 3.949728756954839}, 0.0671614011006787],
          
          "\"under\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "under", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.230480715045088, 5.381379358396403}, 0.0671614011006787],
          
          "\"weary\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "weary", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.621638801045103, 4.980415389376189}, 0.0671614011006787],
          
          "\"but\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "but", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.918983033092864, 2.0674227999199486`}, 
           0.0671614011006787],
          "\"dread\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "dread", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.704383287221359, 1.2115043203915121`}, 
           0.0671614011006787],
          "\"something\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "something", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.428536643552565, 0.8200590954572822}, 0.0671614011006787],
          "\"after\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "after", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.654148716612581, 1.8965499836353763`}, 
           0.0671614011006787],
          "\"undiscovered\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "undiscovered", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.76445164424874, 1.2502946328805375`}, 0.0671614011006787],
          "\"country\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "country", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.58940249658448, 0.9387965175642434}, 0.0671614011006787],
          
          "\"from\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "from", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.734166520490977, 1.3643779960224809`}, 
           0.0671614011006787],
          "\"whose\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "whose", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.98931890052565, 1.9002202282593583`}, 0.0671614011006787],
          "\"bourn\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "bourn", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.621552133939062, 2.068374644058318}, 0.0671614011006787],
          
          "\"traveller\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "traveller", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.38120966975411, 1.752782755925895}, 0.0671614011006787],
          "\"returns\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "returns", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.504009024452078, 2.1629783429699647`}, 
           0.0671614011006787],
          "\"puzzles\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "puzzles", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.32019301572723, 2.069203564747613}, 0.0671614011006787],
          "\"will\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "will", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.44190814843869, 4.342511074435499}, 0.0671614011006787],
          "\"rather\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "rather", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.023254778929178, 5.493756404508913}, 0.0671614011006787],
          
          "\"those\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "those", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.246031895088816, 5.424214591161256}, 0.0671614011006787],
          
          "\"ills\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ills", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.303963659925611, 6.196843253483276}, 0.0671614011006787],
          
          "\"than\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "than", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.254529667273825, 5.803055430296668}, 0.0671614011006787],
          
          "\"fly\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "fly", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.7802121303291, 4.832266414015245}, 0.0671614011006787],
          "\"others\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "others", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.5145469846148725`, 4.468921966786718}, 
           0.0671614011006787],
          "\"know\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "know", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.0514551585248615`, 2.271331776722116}, 
           0.0671614011006787],
          "\"thus\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "thus", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.880365913277923, 1.832430416818754}, 0.0671614011006787],
          
          "\"conscience\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "conscience", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1174788294414415`, 1.9844497854644132`}, 
           0.0671614011006787],
          "\"does\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "does", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.9893420353129723`, 2.2858336966018897`}, 
           0.0671614011006787],
          "\"cowards\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "cowards", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.75890206431565, 3.4994116561945963`}, 0.0671614011006787],
          "\"all\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "all", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.14323322020688, 1.6792235001437081`}, 0.0671614011006787],
          "\"native\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "native", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.5657947394892116`, 1.298438916823582}, 
           0.0671614011006787],
          "\"hue\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "hue", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.7712508277371315`, 2.8425805800823154`}, 
           0.0671614011006787],
          "\"resolution\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "resolution", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.171046249811952, 3.785676689398237}, 0.0671614011006787],
          
          "\"sicklied\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "sicklied", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.7296983794714667`, 3.8439652480265396`}, 
           0.0671614011006787],
          "\"o'er\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "o'er", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.504020633767987, 1.758921236664134}, 0.0671614011006787],
          
          "\"pale\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "pale", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.887731672061396, 1.4668978567571904`}, 
           0.0671614011006787],
          "\"cast\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "cast", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.512943286562156, 1.9101442465280285`}, 
           0.0671614011006787],
          "\"thought\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "thought", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.420572132419822, 1.700317648612181}, 0.0671614011006787],
          
          "\"enterprise\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "enterprise", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.014240377922645, 1.2421150035079034`}, 
           0.0671614011006787],
          "\"great\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "great", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.390105874726696, 1.426263137849097}, 0.0671614011006787],
          
          "\"pitch\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "pitch", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.933116858618527, 2.922537675268689}, 0.0671614011006787],
          
          "\"moment\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "moment", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8626026195938934`, 4.490116957521179}, 
           0.0671614011006787],
          "\"regard\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "regard", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2931691969646906`, 4.093548710508397}, 
           0.0671614011006787],
          "\"their\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "their", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.7745054969335254`, 3.490314717872141}, 
           0.0671614011006787],
          "\"currents\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "currents", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.7684549403471252`, 3.010887525480971}, 
           0.0671614011006787],
          "\"turn\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "turn", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.100507303107535, 2.6738460598170963`}, 
           0.0671614011006787],
          "\"awry\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "awry", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.322028968285791, 2.4358715017978447`}, 
           0.0671614011006787],
          "\"lose\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "lose", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.906965752060233, 2.2798688490971397`}, 
           0.0671614011006787],
          "\"name\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "name", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.507814314892514, 0.8432205496601535}, 0.0671614011006787],
          "\"action\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "action", "Tooltip"]& ], 
        TagBox[
         TooltipBox[DiskBox[{5.989414885145423, 0.}, 0.0671614011006787],
          "\"soft\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "soft", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.5648934906022, 0.2678740952569121}, 0.0671614011006787],
          "\"you\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "you", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.599188488022773, 1.3221725309520966`}, 
           0.0671614011006787],
          "\"now\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "now", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.578582817936315, 2.9278725667145253`}, 
           0.0671614011006787],
          "\"fair\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "fair", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.437977541817116, 3.2958624084846737`}, 
           0.0671614011006787],
          "\"ophelia\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ophelia", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.142266809902143, 3.8948361677230077`}, 
           0.0671614011006787],
          "\"nymph\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "nymph", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.876964262235069, 4.724566396534053}, 0.0671614011006787],
          
          "\"thy\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "thy", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.504760351940558, 5.020384341959129}, 0.0671614011006787],
          
          "\"orisons\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "orisons", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.361609050118435, 3.743269980721996}, 0.0671614011006787],
          
          "\"my\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "my", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.595931415834253, 3.9606124169870194`}, 
           0.0671614011006787],
          "\"sins\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "sins", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.44333446695205, 4.109398184268213}, 0.0671614011006787],
          
          "\"remembered\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "remembered", "Tooltip"]& ]}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{3.676283638257061*^9, 3.67680619914435*^9, 
  3.676806290636568*^9}]
}, Open  ]],

Cell["Calculate the DegreeCentrality of the Graph", "ItemNumbered",
 CellChangeTimes->{{3.676281757546769*^9, 3.676281779991562*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"centralities", "=", 
  RowBox[{"DegreeCentrality", "[", "graph", "]"}]}]], "Input",
 CellChangeTimes->{{3.6768062035291853`*^9, 3.676806209621702*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "20", ",", "6", ",", "4", ",", "4", ",", "14", ",", "6", ",", "38", ",", 
   "2", ",", "2", ",", "4", ",", "2", ",", "6", ",", "2", ",", "2", ",", "2", 
   ",", "22", ",", "2", ",", "30", ",", "2", ",", "2", ",", "2", ",", "2", 
   ",", "2", ",", "10", ",", "2", ",", "2", ",", "3", ",", "2", ",", "4", ",",
    "2", ",", "1", ",", "6", ",", "4", ",", "2", ",", "2", ",", "7", ",", "2",
    ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",",
    "2", ",", "2", ",", "2", ",", "2", ",", "3", ",", "2", ",", "4", ",", "4",
    ",", "2", ",", "2", ",", "2", ",", "2", ",", "4", ",", "3", ",", "2", ",",
    "2", ",", "4", ",", "2", ",", "2", ",", "2", ",", "2", ",", "6", ",", "2",
    ",", "2", ",", "4", ",", "2", ",", "2", ",", "2", ",", "4", ",", "3", ",",
    "3", ",", "6", ",", "2", ",", "2", ",", "2", ",", "4", ",", "2", ",", "2",
    ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",",
    "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2",
    ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "4", ",", "6", ",",
    "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2",
    ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",",
    "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2",
    ",", "2", ",", "2", ",", "2", ",", "2", ",", "4", ",", "2", ",", "2", ",",
    "2", ",", "4", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2",
    ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",",
    "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2",
    ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",", "2", ",",
    "2", ",", "2", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{3.6768062100279093`*^9, 3.676806293223041*^9}]
}, Open  ]],

Cell["\<\
Use the function Pick to find those vertices where the DegreeCentrality is \
greater than 2\[LineSeparator]\[LineSeparator]As you have not used Pick \
before, here is a template.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.67628178327747*^9, 3.676281798655952*^9}, {
  3.676281842239648*^9, 3.676281887902157*^9}, {3.676282192099884*^9, 
  3.6762821929761267`*^9}, {3.676282340603826*^9, 3.676282340634357*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Pick", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\"\<apples\>\"", ",", "\"\<oranges\>\"", ",", "\"\<fruits\>\""}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "1"}], "}"}], ",", 
   RowBox[{"q_", "/;", 
    RowBox[{"q", ">", "1"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.676281799947177*^9, 3.676281831068059*^9}, {
  3.676281865214621*^9, 3.676281873503606*^9}}],

Cell[BoxData[
 RowBox[{"{", "\<\"oranges\"\>", "}"}]], "Output",
 CellChangeTimes->{3.676281831584815*^9, 3.676281873811645*^9}]
}, Open  ]],

Cell["Your pick statement is correct if the following yields true:", "Text",
 CellChangeTimes->{{3.6762821960695972`*^9, 3.676282213384268*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"popularWords", "=", 
  RowBox[{"Pick", "[", 
   RowBox[{
    RowBox[{"VertexList", "[", "graph", "]"}], ",", "centralities", ",", 
    RowBox[{"q_", "/;", 
     RowBox[{"q", ">", "2"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.67680621926188*^9, 3.676806248446453*^9}, {
  3.676806303433255*^9, 3.676806306798298*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"to\"\>", ",", "\<\"be\"\>", ",", "\<\"or\"\>", 
   ",", "\<\"not\"\>", ",", "\<\"that\"\>", ",", "\<\"is\"\>", 
   ",", "\<\"the\"\>", ",", "\<\"tis\"\>", ",", "\<\"in\"\>", 
   ",", "\<\"and\"\>", ",", "\<\"of\"\>", ",", "\<\"a\"\>", ",", "\<\"by\"\>",
    ",", "\<\"end\"\>", ",", "\<\"sleep\"\>", ",", "\<\"no\"\>", 
   ",", "\<\"we\"\>", ",", "\<\"there's\"\>", ",", "\<\"for\"\>", 
   ",", "\<\"death\"\>", ",", "\<\"when\"\>", ",", "\<\"have\"\>", 
   ",", "\<\"this\"\>", ",", "\<\"us\"\>", ",", "\<\"makes\"\>", 
   ",", "\<\"life\"\>", ",", "\<\"who\"\>", ",", "\<\"would\"\>", 
   ",", "\<\"bear\"\>", ",", "\<\"th\"\>", ",", "\<\"make\"\>", 
   ",", "\<\"with\"\>", ",", "\<\"thus\"\>", ",", "\<\"all\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.676806235487796*^9, 3.676806248852399*^9}, {
  3.676806296304068*^9, 3.676806307595662*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Length", "[", "popularWords", "]"}], "==", "34"}]], "Input",
 CellChangeTimes->{{3.676282169875874*^9, 3.676282187466092*^9}, {
  3.676283652998109*^9, 3.676283653052513*^9}, {3.676806310410993*^9, 
  3.6768063111387672`*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.6768063114340343`*^9}]
}, Open  ]],

Cell["\<\
Provide this list of vertices to Subgraph, use VertexLabels to label the \
vertices:\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676282310169447*^9, 3.676282338149255*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Subgraph", "[", 
  RowBox[{"graph", ",", 
   RowBox[{"Pick", "[", 
    RowBox[{
     RowBox[{"VertexList", "[", "graph", "]"}], ",", 
     RowBox[{"DegreeCentrality", "[", "graph", "]"}], ",", 
     RowBox[{"q_", "/;", 
      RowBox[{"q", ">", "2"}]}]}], "]"}], ",", 
   RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}]}], "]"}]], "Input",
 CellChangeTimes->{{3.676281936402828*^9, 3.676281952932898*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "to", "be", "or", "not", "that", "is", "the", "tis", "in", "and", "of", 
       "a", "by", "end", "sleep", "no", "we", "there's", "for", "death", 
       "when", "have", "this", "us", "makes", "life", "who", "would", "bear", 
       "th", "make", "with", "thus", "all"}, {
      Null, {{1, 2}, {1, 2}, {1, 2}, {2, 3}, {3, 1}, {3, 4}, {4, 1}, {2, 5}, {
       5, 6}, {6, 7}, {5, 7}, {1, 8}, {9, 7}, {9, 5}, {10, 7}, {10, 7}, {4, 
       11}, {8, 12}, {10, 13}, {10, 13}, {13, 12}, {14, 7}, {1, 15}, {12, 
       15}, {15, 1}, {1, 15}, {15, 1}, {1, 15}, {5, 15}, {15, 11}, {15, 16}, {
       17, 14}, {5, 17}, {18, 7}, {18, 7}, {19, 9}, {11, 20}, {20, 7}, {21, 
       17}, {17, 22}, {17, 22}, {11, 24}, {5, 25}, {10, 25}, {25, 24}, {26, 
       19}, {19, 27}, {27, 28}, {27, 28}, {28, 29}, {29, 7}, {29, 1}, {11, 
       30}, {31, 32}, {32, 12}, {32, 7}, {32, 23}, {11, 33}, {10, 33}, {33, 
       7}, {24, 34}, {34, 10}, {2, 34}}}, {VertexLabels -> {"Name"}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{4.228394626748616, 3.701769135544291}, {
          3.9127181086562244`, 3.556162093756411}, {3.5722385064922793`, 
          3.6263526572794857`}}], 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.228394626748616, 3.701769135544291}, {
          3.5722385064922793`, 3.6263526572794857`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{4.228394626748616, 3.701769135544291}, {
          3.887915024584672, 3.77195969908481}, {3.5722385064922793`, 
          3.6263526572794857`}}], 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.228394626748616, 3.701769135544291}, {4.071594755762311,
           4.412088859107598}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.228394626748616, 3.701769135544291}, {4.708726149590516,
           4.300820372378637}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.228394626748616, 3.701769135544291}, {5.191292732807838,
           2.9946533397773276`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{4.228394626748616, 3.701769135544291}, {
          4.578597261470727, 3.3464026115432026`}, {4.649504433520395, 
          2.8525408650067865`}}], 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{4.228394626748616, 3.701769135544291}, {
          4.508950014938497, 3.3118663866489224`}, {4.649504433520395, 
          2.8525408650067865`}}], 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.228394626748616, 3.701769135544291}, {4.649504433520395,
           2.8525408650067865`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{4.228394626748616, 3.701769135544291}, {
          4.368949045330522, 3.2424436138767416`}, {4.649504433520395, 
          2.8525408650067865`}}], 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{4.228394626748616, 3.701769135544291}, {
          4.299301798798288, 3.207907389011452}, {4.649504433520395, 
          2.8525408650067865`}}], 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.228394626748616, 3.701769135544291}, {
          3.0072693039627576`, 3.3514823167104972`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.5722385064922793`, 3.6263526572794857`}, {
          4.071594755762311, 4.412088859107598}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.5722385064922793`, 3.6263526572794857`}, {
          3.0945005266543637`, 2.4570272920732124`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.5722385064922793`, 3.6263526572794857`}, {
          3.8925470849543067`, 3.113449954132411}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.071594755762311, 4.412088859107598}, {4.708726149590516,
           4.300820372378637}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.708726149590516, 4.300820372378637}, {4.919882038272117,
           3.4244330791519655`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.0945005266543637`, 2.4570272920732124`}, {
          2.768714147465027, 1.9006501119436503`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.0945005266543637`, 2.4570272920732124`}, {
          3.444814566236289, 2.0160820067879013`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.0945005266543637`, 2.4570272920732124`}, {
          2.1843950245252604`, 2.6325357868164088`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.0945005266543637`, 2.4570272920732124`}, {
          4.649504433520395, 2.8525408650067865`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.0945005266543637`, 2.4570272920732124`}, {
          1.912165931704945, 1.3543939543838224`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.0945005266543637`, 2.4570272920732124`}, {
          3.6845401369294377`, 2.710903307278967}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.768714147465027, 1.9006501119436503`}, {
          3.444814566236289, 2.0160820067879013`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.444814566236289, 2.0160820067879013`}, {
          2.1843950245252604`, 2.6325357868164088`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{3.444814566236289, 2.0160820067879013`}, {
          3.7471009295089233`, 2.1933575263099536`}, {4.095601479185056, 
          2.156601273439133}}], 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{3.444814566236289, 2.0160820067879013`}, {
          3.7933151159124185`, 1.9793257539061655`}, {4.095601479185056, 
          2.156601273439133}}], 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.444814566236289, 2.0160820067879013`}, {
          2.5780448368329134`, 1.3033155966126786`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{3.444814566236289, 2.0160820067879013`}, {
          3.5520725428652797`, 1.4831172607553256`}, {3.3220451483822018`, 
          0.9905291043297446}}], 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{3.444814566236289, 2.0160820067879013`}, {
          3.2147871717532137`, 1.5234938503622242`}, {3.3220451483822018`, 
          0.9905291043297446}}], 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.444814566236289, 2.0160820067879013`}, {
          4.514506006636999, 2.4520785110385193`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.444814566236289, 2.0160820067879013`}, {
          3.0072693039627576`, 3.3514823167104972`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.444814566236289, 2.0160820067879013`}, {
          4.651360382986695, 0.9994704489665622}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.444814566236289, 2.0160820067879013`}, {
          4.224681601895672, 2.612283131250621}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.191292732807838, 2.9946533397773276`}, {
          5.133769703907241, 1.9996922533505928`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.1843950245252604`, 2.6325357868164088`}, {
          0.9567092535658617, 3.3000503289300376`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{4.095601479185056, 2.156601273439133}, {
          4.591384049523234, 1.9902171087442764`}, {4.891624957236198, 
          1.5620355530357233`}}], 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{4.095601479185056, 2.156601273439133}, {
          4.395842386898043, 1.7284197177281135`}, {4.891624957236198, 
          1.5620355530357233`}}], 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.095601479185056, 2.156601273439133}, {
          3.6845401369294377`, 2.710903307278967}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.095601479185056, 2.156601273439133}, {4.224681601895672,
           2.612283131250621}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.095601479185056, 2.156601273439133}, {
          3.8925470849543067`, 3.113449954132411}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.919882038272117, 3.4244330791519655`}, {
          4.649504433520395, 2.8525408650067865`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.919882038272117, 3.4244330791519655`}, {
          4.514506006636999, 2.4520785110385193`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.919882038272117, 3.4244330791519655`}, {
          4.312289747908043, 3.3413078085662207`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.919882038272117, 3.4244330791519655`}, {
          5.80722550304775, 4.112038528571511}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.919882038272117, 3.4244330791519655`}, {
          4.224681601895672, 2.612283131250621}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.133769703907241, 1.9996922533505928`}, {
          4.891624957236198, 1.5620355530357233`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.133769703907241, 1.9996922533505928`}, {
          4.649504433520395, 2.8525408650067865`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.133769703907241, 1.9996922533505928`}, {
          4.651360382986695, 0.9994704489665622}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.5780448368329134`, 1.3033155966126786`}, {
          1.912165931704945, 1.3543939543838224`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.649504433520395, 2.8525408650067865`}, {
          5.816446151116269, 2.9174113721642843`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.912165931704945, 1.3543939543838224`}, {
          1.3163863706462595`, 0.5326708942619809}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{1.912165931704945, 1.3543939543838224`}, {
          1.5088260100916613`, 1.0108201049021064`}, {0.9802904129240333, 
          0.9737228686008137}}], 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{1.912165931704945, 1.3543939543838224`}, {
          1.3836303345373309`, 1.3172967180816475`}, {0.9802904129240333, 
          0.9737228686008137}}], 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{0.9567092535658617, 3.3000503289300376`}, {0., 
          3.525151240501687}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{0.9567092535658617, 3.3000503289300376`}, {
          1.020739240045796, 4.062273507633368}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.392571285092079, 0.2741832297390774}, {
          4.651360382986695, 0.9994704489665622}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.312289747908043, 3.3413078085662207`}, {
          3.6845401369294377`, 2.710903307278967}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.312289747908043, 3.3413078085662207`}, {
          3.8925470849543067`, 3.113449954132411}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{1.020739240045796, 4.062273507633368}, {
          1.481128507694788, 4.167070155612452}, {1.913847797480433, 
          3.978139926579606}}], 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{1.020739240045796, 4.062273507633368}, {
          1.453458529831461, 3.873343278596625}, {1.913847797480433, 
          3.978139926579606}}], 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.913847797480433, 3.978139926579606}, {
          3.0072693039627576`, 3.3514823167104972`}}, 0.04752232632345273]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.906410837217059, 0.}, {4.651360382986695, 
          0.9994704489665622}}, 0.04752232632345273]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {
         DiskBox[{4.228394626748616, 3.701769135544291}, 0.04752232632345273],
          InsetBox["\<\"to\"\>", 
          Offset[{2, 2}, {4.275916953072069, 3.7492914618677435`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.5722385064922793`, 3.6263526572794857`}, 
          0.04752232632345273], 
         InsetBox["\<\"be\"\>", 
          Offset[{2, 2}, {3.619760832815732, 3.6738749836029383`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.071594755762311, 4.412088859107598}, 0.04752232632345273],
          InsetBox["\<\"or\"\>", 
          Offset[{2, 2}, {4.119117082085763, 4.459611185431051}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.708726149590516, 4.300820372378637}, 0.04752232632345273],
          InsetBox["\<\"not\"\>", 
          Offset[{2, 2}, {4.756248475913969, 4.34834269870209}], ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.0945005266543637`, 2.4570272920732124`}, 
          0.04752232632345273], 
         InsetBox["\<\"that\"\>", 
          Offset[{2, 2}, {3.1420228529778162`, 2.504549618396665}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.768714147465027, 1.9006501119436503`}, 
          0.04752232632345273], 
         InsetBox["\<\"is\"\>", 
          Offset[{2, 2}, {2.8162364737884795`, 1.948172438267103}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.444814566236289, 2.0160820067879013`}, 
          0.04752232632345273], 
         InsetBox["\<\"the\"\>", 
          Offset[{2, 2}, {3.4923368925597416`, 2.063604333111354}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{5.191292732807838, 2.9946533397773276`}, 
          0.04752232632345273], 
         InsetBox["\<\"tis\"\>", 
          Offset[{2, 2}, {5.238815059131291, 3.04217566610078}], ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.1843950245252604`, 2.6325357868164088`}, 
          0.04752232632345273], 
         InsetBox["\<\"in\"\>", 
          Offset[{2, 2}, {2.231917350848713, 2.6800581131398613`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.095601479185056, 2.156601273439133}, 0.04752232632345273],
          InsetBox["\<\"and\"\>", 
          Offset[{2, 2}, {4.143123805508509, 2.2041235997625854`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.919882038272117, 3.4244330791519655`}, 
          0.04752232632345273], 
         InsetBox["\<\"of\"\>", 
          Offset[{2, 2}, {4.96740436459557, 3.471955405475418}], ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{5.133769703907241, 1.9996922533505928`}, 
          0.04752232632345273], 
         InsetBox["\<\"a\"\>", 
          Offset[{2, 2}, {5.1812920302306935`, 2.0472145796740455`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.891624957236198, 1.5620355530357233`}, 
          0.04752232632345273], 
         InsetBox["\<\"by\"\>", 
          Offset[{2, 2}, {4.939147283559651, 1.609557879359176}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.5780448368329134`, 1.3033155966126786`}, 
          0.04752232632345273], 
         InsetBox["\<\"end\"\>", 
          Offset[{2, 2}, {2.625567163156366, 1.3508379229361314`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.649504433520395, 2.8525408650067865`}, 
          0.04752232632345273], 
         InsetBox["\<\"sleep\"\>", 
          Offset[{2, 2}, {4.6970267598438475`, 2.900063191330239}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{5.816446151116269, 2.9174113721642843`}, 
          0.04752232632345273], 
         InsetBox["\<\"no\"\>", 
          Offset[{2, 2}, {5.863968477439721, 2.964933698487737}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.912165931704945, 1.3543939543838224`}, 
          0.04752232632345273], 
         InsetBox["\<\"we\"\>", 
          Offset[{2, 2}, {1.9596882580283979`, 1.4019162807072751`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.3220451483822018`, 0.9905291043297446}, 
          0.04752232632345273], 
         InsetBox["\<\"there's\"\>", 
          Offset[{2, 2}, {3.3695674747056543`, 1.0380514306531974`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.9567092535658617, 3.3000503289300376`}, 
          0.04752232632345273], 
         InsetBox["\<\"for\"\>", 
          Offset[{2, 2}, {1.0042315798893144`, 3.34757265525349}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.514506006636999, 2.4520785110385193`}, 
          0.04752232632345273], 
         InsetBox["\<\"death\"\>", 
          Offset[{2, 2}, {4.562028332960452, 2.499600837361972}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.3163863706462595`, 0.5326708942619809}, 
          0.04752232632345273], 
         InsetBox["\<\"when\"\>", 
          Offset[{2, 2}, {1.3639086969697123`, 0.5801932205854337}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.9802904129240333, 0.9737228686008137}, 
          0.04752232632345273], 
         InsetBox["\<\"have\"\>", 
          Offset[{2, 2}, {1.027812739247486, 1.0212451949242665`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{5.392571285092079, 0.2741832297390774}, 
          0.04752232632345273], 
         InsetBox["\<\"this\"\>", 
          Offset[{2, 2}, {5.440093611415532, 0.3217055560625301}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.312289747908043, 3.3413078085662207`}, 
          0.04752232632345273], 
         InsetBox["\<\"us\"\>", 
          Offset[{2, 2}, {4.359812074231495, 3.388830134889673}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.6845401369294377`, 2.710903307278967}, 
          0.04752232632345273], 
         InsetBox["\<\"makes\"\>", 
          Offset[{2, 2}, {3.7320624632528903`, 2.7584256336024193`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0., 3.525151240501687}, 0.04752232632345273], 
         InsetBox["\<\"life\"\>", 
          Offset[{2, 2}, {0.04752232632345273, 3.5726735668251397`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.020739240045796, 4.062273507633368}, 0.04752232632345273],
          InsetBox["\<\"who\"\>", 
          Offset[{2, 2}, {1.0682615663692487`, 4.10979583395682}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.913847797480433, 3.978139926579606}, 0.04752232632345273],
          InsetBox["\<\"would\"\>", 
          Offset[{2, 2}, {1.9613701238038859`, 4.025662252903059}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.0072693039627576`, 3.3514823167104972`}, 
          0.04752232632345273], 
         InsetBox["\<\"bear\"\>", 
          Offset[{2, 2}, {3.05479163028621, 3.39900464303395}], ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{5.80722550304775, 4.112038528571511}, 0.04752232632345273], 
         InsetBox["\<\"th\"\>", 
          Offset[{2, 2}, {5.8547478293712025`, 4.159560854894964}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.906410837217059, 0.}, 0.04752232632345273], 
         InsetBox["\<\"make\"\>", 
          Offset[{2, 2}, {4.953933163540512, 0.04752232632345273}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.651360382986695, 0.9994704489665622}, 
          0.04752232632345273], 
         InsetBox["\<\"with\"\>", 
          Offset[{2, 2}, {4.698882709310148, 1.046992775290015}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{4.224681601895672, 2.612283131250621}, 0.04752232632345273],
          InsetBox["\<\"thus\"\>", 
          Offset[{2, 2}, {4.272203928219125, 2.6598054575740737`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{3.8925470849543067`, 3.113449954132411}, 
          0.04752232632345273], 
         InsetBox["\<\"all\"\>", 
          Offset[{2, 2}, {3.9400694112777592`, 3.1609722804558635`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None,
  ImageSize->{571.8203125, Automatic}]], "Output",
 CellChangeTimes->{{3.6762819416299*^9, 3.676281953539311*^9}, 
   3.676282083050136*^9, 3.6762823446177607`*^9, 3.676283666614028*^9, 
   3.676806318574932*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Always question whether...", "Section",
 CellChangeTimes->{{3.6761107633014383`*^9, 3.676110769096087*^9}, {
   3.6761156799717283`*^9, 3.676115682532858*^9}, {3.6761157161495457`*^9, 
   3.676115721492573*^9}, {3.676116110625745*^9, 3.676116114387026*^9}, {
   3.676202752888332*^9, 3.676202757098895*^9}, {3.67628141267354*^9, 
   3.676281445860187*^9}, {3.676282130414431*^9, 3.676282135318386*^9}, {
   3.676282366838748*^9, 3.67628236971758*^9}, 3.676283770372684*^9}],

Cell["\<\
When we created our concordances the line breaks were not taken into account, \
which is why \[OpenCurlyDoubleQuote]question whether\[CloseCurlyDoubleQuote] \
are connected. Let\[CloseCurlyQuote]s correct for this by formalising our \
concordance processing.\
\>", "Text",
 CellChangeTimes->{{3.676282371561941*^9, 3.676282422524746*^9}, 
   3.676283761823452*^9}],

Cell["\<\
Split the imported string at line breaks (represented by EndOfLine)\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676282512887595*^9, 3.676282549012657*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"toBeSplit", "=", 
  RowBox[{"StringSplit", "[", 
   RowBox[{"toBeOrNotToBe", ",", "EndOfLine"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.676282523045363*^9, 3.676282534538631*^9}, {
  3.676282827020461*^9, 3.676282829064727*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"To be, or not to be--that is the question: \"\>", 
   ",", "\<\"\\nWhether 'tis nobler in the mind to suffer \"\>", 
   ",", "\<\"\\nThe slings and arrows of outrageous fortune \"\>", 
   ",", "\<\"\\nOr to take arms against a sea of troubles \"\>", 
   ",", "\<\"\\nAnd by opposing end them. To die, to sleep-- \"\>", 
   ",", "\<\"\\nNo more--and by a sleep to say we end \"\>", 
   ",", "\<\"\\nThe heartache, and the thousand natural shocks \"\>", 
   ",", "\<\"\\nThat flesh is heir to. 'Tis a consummation \"\>", 
   ",", "\<\"\\nDevoutly to be wished. To die, to sleep-- \"\>", 
   ",", "\<\"\\nTo sleep--perchance to dream: ay, there's the rub, \"\>", 
   ",", "\<\"\\nFor in that sleep of death what dreams may come \"\>", 
   ",", "\<\"\\nWhen we have shuffled off this mortal coil, \"\>", 
   ",", "\<\"\\nMust give us pause. There's the respect \"\>", 
   ",", "\<\"\\nThat makes calamity of so long life. \"\>", 
   ",", "\<\"\\nFor who would bear the whips and scorns of time, \"\>", 
   ",", "\<\"\\nTh' oppressor's wrong, the proud man's contumely \"\>", 
   ",", "\<\"\\nThe pangs of despised love, the law's delay, \"\>", 
   ",", "\<\"\\nThe insolence of office, and the spurns \"\>", 
   ",", "\<\"\\nThat patient merit of th' unworthy takes, \"\>", 
   ",", "\<\"\\nWhen he himself might his quietus make \"\>", 
   ",", "\<\"\\nWith a bare bodkin? Who would fardels bear, \"\>", 
   ",", "\<\"\\nTo grunt and sweat under a weary life, \"\>", 
   ",", "\<\"\\nBut that the dread of something after death, \"\>", 
   ",", "\<\"\\nThe undiscovered country, from whose bourn \"\>", 
   ",", "\<\"\\nNo traveller returns, puzzles the will, \"\>", 
   ",", "\<\"\\nAnd makes us rather bear those ills we have \"\>", 
   ",", "\<\"\\nThan fly to others that we know not of? \"\>", 
   ",", "\<\"\\nThus conscience does make cowards of us all, \"\>", 
   ",", "\<\"\\nAnd thus the native hue of resolution \"\>", 
   ",", "\<\"\\nIs sicklied o'er with the pale cast of thought, \"\>", 
   ",", "\<\"\\nAnd enterprise of great pitch and moment \"\>", 
   ",", "\<\"\\nWith this regard their currents turn awry \"\>", 
   ",", "\<\"\\nAnd lose the name of action. -- Soft you now, \"\>", 
   ",", "\<\"\\nThe fair Ophelia! -- Nymph, in thy orisons \"\>", 
   ",", "\<\"\\nBe all my sins remembered. \"\>", ",", "\<\"\\n\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.67628253492314*^9, 3.676282829679162*^9, 
  3.676806338022056*^9}]
}, Open  ]],

Cell["\<\
Write your steps for partitioning strings into three word concordances into a \
function.\[LineSeparator]\[LineSeparator]Applying your function to the string \
below should provide the output shown:\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676282831821476*^9, 3.676282862623252*^9}, {
  3.676283148463279*^9, 3.676283164423374*^9}, {3.676283210818132*^9, 
  3.676283236236271*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "testString", "=", "\"\<Or to take arms against a sea of troubles\>\""}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.676283237918741*^9, 3.676283249091297*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"concordances", "[", "text_", "]"}], ":=", 
  RowBox[{"UndirectedEdge", "@@@", 
   RowBox[{"Partition", "[", 
    RowBox[{
     RowBox[{"Flatten", "@", 
      RowBox[{"TextWords", "[", "text", "]"}]}], ",", "2", ",", "1"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.6762831656889544`*^9, 3.676283202395583*^9}, {
  3.676283257241579*^9, 3.676283267710822*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"concordances", "[", "testString", "]"}]], "Input",
 CellChangeTimes->{{3.676283250628187*^9, 3.676283253153345*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\"Or\"\>", "\[UndirectedEdge]", "\<\"to\"\>"}], ",", 
   RowBox[{"\<\"to\"\>", "\[UndirectedEdge]", "\<\"take\"\>"}], ",", 
   RowBox[{"\<\"take\"\>", "\[UndirectedEdge]", "\<\"arms\"\>"}], ",", 
   RowBox[{"\<\"arms\"\>", "\[UndirectedEdge]", "\<\"against\"\>"}], ",", 
   RowBox[{"\<\"against\"\>", "\[UndirectedEdge]", "\<\"a\"\>"}], ",", 
   RowBox[{"\<\"a\"\>", "\[UndirectedEdge]", "\<\"sea\"\>"}], ",", 
   RowBox[{"\<\"sea\"\>", "\[UndirectedEdge]", "\<\"of\"\>"}], ",", 
   RowBox[{"\<\"of\"\>", "\[UndirectedEdge]", "\<\"troubles\"\>"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.6762832534598*^9, 3.676283269165546*^9}, 
   3.676806344094243*^9}]
}, Open  ]],

Cell["\<\
Map your function across the split strings from step 1 and generate the \
resultant graph.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676283278937501*^9, 3.676283305648048*^9}, {
  3.676283343200768*^9, 3.676283344053247*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{
   RowBox[{"Flatten", "[", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"concordances", "[", "#", "]"}], "&"}], ",", "toBeSplit"}], 
     "]"}], "]"}], ",", 
   RowBox[{"VertexLabels", "\[Rule]", 
    RowBox[{"Placed", "[", 
     RowBox[{"\"\<Name\>\"", ",", "Tooltip"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.676283346160471*^9, 3.6762833622462463`*^9}, {
  3.676806350533105*^9, 3.676806360022266*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "To", "be", "or", "not", "to", "that", "is", "the", "question", 
       "Whether", "tis", "nobler", "in", "mind", "suffer", "The", "slings", 
       "and", "arrows", "of", "outrageous", "fortune", "Or", "take", "arms", 
       "against", "a", "sea", "troubles", "And", "by", "opposing", "end", 
       "them", "die", "sleep", "No", "more", "say", "we", "heartache", 
       "thousand", "natural", "shocks", "That", "flesh", "heir", "Tis", 
       "consummation", "Devoutly", "wished", "perchance", "dream", "ay", 
       "there's", "rub", "For", "death", "what", "dreams", "may", "come", 
       "When", "have", "shuffled", "off", "this", "mortal", "coil", "Must", 
       "give", "us", "pause", "There's", "respect", "makes", "calamity", "so",
        "long", "life", "who", "would", "bear", "whips", "scorns", "time", 
       "Th", "oppressor's", "wrong", "proud", "man's", "contumely", "pangs", 
       "despised", "love", "law's", "delay", "insolence", "office", "spurns", 
       "patient", "merit", "th", "unworthy", "takes", "he", "himself", 
       "might", "his", "quietus", "make", "With", "bare", "bodkin", "Who", 
       "fardels", "grunt", "sweat", "under", "weary", "But", "dread", 
       "something", "after", "undiscovered", "country", "from", "whose", 
       "bourn", "traveller", "returns", "puzzles", "will", "rather", "those", 
       "ills", "Than", "fly", "others", "know", "Thus", "conscience", "does", 
       "cowards", "all", "thus", "native", "hue", "resolution", "Is", 
       "sicklied", "o'er", "with", "pale", "cast", "thought", "enterprise", 
       "great", "pitch", "moment", "regard", "their", "currents", "turn", 
       "awry", "lose", "name", "action", "Soft", "you", "now", "fair", 
       "Ophelia", "Nymph", "thy", "orisons", "Be", "my", "sins", 
       "remembered"}, {Null, CompressedData["
1:eJwtjnk7VHEYhueM+Z15i6Pj51U4mjEcHDQoWwZZRjk0tjOUJUsjS7axk30L
IYx9CVmyZSn6Yn2DzHX1x309f93XcxtsdsWmVqlUf+9wLqNWu7hoNISo1Syr
1QLcu+/q6ubGcQDu7oQ84D08KPX0RPTyeviIEG9vHx9fX0Hw80N8rNPr/f0N
hoAAhgkMJEQMCg6mVK8XBFEkJCREkgx8aCilAGFh4eFPjBERWm1kJCFRUYLw
9JnzMTr6v8mIYkwMIbGxcXHx8QDPEziOZUUR0WRKTExKSk5+kSJJqalpaenp
ZnNGxstXmZmynJWVnQ3w2mix5OQg5ubm5eUnFBQoitUKUFhIaVER4pu3xcUl
JQClpWVl7/jycsSKispKgKqq97zNhlhd7ez7YKypqa1FrKurr/+Y0tDQ2NjU
1Nzc0mJvFYS2tvb2jg5F6ey0Ml1dlHZ39/QIQm9v/ieWBejrQ+zvHxgw8YOD
Q0PDwyMjo0FjY+PjExMAn3UWiyxPTlqtU1PT03f9X2ZmCJmdZVlJmpvTaPDr
/PzCgt2+uIgoyw7d0hLA8vLKCuLq2vr6xsbmJsDW1vY24jfdzg7i7u7eHqXf
W83m/f2Dg8PDo6MfuuNjgJMTxNPTs7Pz85/8xcXl5dUVx11f//rtcNzc3N7+
+QdSMIL7
       "]}, {VertexLabels -> {
         Placed["Name", Tooltip]}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
        {Arrowheads[0.], 
         ArrowBox[{{9.103255099621435, 7.707138816279929}, {9.548148034515542,
           7.9502510841124225`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.103255099621435, 7.707138816279929}, {8.30059370614353, 
          7.751685863838761}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{9.103255099621435, 7.707138816279929}, {
          8.921098612937522, 7.994385568383593}, {8.944999783876376, 
          8.333679564703159}}], 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{9.103255099621435, 7.707138816279929}, {
          9.127156270560295, 8.046432813520237}, {8.944999783876376, 
          8.333679564703159}}], 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.103255099621435, 7.707138816279929}, {9.547803412016215,
           7.0713924741957666`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.103255099621435, 7.707138816279929}, {9.013072175851601,
           8.046366301371783}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.103255099621435, 7.707138816279929}, {9.79081185185367, 
          7.326075112455934}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.548148034515542, 7.9502510841124225`}, {
          9.523208113653439, 7.43886602336983}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{9.548148034515542, 7.9502510841124225`}, {
          9.464686655027279, 8.05016228906137}, {9.456821343218067, 
          8.180109160574709}}], 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{9.548148034515542, 7.9502510841124225`}, {
          9.540282722706337, 8.080197953489455}, {9.456821343218067, 
          8.180109160574709}}], 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.548148034515542, 7.9502510841124225`}, {
          10.310977484855057`, 8.03879855956404}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.548148034515542, 7.9502510841124225`}, {
          9.013072175851601, 8.046366301371783}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.523208113653439, 7.43886602336983}, {9.73793136910731, 
          6.8641546222888845`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.73793136910731, 6.8641546222888845`}, {
          9.456821343218067, 8.180109160574709}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.73793136910731, 6.8641546222888845`}, {
          10.409057318059384`, 5.371224053303143}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.73793136910731, 6.8641546222888845`}, {
          8.968919246163216, 7.257587170791093}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.456821343218067, 8.180109160574709}, {
          10.710381916748277`, 8.01752037989992}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.456821343218067, 8.180109160574709}, {9.04834412785207, 
          8.921363494968093}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.456821343218067, 8.180109160574709}, {9.206480254355805,
           8.98674474667033}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.456821343218067, 8.180109160574709}, {8.41744974858365, 
          8.539180891618386}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{9.456821343218067, 8.180109160574709}, {
          9.175657331547173, 8.172730043797516}, {8.944999783876376, 
          8.333679564703159}}], 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{9.456821343218067, 8.180109160574709}, {
          9.226163795547302, 8.341058683204977}, {8.944999783876376, 
          8.333679564703159}}], 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{9.456821343218067, 8.180109160574709}, {
          9.68463057793968, 7.640711976503005}, {9.547803412016215, 
          7.0713924741957666`}}], 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.456821343218067, 8.180109160574709}, {9.547803412016215,
           7.0713924741957666`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{9.456821343218067, 8.180109160574709}, {
          9.319994177294607, 7.610789657932659}, {9.547803412016215, 
          7.0713924741957666`}}], 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.456821343218067, 8.180109160574709}, {8.698036360487519,
           8.31847900859136}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.456821343218067, 8.180109160574709}, {
          10.282954255732498`, 7.89366209541239}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.456821343218067, 8.180109160574709}, {8.650842238398937,
           7.642406056583927}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.456821343218067, 8.180109160574709}, {8.899268616624093,
           8.806055829061808}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.456821343218067, 8.180109160574709}, {9.37835961598487, 
          7.676817898817486}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.456821343218067, 8.180109160574709}, {10.12237924195556,
           8.831625522720485}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.456821343218067, 8.180109160574709}, {9.787284988462446,
           9.042909102540214}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.456821343218067, 8.180109160574709}, {9.87627896727397, 
          8.457136551091256}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.310977484855057`, 8.03879855956404}, {
          11.07174733070027, 7.500821638013301}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.310977484855057`, 8.03879855956404}, {
          11.870988152327815`, 7.640377432783642}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.310977484855057`, 8.03879855956404}, {
          11.274307029896246`, 9.205990669319686}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.310977484855057`, 8.03879855956404}, {
          9.547803412016215, 7.0713924741957666`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.310977484855057`, 8.03879855956404}, {
          8.566827515101894, 7.78804478224071}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.310977484855057`, 8.03879855956404}, {
          10.461361810462106`, 8.726834336934118}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.310977484855057`, 8.03879855956404}, {9.87627896727397,
           8.457136551091256}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.07174733070027, 7.500821638013301}, {
          11.870988152327815`, 7.640377432783642}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.07174733070027, 7.500821638013301}, {11.6229251852152, 
          6.503983938423509}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.07174733070027, 7.500821638013301}, {
          10.282954255732498`, 7.89366209541239}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.870988152327815`, 7.640377432783642}, {
          12.308996202459346`, 8.11284216942302}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.870988152327815`, 7.640377432783642}, {
          11.274307029896246`, 9.205990669319686}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.870988152327815`, 7.640377432783642}, {
          10.710381916748277`, 8.01752037989992}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{11.870988152327815`, 7.640377432783642}, {
          11.282863209829356`, 6.993491683347604}, {10.425580450560762`, 
          6.8219737786381645`}}], 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{11.870988152327815`, 7.640377432783642}, {
          11.013705393059197`, 7.468859528030123}, {10.425580450560762`, 
          6.8219737786381645`}}], 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.870988152327815`, 7.640377432783642}, {
          13.20821585039699, 7.602074946040826}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.870988152327815`, 7.640377432783642}, {
          11.586287554662041`, 8.474775491294881}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.870988152327815`, 7.640377432783642}, {
          12.56580071017355, 7.463952968697414}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.870988152327815`, 7.640377432783642}, {
          12.572837525721086`, 6.8636107257811965`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.870988152327815`, 7.640377432783642}, {
          12.635444654549136`, 7.665860946491847}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.870988152327815`, 7.640377432783642}, {
          11.308257648063725`, 8.236689128136373}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.870988152327815`, 7.640377432783642}, {
          11.205269895481765`, 7.266188567641537}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.870988152327815`, 7.640377432783642}, {
          13.084042665961196`, 8.208391909463678}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.870988152327815`, 7.640377432783642}, {
          13.18090253688952, 7.901601395489401}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.870988152327815`, 7.640377432783642}, {
          11.916636864504232`, 6.597257058500031}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.870988152327815`, 7.640377432783642}, {
          12.818519904257068`, 8.167989207586924}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.870988152327815`, 7.640377432783642}, {
          12.49196982028485, 7.969344947928953}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.870988152327815`, 7.640377432783642}, {
          11.173007888097368`, 6.483491850044572}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.870988152327815`, 7.640377432783642}, {
          12.506612115664538`, 8.494961609964587}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.870988152327815`, 7.640377432783642}, {
          12.456293974244659`, 7.764376010834037}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.870988152327815`, 7.640377432783642}, {
          11.405454729450673`, 7.053814280337016}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.870988152327815`, 7.640377432783642}, {
          11.631825080348014`, 6.745307685507932}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.870988152327815`, 7.640377432783642}, {
          13.035146026052459`, 8.559702993175753}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.870988152327815`, 7.640377432783642}, {
          11.81390707952556, 6.7107470132206135`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.870988152327815`, 7.640377432783642}, {
          11.515245150610674`, 6.980014800055065}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.870988152327815`, 7.640377432783642}, {
          11.268773679822916`, 6.4190683068165555`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{12.180738448729082`, 12.180090211423877`}, {
          11.986087370846748`, 11.478663745380583`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.986087370846748`, 11.478663745380583`}, {
          11.684127932309423`, 10.474051741176577`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.684127932309423`, 10.474051741176577`}, {
          11.274307029896246`, 9.205990669319686}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.274307029896246`, 9.205990669319686}, {
          11.355172520553342`, 9.98250637412534}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.274307029896246`, 9.205990669319686}, {
          10.434980611160888`, 9.575006777399098}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.274307029896246`, 9.205990669319686}, {
          11.60665717363537, 10.246735513080278`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.906590718311545, 6.92634618885349}, {9.633046248308068, 
          6.6968327013137126`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.906590718311545, 6.92634618885349}, {9.588447754977913, 
          6.874149301134241}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.906590718311545, 6.92634618885349}, {9.474803527340338, 
          5.944319071902276}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.906590718311545, 6.92634618885349}, {9.561683041944, 
          6.0344204463941375`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.906590718311545, 6.92634618885349}, {
          7.4778356905086545`, 7.531783335513408}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.906590718311545, 6.92634618885349}, {9.08878637437824, 
          8.158060045452213}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.633046248308068, 6.6968327013137126`}, {
          10.425580450560762`, 6.8219737786381645`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.425580450560762`, 6.8219737786381645`}, {
          10.53808813273033, 5.977333273369301}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.425580450560762`, 6.8219737786381645`}, {
          9.46786056140256, 6.7056626570549955`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.425580450560762`, 6.8219737786381645`}, {
          11.241852409681465`, 7.766451261999067}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.425580450560762`, 6.8219737786381645`}, {
          9.588447754977913, 6.874149301134241}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.425580450560762`, 6.8219737786381645`}, {
          11.205269895481765`, 7.266188567641537}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.425580450560762`, 6.8219737786381645`}, {
          10.302395855179812`, 5.969711545623706}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.425580450560762`, 6.8219737786381645`}, {
          10.412112012107363`, 6.042251930087083}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.425580450560762`, 6.8219737786381645`}, {
          9.79081185185367, 7.326075112455934}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.425580450560762`, 6.8219737786381645`}, {
          9.415456108747563, 6.489261218703254}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.425580450560762`, 6.8219737786381645`}, {
          10.088255223072997`, 6.0268876420533495`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.425580450560762`, 6.8219737786381645`}, {
          10.4536155172092, 6.510906866865291}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.53808813273033, 5.977333273369301}, {
          10.409057318059384`, 5.371224053303143}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          10.24318470841649, 4.310531874608834}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          9.166021947249522, 6.022200859823701}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          10.429976276575633`, 4.680705294305587}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          9.547803412016215, 7.0713924741957666`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          10.942694419886111`, 3.884605675673969}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          12.170790899558124`, 5.478018793435984}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          11.103583893923798`, 5.155818361309484}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          9.363940070368962, 4.910792423099599}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          10.302395855179812`, 5.969711545623706}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          10.639816536351809`, 4.715576323590314}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          9.474803527340338, 5.944319071902276}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          11.33799552705614, 5.769238668245194}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {9.561683041944, 
          6.0344204463941375`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          10.412112012107363`, 6.042251930087083}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          11.206148592356147`, 4.858242603119676}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          10.551155389417406`, 4.088668648618445}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          11.173007888097368`, 6.483491850044572}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          10.831090965483996`, 4.378930141827382}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          9.150415959525336, 4.170880521990956}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          11.112043564936863`, 5.942087060145317}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          10.21565958962099, 4.693106342769363}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          11.266457591308328`, 5.907044095540138}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          10.016847165915133`, 4.77373934943342}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          10.770428806060472`, 5.653990727823567}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          10.002569711454472`, 5.373202854056284}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          11.268773679822916`, 6.4190683068165555`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.409057318059384`, 5.371224053303143}, {
          10.224146404287923`, 3.937989850076885}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.24318470841649, 4.310531874608834}, {10.15488755517358,
           3.546612210317514}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.41744974858365, 8.539180891618386}, {7.668153433332304, 
          8.394428738316929}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.668153433332304, 8.394428738316929}, {7.643851376405765,
           7.697370986734574}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.643851376405765, 7.697370986734574}, {8.20461351932465, 
          6.971944340643568}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.20461351932465, 6.971944340643568}, {9.166021947249522, 
          6.022200859823701}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.20461351932465, 6.971944340643568}, {9.46786056140256, 
          6.7056626570549955`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.20461351932465, 6.971944340643568}, {9.547803412016215, 
          7.0713924741957666`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.20461351932465, 6.971944340643568}, {8.650842238398937, 
          7.642406056583927}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.20461351932465, 6.971944340643568}, {7.489629072374479, 
          6.728038818442648}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.20461351932465, 6.971944340643568}, {6.41910343826969, 
          7.206697353945304}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.20461351932465, 6.971944340643568}, {8.195695755781692, 
          8.166182243003933}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.20461351932465, 6.971944340643568}, {8.571396918787203, 
          6.477090014667616}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.20461351932465, 6.971944340643568}, {7.746612601273715, 
          6.062785435316854}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.830339351375507`, 6.398618190019119}, {
          9.46786056140256, 6.7056626570549955`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.830339351375507`, 6.398618190019119}, {
          11.524817523343625`, 5.615305421191337}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.830339351375507`, 6.398618190019119}, {
          11.405454729450673`, 7.053814280337016}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.830339351375507`, 6.398618190019119}, {
          10.770428806060472`, 5.653990727823567}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.830339351375507`, 6.398618190019119}, {
          11.515245150610674`, 6.980014800055065}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.46786056140256, 6.7056626570549955`}, {
          8.589793808618477, 6.89519463647273}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.589793808618477, 6.89519463647273}, {8.151627925921739, 
          7.407632113372706}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.151627925921739, 7.407632113372706}, {8.30059370614353, 
          7.751685863838761}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.151627925921739, 7.407632113372706}, {8.566827515101894,
           7.78804478224071}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.547803412016215, 7.0713924741957666`}, {
          9.37835961598487, 7.676817898817486}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.963864978377933`, 8.59809529654711}, {
          11.241852409681465`, 7.766451261999067}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.963864978377933`, 8.59809529654711}, {
          12.53754492657071, 9.192656639811105}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.698036360487519, 8.31847900859136}, {8.566827515101894, 
          7.78804478224071}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.566827515101894, 7.78804478224071}, {7.397015186899203, 
          6.945022109973101}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{8.566827515101894, 7.78804478224071}, {
          7.867625283898024, 7.647122920276966}, {7.221269508551219, 
          7.948730186443482}}], 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[BezierCurveBox[{{8.566827515101894, 7.78804478224071}, {
          7.920471739755052, 8.089652048320055}, {7.221269508551219, 
          7.948730186443482}}], 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.566827515101894, 7.78804478224071}, {9.38156707218457, 
          8.385542059841741}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.566827515101894, 7.78804478224071}, {8.968919246163216, 
          7.257587170791093}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{13.20821585039699, 7.602074946040826}, {
          14.284671349368228`, 7.608295998055004}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{14.284671349368228`, 7.608295998055004}, {
          15.044465254295712`, 7.6421305833183615`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.919357589430895`, 5.613909194755063}, {
          11.6229251852152, 6.503983938423509}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.919357589430895`, 5.613909194755063}, {
          11.524817523343625`, 5.615305421191337}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.919357589430895`, 5.613909194755063}, {
          11.871098046704525`, 4.905525021653482}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.12237924195556, 8.831625522720485}, {
          10.928926565689832`, 8.93400492331488}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.928926565689832`, 8.93400492331488}, {
          11.586287554662041`, 8.474775491294881}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.355172520553342`, 9.98250637412534}, {
          10.999898843629593`, 10.09478130605388}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.942694419886111`, 3.884605675673969}, {
          11.395368602504684`, 2.600361998086793}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.942694419886111`, 3.884605675673969}, {
          11.111674155906401`, 3.6723272864710843`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.395368602504684`, 2.600361998086793}, {
          11.765827769503252`, 1.5085851832349828`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.765827769503252`, 1.5085851832349828`}, {
          12.06318058238678, 0.6266100829938095}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{12.06318058238678, 0.6266100829938095}, {
          12.271877096203115`, 0.}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.397015186899203, 6.945022109973101}, {6.540750393282857,
           6.007376918168658}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.221269508551219, 7.948730186443482}, {6.109697231511433,
           7.937314295602747}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.109697231511433, 7.937314295602747}, {5.26302163030597, 
          7.80192727721005}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.26302163030597, 7.80192727721005}, {4.7905022303340115`,
           7.4679044963048895`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.7905022303340115`, 7.4679044963048895`}, {
          3.8946080391020823`, 7.439394629203244}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.7905022303340115`, 7.4679044963048895`}, {
          6.41910343826969, 7.206697353945304}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.7905022303340115`, 7.4679044963048895`}, {
          3.4808959097618235`, 7.642972083807428}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.8946080391020823`, 7.439394629203244}, {
          3.235283175304362, 7.395877016011976}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{13.752603009888373`, 4.657068565370909}, {
          13.083645920041414`, 4.97642449348111}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{13.083645920041414`, 4.97642449348111}, {
          12.170790899558124`, 5.478018793435984}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{12.170790899558124`, 5.478018793435984}, {
          12.734345310972525`, 6.046510186896855}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{12.170790899558124`, 5.478018793435984}, {
          11.524817523343625`, 5.615305421191337}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{12.170790899558124`, 5.478018793435984}, {
          11.929987278206262`, 6.8957141957406645`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{12.170790899558124`, 5.478018793435984}, {
          13.409116067039113`, 4.521783064931835}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{12.734345310972525`, 6.046510186896855}, {
          12.572837525721086`, 6.8636107257811965`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.524817523343625`, 5.615305421191337}, {
          11.103583893923798`, 5.155818361309484}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.363940070368962, 4.910792423099599}, {8.432740692269846,
           4.825065562433241}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.432740692269846, 4.825065562433241}, {7.798071653232464,
           5.25298189149115}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.798071653232464, 5.25298189149115}, {7.746612601273715, 
          6.062785435316854}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.999898843629593`, 10.09478130605388}, {
          10.779381718287537`, 9.327045691612376}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.779381718287537`, 9.327045691612376}, {
          11.308257648063725`, 8.236689128136373}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.779381718287537`, 9.327045691612376}, {
          9.695969243406848, 9.585767825466256}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.779381718287537`, 9.327045691612376}, {
          11.276781806474924`, 9.015619438713518}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.308257648063725`, 8.236689128136373}, {
          11.276781806474924`, 9.015619438713518}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.308257648063725`, 8.236689128136373}, {
          11.929987278206262`, 6.8957141957406645`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.308257648063725`, 8.236689128136373}, {
          10.365841683313942`, 8.48962910224684}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{14.704385695022875`, 9.044720882989743}, {
          14.035901145260574`, 8.701026408422113}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{14.035901145260574`, 8.701026408422113}, {
          13.084042665961196`, 8.208391909463678}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{13.18090253688952, 7.901601395489401}, {14.22747210226064,
           8.149412202509122}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{14.22747210226064, 8.149412202509122}, {
          14.961984636484452`, 8.34903693445027}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.33799552705614, 5.769238668245194}, {
          11.916636864504232`, 6.597257058500031}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{12.818519904257068`, 8.167989207586924}, {
          13.508512631537307`, 8.559797980581834}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.871098046704525`, 4.905525021653482}, {
          11.206148592356147`, 4.858242603119676}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.551155389417406`, 4.088668648618445}, {
          10.665569635013844`, 3.058225484406317}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.665569635013844`, 3.058225484406317}, {
          10.750081993013469`, 2.340456930768129}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.540750393282857, 6.007376918168658}, {6.00296029950947, 
          5.062214231864507}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.00296029950947, 5.062214231864507}, {5.859147555710652, 
          4.157939271481103}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.859147555710652, 4.157939271481103}, {6.203008444289601,
           3.4324585313129825`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.203008444289601, 3.4324585313129825`}, {
          6.968250299240962, 3.098536779216451}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.968250299240962, 3.098536779216451}, {
          7.9404626415975175`, 3.1681584829974163`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.9404626415975175`, 3.1681584829974163`}, {
          7.327348455629201, 2.2048827535217876`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.9404626415975175`, 3.1681584829974163`}, {
          9.150415959525336, 4.170880521990956}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.195695755781692, 8.166182243003933}, {8.719182955038688,
           9.161183043285266}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{8.719182955038688, 9.161183043285266}, {9.695969243406848,
           9.585767825466256}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.415456108747563, 6.489261218703254}, {8.571396918787203,
           6.477090014667616}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.831090965483996`, 4.378930141827382}, {
          11.111674155906401`, 3.6723272864710843`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{7.4778356905086545`, 7.531783335513408}, {
          6.294669144699663, 8.18914115066276}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.294669144699663, 8.18914115066276}, {5.29550316603098, 
          8.756726672147671}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{5.29550316603098, 8.756726672147671}, {4.502707242931401, 
          9.238720910800728}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{4.502707242931401, 9.238720910800728}, {3.941051916626801,
           9.587656086609645}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{12.53754492657071, 9.192656639811105}, {
          12.907056464618881`, 9.142476771272765}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{12.907056464618881`, 9.142476771272765}, {
          12.506612115664538`, 8.494961609964587}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.365841683313942`, 8.48962910224684}, {9.38156707218457,
           8.385542059841741}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.349916624922745`, 9.367889791908791}, {
          9.787284988462446, 9.042909102540214}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.4497117328482325`, 0.8949119818257554}, {
          6.818378912664407, 1.437624157433702}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{6.818378912664407, 1.437624157433702}, {7.327348455629201,
           2.2048827535217876`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{13.409116067039113`, 4.521783064931835}, {
          13.964861156659117`, 4.070260213140347}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{13.409116067039113`, 4.521783064931835}, {
          14.36893887246821, 3.8210746832759606`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.631825080348014`, 6.745307685507932}, {
          11.112043564936863`, 5.942087060145317}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{15.393097245271834`, 10.372700616073253`}, {
          14.82275226722954, 9.949573778622126}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{14.82275226722954, 9.949573778622126}, {
          14.018775032388698`, 9.340519166544697}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{14.018775032388698`, 9.340519166544697}, {
          13.035146026052459`, 8.559702993175753}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.81390707952556, 6.7107470132206135`}, {
          11.266457591308328`, 5.907044095540138}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.002569711454472`, 5.373202854056284}, {
          10.088255223072997`, 6.0268876420533495`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{3.4808959097618235`, 7.642972083807428}, {
          2.3266695230708363`, 7.772293313074241}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{2.3266695230708363`, 7.772293313074241}, {
          1.3467512295939859`, 7.881899730590119}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.3467512295939859`, 7.881899730590119}, {
          0.5527963311486985, 7.9721746959582145`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{0.5527963311486985, 7.9721746959582145`}, {0., 
          8.035112275884993}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.224146404287923`, 3.937989850076885}, {
          10.109188387710658`, 2.7157638280293757`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.109188387710658`, 2.7157638280293757`}, {
          10.040555328750806`, 1.7349441479575214`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{10.040555328750806`, 1.7349441479575214`}, {
          9.996696389128322, 1.0376274398170207`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.08878637437824, 8.158060045452213}, {9.599973726399346, 
          9.142176531444392}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{9.599973726399346, 9.142176531444392}, {
          10.434980611160888`, 9.575006777399098}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{11.60665717363537, 10.246735513080278`}, {
          11.79347740485192, 11.00216910599722}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{14.36893887246821, 3.8210746832759606`}, {
          15.137852363201878`, 3.2682617716743843`}}, 0.08193540278690878]}, 
        {Arrowheads[0.], 
         ArrowBox[{{15.137852363201878`, 3.2682617716743843`}, {
          15.683851251459835`, 2.877707613869084}}, 0.08193540278690878]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
        TagBox[
         TooltipBox[
          DiskBox[{9.103255099621435, 7.707138816279929}, 0.08193540278690878],
          "\"To\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "To", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.548148034515542, 7.9502510841124225`}, 
           0.08193540278690878],
          "\"be\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "be", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.523208113653439, 7.43886602336983}, 0.08193540278690878],
          
          "\"or\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "or", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.73793136910731, 6.8641546222888845`}, 
           0.08193540278690878],
          "\"not\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "not", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.456821343218067, 8.180109160574709}, 0.08193540278690878],
          "\"to\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "to", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.310977484855057`, 8.03879855956404}, 
           0.08193540278690878],
          "\"that\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "that", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.07174733070027, 7.500821638013301}, 0.08193540278690878],
          "\"is\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "is", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.870988152327815`, 7.640377432783642}, 
           0.08193540278690878],
          "\"the\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "the", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{12.308996202459346`, 8.11284216942302}, 
           0.08193540278690878],
          "\"question\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "question", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{12.180738448729082`, 12.180090211423877`}, 
           0.08193540278690878],
          "\"Whether\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "Whether", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.986087370846748`, 11.478663745380583`}, 
           0.08193540278690878],
          "\"tis\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "tis", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.684127932309423`, 10.474051741176577`}, 
           0.08193540278690878],
          "\"nobler\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "nobler", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.274307029896246`, 9.205990669319686}, 
           0.08193540278690878],
          "\"in\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "in", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.710381916748277`, 8.01752037989992}, 
           0.08193540278690878],
          "\"mind\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "mind", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.04834412785207, 8.921363494968093}, 0.08193540278690878],
          
          "\"suffer\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "suffer", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.906590718311545, 6.92634618885349}, 0.08193540278690878],
          
          "\"The\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "The", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.633046248308068, 6.6968327013137126`}, 
           0.08193540278690878],
          "\"slings\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "slings", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.425580450560762`, 6.8219737786381645`}, 
           0.08193540278690878],
          "\"and\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "and", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.53808813273033, 5.977333273369301}, 0.08193540278690878],
          "\"arrows\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "arrows", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.409057318059384`, 5.371224053303143}, 
           0.08193540278690878],
          "\"of\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "of", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.24318470841649, 4.310531874608834}, 0.08193540278690878],
          "\"outrageous\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "outrageous", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.15488755517358, 3.546612210317514}, 0.08193540278690878],
          "\"fortune\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "fortune", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.206480254355805, 8.98674474667033}, 0.08193540278690878],
          
          "\"Or\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "Or", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.41744974858365, 8.539180891618386}, 0.08193540278690878],
          
          "\"take\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "take", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.668153433332304, 8.394428738316929}, 0.08193540278690878],
          "\"arms\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "arms", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.643851376405765, 7.697370986734574}, 0.08193540278690878],
          "\"against\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "against", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.20461351932465, 6.971944340643568}, 0.08193540278690878],
          
          "\"a\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "a", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.166021947249522, 6.022200859823701}, 0.08193540278690878],
          "\"sea\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "sea", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.429976276575633`, 4.680705294305587}, 
           0.08193540278690878],
          "\"troubles\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "troubles", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.830339351375507`, 6.398618190019119}, 
           0.08193540278690878],
          "\"And\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "And", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.46786056140256, 6.7056626570549955`}, 
           0.08193540278690878],
          "\"by\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "by", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.589793808618477, 6.89519463647273}, 0.08193540278690878],
          
          "\"opposing\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "opposing", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.151627925921739, 7.407632113372706}, 0.08193540278690878],
          "\"end\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "end", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.30059370614353, 7.751685863838761}, 0.08193540278690878],
          
          "\"them\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "them", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.944999783876376, 8.333679564703159}, 0.08193540278690878],
          "\"die\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "die", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.547803412016215, 7.0713924741957666`}, 
           0.08193540278690878],
          "\"sleep\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "sleep", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.963864978377933`, 8.59809529654711}, 
           0.08193540278690878],
          "\"No\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "No", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.241852409681465`, 7.766451261999067}, 
           0.08193540278690878],
          "\"more\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "more", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.698036360487519, 8.31847900859136}, 0.08193540278690878],
          
          "\"say\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "say", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.566827515101894, 7.78804478224071}, 0.08193540278690878],
          
          "\"we\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "we", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.588447754977913, 6.874149301134241}, 0.08193540278690878],
          "\"heartache\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "heartache", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{13.20821585039699, 7.602074946040826}, 0.08193540278690878],
          "\"thousand\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "thousand", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{14.284671349368228`, 7.608295998055004}, 
           0.08193540278690878],
          "\"natural\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "natural", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{15.044465254295712`, 7.6421305833183615`}, 
           0.08193540278690878],
          "\"shocks\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "shocks", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.919357589430895`, 5.613909194755063}, 
           0.08193540278690878],
          "\"That\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "That", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.6229251852152, 6.503983938423509}, 0.08193540278690878],
          
          "\"flesh\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "flesh", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.282954255732498`, 7.89366209541239}, 
           0.08193540278690878],
          "\"heir\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "heir", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.650842238398937, 7.642406056583927}, 0.08193540278690878],
          "\"Tis\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "Tis", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.489629072374479, 6.728038818442648}, 0.08193540278690878],
          "\"consummation\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "consummation", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.899268616624093, 8.806055829061808}, 0.08193540278690878],
          "\"Devoutly\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "Devoutly", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.013072175851601, 8.046366301371783}, 0.08193540278690878],
          "\"wished\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "wished", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.37835961598487, 7.676817898817486}, 0.08193540278690878],
          
          "\"perchance\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "perchance", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.12237924195556, 8.831625522720485}, 0.08193540278690878],
          "\"dream\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "dream", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.928926565689832`, 8.93400492331488}, 
           0.08193540278690878],
          "\"ay\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ay", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.586287554662041`, 8.474775491294881}, 
           0.08193540278690878],
          "\"there's\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "there's", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{12.56580071017355, 7.463952968697414}, 0.08193540278690878],
          "\"rub\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "rub", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.355172520553342`, 9.98250637412534}, 
           0.08193540278690878],
          "\"For\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "For", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.942694419886111`, 3.884605675673969}, 
           0.08193540278690878],
          "\"death\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "death", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.395368602504684`, 2.600361998086793}, 
           0.08193540278690878],
          "\"what\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "what", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.765827769503252`, 1.5085851832349828`}, 
           0.08193540278690878],
          "\"dreams\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "dreams", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{12.06318058238678, 0.6266100829938095}, 
           0.08193540278690878],
          "\"may\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "may", "Tooltip"]& ], 
        TagBox[
         TooltipBox[DiskBox[{12.271877096203115`, 0.}, 0.08193540278690878],
          "\"come\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "come", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.397015186899203, 6.945022109973101}, 0.08193540278690878],
          "\"When\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "When", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.221269508551219, 7.948730186443482}, 0.08193540278690878],
          "\"have\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "have", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.109697231511433, 7.937314295602747}, 0.08193540278690878],
          "\"shuffled\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "shuffled", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.26302163030597, 7.80192727721005}, 0.08193540278690878],
          "\"off\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "off", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.7905022303340115`, 7.4679044963048895`}, 
           0.08193540278690878],
          "\"this\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "this", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8946080391020823`, 7.439394629203244}, 
           0.08193540278690878],
          "\"mortal\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "mortal", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.235283175304362, 7.395877016011976}, 0.08193540278690878],
          "\"coil\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "coil", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{13.752603009888373`, 4.657068565370909}, 
           0.08193540278690878],
          "\"Must\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "Must", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{13.083645920041414`, 4.97642449348111}, 
           0.08193540278690878],
          "\"give\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "give", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{12.170790899558124`, 5.478018793435984}, 
           0.08193540278690878],
          "\"us\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "us", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{12.734345310972525`, 6.046510186896855}, 
           0.08193540278690878],
          "\"pause\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "pause", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{12.572837525721086`, 6.8636107257811965`}, 
           0.08193540278690878],
          "\"There's\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "There's", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{12.635444654549136`, 7.665860946491847}, 
           0.08193540278690878],
          "\"respect\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "respect", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.524817523343625`, 5.615305421191337}, 
           0.08193540278690878],
          "\"makes\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "makes", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.103583893923798`, 5.155818361309484}, 
           0.08193540278690878],
          "\"calamity\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "calamity", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.363940070368962, 4.910792423099599}, 0.08193540278690878],
          "\"so\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "so", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.432740692269846, 4.825065562433241}, 0.08193540278690878],
          "\"long\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "long", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.798071653232464, 5.25298189149115}, 0.08193540278690878],
          
          "\"life\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "life", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.999898843629593`, 10.09478130605388}, 
           0.08193540278690878],
          "\"who\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "who", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.779381718287537`, 9.327045691612376}, 
           0.08193540278690878],
          "\"would\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "would", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.308257648063725`, 8.236689128136373}, 
           0.08193540278690878],
          "\"bear\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "bear", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.205269895481765`, 7.266188567641537}, 
           0.08193540278690878],
          "\"whips\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "whips", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.302395855179812`, 5.969711545623706}, 
           0.08193540278690878],
          "\"scorns\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "scorns", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.639816536351809`, 4.715576323590314}, 
           0.08193540278690878],
          "\"time\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "time", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{14.704385695022875`, 9.044720882989743}, 
           0.08193540278690878],
          "\"Th\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "Th", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{14.035901145260574`, 8.701026408422113}, 
           0.08193540278690878],
          "\"oppressor's\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "oppressor's", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{13.084042665961196`, 8.208391909463678}, 
           0.08193540278690878],
          "\"wrong\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "wrong", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{13.18090253688952, 7.901601395489401}, 0.08193540278690878],
          "\"proud\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "proud", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{14.22747210226064, 8.149412202509122}, 0.08193540278690878],
          "\"man's\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "man's", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{14.961984636484452`, 8.34903693445027}, 
           0.08193540278690878],
          "\"contumely\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "contumely", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.474803527340338, 5.944319071902276}, 0.08193540278690878],
          "\"pangs\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "pangs", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.33799552705614, 5.769238668245194}, 0.08193540278690878],
          "\"despised\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "despised", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.916636864504232`, 6.597257058500031}, 
           0.08193540278690878],
          "\"love\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "love", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{12.818519904257068`, 8.167989207586924}, 
           0.08193540278690878],
          "\"law's\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "law's", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{13.508512631537307`, 8.559797980581834}, 
           0.08193540278690878],
          "\"delay\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "delay", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.561683041944, 6.0344204463941375`}, 0.08193540278690878],
          
          "\"insolence\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "insolence", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.412112012107363`, 6.042251930087083}, 
           0.08193540278690878],
          "\"office\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "office", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{12.49196982028485, 7.969344947928953}, 0.08193540278690878],
          "\"spurns\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "spurns", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.871098046704525`, 4.905525021653482}, 
           0.08193540278690878],
          "\"patient\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "patient", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.206148592356147`, 4.858242603119676}, 
           0.08193540278690878],
          "\"merit\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "merit", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.551155389417406`, 4.088668648618445}, 
           0.08193540278690878],
          "\"th\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "th", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.665569635013844`, 3.058225484406317}, 
           0.08193540278690878],
          "\"unworthy\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "unworthy", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.750081993013469`, 2.340456930768129}, 
           0.08193540278690878],
          "\"takes\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "takes", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.540750393282857, 6.007376918168658}, 0.08193540278690878],
          "\"he\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "he", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.00296029950947, 5.062214231864507}, 0.08193540278690878],
          
          "\"himself\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "himself", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.859147555710652, 4.157939271481103}, 0.08193540278690878],
          "\"might\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "might", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.203008444289601, 3.4324585313129825`}, 
           0.08193540278690878],
          "\"his\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "his", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.968250299240962, 3.098536779216451}, 0.08193540278690878],
          "\"quietus\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "quietus", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.9404626415975175`, 3.1681584829974163`}, 
           0.08193540278690878],
          "\"make\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "make", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.41910343826969, 7.206697353945304}, 0.08193540278690878],
          
          "\"With\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "With", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.195695755781692, 8.166182243003933}, 0.08193540278690878],
          "\"bare\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "bare", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.719182955038688, 9.161183043285266}, 0.08193540278690878],
          "\"bodkin\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "bodkin", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.695969243406848, 9.585767825466256}, 0.08193540278690878],
          "\"Who\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "Who", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.276781806474924`, 9.015619438713518}, 
           0.08193540278690878],
          "\"fardels\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "fardels", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.79081185185367, 7.326075112455934}, 0.08193540278690878],
          
          "\"grunt\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "grunt", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.415456108747563, 6.489261218703254}, 0.08193540278690878],
          "\"sweat\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "sweat", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.571396918787203, 6.477090014667616}, 0.08193540278690878],
          "\"under\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "under", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.746612601273715, 6.062785435316854}, 0.08193540278690878],
          "\"weary\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "weary", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.461361810462106`, 8.726834336934118}, 
           0.08193540278690878],
          "\"But\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "But", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.173007888097368`, 6.483491850044572}, 
           0.08193540278690878],
          "\"dread\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "dread", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.831090965483996`, 4.378930141827382}, 
           0.08193540278690878],
          "\"something\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "something", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.111674155906401`, 3.6723272864710843`}, 
           0.08193540278690878],
          "\"after\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "after", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.4778356905086545`, 7.531783335513408}, 
           0.08193540278690878],
          "\"undiscovered\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "undiscovered", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.294669144699663, 8.18914115066276}, 0.08193540278690878],
          
          "\"country\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "country", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.29550316603098, 8.756726672147671}, 0.08193540278690878],
          
          "\"from\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "from", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.502707242931401, 9.238720910800728}, 0.08193540278690878],
          "\"whose\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "whose", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.941051916626801, 9.587656086609645}, 0.08193540278690878],
          "\"bourn\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "bourn", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{12.53754492657071, 9.192656639811105}, 0.08193540278690878],
          "\"traveller\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "traveller", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{12.907056464618881`, 9.142476771272765}, 
           0.08193540278690878],
          "\"returns\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "returns", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{12.506612115664538`, 8.494961609964587}, 
           0.08193540278690878],
          "\"puzzles\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "puzzles", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{12.456293974244659`, 7.764376010834037}, 
           0.08193540278690878],
          "\"will\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "will", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.929987278206262`, 6.8957141957406645`}, 
           0.08193540278690878],
          "\"rather\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "rather", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.365841683313942`, 8.48962910224684}, 
           0.08193540278690878],
          "\"those\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "those", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.38156707218457, 8.385542059841741}, 0.08193540278690878],
          
          "\"ills\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ills", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.349916624922745`, 9.367889791908791}, 
           0.08193540278690878],
          "\"Than\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "Than", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.787284988462446, 9.042909102540214}, 0.08193540278690878],
          "\"fly\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "fly", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.87627896727397, 8.457136551091256}, 0.08193540278690878],
          
          "\"others\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "others", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.968919246163216, 7.257587170791093}, 0.08193540278690878],
          "\"know\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "know", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.4497117328482325`, 0.8949119818257554}, 
           0.08193540278690878],
          "\"Thus\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "Thus", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.818378912664407, 1.437624157433702}, 0.08193540278690878],
          "\"conscience\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "conscience", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.327348455629201, 2.2048827535217876`}, 
           0.08193540278690878],
          "\"does\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "does", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.150415959525336, 4.170880521990956}, 0.08193540278690878],
          "\"cowards\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "cowards", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{13.409116067039113`, 4.521783064931835}, 
           0.08193540278690878],
          "\"all\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "all", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.405454729450673`, 7.053814280337016}, 
           0.08193540278690878],
          "\"thus\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "thus", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.631825080348014`, 6.745307685507932}, 
           0.08193540278690878],
          "\"native\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "native", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.112043564936863`, 5.942087060145317}, 
           0.08193540278690878],
          "\"hue\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "hue", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.21565958962099, 4.693106342769363}, 0.08193540278690878],
          "\"resolution\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "resolution", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{15.393097245271834`, 10.372700616073253`}, 
           0.08193540278690878],
          "\"Is\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "Is", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{14.82275226722954, 9.949573778622126}, 0.08193540278690878],
          "\"sicklied\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "sicklied", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{14.018775032388698`, 9.340519166544697}, 
           0.08193540278690878],
          "\"o'er\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "o'er", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{13.035146026052459`, 8.559702993175753}, 
           0.08193540278690878],
          "\"with\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "with", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.81390707952556, 6.7107470132206135`}, 
           0.08193540278690878],
          "\"pale\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "pale", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.266457591308328`, 5.907044095540138}, 
           0.08193540278690878],
          "\"cast\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "cast", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.016847165915133`, 4.77373934943342}, 
           0.08193540278690878],
          "\"thought\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "thought", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.770428806060472`, 5.653990727823567}, 
           0.08193540278690878],
          "\"enterprise\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "enterprise", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.002569711454472`, 5.373202854056284}, 
           0.08193540278690878],
          "\"great\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "great", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.088255223072997`, 6.0268876420533495`}, 
           0.08193540278690878],
          "\"pitch\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "pitch", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.4536155172092, 6.510906866865291}, 0.08193540278690878],
          
          "\"moment\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "moment", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4808959097618235`, 7.642972083807428}, 
           0.08193540278690878],
          "\"regard\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "regard", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3266695230708363`, 7.772293313074241}, 
           0.08193540278690878],
          "\"their\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "their", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3467512295939859`, 7.881899730590119}, 
           0.08193540278690878],
          "\"currents\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "currents", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5527963311486985, 7.9721746959582145`}, 
           0.08193540278690878],
          "\"turn\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "turn", "Tooltip"]& ], 
        TagBox[
         TooltipBox[DiskBox[{0., 8.035112275884993}, 0.08193540278690878],
          "\"awry\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "awry", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.515245150610674`, 6.980014800055065}, 
           0.08193540278690878],
          "\"lose\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "lose", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.268773679822916`, 6.4190683068165555`}, 
           0.08193540278690878],
          "\"name\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "name", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.224146404287923`, 3.937989850076885}, 
           0.08193540278690878],
          "\"action\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "action", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.109188387710658`, 2.7157638280293757`}, 
           0.08193540278690878],
          "\"Soft\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "Soft", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.040555328750806`, 1.7349441479575214`}, 
           0.08193540278690878],
          "\"you\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "you", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.996696389128322, 1.0376274398170207`}, 
           0.08193540278690878],
          "\"now\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "now", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.08878637437824, 8.158060045452213}, 0.08193540278690878],
          
          "\"fair\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "fair", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{9.599973726399346, 9.142176531444392}, 0.08193540278690878],
          "\"Ophelia\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "Ophelia", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{10.434980611160888`, 9.575006777399098}, 
           0.08193540278690878],
          "\"Nymph\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "Nymph", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.60665717363537, 10.246735513080278`}, 
           0.08193540278690878],
          "\"thy\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "thy", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{11.79347740485192, 11.00216910599722}, 0.08193540278690878],
          "\"orisons\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "orisons", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{13.964861156659117`, 4.070260213140347}, 
           0.08193540278690878],
          "\"Be\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "Be", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{14.36893887246821, 3.8210746832759606`}, 
           0.08193540278690878],
          "\"my\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "my", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{15.137852363201878`, 3.2682617716743843`}, 
           0.08193540278690878],
          "\"sins\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "sins", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{15.683851251459835`, 2.877707613869084}, 
           0.08193540278690878],
          "\"remembered\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "remembered", "Tooltip"]& ]}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{{3.6762833558417387`*^9, 3.6762833627104*^9}, {
  3.6768063453007812`*^9, 3.676806360797825*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{840, 1001},
WindowMargins->{{Automatic, 0}, {Automatic, 0}},
FrontEndVersion->"10.4 for Mac OS X x86 (32-bit, 64-bit Kernel) (April 11, \
2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 149, 2, 92, "Title"],
Cell[CellGroupData[{
Cell[754, 28, 356, 5, 64, "Section"],
Cell[1113, 35, 272, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[1410, 44, 310, 7, 63, "Input"],
Cell[1723, 53, 1741, 22, 624, "Output"]
}, Open  ]],
Cell[3479, 78, 430, 7, 49, "ItemNumbered"],
Cell[3912, 87, 204, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[4141, 95, 338, 6, 45, "Item"],
Cell[4482, 103, 494, 8, 79, "Item"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5013, 116, 550, 9, 28, "Input"],
Cell[5566, 127, 6343, 95, 352, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11946, 227, 199, 5, 28, "Input"],
Cell[12148, 234, 294, 5, 28, "Output"]
}, Open  ]],
Cell[12457, 242, 476, 8, 49, "ItemNumbered"],
Cell[CellGroupData[{
Cell[12958, 254, 286, 5, 28, "Input"],
Cell[13247, 261, 22517, 554, 794, "Output"]
}, Open  ]],
Cell[35779, 818, 195, 4, 30, "ItemNumbered"],
Cell[CellGroupData[{
Cell[35999, 826, 173, 3, 28, "Input"],
Cell[36175, 831, 40257, 638, 249, "Output"]
}, Open  ]],
Cell[76447, 1472, 287, 5, 49, "ItemNumbered"]
}, Open  ]],
Cell[CellGroupData[{
Cell[76771, 1482, 389, 5, 64, "Section"],
Cell[77163, 1489, 167, 3, 30, "Text"],
Cell[77333, 1494, 263, 5, 49, "ItemNumbered"],
Cell[CellGroupData[{
Cell[77621, 1503, 394, 9, 28, "Input"],
Cell[78018, 1514, 88684, 2034, 249, "Output"]
}, Open  ]],
Cell[166717, 3551, 133, 1, 30, "ItemNumbered"],
Cell[CellGroupData[{
Cell[166875, 3556, 175, 3, 28, "Input"],
Cell[167053, 3561, 1886, 26, 114, "Output"]
}, Open  ]],
Cell[168954, 3590, 421, 7, 68, "ItemNumbered"],
Cell[CellGroupData[{
Cell[169400, 3601, 419, 11, 28, "Input"],
Cell[169822, 3614, 128, 2, 28, "Output"]
}, Open  ]],
Cell[169965, 3619, 144, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[170134, 3624, 346, 8, 28, "Input"],
Cell[170483, 3634, 899, 15, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[171419, 3654, 261, 5, 28, "Input"],
Cell[171683, 3661, 75, 1, 28, "Output"]
}, Open  ]],
Cell[171773, 3665, 182, 4, 30, "ItemNumbered"],
Cell[CellGroupData[{
Cell[171980, 3673, 432, 10, 46, "Input"],
Cell[172415, 3685, 21912, 426, 459, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[194376, 4117, 479, 6, 64, "Section"],
Cell[194858, 4125, 374, 7, 49, "Text"],
Cell[195235, 4134, 165, 3, 30, "ItemNumbered"],
Cell[CellGroupData[{
Cell[195425, 4141, 254, 5, 28, "Input"],
Cell[195682, 4148, 2492, 39, 624, "Output"]
}, Open  ]],
Cell[198189, 4190, 394, 7, 68, "ItemNumbered"],
Cell[198586, 4199, 196, 5, 28, "Input"],
Cell[198785, 4206, 400, 10, 28, "Input"],
Cell[CellGroupData[{
Cell[199210, 4220, 140, 2, 28, "Input"],
Cell[199353, 4224, 714, 13, 46, "Output"]
}, Open  ]],
Cell[200082, 4240, 237, 5, 30, "ItemNumbered"],
Cell[CellGroupData[{
Cell[200344, 4249, 490, 13, 28, "Input"],
Cell[200837, 4264, 86091, 1994, 298, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

