(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.4' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    466644,      10067]
NotebookOptionsPosition[    451501,       9691]
NotebookOutlinePosition[    461336,       9912]
CellTagsIndexPosition[    461256,       9907]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Prosopographical Networks - Guided Workshop", "Title",
 CellChangeTimes->{
  3.6695419383340187`*^9, {3.6695436273978767`*^9, 3.669543635518165*^9}, {
   3.673077547116518*^9, 3.673077571043455*^9}, {3.673080175394973*^9, 
   3.673080187779351*^9}, {3.673080228269444*^9, 3.673080230384207*^9}, {
   3.6762728255778418`*^9, 3.676272833200596*^9}}],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Prosopographical Networks", "Title",
 CellChangeTimes->{3.676272209036519*^9}],

Cell[TextData[{
 "For this evening\[CloseCurlyQuote]s session I woud like to invite you to \
form into three groups of four to study a dataset from the ",
 ButtonBox["Cultures of Knowledge",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.culturesofknowledge.org/"], None},
  ButtonNote->"http://www.culturesofknowledge.org/"],
 " project, concerning the prosopography of a number of the individuals in \
their dataset."
}], "Text",
 CellChangeTimes->{{3.676272212092185*^9, 3.676272302744831*^9}}],

Cell[TextData[{
 "As I\[CloseCurlyQuote]m not a digital humanities researcher, I will bow to \
Arno Bosse and Robin Buning for an explanation of the topic and data - but I \
can show off what I\[CloseCurlyQuote]ve built for them: ",
 ButtonBox["http://drupal-pilot-livedata.it.ox.ac.uk/article/prosopographical-\
network-samuel-hartlib-ii",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://drupal-pilot-livedata.it.ox.ac.uk/article/prosopographical-\
network-samuel-hartlib-ii"], None},
  ButtonNote->
   "http://drupal-pilot-livedata.it.ox.ac.uk/article/prosopographical-network-\
samuel-hartlib-ii"]
}], "Text",
 CellChangeTimes->{{3.6762723046226587`*^9, 3.676272321116435*^9}, {
  3.676272420254191*^9, 3.6762724362728863`*^9}, {3.676272542251534*^9, 
  3.676272561224519*^9}}],

Cell[TextData[StyleBox["NOTE: Data has been anonymised",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.6778196969034967`*^9, 3.677819705846488*^9}}],

Cell[TextData[StyleBox["\[OpenCurlyDoubleQuote]Prosopography, or collective \
biography, is concerned with identifying patterns of activity and \
connectivity in large quantities of data that may be missed using synthetic \
approaches. It is a potentially useful method for gaining insight into the \
large and sometimes complex networks that constituted the \
\[OpenCurlyQuote]Republic of Letters\[CloseCurlyQuote], the intellectual \
community of 16\[Dash]19th-century Europe. The prosopographical approach \
consists of collecting relevant quantities of biographical data of all \
members of a well-defined group according to pre-selected categories, which \
are then analyzed in different ways.\n\nThe modules included in this \
application aim to provide a powerful and easy-to-use tool for \
prosopographical data visualization and analysis.\n\nThe network of Samuel \
Hartlib was chosen, together with the complementary network of John Amos \
Comenius (1592\[Dash]1670), as case studies, because they represent the \
intricate networks one should be able to unravel with the use of the \
prosopographical tool. The members of these networks were widely dispersed, \
highly mobile, and included some well-known figures, but many more figures \
about whom little is known.\n\nThe conceptual data model underlying the \
prosopographical tool is event-based and person-centred. It was designed to \
facilitate capturing the broad range of relationships and activities typical \
of an early modern intellectual, with a focus on contact and location \
history. The data were originally captured in spreadsheets, each revolving \
around a member of Hartlib\[CloseCurlyQuote]s circle who is entered as the \
\[OpenCurlyQuote]primary participant\[CloseCurlyQuote]. The people and \
organizations connected to the primary participant are entered in his \
spreadsheet as \[OpenCurlyQuote]secondary participants\[CloseCurlyQuote]. To \
date (May 2016) the complete Hartlib dataset contains the prosopographical \
data of 130 people, numbering over 6,000 events in total.\n\nFor these proof \
of concepts a representative subset of eleven spreadsheets was selected, \
combining the most populated spreadsheets and spreadsheets of people who were \
at the centre of Hartlib\[CloseCurlyQuote]s network, and taking into account \
geographical distribution and varying social positions. The selection \
consists of:\n\nJohann Heinrich Alting (1618\[Dash]1679)\nHeinrich Appelius \
(fl. 1628\[Dash]1658)\nNicholas Arnold (1618\[Dash]1680)\nTheodor Haak (1605\
\[Dash]1690)\nGeorg Hartlib (d. 1651)\nSamuel Hartlib (c.1600\[Dash]1662)\n\
Goddofred Hotton (1596\[Dash]1656)\nThomas Roe (1581\[Dash]1644)\nJohann \
Friedrich Schlezer (1610\[Dash]1673)\nCaspar Streso (1603\[Dash]1664)\n\
William Waller (1598\[Dash]1668)\[CloseCurlyDoubleQuote]",
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{
  3.676272202208538*^9, 3.67627243943392*^9, {3.676272475321886*^9, 
   3.676272475824065*^9}, {3.6762725111311197`*^9, 3.67627251892951*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Workshop/Guided Data Exploration", "Title",
 CellChangeTimes->{
  3.676272209036519*^9, {3.676272603484109*^9, 3.676272611829893*^9}}],

Cell["\<\
Please separate into three groups of four to work on these exercises together \
- there are a number of new subjects/functions introduced in this workshop \
and we would like you to build skills together, and learn how to debug.\
\>", "Text",
 CellChangeTimes->{{3.676194546120261*^9, 3.6761945747074757`*^9}, {
  3.676195321913344*^9, 3.6761953772770042`*^9}}],

Cell["\<\
We will be wandering out to help you with your code and will take the \
opportunity at times to speak to the entire workshop on a particular subject.

Please consider the following advice before starting:\
\>", "Text",
 CellChangeTimes->{{3.6761953788182487`*^9, 3.67619542114191*^9}, {
  3.6761964287166433`*^9, 3.676196468507123*^9}}],

Cell[CellGroupData[{

Cell["Save regularly", "Item",
 CellChangeTimes->{{3.676196474885923*^9, 3.676196477164884*^9}}],

Cell["\<\
Write an explanation of what your code does, the best explanations are \
written as text cells - but comments can easily be included in code.\
\>", "Item",
 CellChangeTimes->{{3.676196474885923*^9, 3.67619651078575*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"2", "+", "2"}], "<", "5"}], 
    RowBox[{"(*", 
     RowBox[{"the", " ", "test"}], "*)"}], ",", "\[IndentingNewLine]", 
    "\"\<Truth\>\"", ",", 
    RowBox[{"(*", 
     RowBox[{
     "return", " ", "if", " ", "the", " ", "test", " ", "yields", " ", 
      "true"}], "*)"}], ",", "\[IndentingNewLine]", "\"\<False\>\""}], 
   RowBox[{"(*", 
    RowBox[{
    "return", " ", "if", " ", "the", " ", "test", " ", "yields", " ", 
     "false"}], "*)"}], "\[IndentingNewLine]", "]"}], " "}]], "Input",
 CellChangeTimes->{{3.6761965159464283`*^9, 3.676196529245915*^9}, {
  3.676196603486597*^9, 3.676196631634961*^9}, {3.6761966669057617`*^9, 
  3.67619668460151*^9}}],

Cell["\<\
Try things together and insolation, but work together on understanding and \
fixing each other\[CloseCurlyQuote]s code. Learning to program requires that \
you learn how other people approach a problem\
\>", "Item",
 CellChangeTimes->{{3.676196701692339*^9, 3.676196742832221*^9}, {
  3.676272645209642*^9, 3.676272691323285*^9}, {3.676272785094593*^9, 
  3.6762728006307373`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Data Import", "Title",
 CellChangeTimes->{{3.676198782006147*^9, 3.67619878343435*^9}}],

Cell["\<\
The dataset you\[CloseCurlyQuote]ll be working with is provided in a \
subfolder of the folder where this notebook is stored, the folders look like \
this:

thisFolder/
------------- thisNotebook.nb
------------- /data
--------------------- master_life _events _sheet.csv\
\>", "Text",
 CellChangeTimes->{{3.676195432122506*^9, 3.6761955375101147`*^9}}],

Cell["\<\
Mathematica has a \[OpenCurlyDoubleQuote]working directory\
\[CloseCurlyDoubleQuote] where it looks for files for importing - this is \
modified using the function SetDirectory.\
\>", "Text",
 CellChangeTimes->{{3.676195543378767*^9, 3.676195578735024*^9}}],

Cell["\<\
Use the functions NotebookDirectory and SetDirectory to change the current \
working directory to the \[OpenCurlyDoubleQuote]data\[CloseCurlyDoubleQuote] \
folder of the file tree set out above\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676195582820417*^9, 3.676195622899311*^9}, {
  3.676195670852845*^9, 3.6761957207806997`*^9}}],

Cell["You will know this has worked if the following yields true", "Text",
 CellChangeTimes->{{3.676195726416465*^9, 3.6761957397824507`*^9}, {
  3.6761958387291594`*^9, 3.676195857639531*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"FileNames", "[", "\"\<*.csv\>\"", "]"}], "==", 
  RowBox[{"{", 
   RowBox[{
   "\"\<interaction_tallies.csv\>\"", ",", 
    "\"\<master_life_events_sheet.csv\>\"", ",", "\"\<people-info.csv\>\""}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.676195740647111*^9, 3.67619576368143*^9}, 
   3.676195832219305*^9, 3.676271844398509*^9}],

Cell["Based on that, what does the function FileNames do?", "Text",
 CellChangeTimes->{{3.676195859901044*^9, 3.676195868496026*^9}}],

Cell["\<\
Import the master_life_events_sheet.csv file and store the data against an \
appropriate symbol\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676195882290853*^9, 3.676195904302414*^9}}],

Cell["\<\
There are too many columns for us to reasonably handle the data as a list of \
lists - we must convert the data into Associations. The steps below will \
guide you on how to do this.\
\>", "Text",
 CellChangeTimes->{{3.676195882290853*^9, 3.676195939935041*^9}, 
   3.676198373294202*^9, {3.676272899970887*^9, 3.6762729088338947`*^9}}],

Cell[CellGroupData[{

Cell["AssocationThread", "Section",
 CellChangeTimes->{{3.676195942117484*^9, 3.676195944942113*^9}}],

Cell["\<\
Lists of associations can be easily constructed with the function \
AssociationThread, for instance:\
\>", "Text",
 CellChangeTimes->{{3.676195972201304*^9, 3.6761959968724117`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AssociationThread", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\"\<Key 1\>\"", ",", "\"\<Key 2\>\""}], "}"}], "\[Rule]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.676195997763034*^9, 3.676196014141762*^9}}],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"\<\"Key 1\"\>", "\[Rule]", "1"}], ",", 
   RowBox[{"\<\"Key 2\"\>", "\[Rule]", "2"}]}], 
  "\[RightAssociation]"}]], "Output",
 CellChangeTimes->{3.676196014552053*^9}]
}, Open  ]],

Cell["\<\
Use AssociationThread and Map to construct a list of associations containing \
the data from the datafile you imported.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.6761960215793533`*^9, 3.676196045484956*^9}, {
  3.676196355535255*^9, 3.676196357795003*^9}, {3.6761963985181093`*^9, 
  3.676196404717133*^9}}],

Cell["The associations will individually look like this:", "Text",
 CellChangeTimes->{{3.676196406798375*^9, 3.676196413885996*^9}}],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"\"\<Event.Label\>\"", "\[Rule]", "6"}], ",", 
   RowBox[{"\"\<Category\>\"", "\[Rule]", "\"\<BasicData\>\""}], ",", 
   RowBox[{
   "\"\<Event.or.Relationship.Type\>\"", "\[Rule]", 
    "\"\<FamilyRelationships\>\""}], ",", 
   RowBox[{"\"\<Event.Name.or.Description\>\"", "\[Rule]", "\"\<\>\""}], ",", 
   "...", ",", 
   RowBox[{"\"\<Who.Entered.Data\>\"", "\[Rule]", "\"\<Robin Buning\>\""}], 
   ",", 
   RowBox[{"\"\<Whose.Notes\>\"", "\[Rule]", "\"\<\>\""}], ",", 
   RowBox[{"\"\<Additional.Notes\>\"", "\[Rule]", "\"\<\>\""}]}], 
  "\[RightAssociation]"}]], "Input",
 CellChangeTimes->{{3.676196378191931*^9, 3.676196393264283*^9}}],

Cell["\<\
You will know that the data your output is correct if the following yields \
true:\
\>", "Text",
 CellChangeTimes->{{3.676196417081533*^9, 3.676196421851451*^9}, {
  3.676196785079638*^9, 3.676196819457255*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Dimensions", "[", "yourSymbol", "]"}], "==", 
   RowBox[{"{", "813", "}"}]}], "&&", 
  RowBox[{"AllTrue", "[", 
   RowBox[{
    RowBox[{"Map", "[", 
     RowBox[{"AssociationQ", ",", "yourSymbol"}], "]"}], ",", "TrueQ"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.676196841703506*^9, 3.67619686363721*^9}, {
  3.676196917879393*^9, 3.676196920709096*^9}}],

Cell["\<\
Each entry is a description of a relationship between a \
\[OpenCurlyDoubleQuote]Primary.Participant.Emlo_ID\[CloseCurlyDoubleQuote] \
and \[OpenCurlyDoubleQuote]Secondary.Participant.Emlo_ID\
\[CloseCurlyDoubleQuote] - but the secondary participant is not necessarily a \
person.\[LineSeparator]\[LineSeparator]Extract the \
\[OpenCurlyDoubleQuote]Secondary.Participant.Type\[CloseCurlyDoubleQuote] key \
from your list of associations and list just the unique values, if you\
\[CloseCurlyQuote]ve done this correct the following will yield True\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676196957681127*^9, 3.6761970757262697`*^9}, {
  3.676198107219685*^9, 3.6761981358147182`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Length", "[", "yourEventTypes", "]"}], "\[Equal]", "4"}]], "Input",\

 CellChangeTimes->{{3.676198141347348*^9, 3.676198184101687*^9}}],

Cell["\<\
OPTIONAL: Look into the event type \[OpenCurlyDoubleQuote]\
\[OpenCurlyDoubleQuote] - what kind of events do these relate to, are they \
important for analysing who corresponds with whom?\
\>", "SubitemNumbered",
 CellChangeTimes->{{3.6761981897599792`*^9, 3.676198278806046*^9}}],

Cell["\<\
Use Query to select only those elements where the secondary participant type \
is \[OpenCurlyDoubleQuote]Person\[CloseCurlyDoubleQuote] - store this list of \
assocations against the symbol \[OpenCurlyDoubleQuote]multiPersonEvents\
\[CloseCurlyDoubleQuote]\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676196957681127*^9, 3.676197040625785*^9}, {
  3.676198288200897*^9, 3.6761983413901587`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summarising the Data", "Section",
 CellChangeTimes->{{3.67619847536856*^9, 3.6761984816475153`*^9}}],

Cell["\<\
Before converting the data into a Graph - it\[CloseCurlyQuote]s useful to \
have a feel for how the data looks.\
\>", "Text",
 CellChangeTimes->{{3.676198547935608*^9, 3.676198570512807*^9}}],

Cell[CellGroupData[{

Cell["\<\
Use Tally to calculate the distribution of life events in the \
multiPersonEvents symbol between the different categories of interaction:\
\>", "ItemNumbered",
 CellChangeTimes->{{3.6761985736633043`*^9, 3.676198614659358*^9}}],

Cell["\<\
For the last time this week, I\[CloseCurlyQuote]ll ask you to convert the \
Tally into a BarChart:\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676198620362824*^9, 3.676198634830284*^9}, {
  3.6761987418798027`*^9, 3.676198745284683*^9}}]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[{
   {Opacity[0], PointBox[{0., 0.40424519670631287`}]}, {{}, 
    {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.651], 
     Thickness[Small]}], 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.651], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 0.5425434583714547}, {1., 1.4574565416285452`}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{109.75, 110.93714285714286`}, {
           42.816640377114624`, 62.15994850301434}}],
         StatusArea[#, 1]& ,
         TagBoxNote->"1"],
        StyleBox["1", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[1, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.651], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 1.5425434583714546`}, {6., 2.457456541628545}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{109.75, 114.37285714285714`}, {
           22.220904595506234`, 41.56421272140595}}],
         StatusArea[#, 6]& ,
         TagBoxNote->"6"],
        StyleBox["6", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[6, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.651], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 2.542543458371455}, {9., 3.457456541628545}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{109.75, 116.43428571428572`}, {
           1.6251688138978437`, 20.968476939797554`}}],
         StatusArea[#, 9]& ,
         TagBoxNote->"9"],
        StyleBox["9", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[9, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.651], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 3.542543458371455}, {11., 4.457456541628545}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{109.75, 
           117.80857142857143`}, {-18.970566967710553`, 0.3727411581891573}}],
         
         StatusArea[#, 11]& ,
         TagBoxNote->"11"],
        StyleBox["11", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[11, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.651], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 4.542543458371455}, {32., 5.457456541628545}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{109.75, 
           132.23857142857142`}, {-39.56630274931895, -20.22299462341924}}],
         StatusArea[#, 32]& ,
         TagBoxNote->"32"],
        StyleBox["32", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[32, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.651], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 5.542543458371455}, {72., 6.457456541628545}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{109.75, 
           159.7242857142857}, {-60.16203853092735, -40.81873040502762}}],
         StatusArea[#, 72]& ,
         TagBoxNote->"72"],
        StyleBox["72", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[72, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.651], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 6.542543458371455}, {338., 7.457456541628545}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{109.75, 
           342.50428571428574`}, {-80.75777431253574, -61.414466186636034`}}],
         
         StatusArea[#, 338]& ,
         TagBoxNote->"338"],
        StyleBox["338", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[338, {}], "Tooltip"]& ]}}, {}, {}}, {}, {}, 
   StyleBox[{
     {Thickness[Tiny], 
      LineBox[{{0., 0.40424519670631287`}, {0., 7.598520768526989}}], 
      StyleBox[{}, "GraphicsLabel",
       StripOnInput->False]}, 
     StyleBox[{
       {Thickness[Tiny], 
        LineBox[{{0., 0.5425434583714547}, 
          Offset[{-6., 0.}, {0., 0.5425434583714547}]}], 
        LineBox[{{0., 7.457456541628544}, 
          Offset[{-6., 0.}, {0., 
           7.457456541628544}]}], {{}, {}, {}, {}, {}, {}, {}, {
          LineBox[{{0., 1.4574565416285452`}, 
            Offset[{-4., 0.}, {0., 1.4574565416285452`}]}], 
          LineBox[{{0., 1.5425434583714546`}, 
            Offset[{-4., 0.}, {0., 1.5425434583714546`}]}], 
          LineBox[{{0., 2.457456541628545}, 
            Offset[{-4., 0.}, {0., 2.457456541628545}]}], 
          LineBox[{{0., 2.5425434583714543`}, 
            Offset[{-4., 0.}, {0., 2.5425434583714543`}]}], 
          LineBox[{{0., 3.4574565416285448`}, 
            Offset[{-4., 0.}, {0., 3.4574565416285448`}]}], 
          LineBox[{{0., 3.5425434583714543`}, 
            Offset[{-4., 0.}, {0., 3.5425434583714543`}]}], 
          LineBox[{{0., 4.457456541628544}, 
            Offset[{-4., 0.}, {0., 4.457456541628544}]}], 
          LineBox[{{0., 4.542543458371454}, 
            Offset[{-4., 0.}, {0., 4.542543458371454}]}], 
          LineBox[{{0., 5.457456541628544}, 
            Offset[{-4., 0.}, {0., 5.457456541628544}]}], 
          LineBox[{{0., 5.542543458371454}, 
            Offset[{-4., 0.}, {0., 5.542543458371454}]}], 
          LineBox[{{0., 6.457456541628544}, 
            Offset[{-4., 0.}, {0., 6.457456541628544}]}], 
          LineBox[{{0., 6.542543458371454}, 
            Offset[{-4., 0.}, {0., 6.542543458371454}]}]}, {}}}, 
       StyleBox[
        {Thickness[Tiny], 
         InsetBox["\<\"EcclesiasticActivity\"\>", 
          Offset[{-1.9999999999999998`, 0.}, {0., 0.9999999999999999}], {1, 0},
           Automatic, {1, 0}], 
         InsetBox["\<\"ProfessionalActivity\"\>", 
          Offset[{-1.9999999999999998`, 0.}, {0., 1.9999999999999996`}], {1, 0},
           Automatic, {1, 0}], 
         InsetBox["\<\"HierarchicalRelationship\"\>", 
          Offset[{-1.9999999999999998`, 0.}, {0., 2.9999999999999996`}], {1, 0},
           Automatic, {1, 0}], 
         InsetBox["\<\"LearnedActivity\"\>", 
          Offset[{-1.9999999999999998`, 0.}, {0., 3.9999999999999996`}], {1, 0},
           Automatic, {1, 0}], 
         InsetBox["\<\"Education\"\>", 
          Offset[{-1.9999999999999998`, 0.}, {0., 4.999999999999999}], {1, 0},
           Automatic, {1, 0}], 
         InsetBox["\<\"BasicData\"\>", 
          Offset[{-1.9999999999999998`, 0.}, {0., 5.999999999999999}], {1, 0},
           Automatic, {1, 0}], 
         InsetBox["\<\"SocialContacts\"\>", 
          Offset[{-1.9999999999999998`, 0.}, {0., 6.999999999999999}], {1, 0},
           Automatic, {1, 0}]}, "GraphicsLabel",
        StripOnInput->False]}, "GraphicsTicks",
      StripOnInput->False]}, "GraphicsAxes",
    StripOnInput->False,
    Antialiasing->False]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, False},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.40424519670631287`},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Identity[
       Part[#, 1]], 
      Identity[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Identity[
       Part[#, 1]], 
      Identity[
       Part[#, 2]]}& )},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{{{1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {1., 
       FormBox["\"EcclesiasticActivity\"", TraditionalForm], 0}, {2., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
       FormBox["\"ProfessionalActivity\"", TraditionalForm], 0}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
       FormBox["\"HierarchicalRelationship\"", TraditionalForm], 0}, {4., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
       FormBox["\"LearnedActivity\"", TraditionalForm], 0}, {5., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
       FormBox["\"Education\"", TraditionalForm], 0}, {6., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
       FormBox["\"BasicData\"", TraditionalForm], 0}, {7., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
       FormBox["\"SocialContacts\"", TraditionalForm], 0}}, {{1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}}}, {Automatic, Automatic}},
  
  GridLines->{Automatic, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{All, All}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.05]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, None}]], "Output",
 CellChangeTimes->{{3.676198666691237*^9, 3.676198754151697*^9}, 
   3.6762618788437567`*^9, 3.6762718935555973`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Visualising the Multigraph", "Title",
 CellChangeTimes->{{3.676198470768581*^9, 3.676198472590466*^9}, {
  3.67619879619456*^9, 3.6761987983857603`*^9}, {3.6762618027094793`*^9, 
  3.676261810307352*^9}}],

Cell["\<\
After these exercises you\[CloseCurlyQuote]ll have a multigraph that looks \
like this (hover over vertices)\
\>", "Text",
 CellChangeTimes->{{3.676192667822947*^9, 3.676192669588736*^9}, {
  3.676192707929297*^9, 3.676192722880842*^9}, {3.6761988011138973`*^9, 
  3.676198834634193*^9}, {3.676261814617209*^9, 3.676261819602014*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "MARY", "FLORENCE", "JEAN", "JULIE", "CLAIRE", "LAURA", "DORIS", "JOAN",
        "CHRISTINE", "KAREN", "NICOLA", "DOROTHY", "JOYCE", "JACQUELINE", 
       "EMMA", "KATHLEEN", "JANET", "LISA", "ANNIE", "SHEILA", "ANN", 
       "JOANNE", "ELSIE", "BARBARA", "CAROL", "JANE", "MICHELLE", "VICTORIA", 
       "ALICE", "IRENE", "HELEN", "SAMANTHA", "JUNE", "MAUREEN", "DIANE", 
       "RACHEL", "WINIFRED", "EILEEN", "SHIRLEY", "ANNE", "SHARON", "AMY", 
       "GLADYS", "BETTY", "VALERIE", "AMANDA", "JENNIFER", "ANGELA", "ETHEL", 
       "SANDRA", "LOUISE", "KATIE", "HILDA", "PHYLLIS", "DOREEN", "PAULINE", 
       "LILIAN", "AUDREY", "CLARE", "KELLY", "IVY", "VERA", "BRENDA", 
       "GILLIAN", "NATALIE", "VIOLET", "PAMELA", "SYLVIA", "ELAINE", "ELLEN", 
       "LESLEY", "CATHERINE", "HAYLEY", "LILY", "EDNA", "HANNAH", "NELLIE", 
       "BERYL", "WENDY", "LUCY", "ADA", "DAWN", "DONNA", "BEATRICE", "OLIVE", 
       "CAROLE", "DANIELLE", "MAY", "EVELYN", "ROSE", "MAVIS", "SALLY", 
       "KATHERINE", "IRIS", "JUDITH", "MARIA", "ZOE", "KERRY", "DEBRA", 
       "MELANIE", "STACEY", "GERTRUDE", "MURIEL", "PAULA", "LAUREN", "MARION",
        "JOANNA", "MARINA", "JANICE", "LORRAINE", "JESSIE", "PEGGY", 
       "ROSEMARY", "LYNN", "ANDREA", "FRANCES", "SUZANNE", "GRACE", 
       "JOSEPHINE", "YVONNE", "SOPHIE", "LYNNE", "ANNA", "EVA", "GWENDOLINE", 
       "JESSICA", "NORMA", "BEVERLEY", "KIRSTY", "KIMBERLEY", "HAZEL", 
       "FIONA", "MARIE", "JENNA", "MARILYN", "DAISY", "NORA", "NATASHA", 
       "MINNIE", "FREDA", "MANDY", "RACHAEL", "KATHRYN", "NANCY", "RUTH", 
       "JAYNE", "DIANA", "MARIAN", "ELEANOR", "VERONICA", "SARA", "ALEXANDRA",
        "LOUISA", "JODIE", "DORA", "DAPHNE", "TERESA", "JULIA", "NORAH", 
       "HEATHER", "KIM", "JEMMA", "THELMA", "CARLY", "IDA", "CLARA", "GLORIA",
        "HOLLY", "HILARY", "MELISSA", "MARTHA", "CYNTHIA", "BERTHA", "KATY", 
       "LILLIAN", "CHERYL", "RUBY", "NAOMI", "BESSIE", "GAIL", "MILDRED", 
       "PENELOPE", "CHARLENE", "JADE", "CHRISTINA", "ANNETTE", "JEANETTE", 
       "ESTHER", "CAROLYN", "HARRIET", "ANITA", "GERALDINE", "BRIDGET", 
       "GEORGINA", "LINDSEY", "KAY", "STELLA", "GEMMA", "NICHOLA", "AIMEE", 
       "HEIDI", "MILLICENT", "MONICA", "THERESA", "MARGERY", "MAXINE", 
       "TANYA", "CARLA", "FANNY", "JOY", "LYDIA", "ALMA", "GLENYS", "DEBBIE", 
       "JENNY", "BLANCHE", "VIVIENNE", "TARA", "MIRIAM", "GLYNIS", "CLAIR", 
       "LYNDSEY", "SONIA", "MOLLY", "ELLA", "CHLOE", "SYBIL", "LEAH", "TONI", 
       "WILLIAM", "JOHN", "PAUL", "MARK", "JAMES", "MICHAEL", "STEPHEN", 
       "ANDREW", "DANIEL", "ARTHUR", "ROBERT", "RICHARD", "RONALD", "ANTHONY",
        "MATTHEW", "CHARLES", "FREDERICK", "KENNETH", "ALBERT", "ALAN", "IAN",
        "SIMON", "ERNEST", "ALFRED", "EDWARD", "JOSEPH", "LEE", "ADAM", 
       "ROGER", "HAROLD", "DEREK", "KEITH", "FRANK", "LESLIE", "RAYMOND", 
       "COLIN", "KEVIN", "DARREN", "HENRY", "PHILIP", "GARY", "BENJAMIN", 
       "STANLEY", "STEVEN", "ERIC", "MARTIN", "WALTER", "GRAHAM", "NICHOLAS", 
       "LEONARD", "BARRY", "HERBERT", "GORDON", "NORMAN", "NEIL", "NIGEL", 
       "MALCOLM", "TIMOTHY", "STUART", "GEOFFREY", "ALEXANDER", "CYRIL", 
       "SIDNEY", "FRANCIS", "RYAN", "PERCY", "LUKE", "JACK", "TREVOR", 
       "ADRIAN", "JAMIE", "WILFRED", "PATRICK", "SCOTT", "SAMUEL", "WAYNE", 
       "CECIL", "GARETH", "SEAN", "HORACE", "BERNARD", "FRED", "EDWIN", 
       "GERALD", "SHAUN", "CLIFFORD", "MAURICE", "CLIVE", "BEN", "ANTONY", 
       "VICTOR", "JUSTIN", "JEFFREY", "OLIVER", "EDGAR", "CHRISTIAN", 
       "ASHLEY", "KARL", "AARON", "MARC", "MOHAMMED", "HUGH", "RUSSELL", 
       "GAVIN", "LAWRENCE", "LIAM", "ROBIN", "PHILLIP", "NATHAN", 
       "DENIS"}, {CompressedData["
1:eJxN1WV4FUcUANBdgtt7eIIE8gJ5WIDgrklIcELdS700UG8ppW3qlJRChbp7
qVE36u5ulLq7u+2y533w434n986d2Z3ZSVI0f1HNwgZBEKwOgyC2IopjeAHX
8gqmeEIUbaJ5HcLEfKbUc+MLmA2TeSfL28mPl7eXV8orPedans5jjQ/Uv1z9
TN7Ien318uvlg7xnKTuxPwdY94YoNkTxLt/jB/yQH/ETfsav+C2/53L+wJ/4
M3/hb/yTf/MfhmFiAzZkC7Zia6bs62LncXYUM6KYyVmczblMcQtuyW25PXfg
TtyZu3A37s49uRf35j5cwIU8hIfycB7BCnEqb1HfSn61fOso8oNN9/hE55nn
nBo5p4x6xr3J5X/wyyiyUVzHtUxxvedlPSdrnVx+Ci9Vj10ZxWN8nBV8kk/x
aab4DPNZyiyfZ4Yv8EW+xHV8ma/wVb7G1/kGK/kW1/OdzfYQu5rnOcev+atz
KAyT3ip5lT28bd7NzvUA895nc+OXy78zv2uY9G+j3sT3PV/e1Hdvpm+Rdc7w
nP30BeZdZt0++g+S3x1Z4nvE3so7eCfvYq7/Ht7Hdbyfxazmg3yYjzDLR733
Eme+RP0B9e242Phi71/iHL4wXmPfZcZ7RjHe/Y3HDwyS/xl5+v7V1zdMnnev
c1yhvsK8+VHUBZv+z9R5jzrrpJ3zOfKW1ntI/5HW2cO6xf5ud/Q95hg/LIqR
UYziaI7hWI5jhllO4ERO4mROYYoVrORUVrGa0zfrjV1m/8vsp5vv8Kn6m/az
r/6z9PW27yL93+jbVd9V8beLxgaHiUM4lMM4giM5mmM4luM5gRNZyEmczCks
Z5n3ybJSfSqrWM2Mvmny6ZzBmbl5+uo5W30uazgvTM683DmVO6dy51zuXHP1
K6MoiPIezrmAbd3P03zD8Z5bEW78E7HxdyK2IRuxMZuwKZuxOVuyFVNsw7bs
wI7sxHwWsDO7sCu7sZDd2YNFzLCYPVnCLHszj33Yl/1ZygEcyEEs42AO4VAO
5wjfMf45vv+f8y/fb413WyM/Wn67Of30/2j8Il7oHnSOYmn081FB4knGl5r3
u+fvqH6NemP3pDt7hclZ3RYk92SOehf3pZf3aWd8lPt1iXWPM54OkvuW9ty0
8diV3MB4/bT10ua3Nn+a+Qeb96x1bpI/YbxWvVa91no5Z4X+79pPxu/ZOA6P
okWQ3Ou47z/rzrPuueofq+/vPdtzmL5V9rPKezwn7xfF/7iKHnY=
       "], Null}, {
      VertexLabels -> {
         Placed["Name", Tooltip]}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[0.018544322907928002`], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.5001357454627087`, 6.002609917393925}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.576053100782418, 5.895842978123906}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9482352292499296`, 6.097613755961862}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9151738067450674`, 5.438187776093255}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9567074804668376`, 5.823109470968475}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.4311982915193564`, 5.6103629903875545`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.6547283295530573`, 5.470141876035472}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.3291315986460237`, 5.564923358575424}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         4.785953480575827, 4.792650979773929}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.6086243433705767`, 5.696340227043807}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.358444073478961, 5.720908552907942}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.104039957029104, 5.853325291739553}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.058154943199654, 6.028434144407518}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.911581255082521, 5.666345199323741}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.268654685620686, 5.835784189884132}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.740113935424552, 5.607079548351958}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.067717251909292, 5.577496225407183}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.1901160987714365`, 5.367156079183836}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.464302487648301, 5.810836314891446}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.352267967999519, 3.8957326391109772`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.5019330232187524`, 5.409922858738638}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.2683486202440615`, 6.000228186556448}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.4965891867976207`, 5.591165272469905}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.5973121055785473`, 6.06625200222989}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.546530712831092, 5.573524194826402}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.8188699679133604`, 6.085705867024174}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.3210376704601803`, 5.334694823182663}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.782379851104637, 5.965672351271724}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.254307918443584, 5.5496448155168885`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         1.8480168639532184`, 4.371045396255162}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {2.47628317627636,
          5.3971524682153955`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.7028347408065194`, 6.093244776759786}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         1.015069443528973, 3.528774386330581}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {2.3055152107392, 
         5.888803933863012}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.331821291441601, 5.716887595061483}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.4857107529680147`, 5.738563878031519}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.4013526182698466`, 5.880377038950135}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.354722758719908, 5.3840968980770985`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.2825463330866027`, 3.986538935106582}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.3862080289961396`, 5.96445637275853}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.1661911124691793`, 6.017348842219756}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.679605445673041, 5.812763152337811}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         4.240273969422595, 3.294538442130717}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.150490349131523, 5.706038430596417}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.810332911515744, 5.814005780601199}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.220199677819779, 5.776796601251533}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9578274128557434`, 5.954294043242812}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.1861620991869795`, 5.63598141436367}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.188557496372201, 5.486614363414871}}, 0.05570143050888991], 
        ArrowBox[{{2.5001357454627087`, 6.002609917393925}, {
         2.576053100782418, 5.895842978123906}}, 0.05570143050888991], 
        ArrowBox[{{5.241668688810895, 5.4646874707731214`}, {
         4.785953480575827, 4.792650979773929}}, 0.05570143050888991], 
        ArrowBox[{{2.352267967999519, 3.8957326391109772`}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         1.8480168639532184`, 4.371045396255162}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {1.597638796308375, 
         2.822580191656698}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.0523930015783991,
          3.706412131116615}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.2573432638898039,
          3.024065950763953}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.149534950406232, 
         3.104895596389688}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.16375040268722163`, 3.277185090685656}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.32390662595910724`, 3.4694697204244216`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         2.2521088624868315`, 2.7009640096630276`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.12229625603424887`, 3.787375236833959}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.10083672655948739`, 3.601472315531462}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0., 
         3.502118652485}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {1.175365870848454, 
         3.080538658374356}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.2612918723690236,
          3.712739580181321}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.3113085352775964,
          3.298363826840268}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.14917822500752154`, 3.4254397730806256`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.049757259634716, 
         3.2075581295494073`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.32668261120661146`, 3.155053482431751}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.2283345869280864,
          3.57572093998461}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.0020333003880268485`, 3.36159621491312}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {
         1.9310109034488097`, 3.135898153365598}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {2.942715326111345,
          3.3644759808467883`}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {2.969792695888759,
          3.226794349488862}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {1.979892822619038,
          3.311264616838231}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {
         1.9521184939841647`, 2.973042113831754}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {
         2.0648042207302373`, 2.715105008020585}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.0858918689478205`, 1.3686553831522517`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.158130764593345, 1.687858510106223}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.7872134804660247`, 1.501120672851946}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.8217485775752578`, 1.6835647125534663`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.2997933320975226`, 1.6206871164841348`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.708578448660259, 1.6276896036343267`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.0194579833936253`, 1.769213485184401}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.116707127932865, 1.5251410737698965`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.8676771058475212`, 1.8258680307398885`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.9178189325188169`, 1.391703535041099}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.9785572225889283`, 1.4912482384743169`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.7820472184635174`, 3.011445940856201}, {3.528800617824225, 
         3.4153936059804266`}}], 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.8936735482897027`, 2.6065550216699744`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.2328261514407464`, 1.4084201232941602`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.7321852594693112`, 1.9274867347286038`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.597638796308375, 2.822580191656698}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.9423447173186847`, 1.6152319259806995`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.3763239273976744`, 1.5033353754050143`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.1675898153049924`, 2.6470570184353863`}, {2.420836415944293, 
         2.2431093533062914`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.8936735482897027`, 2.6065550216699744`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {2.47854069729822,
          2.8454206567419718`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.2021617590475486`, 3.8687370380391304`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.430511042091697, 4.473728563866835}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.250815849483389, 3.5696337399653917`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.142566988890562, 3.1686275723500845`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.780141837132228, 3.0186312033407585`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.093822430629724, 2.906375517885318}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.8310392015705985`, 3.940500392214558}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.9424344226979815`, 4.1837777970750905`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.8075104349989717`, 2.6243579693144916`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {4.08749027015602,
          3.657082668658042}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.977474783878852, 4.049251013933451}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.695603974218695, 3.101816580844254}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.121059226743537, 3.171509965025869}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         5.089215577985817, 3.727051939623592}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.421474358397713, 2.190761571584863}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.894149394496038, 3.1689813972080367`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {3.70864795419601,
          2.615078784679503}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {4.10375792406919,
          3.464526110277083}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.829893270060526, 2.825695921522285}, {1.9173987331348583`, 
         2.7659584969191062`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5143437045371493`, 2.631688889708302}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.8937742888023044`, 3.511704774846602}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.480532646954007, 3.898639297232747}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.271285278493838, 3.080504665143418}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5936973336907365`, 4.134567590393875}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.383769973042954, 3.1431328987805087`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {3.66708201965197,
          3.919179018307792}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.7999915408060856`, 4.0944452232614905`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.135393023043709, 4.073502578805177}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.280637293984499, 3.4155044991217074`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.9939189361277716`, 3.3272009351431175`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.405503519385941, 3.270043524053674}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.070678820145944, 3.9323075706675006`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.239001584183471, 3.956164829537265}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {4.42975593123907,
          3.530715126116566}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5308128083228962`, 3.684012744192402}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.620491637143561, 2.635471976196063}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.727779462485876, 4.205311459421361}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.164943754401822, 3.796129407611249}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.2435476242779595`, 3.6993666739913427`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.3237636738212215`, 3.7328502920809923`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.401750579498126, 3.6513262470434413`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.9698408995471217`, 3.8055730640819547`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.448791131927424, 4.090933904285507}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.8550673799758357`, 2.9392153854630445`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.942715326111345, 3.3644759808467883`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.312071324715001, 3.8538501104467087`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.2407252861086775`, 2.959539268956114}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.7884955443447814`, 3.699892149571761}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {4.45271978013659,
          3.3929475838811536`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.011991317923822, 3.036747773860446}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.969792695888759, 3.226794349488862}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.303747585734906, 4.009134785783969}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.8312252633985353`, 5.035038489761629}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         3.528800617824225, 3.4153936059804266`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.40785500153673926`, 4.976406801699863}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.9721685574452104, 4.878482660544747}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.3348605704734469`, 4.957690588079347}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8356128503657425, 4.7757653239935305`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.3115427379293525, 4.389448564296204}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.34047356613598767`, 4.867129181171479}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6915615283338803, 5.016260087063726}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.5955992707905655, 5.196042024112448}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8526101898675127, 4.630801060380589}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.7973218127784216, 5.309327189878359}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.4761450601789994, 4.616543958931642}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6456923969659738, 4.297023158634975}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.5121956560123038, 4.912632616901693}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.1335695410431113`, 5.308978399644691}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.0882241249858984`, 4.718258641356753}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.5751836336992446, 5.05690184501653}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.469824124602396, 5.104041355271252}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8111154356254753, 4.307441482229554}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.9639135195187563, 5.351582525329796}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.5245821466388976, 4.1755742699901655`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.1570296631032222`, 4.93157558571205}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.28107756110461724`, 4.53044812328401}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.4743370203504087, 4.770891969196664}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.2700113959364694`, 5.216234865895061}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.42525919744296914`, 4.487389538446732}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.122124740619637, 5.126947335427426}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6549332117216733, 4.5921800581849155`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8205650367556543, 4.937147459315856}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.7146891851664909, 4.132475827523839}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.34263158638482816`, 4.636992912800938}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.3969266456918503`, 3.1981103616770197`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.3075950641940195, 4.746511591063642}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {2.47854069729822,
          2.8454206567419718`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6547419541326955, 4.863807700351988}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.49381208403271515`, 4.375955918345492}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8840158256227015, 5.228855102061041}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.4153070868230553, 4.270270166834985}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.7045673804419805, 5.219838233621284}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8761205997475692, 4.462482997072011}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6299052385371002, 4.714382051200481}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.2630543941416832`, 5.08193444559997}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8072815412905161, 5.104601698173099}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6318581063100894, 4.462220058202436}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.9556190288915065, 5.060575878942867}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.4880864554634101`, 3.5849160660106336`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.0179552862225605`, 5.218444329525832}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.3911945670759331`, 3.5449209449397725`}}, 0.05570143050888991], 
        ArrowBox[{{4.430511042091697, 4.473728563866835}, {4.981213223955975, 
         5.0445610970507975`}}, 0.05570143050888991], 
        ArrowBox[{{4.430511042091697, 4.473728563866835}, {4.867566821905859, 
         5.1563861762750385`}}, 0.05570143050888991], 
        ArrowBox[{{2.780141837132228, 3.0186312033407585`}, {
         3.142566988890562, 3.1686275723500845`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.352267967999519, 3.8957326391109772`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.2825463330866027`, 3.986538935106582}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.6163060808985588`, 3.3556561813862746`}, {3.528800617824225, 
         3.4153936059804266`}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.8936735482897027`, 2.6065550216699744`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.7321852594693112`, 1.9274867347286038`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.47854069729822, 2.8454206567419718`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.4880864554634101`, 3.5849160660106336`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.3911945670759331`, 3.5449209449397725`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.780141837132228, 3.0186312033407585`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.695603974218695, 3.101816580844254}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.175365870848454, 3.080538658374356}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.0774078703579866`, 2.762021135226445}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.5671950887519348`, 2.2865173398017777`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.1777948334100428`, 2.6217420157641214`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.3803050652017146`, 2.477758651764651}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.109385498151434, 2.4917851013821215`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.1688366839844044`, 2.8533041468787195`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.3442796757106674`, 2.620655965758532}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.0093171896476711`, 2.342119382412407}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.654812508403634, 2.1482345319902834`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.136379271804913, 2.10179967534156}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.398893722561458, 2.337537030955006}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.0445336068141367`, 2.2145012697976156`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.5178886194675658`, 2.070324688298257}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.392985116128974, 2.0172300490268786`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.2701560228774893`, 2.170868016397018}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.3975982075832798`, 2.18479886837523}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.0010160736343976`, 2.6224015147170086`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.2584534476124616`, 2.0186966525050893`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         0.9660759676933837, 2.472803415911055}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.307329914043703, 2.8190553153022355`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.2203116837267625`, 2.403725156264022}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.0648042207302373`, 2.715105008020585}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.1743389460149922`, 2.274227348673222}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {4.785953480575827, 
         4.792650979773929}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {4.240273969422595, 
         3.294538442130717}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {5.089215577985817, 
         3.727051939623592}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.07605019362437, 
         4.7921768996926755`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.108569302428034, 
         4.289256406799745}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.162718825972419, 
         4.485721789141594}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.217602994975898, 
         3.9554024603260465`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.069766489239364, 
         3.4849957919804195`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.839643628137155, 
         4.449570510691226}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.339445919688016, 
         4.06213114401514}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.930031394773706, 
         3.334106453459885}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.29515948689261, 
         3.6711682743193585`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.384969987960359, 
         4.4221485605780035`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.497997598777275, 
         4.020280573460792}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.157390138415499, 
         4.132924398807478}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.202438494892904, 
         3.420668394795633}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.722960004274572, 
         4.310322961527341}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.920383828516393, 
         4.5673503536250575`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.348361489395701, 
         3.913040092783218}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.724336630874012, 
         3.5382502837181464`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.04286578353353, 
         3.992902738035645}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.313344466056199, 
         3.511235759908192}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.246250065585384, 
         3.7936881591370293`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.49221300887856, 
         4.6428349632936685`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.872934999963933, 
         3.9116529007241962`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.99589646107202, 
         4.4221152403054855`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.030576710727809, 
         3.6677971129569764`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.402875651459135, 
         4.206617655166467}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         7.5092294802897115`, 4.155850833215487}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.826626790601779, 
         4.124531057816174}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.182830794179319, 
         4.711163026407839}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.909356644316942, 
         3.531218243022184}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.940971265755323, 
         4.7371375157582545`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.051834577147967, 
         4.623993472853848}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.979285916089861, 
         4.202026505373777}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.765187881582182, 
         4.849704246674317}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         7.1647163047764835`, 3.6052812946290684`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.256449545263353, 
         4.602101352336273}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.450823132744214, 
         4.3296976212458285`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         6.7332729528748025`, 4.739823640833926}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.073475795754592, 
         3.3446634144767353`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.243126257987642, 
         4.3742895738521925`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         6.5865952470127995`, 4.480947617956097}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.813630168216543, 
         3.719486279249364}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.082709938405188, 
         3.811335885439358}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         6.7900103730083154`, 3.3864915489480705`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.726461226363466, 
         4.580391401353141}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.271976368383317, 
         4.217171575296142}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.417303205744281, 
         3.641247907462545}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.889499163828672, 
         4.854877707567038}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.436827334648331, 
         3.776543704867336}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.36669655127135, 
         4.539807801375816}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.487593683926255, 
         3.8913864754248957`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.568781576929737, 
         4.791634583666779}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.8936735482897027`, 2.6065550216699744`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.7321852594693112`, 1.9274867347286038`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.3969266456918503`, 3.1981103616770197`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8075104349989717`, 2.6243579693144916`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.421474358397713, 2.190761571584863}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {3.70864795419601,
          2.615078784679503}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.5143437045371493`, 2.631688889708302}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.620491637143561, 2.635471976196063}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.2521088624868315`, 2.7009640096630276`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.086947054882777, 1.519870605989537}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {4.18209667336294,
          1.4140793613221037`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.925138690548266, 1.4347354403711694`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8679255336938736`, 1.2632213976747777`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.979849145266797, 1.6416616732844578`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {4.46363350817925,
          1.8072214144657355`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.349911798840048, 1.7078513085738685`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.471555947280286, 1.068618203063001}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.295671362053043, 1.5656152959568475`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.026224270844277, 1.194980682649728}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {4.19088866799243,
          1.6685142500137031`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8432883078061626`, 1.6652882090850187`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.274060087359451, 1.3715767941168013`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.7164694653507095`, 1.2254168366564895`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.025537181086292, 1.3306997299521077`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.437201726066682, 1.4788486729610324`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.272361280221109, 1.8734433678623728`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.5869571021565627`, 1.5841419622038597`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.403274340812292, 1.4813956224851554`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.124709468232238, 1.8263122936120195`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.6289533279741266`, 1.2779280947152851`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.455341129301084, 1.628651384177883}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.4177692935803883`, 1.2962703706061052`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.6759923074530665`, 1.446008295597642}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.310076412808286, 1.3736411898265515`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8058864883790147`, 1.1742553557001956`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.377534460488725, 1.9508173489446283`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.5908997950331663`, 1.1746006289113988`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8167824403242876`, 1.41118222984997}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.184505427359471, 1.2669661240102115`}}, 0.05570143050888991], 
        ArrowBox[{{4.471555947280286, 1.068618203063001}, {5.047638369107941, 
         0.4111912972831533}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         4.240273969422595, 3.294538442130717}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.7321852594693112`, 1.9274867347286038`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.47854069729822, 2.8454206567419718`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.421474358397713, 2.190761571584863}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.274060087359451, 1.3715767941168013`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.529183377782783, 0.3459540572094859}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.855260453944898, 0.3303523773370447}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.632165776231189, 0.11103641985856338`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.623085392018389, 0.24813975997412197`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.691707167723954, 0.5505356231454419}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.189233266615462, 0.25849377658537387`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.0191831405526632`, 0.4113205932000388}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3710776248337075`, 0.2999523784538045}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.167773717230054, 0.4385212239551035}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.7716537203514955`, 0.4302322473870501}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3108059160742314`, 0.15061590799352498`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.967013800042194, 0.17293923908540476`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.834010241282577, 1.990508425310403}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.8663225857892227`, 0.3162379741460035}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.033793051399473, 0.27333934580722286`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.1533319156711497`, 0.12824719894068837`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.901323876584327, 0.46408514083271557`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.5778245924135943`, 0.4688222282786785}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.5170786709362716`, 0.04384570570227053}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.733477488615379, 0.3594720657048902}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.764343642195909, 0.2002421538590511}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3889215317152495`, 0.03714367247629635}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.852030977769403, 0.09540886872204357}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.8913260505315477`, 0.5169506416851912}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.2711795821890868`, 0.}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.4757292291894126`, 0.17919497776812854`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.131451414038333, 0.017911701145744807`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.62996839398561, 0.3358079206113249}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.760508776801317, 0.5082595388835616}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.57736217973407, 0.4804479081603814}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3532423647517455`, 0.4616839528821379}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.81669742895982, 0.2197850566076167}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.687649817279081, 0.20397739499959755`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.9942706618603867`, 0.04006566250262589}}, 0.05570143050888991], 
        ArrowBox[{{2.834010241282577, 1.990508425310403}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991]}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8312252633985353`, 5.035038489761629}, 
           0.05570143050888991],
          "\"MARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.5001357454627087`, 6.002609917393925}, 
           0.05570143050888991],
          "\"FLORENCE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FLORENCE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.576053100782418, 5.895842978123906}, 0.05570143050888991],
          "\"JEAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9482352292499296`, 6.097613755961862}, 
           0.05570143050888991],
          "\"JULIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JULIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9151738067450674`, 5.438187776093255}, 
           0.05570143050888991],
          "\"CLAIRE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLAIRE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9567074804668376`, 5.823109470968475}, 
           0.05570143050888991],
          "\"LAURA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LAURA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4311982915193564`, 5.6103629903875545`}, 
           0.05570143050888991],
          "\"DORIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DORIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.6547283295530573`, 5.470141876035472}, 
           0.05570143050888991],
          "\"JOAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3291315986460237`, 5.564923358575424}, 
           0.05570143050888991],
          "\"CHRISTINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHRISTINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.785953480575827, 4.792650979773929}, 0.05570143050888991],
          "\"KAREN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KAREN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.241668688810895, 5.4646874707731214`}, 
           0.05570143050888991],
          "\"NICOLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NICOLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.6086243433705767`, 5.696340227043807}, 
           0.05570143050888991],
          "\"DOROTHY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DOROTHY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.358444073478961, 5.720908552907942}, 0.05570143050888991],
          "\"JOYCE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOYCE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.104039957029104, 5.853325291739553}, 0.05570143050888991],
          "\"JACQUELINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JACQUELINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.4086328226038205`, 3.4233982178356124`}, 
           0.05570143050888991],
          "\"EMMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EMMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3880612796376046`, 3.247166015126839}, 
           0.05570143050888991],
          "\"KATHLEEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATHLEEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.058154943199654, 6.028434144407518}, 0.05570143050888991],
          "\"JANET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JANET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.911581255082521, 5.666345199323741}, 0.05570143050888991],
          "\"LISA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LISA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.268654685620686, 5.835784189884132}, 0.05570143050888991],
          "\"ANNIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.740113935424552, 5.607079548351958}, 0.05570143050888991],
          "\"SHEILA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHEILA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.067717251909292, 5.577496225407183}, 0.05570143050888991],
          "\"ANN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1901160987714365`, 5.367156079183836}, 
           0.05570143050888991],
          "\"JOANNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOANNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.464302487648301, 5.810836314891446}, 0.05570143050888991],
          "\"ELSIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELSIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.352267967999519, 3.8957326391109772`}, 
           0.05570143050888991],
          "\"BARBARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BARBARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5019330232187524`, 5.409922858738638}, 
           0.05570143050888991],
          "\"CAROL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CAROL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2683486202440615`, 6.000228186556448}, 
           0.05570143050888991],
          "\"JANE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JANE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.4965891867976207`, 5.591165272469905}, 
           0.05570143050888991],
          "\"MICHELLE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MICHELLE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.5973121055785473`, 6.06625200222989}, 
           0.05570143050888991],
          "\"VICTORIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VICTORIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.546530712831092, 5.573524194826402}, 0.05570143050888991],
          "\"ALICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8188699679133604`, 6.085705867024174}, 
           0.05570143050888991],
          "\"IRENE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IRENE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3210376704601803`, 5.334694823182663}, 
           0.05570143050888991],
          "\"HELEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HELEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.782379851104637, 5.965672351271724}, 0.05570143050888991],
          "\"SAMANTHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SAMANTHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.254307918443584, 5.5496448155168885`}, 
           0.05570143050888991],
          "\"JUNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JUNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6909004173798046`, 3.0661122801603264`}, 
           0.05570143050888991],
          "\"MAUREEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAUREEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8480168639532184`, 4.371045396255162}, 
           0.05570143050888991],
          "\"DIANE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DIANE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.47628317627636, 5.3971524682153955`}, 
           0.05570143050888991],
          "\"RACHEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RACHEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.7028347408065194`, 6.093244776759786}, 
           0.05570143050888991],
          "\"WINIFRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WINIFRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.015069443528973, 3.528774386330581}, 0.05570143050888991],
          "\"EILEEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EILEEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.4780412190946257`, 3.04953873904153}, 
           0.05570143050888991],
          "\"SHIRLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHIRLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3055152107392, 5.888803933863012}, 0.05570143050888991],
          "\"ANNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.331821291441601, 5.716887595061483}, 0.05570143050888991],
          "\"SHARON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHARON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4857107529680147`, 5.738563878031519}, 
           0.05570143050888991],
          "\"AMY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AMY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4013526182698466`, 5.880377038950135}, 
           0.05570143050888991],
          "\"GLADYS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLADYS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.354722758719908, 5.3840968980770985`}, 
           0.05570143050888991],
          "\"BETTY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BETTY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2825463330866027`, 3.986538935106582}, 
           0.05570143050888991],
          "\"VALERIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VALERIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3862080289961396`, 5.96445637275853}, 
           0.05570143050888991],
          "\"AMANDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AMANDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1661911124691793`, 6.017348842219756}, 
           0.05570143050888991],
          "\"JENNIFER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JENNIFER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.679605445673041, 5.812763152337811}, 0.05570143050888991],
          "\"ANGELA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANGELA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.240273969422595, 3.294538442130717}, 0.05570143050888991],
          "\"ETHEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ETHEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.150490349131523, 5.706038430596417}, 0.05570143050888991],
          "\"SANDRA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SANDRA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.810332911515744, 5.814005780601199}, 0.05570143050888991],
          "\"LOUISE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LOUISE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.220199677819779, 5.776796601251533}, 0.05570143050888991],
          "\"KATIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9578274128557434`, 5.954294043242812}, 
           0.05570143050888991],
          "\"HILDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HILDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.1861620991869795`, 5.63598141436367}, 
           0.05570143050888991],
          "\"PHYLLIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PHYLLIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.188557496372201, 5.486614363414871}, 0.05570143050888991],
          "\"DOREEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DOREEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.420836415944293, 2.2431093533062914`}, 
           0.05570143050888991],
          "\"PAULINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAULINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.0858918689478205`, 1.3686553831522517`}, 
           0.05570143050888991],
          "\"LILIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LILIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.158130764593345, 1.687858510106223}, 0.05570143050888991],
          "\"AUDREY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AUDREY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.7872134804660247`, 1.501120672851946}, 
           0.05570143050888991],
          "\"CLARE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLARE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8217485775752578`, 1.6835647125534663`}, 
           0.05570143050888991],
          "\"KELLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KELLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2997933320975226`, 1.6206871164841348`}, 
           0.05570143050888991],
          "\"IVY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IVY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.708578448660259, 1.6276896036343267`}, 
           0.05570143050888991],
          "\"VERA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VERA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.0194579833936253`, 1.769213485184401}, 
           0.05570143050888991],
          "\"BRENDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BRENDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.116707127932865, 1.5251410737698965`}, 
           0.05570143050888991],
          "\"GILLIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GILLIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8676771058475212`, 1.8258680307398885`}, 
           0.05570143050888991],
          "\"NATALIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NATALIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9178189325188169`, 1.391703535041099}, 
           0.05570143050888991],
          "\"VIOLET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VIOLET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9785572225889283`, 1.4912482384743169`}, 
           0.05570143050888991],
          "\"PAMELA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAMELA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.518440375008683, 3.1045688674195313`}, 
           0.05570143050888991],
          "\"SYLVIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SYLVIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.528800617824225, 3.4153936059804266`}, 
           0.05570143050888991],
          "\"ELAINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELAINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8936735482897027`, 2.6065550216699744`}, 
           0.05570143050888991],
          "\"ELLEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELLEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2328261514407464`, 1.4084201232941602`}, 
           0.05570143050888991],
          "\"LESLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LESLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.7321852594693112`, 1.9274867347286038`}, 
           0.05570143050888991],
          "\"CATHERINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CATHERINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.597638796308375, 2.822580191656698}, 0.05570143050888991],
          "\"HAYLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HAYLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9423447173186847`, 1.6152319259806995`}, 
           0.05570143050888991],
          "\"LILY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LILY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3763239273976744`, 1.5033353754050143`}, 
           0.05570143050888991],
          "\"EDNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3188303280332685`, 4.388954662649468}, 
           0.05570143050888991],
          "\"HANNAH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HANNAH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.40785500153673926`, 4.976406801699863}, 
           0.05570143050888991],
          "\"NELLIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NELLIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9721685574452104, 4.878482660544747}, 
           0.05570143050888991],
          "\"BERYL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BERYL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3348605704734469`, 4.957690588079347}, 
           0.05570143050888991],
          "\"WENDY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WENDY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8356128503657425, 4.7757653239935305`}, 
           0.05570143050888991],
          "\"LUCY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LUCY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.3115427379293525, 4.389448564296204}, 
           0.05570143050888991],
          "\"ADA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ADA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.34047356613598767`, 4.867129181171479}, 
           0.05570143050888991],
          "\"DAWN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DAWN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6915615283338803, 5.016260087063726}, 
           0.05570143050888991],
          "\"DONNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DONNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5955992707905655, 5.196042024112448}, 
           0.05570143050888991],
          "\"BEATRICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BEATRICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8526101898675127, 4.630801060380589}, 
           0.05570143050888991],
          "\"OLIVE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "OLIVE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.7973218127784216, 5.309327189878359}, 
           0.05570143050888991],
          "\"CAROLE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CAROLE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.4761450601789994, 4.616543958931642}, 
           0.05570143050888991],
          "\"DANIELLE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DANIELLE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6456923969659738, 4.297023158634975}, 
           0.05570143050888991],
          "\"MAY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5121956560123038, 4.912632616901693}, 
           0.05570143050888991],
          "\"EVELYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EVELYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1335695410431113`, 5.308978399644691}, 
           0.05570143050888991],
          "\"ROSE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROSE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0882241249858984`, 4.718258641356753}, 
           0.05570143050888991],
          "\"MAVIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAVIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5751836336992446, 5.05690184501653}, 0.05570143050888991],
          "\"SALLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SALLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.469824124602396, 5.104041355271252}, 0.05570143050888991],
          "\"KATHERINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATHERINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8111154356254753, 4.307441482229554}, 
           0.05570143050888991],
          "\"IRIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IRIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9639135195187563, 5.351582525329796}, 
           0.05570143050888991],
          "\"JUDITH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JUDITH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5245821466388976, 4.1755742699901655`}, 
           0.05570143050888991],
          "\"MARIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1570296631032222`, 4.93157558571205}, 
           0.05570143050888991],
          "\"ZOE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ZOE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.28107756110461724`, 4.53044812328401}, 
           0.05570143050888991],
          "\"KERRY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KERRY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.4743370203504087, 4.770891969196664}, 
           0.05570143050888991],
          "\"DEBRA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DEBRA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2700113959364694`, 5.216234865895061}, 
           0.05570143050888991],
          "\"MELANIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MELANIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.42525919744296914`, 4.487389538446732}, 
           0.05570143050888991],
          "\"STACEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STACEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.122124740619637, 5.126947335427426}, 0.05570143050888991],
          "\"GERTRUDE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GERTRUDE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6549332117216733, 4.5921800581849155`}, 
           0.05570143050888991],
          "\"MURIEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MURIEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8205650367556543, 4.937147459315856}, 
           0.05570143050888991],
          "\"PAULA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAULA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.7146891851664909, 4.132475827523839}, 
           0.05570143050888991],
          "\"LAUREN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LAUREN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.34263158638482816`, 4.636992912800938}, 
           0.05570143050888991],
          "\"MARION\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARION", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3969266456918503`, 3.1981103616770197`}, 
           0.05570143050888991],
          "\"JOANNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOANNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.3075950641940195, 4.746511591063642}, 
           0.05570143050888991],
          "\"MARINA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARINA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.47854069729822, 2.8454206567419718`}, 
           0.05570143050888991],
          "\"JANICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JANICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6547419541326955, 4.863807700351988}, 
           0.05570143050888991],
          "\"LORRAINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LORRAINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.49381208403271515`, 4.375955918345492}, 
           0.05570143050888991],
          "\"JESSIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JESSIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8840158256227015, 5.228855102061041}, 
           0.05570143050888991],
          "\"PEGGY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PEGGY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.4153070868230553, 4.270270166834985}, 
           0.05570143050888991],
          "\"ROSEMARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROSEMARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.7045673804419805, 5.219838233621284}, 
           0.05570143050888991],
          "\"LYNN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYNN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8761205997475692, 4.462482997072011}, 
           0.05570143050888991],
          "\"ANDREA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANDREA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6299052385371002, 4.714382051200481}, 
           0.05570143050888991],
          "\"FRANCES\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRANCES", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2630543941416832`, 5.08193444559997}, 
           0.05570143050888991],
          "\"SUZANNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SUZANNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8072815412905161, 5.104601698173099}, 
           0.05570143050888991],
          "\"GRACE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GRACE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6318581063100894, 4.462220058202436}, 
           0.05570143050888991],
          "\"JOSEPHINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOSEPHINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9556190288915065, 5.060575878942867}, 
           0.05570143050888991],
          "\"YVONNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "YVONNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.4880864554634101`, 3.5849160660106336`}, 
           0.05570143050888991],
          "\"SOPHIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SOPHIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0179552862225605`, 5.218444329525832}, 
           0.05570143050888991],
          "\"LYNNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYNNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3911945670759331`, 3.5449209449397725`}, 
           0.05570143050888991],
          "\"ANNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2021617590475486`, 3.8687370380391304`}, 
           0.05570143050888991],
          "\"EVA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EVA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.430511042091697, 4.473728563866835}, 0.05570143050888991],
          "\"GWENDOLINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GWENDOLINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.981213223955975, 5.0445610970507975`}, 
           0.05570143050888991],
          "\"JESSICA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JESSICA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.250815849483389, 3.5696337399653917`}, 
           0.05570143050888991],
          "\"NORMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.142566988890562, 3.1686275723500845`}, 
           0.05570143050888991],
          "\"BEVERLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BEVERLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.780141837132228, 3.0186312033407585`}, 
           0.05570143050888991],
          "\"KIRSTY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIRSTY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.093822430629724, 2.906375517885318}, 0.05570143050888991],
          "\"KIMBERLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIMBERLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8310392015705985`, 3.940500392214558}, 
           0.05570143050888991],
          "\"HAZEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HAZEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.9424344226979815`, 4.1837777970750905`}, 
           0.05570143050888991],
          "\"FIONA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FIONA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8075104349989717`, 2.6243579693144916`}, 
           0.05570143050888991],
          "\"MARIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.08749027015602, 3.657082668658042}, 0.05570143050888991],
          
          "\"JENNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JENNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.867566821905859, 5.1563861762750385`}, 
           0.05570143050888991],
          "\"MARILYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARILYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.977474783878852, 4.049251013933451}, 0.05570143050888991],
          "\"DAISY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DAISY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.695603974218695, 3.101816580844254}, 0.05570143050888991],
          "\"NORA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.121059226743537, 3.171509965025869}, 0.05570143050888991],
          "\"NATASHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NATASHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.089215577985817, 3.727051939623592}, 0.05570143050888991],
          "\"MINNIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MINNIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.421474358397713, 2.190761571584863}, 0.05570143050888991],
          "\"FREDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FREDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.894149394496038, 3.1689813972080367`}, 
           0.05570143050888991],
          "\"MANDY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MANDY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.70864795419601, 2.615078784679503}, 0.05570143050888991],
          
          "\"RACHAEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RACHAEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.10375792406919, 3.464526110277083}, 0.05570143050888991],
          
          "\"KATHRYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATHRYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9173987331348583`, 2.7659584969191062`}, 
           0.05570143050888991],
          "\"NANCY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NANCY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5143437045371493`, 2.631688889708302}, 
           0.05570143050888991],
          "\"RUTH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RUTH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8937742888023044`, 3.511704774846602}, 
           0.05570143050888991],
          "\"JAYNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JAYNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.480532646954007, 3.898639297232747}, 0.05570143050888991],
          "\"DIANA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DIANA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.271285278493838, 3.080504665143418}, 0.05570143050888991],
          "\"MARIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5936973336907365`, 4.134567590393875}, 
           0.05570143050888991],
          "\"ELEANOR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELEANOR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.383769973042954, 3.1431328987805087`}, 
           0.05570143050888991],
          "\"VERONICA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VERONICA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.66708201965197, 3.919179018307792}, 0.05570143050888991],
          
          "\"SARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.7999915408060856`, 4.0944452232614905`}, 
           0.05570143050888991],
          "\"ALEXANDRA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALEXANDRA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.135393023043709, 4.073502578805177}, 0.05570143050888991],
          "\"LOUISA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LOUISA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.280637293984499, 3.4155044991217074`}, 
           0.05570143050888991],
          "\"JODIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JODIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.9939189361277716`, 3.3272009351431175`}, 
           0.05570143050888991],
          "\"DORA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DORA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.405503519385941, 3.270043524053674}, 0.05570143050888991],
          "\"DAPHNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DAPHNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.070678820145944, 3.9323075706675006`}, 
           0.05570143050888991],
          "\"TERESA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TERESA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.239001584183471, 3.956164829537265}, 0.05570143050888991],
          "\"JULIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JULIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.42975593123907, 3.530715126116566}, 0.05570143050888991],
          
          "\"NORAH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORAH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5308128083228962`, 3.684012744192402}, 
           0.05570143050888991],
          "\"HEATHER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HEATHER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.620491637143561, 2.635471976196063}, 0.05570143050888991],
          "\"KIM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.727779462485876, 4.205311459421361}, 0.05570143050888991],
          "\"JEMMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEMMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.164943754401822, 3.796129407611249}, 0.05570143050888991],
          "\"THELMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "THELMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2435476242779595`, 3.6993666739913427`}, 
           0.05570143050888991],
          "\"CARLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CARLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.3237636738212215`, 3.7328502920809923`}, 
           0.05570143050888991],
          "\"IDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.401750579498126, 3.6513262470434413`}, 
           0.05570143050888991],
          "\"CLARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.9698408995471217`, 3.8055730640819547`}, 
           0.05570143050888991],
          "\"GLORIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLORIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.448791131927424, 4.090933904285507}, 0.05570143050888991],
          "\"HOLLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HOLLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8550673799758357`, 2.9392153854630445`}, 
           0.05570143050888991],
          "\"HILARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HILARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9310109034488097`, 3.135898153365598}, 
           0.05570143050888991],
          "\"MELISSA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MELISSA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.942715326111345, 3.3644759808467883`}, 
           0.05570143050888991],
          "\"MARTHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARTHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.312071324715001, 3.8538501104467087`}, 
           0.05570143050888991],
          "\"CYNTHIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CYNTHIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.2407252861086775`, 2.959539268956114}, 
           0.05570143050888991],
          "\"BERTHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BERTHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.7884955443447814`, 3.699892149571761}, 
           0.05570143050888991],
          "\"KATY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.45271978013659, 3.3929475838811536`}, 
           0.05570143050888991],
          "\"LILLIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LILLIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.011991317923822, 3.036747773860446}, 0.05570143050888991],
          "\"CHERYL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHERYL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.969792695888759, 3.226794349488862}, 0.05570143050888991],
          "\"RUBY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RUBY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.303747585734906, 4.009134785783969}, 0.05570143050888991],
          "\"NAOMI\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NAOMI", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.0523930015783991, 3.706412131116615}, 
           0.05570143050888991],
          "\"BESSIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BESSIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.2573432638898039, 3.024065950763953}, 
           0.05570143050888991],
          "\"GAIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GAIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.979892822619038, 3.311264616838231}, 0.05570143050888991],
          "\"MILDRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MILDRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.149534950406232, 3.104895596389688}, 0.05570143050888991],
          "\"PENELOPE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PENELOPE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.16375040268722163`, 3.277185090685656}, 
           0.05570143050888991],
          "\"CHARLENE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHARLENE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.32390662595910724`, 3.4694697204244216`}, 
           0.05570143050888991],
          "\"JADE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JADE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2521088624868315`, 2.7009640096630276`}, 
           0.05570143050888991],
          "\"CHRISTINA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHRISTINA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.12229625603424887`, 3.787375236833959}, 
           0.05570143050888991],
          "\"ANNETTE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNETTE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.10083672655948739`, 3.601472315531462}, 
           0.05570143050888991],
          "\"JEANETTE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEANETTE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[DiskBox[{0., 3.502118652485}, 0.05570143050888991],
          "\"ESTHER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ESTHER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.175365870848454, 3.080538658374356}, 0.05570143050888991],
          "\"CAROLYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CAROLYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.2612918723690236, 3.712739580181321}, 
           0.05570143050888991],
          "\"HARRIET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HARRIET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.3113085352775964, 3.298363826840268}, 
           0.05570143050888991],
          "\"ANITA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANITA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.14917822500752154`, 3.4254397730806256`}, 
           0.05570143050888991],
          "\"GERALDINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GERALDINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.049757259634716, 3.2075581295494073`}, 
           0.05570143050888991],
          "\"BRIDGET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BRIDGET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.32668261120661146`, 3.155053482431751}, 
           0.05570143050888991],
          "\"GEORGINA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GEORGINA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.2283345869280864, 3.57572093998461}, 0.05570143050888991],
          "\"LINDSEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LINDSEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.0020333003880268485`, 3.36159621491312}, 
           0.05570143050888991],
          "\"KAY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KAY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0774078703579866`, 2.762021135226445}, 
           0.05570143050888991],
          "\"STELLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STELLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.5671950887519348`, 2.2865173398017777`}, 
           0.05570143050888991],
          "\"GEMMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GEMMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1777948334100428`, 2.6217420157641214`}, 
           0.05570143050888991],
          "\"NICHOLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NICHOLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3803050652017146`, 2.477758651764651}, 
           0.05570143050888991],
          "\"AIMEE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AIMEE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.109385498151434, 2.4917851013821215`}, 
           0.05570143050888991],
          "\"HEIDI\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HEIDI", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1688366839844044`, 2.8533041468787195`}, 
           0.05570143050888991],
          "\"MILLICENT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MILLICENT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3442796757106674`, 2.620655965758532}, 
           0.05570143050888991],
          "\"MONICA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MONICA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0093171896476711`, 2.342119382412407}, 
           0.05570143050888991],
          "\"THERESA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "THERESA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.654812508403634, 2.1482345319902834`}, 
           0.05570143050888991],
          "\"MARGERY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARGERY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.136379271804913, 2.10179967534156}, 0.05570143050888991],
          
          "\"MAXINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAXINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.398893722561458, 2.337537030955006}, 0.05570143050888991],
          "\"TANYA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TANYA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0445336068141367`, 2.2145012697976156`}, 
           0.05570143050888991],
          "\"CARLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CARLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.5178886194675658`, 2.070324688298257}, 
           0.05570143050888991],
          "\"FANNY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FANNY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.392985116128974, 2.0172300490268786`}, 
           0.05570143050888991],
          "\"JOY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2701560228774893`, 2.170868016397018}, 
           0.05570143050888991],
          "\"LYDIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYDIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3975982075832798`, 2.18479886837523}, 
           0.05570143050888991],
          "\"ALMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0010160736343976`, 2.6224015147170086`}, 
           0.05570143050888991],
          "\"GLENYS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLENYS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2584534476124616`, 2.0186966525050893`}, 
           0.05570143050888991],
          "\"DEBBIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DEBBIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9660759676933837, 2.472803415911055}, 
           0.05570143050888991],
          "\"JENNY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JENNY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.307329914043703, 2.8190553153022355`}, 
           0.05570143050888991],
          "\"BLANCHE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BLANCHE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2203116837267625`, 2.403725156264022}, 
           0.05570143050888991],
          "\"VIVIENNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VIVIENNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9521184939841647`, 2.973042113831754}, 
           0.05570143050888991],
          "\"TARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.0648042207302373`, 2.715105008020585}, 
           0.05570143050888991],
          "\"MIRIAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MIRIAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1743389460149922`, 2.274227348673222}, 
           0.05570143050888991],
          "\"GLYNIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLYNIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.449660611658213, 4.002162346020976}, 0.05570143050888991],
          "\"CLAIR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLAIR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.07605019362437, 4.7921768996926755`}, 
           0.05570143050888991],
          "\"LYNDSEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYNDSEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.108569302428034, 4.289256406799745}, 0.05570143050888991],
          "\"SONIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SONIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.162718825972419, 4.485721789141594}, 0.05570143050888991],
          "\"MOLLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MOLLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.217602994975898, 3.9554024603260465`}, 
           0.05570143050888991],
          "\"ELLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.069766489239364, 3.4849957919804195`}, 
           0.05570143050888991],
          "\"CHLOE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHLOE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.839643628137155, 4.449570510691226}, 0.05570143050888991],
          "\"SYBIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SYBIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.339445919688016, 4.06213114401514}, 0.05570143050888991],
          
          "\"LEAH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LEAH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.930031394773706, 3.334106453459885}, 0.05570143050888991],
          "\"TONI\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TONI", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.29515948689261, 3.6711682743193585`}, 
           0.05570143050888991],
          "\"WILLIAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WILLIAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.384969987960359, 4.4221485605780035`}, 
           0.05570143050888991],
          "\"JOHN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOHN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.497997598777275, 4.020280573460792}, 0.05570143050888991],
          "\"PAUL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAUL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.157390138415499, 4.132924398807478}, 0.05570143050888991],
          "\"MARK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.202438494892904, 3.420668394795633}, 0.05570143050888991],
          "\"JAMES\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JAMES", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.722960004274572, 4.310322961527341}, 0.05570143050888991],
          "\"MICHAEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MICHAEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.920383828516393, 4.5673503536250575`}, 
           0.05570143050888991],
          "\"STEPHEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STEPHEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.348361489395701, 3.913040092783218}, 0.05570143050888991],
          "\"ANDREW\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANDREW", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.724336630874012, 3.5382502837181464`}, 
           0.05570143050888991],
          "\"DANIEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DANIEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.04286578353353, 3.992902738035645}, 0.05570143050888991],
          
          "\"ARTHUR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ARTHUR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.313344466056199, 3.511235759908192}, 0.05570143050888991],
          "\"ROBERT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROBERT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.246250065585384, 3.7936881591370293`}, 
           0.05570143050888991],
          "\"RICHARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RICHARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.49221300887856, 4.6428349632936685`}, 
           0.05570143050888991],
          "\"RONALD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RONALD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.872934999963933, 3.9116529007241962`}, 
           0.05570143050888991],
          "\"ANTHONY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANTHONY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.99589646107202, 4.4221152403054855`}, 
           0.05570143050888991],
          "\"MATTHEW\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MATTHEW", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.030576710727809, 3.6677971129569764`}, 
           0.05570143050888991],
          "\"CHARLES\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHARLES", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.402875651459135, 4.206617655166467}, 0.05570143050888991],
          "\"FREDERICK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FREDERICK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.5092294802897115`, 4.155850833215487}, 
           0.05570143050888991],
          "\"KENNETH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KENNETH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.826626790601779, 4.124531057816174}, 0.05570143050888991],
          "\"ALBERT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALBERT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.182830794179319, 4.711163026407839}, 0.05570143050888991],
          "\"ALAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.909356644316942, 3.531218243022184}, 0.05570143050888991],
          "\"IAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.940971265755323, 4.7371375157582545`}, 
           0.05570143050888991],
          "\"SIMON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SIMON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.051834577147967, 4.623993472853848}, 0.05570143050888991],
          "\"ERNEST\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ERNEST", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.979285916089861, 4.202026505373777}, 0.05570143050888991],
          "\"ALFRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALFRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.765187881582182, 4.849704246674317}, 0.05570143050888991],
          "\"EDWARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDWARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.1647163047764835`, 3.6052812946290684`}, 
           0.05570143050888991],
          "\"JOSEPH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOSEPH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.256449545263353, 4.602101352336273}, 0.05570143050888991],
          "\"LEE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LEE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.450823132744214, 4.3296976212458285`}, 
           0.05570143050888991],
          "\"ADAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ADAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.7332729528748025`, 4.739823640833926}, 
           0.05570143050888991],
          "\"ROGER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROGER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.073475795754592, 3.3446634144767353`}, 
           0.05570143050888991],
          "\"HAROLD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HAROLD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.243126257987642, 4.3742895738521925`}, 
           0.05570143050888991],
          "\"DEREK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DEREK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.5865952470127995`, 4.480947617956097}, 
           0.05570143050888991],
          "\"KEITH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KEITH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.813630168216543, 3.719486279249364}, 0.05570143050888991],
          "\"FRANK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRANK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.082709938405188, 3.811335885439358}, 0.05570143050888991],
          "\"LESLIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LESLIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.7900103730083154`, 3.3864915489480705`}, 
           0.05570143050888991],
          "\"RAYMOND\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RAYMOND", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.726461226363466, 4.580391401353141}, 0.05570143050888991],
          "\"COLIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "COLIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.271976368383317, 4.217171575296142}, 0.05570143050888991],
          "\"KEVIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KEVIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.417303205744281, 3.641247907462545}, 0.05570143050888991],
          "\"DARREN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DARREN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.889499163828672, 4.854877707567038}, 0.05570143050888991],
          "\"HENRY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HENRY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.436827334648331, 3.776543704867336}, 0.05570143050888991],
          "\"PHILIP\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PHILIP", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.36669655127135, 4.539807801375816}, 0.05570143050888991],
          
          "\"GARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.487593683926255, 3.8913864754248957`}, 
           0.05570143050888991],
          "\"BENJAMIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BENJAMIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.568781576929737, 4.791634583666779}, 0.05570143050888991],
          "\"STANLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STANLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5813031800360937`, 2.017544372999396}, 
           0.05570143050888991],
          "\"STEVEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STEVEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.086947054882777, 1.519870605989537}, 0.05570143050888991],
          "\"ERIC\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ERIC", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.18209667336294, 1.4140793613221037`}, 
           0.05570143050888991],
          "\"MARTIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARTIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.925138690548266, 1.4347354403711694`}, 
           0.05570143050888991],
          "\"WALTER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WALTER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8679255336938736`, 1.2632213976747777`}, 
           0.05570143050888991],
          "\"GRAHAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GRAHAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.979849145266797, 1.6416616732844578`}, 
           0.05570143050888991],
          "\"NICHOLAS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NICHOLAS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.46363350817925, 1.8072214144657355`}, 
           0.05570143050888991],
          "\"LEONARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LEONARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.349911798840048, 1.7078513085738685`}, 
           0.05570143050888991],
          "\"BARRY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BARRY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.471555947280286, 1.068618203063001}, 0.05570143050888991],
          "\"HERBERT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HERBERT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.295671362053043, 1.5656152959568475`}, 
           0.05570143050888991],
          "\"GORDON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GORDON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.026224270844277, 1.194980682649728}, 0.05570143050888991],
          "\"NORMAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORMAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.19088866799243, 1.6685142500137031`}, 
           0.05570143050888991],
          "\"NEIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NEIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8432883078061626`, 1.6652882090850187`}, 
           0.05570143050888991],
          "\"NIGEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NIGEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.274060087359451, 1.3715767941168013`}, 
           0.05570143050888991],
          "\"MALCOLM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MALCOLM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.7164694653507095`, 1.2254168366564895`}, 
           0.05570143050888991],
          "\"TIMOTHY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TIMOTHY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.047638369107941, 0.4111912972831533}, 
           0.05570143050888991],
          "\"STUART\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STUART", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.025537181086292, 1.3306997299521077`}, 
           0.05570143050888991],
          "\"GEOFFREY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GEOFFREY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.437201726066682, 1.4788486729610324`}, 
           0.05570143050888991],
          "\"ALEXANDER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALEXANDER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.272361280221109, 1.8734433678623728`}, 
           0.05570143050888991],
          "\"CYRIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CYRIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5869571021565627`, 1.5841419622038597`}, 
           0.05570143050888991],
          "\"SIDNEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SIDNEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.403274340812292, 1.4813956224851554`}, 
           0.05570143050888991],
          "\"FRANCIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRANCIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.124709468232238, 1.8263122936120195`}, 
           0.05570143050888991],
          "\"RYAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RYAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6289533279741266`, 1.2779280947152851`}, 
           0.05570143050888991],
          "\"PERCY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PERCY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.455341129301084, 1.628651384177883}, 0.05570143050888991],
          "\"LUKE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LUKE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4177692935803883`, 1.2962703706061052`}, 
           0.05570143050888991],
          "\"JACK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JACK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6759923074530665`, 1.446008295597642}, 
           0.05570143050888991],
          "\"TREVOR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TREVOR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.310076412808286, 1.3736411898265515`}, 
           0.05570143050888991],
          "\"ADRIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ADRIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8058864883790147`, 1.1742553557001956`}, 
           0.05570143050888991],
          "\"JAMIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JAMIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.377534460488725, 1.9508173489446283`}, 
           0.05570143050888991],
          "\"WILFRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WILFRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5908997950331663`, 1.1746006289113988`}, 
           0.05570143050888991],
          "\"PATRICK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PATRICK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8167824403242876`, 1.41118222984997}, 
           0.05570143050888991],
          "\"SCOTT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SCOTT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.184505427359471, 1.2669661240102115`}, 
           0.05570143050888991],
          "\"SAMUEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SAMUEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2290791913113557`, 1.0785109381376787`}, 
           0.05570143050888991],
          "\"WAYNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WAYNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.529183377782783, 0.3459540572094859}, 
           0.05570143050888991],
          "\"CECIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CECIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.855260453944898, 0.3303523773370447}, 
           0.05570143050888991],
          "\"GARETH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GARETH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.632165776231189, 0.11103641985856338`}, 
           0.05570143050888991],
          "\"SEAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SEAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.623085392018389, 0.24813975997412197`}, 
           0.05570143050888991],
          "\"HORACE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HORACE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.691707167723954, 0.5505356231454419}, 
           0.05570143050888991],
          "\"BERNARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BERNARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.189233266615462, 0.25849377658537387`}, 
           0.05570143050888991],
          "\"FRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.0191831405526632`, 0.4113205932000388}, 
           0.05570143050888991],
          "\"EDWIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDWIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3710776248337075`, 0.2999523784538045}, 
           0.05570143050888991],
          "\"GERALD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GERALD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.167773717230054, 0.4385212239551035}, 
           0.05570143050888991],
          "\"SHAUN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHAUN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.7716537203514955`, 0.4302322473870501}, 
           0.05570143050888991],
          "\"CLIFFORD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLIFFORD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3108059160742314`, 0.15061590799352498`}, 
           0.05570143050888991],
          "\"MAURICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAURICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.967013800042194, 0.17293923908540476`}, 
           0.05570143050888991],
          "\"CLIVE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLIVE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.834010241282577, 1.990508425310403}, 0.05570143050888991],
          "\"BEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8663225857892227`, 0.3162379741460035}, 
           0.05570143050888991],
          "\"ANTONY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANTONY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.033793051399473, 0.27333934580722286`}, 
           0.05570143050888991],
          "\"VICTOR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VICTOR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1533319156711497`, 0.12824719894068837`}, 
           0.05570143050888991],
          "\"JUSTIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JUSTIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.901323876584327, 0.46408514083271557`}, 
           0.05570143050888991],
          "\"JEFFREY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEFFREY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.5778245924135943`, 0.4688222282786785}, 
           0.05570143050888991],
          "\"OLIVER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "OLIVER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5170786709362716`, 0.04384570570227053}, 
           0.05570143050888991],
          "\"EDGAR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDGAR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.733477488615379, 0.3594720657048902}, 
           0.05570143050888991],
          "\"CHRISTIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHRISTIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.764343642195909, 0.2002421538590511}, 
           0.05570143050888991],
          "\"ASHLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ASHLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3889215317152495`, 0.03714367247629635}, 
           0.05570143050888991],
          "\"KARL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KARL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.852030977769403, 0.09540886872204357}, 
           0.05570143050888991],
          "\"AARON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AARON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8913260505315477`, 0.5169506416851912}, 
           0.05570143050888991],
          "\"MARC\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARC", "Tooltip"]& ], 
        TagBox[
         TooltipBox[DiskBox[{3.2711795821890868`, 0.}, 0.05570143050888991],
          "\"MOHAMMED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MOHAMMED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4757292291894126`, 0.17919497776812854`}, 
           0.05570143050888991],
          "\"HUGH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HUGH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.131451414038333, 0.017911701145744807`}, 
           0.05570143050888991],
          "\"RUSSELL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RUSSELL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.62996839398561, 0.3358079206113249}, 0.05570143050888991],
          "\"GAVIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GAVIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.760508776801317, 0.5082595388835616}, 
           0.05570143050888991],
          "\"LAWRENCE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LAWRENCE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.57736217973407, 0.4804479081603814}, 0.05570143050888991],
          "\"LIAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LIAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3532423647517455`, 0.4616839528821379}, 
           0.05570143050888991],
          "\"ROBIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROBIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.81669742895982, 0.2197850566076167}, 0.05570143050888991],
          "\"PHILLIP\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PHILLIP", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.687649817279081, 0.20397739499959755`}, 
           0.05570143050888991],
          "\"NATHAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NATHAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9942706618603867`, 0.04006566250262589}, 
           0.05570143050888991],
          "\"DENIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DENIS", "Tooltip"]& ]}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Input",
 CellChangeTimes->{{3.677823193563076*^9, 3.677823211744194*^9}}],

Cell[CellGroupData[{

Cell["\<\
Extract only the \[OpenCurlyDoubleQuote]Primary.Participant.Name\
\[CloseCurlyDoubleQuote] and \
\[CloseCurlyDoubleQuote]Secondary.Participant.Name\[CloseCurlyDoubleQuote] \
columns from multiPersonEvents.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676198844276435*^9, 3.676198846908072*^9}, {
  3.6761988819052467`*^9, 3.676198926515267*^9}, {3.67619921509544*^9, 
  3.6761992164116173`*^9}}],

Cell[TextData[{
 "Use the function Apply (or the shorthand @@@) to replace the Head ",
 StyleBox["Association",
  FontWeight->"Bold"],
 " with DirectedEdge - refer to the notes from this morning for a refresher. \
Provide this output to Graph, which should generate the following object:"
}], "ItemNumbered",
 CellChangeTimes->{{3.67619894335738*^9, 3.676198978288307*^9}, 
   3.6762618315833473`*^9, {3.676261894336972*^9, 3.67626192821015*^9}}]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "MARY", "FLORENCE", "JEAN", "JULIE", "CLAIRE", "LAURA", "DORIS", "JOAN",
        "CHRISTINE", "KAREN", "NICOLA", "DOROTHY", "JOYCE", "JACQUELINE", 
       "EMMA", "KATHLEEN", "JANET", "LISA", "ANNIE", "SHEILA", "ANN", 
       "JOANNE", "ELSIE", "BARBARA", "CAROL", "JANE", "MICHELLE", "VICTORIA", 
       "ALICE", "IRENE", "HELEN", "SAMANTHA", "JUNE", "MAUREEN", "DIANE", 
       "RACHEL", "WINIFRED", "EILEEN", "SHIRLEY", "ANNE", "SHARON", "AMY", 
       "GLADYS", "BETTY", "VALERIE", "AMANDA", "JENNIFER", "ANGELA", "ETHEL", 
       "SANDRA", "LOUISE", "KATIE", "HILDA", "PHYLLIS", "DOREEN", "PAULINE", 
       "LILIAN", "AUDREY", "CLARE", "KELLY", "IVY", "VERA", "BRENDA", 
       "GILLIAN", "NATALIE", "VIOLET", "PAMELA", "SYLVIA", "ELAINE", "ELLEN", 
       "LESLEY", "CATHERINE", "HAYLEY", "LILY", "EDNA", "HANNAH", "NELLIE", 
       "BERYL", "WENDY", "LUCY", "ADA", "DAWN", "DONNA", "BEATRICE", "OLIVE", 
       "CAROLE", "DANIELLE", "MAY", "EVELYN", "ROSE", "MAVIS", "SALLY", 
       "KATHERINE", "IRIS", "JUDITH", "MARIA", "ZOE", "KERRY", "DEBRA", 
       "MELANIE", "STACEY", "GERTRUDE", "MURIEL", "PAULA", "LAUREN", "MARION",
        "JOANNA", "MARINA", "JANICE", "LORRAINE", "JESSIE", "PEGGY", 
       "ROSEMARY", "LYNN", "ANDREA", "FRANCES", "SUZANNE", "GRACE", 
       "JOSEPHINE", "YVONNE", "SOPHIE", "LYNNE", "ANNA", "EVA", "GWENDOLINE", 
       "JESSICA", "NORMA", "BEVERLEY", "KIRSTY", "KIMBERLEY", "HAZEL", 
       "FIONA", "MARIE", "JENNA", "MARILYN", "DAISY", "NORA", "NATASHA", 
       "MINNIE", "FREDA", "MANDY", "RACHAEL", "KATHRYN", "NANCY", "RUTH", 
       "JAYNE", "DIANA", "MARIAN", "ELEANOR", "VERONICA", "SARA", "ALEXANDRA",
        "LOUISA", "JODIE", "DORA", "DAPHNE", "TERESA", "JULIA", "NORAH", 
       "HEATHER", "KIM", "JEMMA", "THELMA", "CARLY", "IDA", "CLARA", "GLORIA",
        "HOLLY", "HILARY", "MELISSA", "MARTHA", "CYNTHIA", "BERTHA", "KATY", 
       "LILLIAN", "CHERYL", "RUBY", "NAOMI", "BESSIE", "GAIL", "MILDRED", 
       "PENELOPE", "CHARLENE", "JADE", "CHRISTINA", "ANNETTE", "JEANETTE", 
       "ESTHER", "CAROLYN", "HARRIET", "ANITA", "GERALDINE", "BRIDGET", 
       "GEORGINA", "LINDSEY", "KAY", "STELLA", "GEMMA", "NICHOLA", "AIMEE", 
       "HEIDI", "MILLICENT", "MONICA", "THERESA", "MARGERY", "MAXINE", 
       "TANYA", "CARLA", "FANNY", "JOY", "LYDIA", "ALMA", "GLENYS", "DEBBIE", 
       "JENNY", "BLANCHE", "VIVIENNE", "TARA", "MIRIAM", "GLYNIS", "CLAIR", 
       "LYNDSEY", "SONIA", "MOLLY", "ELLA", "CHLOE", "SYBIL", "LEAH", "TONI", 
       "WILLIAM", "JOHN", "PAUL", "MARK", "JAMES", "MICHAEL", "STEPHEN", 
       "ANDREW", "DANIEL", "ARTHUR", "ROBERT", "RICHARD", "RONALD", "ANTHONY",
        "MATTHEW", "CHARLES", "FREDERICK", "KENNETH", "ALBERT", "ALAN", "IAN",
        "SIMON", "ERNEST", "ALFRED", "EDWARD", "JOSEPH", "LEE", "ADAM", 
       "ROGER", "HAROLD", "DEREK", "KEITH", "FRANK", "LESLIE", "RAYMOND", 
       "COLIN", "KEVIN", "DARREN", "HENRY", "PHILIP", "GARY", "BENJAMIN", 
       "STANLEY", "STEVEN", "ERIC", "MARTIN", "WALTER", "GRAHAM", "NICHOLAS", 
       "LEONARD", "BARRY", "HERBERT", "GORDON", "NORMAN", "NEIL", "NIGEL", 
       "MALCOLM", "TIMOTHY", "STUART", "GEOFFREY", "ALEXANDER", "CYRIL", 
       "SIDNEY", "FRANCIS", "RYAN", "PERCY", "LUKE", "JACK", "TREVOR", 
       "ADRIAN", "JAMIE", "WILFRED", "PATRICK", "SCOTT", "SAMUEL", "WAYNE", 
       "CECIL", "GARETH", "SEAN", "HORACE", "BERNARD", "FRED", "EDWIN", 
       "GERALD", "SHAUN", "CLIFFORD", "MAURICE", "CLIVE", "BEN", "ANTONY", 
       "VICTOR", "JUSTIN", "JEFFREY", "OLIVER", "EDGAR", "CHRISTIAN", 
       "ASHLEY", "KARL", "AARON", "MARC", "MOHAMMED", "HUGH", "RUSSELL", 
       "GAVIN", "LAWRENCE", "LIAM", "ROBIN", "PHILLIP", "NATHAN", 
       "DENIS"}, {CompressedData["
1:eJxd1Wd0FFUYBuANnVB26aEFsoEsLUDoNbQkJHSCvYtdDNgVsaGiIhHF3hW7
Yu+o2Htv2LD33nvf0WcO6/3xnee8d+58986d2bNF8xfVLmyQSCTW5yUSkVn+
NaqGciM2ZhM2ZTM2Z36OLXJyS7ZiayYDU2zDtmzH9uzAjsG6nVjAzuzCruzG
7kEuZA/2ZFFgOthnMXuxN0uYYZ/AeL/xefdlP/YP9j2ApRwYOChYfzDLgnMY
wqEcxuEcwZE55zsqW6OZ4pggh44N8jiOZ5oZlnMCJ3ISJ3MKk6xgJas4ldXB
OvF+ajgtuD49WzOyNZOzOJtzOJe1THIeN+Gm3IybB+NbcEtuxa25DbcN7ovd
jttzB+7I+cH8nbgzd+Gu3I27cw/uyQXM416s40Iu4t7ch/sywwrux/2Z4gHB
/AN5EA/mYh7CSi7JeT/R2KE8TB0uH8EMj+RSHsWjeQyX8Vj9jpPreDyXM97H
CVwRrFPPEwNXMsWTeHKwjyqu4ik8lafxdJ7BM3kWz2Y6sILnBPlcnpfY+FvM
vX4+L+CFvIireTEv4aW8jJc7q/j9XMEreVXOOUTv8mp5Da/htbyO1/MG3sib
9FnDaLzEe8wwyjfzFuO3yrfx9sA7uJZ38i7ezXW8h/eymDW8j/fzAT7ITDD+
UOK/b+dhPsJHExu/qcjH+DifYJJPsoAVLOVTzHAJn+YzTHMxn+VzfJ4pruNS
vsA6vsiX7C3eb+x6VvPloH/scr7CqqBP/Dzxfl7la575dXmDvEF+I1tvZust
vs13+C7f4/v8gB/yI5YFfhzkT/gpP+Pn/IJf8it+zfygX5i/4Qp+y++Y4vf8
gT/yJ/4cXI/v+4W/Bn1+4+/8g3/yL/7N6I8rMo8N2JCN2JhN2JRpfZrJzZnP
FmzJVmzNJFNZ22SrLaPvKjLNFNu5npHbyx3YkZ1YwM7swq55/+8bG/etCuxm
fncWsofePeWk+asD61kUrLsyWDfterVcEfRZxWLzenFZsM8F8lr2Nl4Snx/7
sC/7sT8HsDToOzDIg+TB2SrL1hAO5TAO5wiO5CiO5hiO5TiOZzkncCILOSnI
kzmFFYx+r2XOv8x7Kc/JleZVcSqrWcO0+dPk6awzPkOeGd9vfFZwfz1nG5/D
uazlvGz9A6CXPuY=
       "], Null}, {VertexLabels -> {
         Placed["Name", Tooltip]}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[0.018544322907928002`], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.5001357454627087`, 6.002609917393925}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.576053100782418, 5.895842978123906}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9482352292499296`, 6.097613755961862}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9151738067450674`, 5.438187776093255}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9567074804668376`, 5.823109470968475}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.4311982915193564`, 5.6103629903875545`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.6547283295530573`, 5.470141876035472}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.3291315986460237`, 5.564923358575424}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.8484477552373964`, 5.23528170334823}, {4.785953480575827, 
         4.792650979773929}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.8219155148254793`, 5.021313091663652}, {4.785953480575827, 
         4.792650979773929}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.795263229149113, 4.806376377871383}, {4.785953480575827, 
         4.792650979773929}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.768730988736946, 4.592407766202326}, {4.785953480575827, 
         4.792650979773929}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.6086243433705767`, 5.696340227043807}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.358444073478961, 5.720908552907942}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.104039957029104, 5.853325291739553}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.8849483735070924`, 4.159726937075257}, {2.4086328226038205`, 
         3.4233982178356124`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.354909712495269, 4.298709770518417}, {2.4086328226038205`, 
         3.4233982178356124`}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.781335379600659, 5.569052803189472}, {3.058154943199654, 
         6.028434144407518}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.1080448269975265`, 5.4944198310299175`}, {3.058154943199654, 
         6.028434144407518}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.911581255082521, 5.666345199323741}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.268654685620686, 5.835784189884132}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.740113935424552, 5.607079548351958}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.067717251909292, 5.577496225407183}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.1901160987714365`, 5.367156079183836}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.520191101496037, 5.362600346886898}, {2.464302487648301, 
         5.810836314891446}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.7753366495508, 5.483274457665864}, {2.464302487648301, 
         5.810836314891446}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.352267967999519, 3.8957326391109772`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.5019330232187524`, 5.409922858738638}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.891070426906905, 5.589514229585345}, {3.2683486202440615`, 
         6.000228186556448}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.208503456735674, 5.445752446748563}, {3.2683486202440615`, 
         6.000228186556448}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.572457321420985, 5.258074074588143}, {2.4965891867976207`, 
         5.591165272469905}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.7553571287751715`, 5.368129687605624}, {2.4965891867976207`, 
         5.591165272469905}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.5446951639929356`, 5.512180391519053}, {2.5973121055785473`, 
         6.06625200222989}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.8838422049841435`, 5.589110100505191}, {2.5973121055785473`, 
         6.06625200222989}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.546530712831092, 5.573524194826402}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.8188699679133604`, 6.085705867024174}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.3210376704601803`, 5.334694823182663}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.782379851104637, 5.965672351271724}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.958144342208718, 5.361913680577685}, {3.254307918443584, 
         5.5496448155168885`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.1273888396334026`, 5.222769624771382}, {3.254307918443584, 
         5.5496448155168885`}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         1.8480168639532184`, 4.371045396255162}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {2.47628317627636,
          5.3971524682153955`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.5930177695946828`, 5.543028999812309}, {2.7028347408065194`, 
         6.093244776759786}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9410422346103724`, 5.5852542667406775`}, {2.7028347408065194`, 
         6.093244776759786}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         1.015069443528973, 3.528774386330581}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.4279764095217113`, 5.3754730579667935`}, {2.3055152107392, 
         5.888803933863012}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.7087640646160263`, 5.548369365598673}, {2.3055152107392, 
         5.888803933863012}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.331821291441601, 5.716887595061483}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.4857107529680147`, 5.738563878031519}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.4013526182698466`, 5.880377038950135}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.354722758719908, 5.3840968980770985`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.2825463330866027`, 3.986538935106582}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.455882475071982, 5.426568464653732}, {2.3862080289961396`, 
         5.96445637275853}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.7615508173227004`, 5.5729263977756505`}, {2.3862080289961396`, 
         5.96445637275853}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.1661911124691793`, 6.017348842219756}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.679605445673041, 5.812763152337811}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         4.240273969422595, 3.294538442130717}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.150490349131523, 5.706038430596417}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.810332911515744, 5.814005780601199}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.220199677819779, 5.776796601251533}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9578274128557434`, 5.954294043242812}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.1861620991869795`, 5.63598141436367}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.188557496372201, 5.486614363414871}}, 0.05570143050888991], 
        ArrowBox[{{2.5001357454627087`, 6.002609917393925}, {
         2.576053100782418, 5.895842978123906}}, 0.05570143050888991], 
        ArrowBox[{{5.241668688810895, 5.4646874707731214`}, {
         4.785953480575827, 4.792650979773929}}, 0.05570143050888991], 
        ArrowBox[{{2.352267967999519, 3.8957326391109772`}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         1.8480168639532184`, 4.371045396255162}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {1.597638796308375, 
         2.822580191656698}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.0523930015783991,
          3.706412131116615}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.2573432638898039,
          3.024065950763953}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.149534950406232, 
         3.104895596389688}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.015069443528973, 3.528774386330581}, {
         0.6307814548672267, 3.2629881993466556`}, {0.16375040268722163`, 
         3.277185090685656}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.015069443528973, 3.528774386330581}, {
         0.5480383913489689, 3.542971277682385}, {0.16375040268722163`, 
         3.277185090685656}}], 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.32390662595910724`, 3.4694697204244216`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         2.2521088624868315`, 2.7009640096630276`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.12229625603424887`, 3.787375236833959}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.10083672655948739`, 3.601472315531462}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0., 
         3.502118652485}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {1.175365870848454, 
         3.080538658374356}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.2612918723690236,
          3.712739580181321}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.3113085352775964,
          3.298363826840268}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.14917822500752154`, 3.4254397730806256`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.049757259634716, 
         3.2075581295494073`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.015069443528973, 3.528774386330581}, {
         0.7323309720428639, 3.2287150893303744`}, {0.32668261120661146`, 
         3.155053482431751}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.015069443528973, 3.528774386330581}, {
         0.6094210826927068, 3.4551127794321226`}, {0.32668261120661146`, 
         3.155053482431751}}], 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.2283345869280864,
          3.57572093998461}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.0020333003880268485`, 3.36159621491312}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {
         1.9310109034488097`, 3.135898153365598}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {2.942715326111345,
          3.3644759808467883`}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {2.969792695888759,
          3.226794349488862}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {1.979892822619038,
          3.311264616838231}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {
         1.9521184939841647`, 2.973042113831754}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {
         2.0648042207302373`, 2.715105008020585}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.739341020106996, 2.9041888634933355`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.8051710924460034`, 2.8407736348909403`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.871319615308519, 2.777051637452472}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.9375780802734237`, 2.713223730970225}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         3.0037266031359064`, 2.6495017335537403`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         3.069556675474905, 2.586086504936254}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.3168289667787323`, 2.6557308467518714`}, {2.4780412190946257`, 
         3.04953873904153}}], 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.582048668260187, 2.636917245603628}, {2.4780412190946257`, 
         3.04953873904153}}], 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.0858918689478205`, 1.3686553831522517`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.158130764593345, 1.687858510106223}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.7872134804660247`, 1.501120672851946}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.8217485775752578`, 1.6835647125534663`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.2997933320975226`, 1.6206871164841348`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.708578448660259, 1.6276896036343267`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.0194579833936253`, 1.769213485184401}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.116707127932865, 1.5251410737698965`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.8676771058475212`, 1.8258680307398885`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.9178189325188169`, 1.391703535041099}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.9785572225889283`, 1.4912482384743169`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.7820472184635174`, 3.011445940856201}, {3.528800617824225, 
         3.4153936059804266`}}], 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.8936735482897027`, 2.6065550216699744`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.2328261514407464`, 1.4084201232941602`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.7321852594693112`, 1.9274867347286038`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.597638796308375, 2.822580191656698}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.9423447173186847`, 1.6152319259806995`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.3763239273976744`, 1.5033353754050143`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.6672865997969786`, 3.267408755140863}, {3.6909004173798046`, 
         3.0661122801603264`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5524144354070515`, 3.214097130898387}, {3.6909004173798046`, 
         3.0661122801603264`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.1675898153049924`, 2.6470570184353863`}, {2.420836415944293, 
         2.2431093533062914`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.0747327486684077`, 3.0938368434498473`}, {2.518440375008683, 
         3.1045688674195313`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.972508244164518, 3.4261256299514575`}, {2.518440375008683, 
         3.1045688674195313`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.344243104211506, 2.906533543959526}, {2.8936735482897027`, 
         2.6065550216699744`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.078231061902422, 3.1154150837058654`}, {2.8936735482897027`, 
         2.6065550216699744`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {2.47854069729822,
          2.8454206567419718`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.2021617590475486`, 3.8687370380391304`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.430511042091697, 4.473728563866835}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.250815849483389, 3.5696337399653917`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.142566988890562, 3.1686275723500845`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.2197151334224667`, 3.09390239538722}, {2.780141837132228, 
         3.0186312033407585`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.08922732153398, 3.340122413972776}, {2.780141837132228, 
         3.0186312033407585`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.093822430629724, 2.906375517885318}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.8310392015705985`, 3.940500392214558}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.9424344226979815`, 4.1837777970750905`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.7982340175534173`, 3.0657070382494767`}, {3.8075104349989717`, 
         2.6243579693144916`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5380770352697803`, 2.97404453705058}, {3.8075104349989717`, 
         2.6243579693144916`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {4.08749027015602,
          3.657082668658042}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.977474783878852, 4.049251013933451}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.695603974218695, 3.101816580844254}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.121059226743537, 3.171509965025869}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         5.089215577985817, 3.727051939623592}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.421474358397713, 2.190761571584863}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.751995213885709, 3.352265727245333}, {3.894149394496038, 
         3.1689813972080367`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.6709547984345567`, 3.2321092757899734`}, {3.894149394496038, 
         3.1689813972080367`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {3.70864795419601,
          2.615078784679503}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {4.10375792406919,
          3.464526110277083}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.829893270060526, 2.825695921522285}, {1.9173987331348583`, 
         2.7659584969191062`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5143437045371493`, 2.631688889708302}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.8937742888023044`, 3.511704774846602}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.480532646954007, 3.898639297232747}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.271285278493838, 3.080504665143418}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5936973336907365`, 4.134567590393875}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.383769973042954, 3.1431328987805087`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {3.66708201965197,
          3.919179018307792}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.7999915408060856`, 4.0944452232614905`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.135393023043709, 4.073502578805177}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.280637293984499, 3.4155044991217074`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.9939189361277716`, 3.3272009351431175`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.405503519385941, 3.270043524053674}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.070678820145944, 3.9323075706675006`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.239001584183471, 3.956164829537265}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {4.42975593123907,
          3.530715126116566}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5308128083228962`, 3.684012744192402}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.620491637143561, 2.635471976196063}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.727779462485876, 4.205311459421361}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.164943754401822, 3.796129407611249}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.2435476242779595`, 3.6993666739913427`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.3237636738212215`, 3.7328502920809923`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.401750579498126, 3.6513262470434413`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.9698408995471217`, 3.8055730640819547`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.448791131927424, 4.090933904285507}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.8550673799758357`, 2.9392153854630445`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.942715326111345, 3.3644759808467883`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.312071324715001, 3.8538501104467087`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.2407252861086775`, 2.959539268956114}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.7884955443447814`, 3.699892149571761}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {4.45271978013659,
          3.3929475838811536`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.011991317923822, 3.036747773860446}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.969792695888759, 3.226794349488862}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.303747585734906, 4.009134785783969}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.8312252633985353`, 5.035038489761629}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.02250839855121, 4.085384376734948}, {2.4086328226038205`, 
         3.4233982178356124`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.7049547520858848`, 3.7269685037551326`}, {2.4086328226038205`, 
         3.4233982178356124`}}], 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.1186903288310046`, 3.9098682059113075`}, {2.4780412190946257`, 
         3.04953873904153}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.6781812182968945`, 3.5286251957755383`}, {2.4780412190946257`, 
         3.04953873904153}}], 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         3.528800617824225, 3.4153936059804266`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.40785500153673926`, 4.976406801699863}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.9721685574452104, 4.878482660544747}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.3348605704734469`, 4.957690588079347}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8356128503657425, 4.7757653239935305`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.3115427379293525, 4.389448564296204}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.34047356613598767`, 4.867129181171479}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6915615283338803, 5.016260087063726}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.5955992707905655, 5.196042024112448}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.0459508566039295`, 4.433212273658721}, {0.8526101898675127, 
         4.630801060380589}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.065785259520211, 4.471448104883598}, {0.8526101898675127, 
         4.630801060380589}}], 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8526101898675127, 4.630801060380589}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.1056552583805983`, 4.548307618050227}, {0.8526101898675127, 
         4.630801060380589}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.125489661296848, 4.58654344936516}, {0.8526101898675127, 
         4.630801060380589}}], 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.7973218127784216, 5.309327189878359}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.4761450601789994, 4.616543958931642}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6456923969659738, 4.297023158634975}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.5121956560123038, 4.912632616901693}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.1335695410431113`, 5.308978399644691}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.0882241249858984`, 4.718258641356753}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.5751836336992446, 5.05690184501653}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.469824124602396, 5.104041355271252}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8111154356254753, 4.307441482229554}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.9639135195187563, 5.351582525329796}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.5245821466388976, 4.1755742699901655`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.1570296631032222`, 4.93157558571205}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.28107756110461724`, 4.53044812328401}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.4743370203504087, 4.770891969196664}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.2700113959364694`, 5.216234865895061}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.42525919744296914`, 4.487389538446732}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.122124740619637, 5.126947335427426}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6549332117216733, 4.5921800581849155`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8205650367556543, 4.937147459315856}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.7146891851664909, 4.132475827523839}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.34263158638482816`, 4.636992912800938}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.3969266456918503`, 3.1981103616770197`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.3075950641940195, 4.746511591063642}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {2.47854069729822,
          2.8454206567419718`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6547419541326955, 4.863807700351988}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.49381208403271515`, 4.375955918345492}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8840158256227015, 5.228855102061041}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.4153070868230553, 4.270270166834985}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.7045673804419805, 5.219838233621284}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8761205997475692, 4.462482997072011}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6299052385371002, 4.714382051200481}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.2630543941416832`, 5.08193444559997}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8072815412905161, 5.104601698173099}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6318581063100894, 4.462220058202436}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.9556190288915065, 5.060575878942867}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.4880864554634101`, 3.5849160660106336`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.0179552862225605`, 5.218444329525832}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.3911945670759331`, 3.5449209449397725`}}, 0.05570143050888991], 
        ArrowBox[{{4.430511042091697, 4.473728563866835}, {4.981213223955975, 
         5.0445610970507975`}}, 0.05570143050888991], 
        ArrowBox[{{4.430511042091697, 4.473728563866835}, {4.867566821905859, 
         5.1563861762750385`}}, 0.05570143050888991], 
        ArrowBox[{{2.780141837132228, 3.0186312033407585`}, {
         3.142566988890562, 3.1686275723500845`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.0549058989339706`, 3.175457258094726}, {2.4086328226038205`, 
         3.4233982178356124`}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.271125656804717, 3.01389945667147}, {2.4086328226038205`, 
         3.4233982178356124`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.5735998825420134`, 3.2483991040245725`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.7318601302304497`, 2.7647254080153565`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.352267967999519, 3.8957326391109772`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.2825463330866027`, 3.986538935106582}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.6163060808985588`, 3.3556561813862746`}, {3.528800617824225, 
         3.4153936059804266`}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.8936735482897027`, 2.6065550216699744`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.7321852594693112`, 1.9274867347286038`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.47854069729822, 2.8454206567419718`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.4880864554634101`, 3.5849160660106336`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.5262034831252875`, 3.0689103146972503`}, {1.3911945670759331`, 
         3.5449209449397725`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.7823898170855064`, 3.2419691271574425`}, {1.3911945670759331`, 
         3.5449209449397725`}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.780141837132228, 3.0186312033407585`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.695603974218695, 3.101816580844254}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.4946525051929707`, 2.8012281393391385`}, {1.175365870848454, 
         3.080538658374356}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.5981120987903408`, 3.045269015956232}, {1.175365870848454, 
         3.080538658374356}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.0774078703579866`, 2.762021135226445}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.5671950887519348`, 2.2865173398017777`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.1777948334100428`, 2.6217420157641214`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.3803050652017146`, 2.477758651764651}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.109385498151434, 2.4917851013821215`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.1688366839844044`, 2.8533041468787195`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.3442796757106674`, 2.620655965758532}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.0093171896476711`, 2.342119382412407}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.654812508403634, 2.1482345319902834`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.136379271804913, 2.10179967534156}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.398893722561458, 2.337537030955006}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.0445336068141367`, 2.2145012697976156`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.5178886194675658`, 2.070324688298257}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.392985116128974, 2.0172300490268786`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.2701560228774893`, 2.170868016397018}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.3975982075832798`, 2.18479886837523}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.0010160736343976`, 2.6224015147170086`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.2584534476124616`, 2.0186966525050893`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         0.9660759676933837, 2.472803415911055}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.307329914043703, 2.8190553153022355`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.2203116837267625`, 2.403725156264022}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.0648042207302373`, 2.715105008020585}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.1743389460149922`, 2.274227348673222}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.487818504542941, 4.123825419169118}, {4.785953480575827, 
         4.792650979773929}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.7477955876911, 4.670987906612375}, {4.785953480575827, 
         4.792650979773929}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.043013106420663, 3.1212124988415524`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         4.794708784875165, 4.128115862303972}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.461329494020754, 3.285037203814879}, {4.240273969422595, 
         3.294538442130717}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.403295561100528, 3.46623429946399}, {4.240273969422595, 
         3.294538442130717}}], 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {4.240273969422595, 
         3.294538442130717}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.286639019980282, 3.8304664886949586`}, {4.240273969422595, 
         3.294538442130717}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.228605087060059, 4.011663584345868}, {4.240273969422595, 
         3.294538442130717}}], 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {5.089215577985817, 
         3.727051939623592}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.07605019362437, 
         4.7921768996926755`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.108569302428034, 
         4.289256406799745}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.162718825972419, 
         4.485721789141594}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.217602994975898, 
         3.9554024603260465`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.069766489239364, 
         3.4849957919804195`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.839643628137155, 
         4.449570510691226}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.339445919688016, 
         4.06213114401514}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.930031394773706, 
         3.334106453459885}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.29515948689261, 
         3.6711682743193585`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.384969987960359, 
         4.4221485605780035`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.497997598777275, 
         4.020280573460792}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.157390138415499, 
         4.132924398807478}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.202438494892904, 
         3.420668394795633}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.722960004274572, 
         4.310322961527341}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.920383828516393, 
         4.5673503536250575`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.348361489395701, 
         3.913040092783218}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.724336630874012, 
         3.5382502837181464`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.04286578353353, 
         3.992902738035645}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.313344466056199, 
         3.511235759908192}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.246250065585384, 
         3.7936881591370293`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.49221300887856, 
         4.6428349632936685`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         6.676181246622793, 4.0265111802172}, {6.872934999963933, 
         3.9116529007241962`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         6.646414364999324, 3.8873040670134915`}, {6.872934999963933, 
         3.9116529007241962`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         6.653721168647265, 4.301962224361364}, {6.99589646107202, 
         4.4221152403054855`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         6.79183590408297, 4.122315361915772}, {6.99589646107202, 
         4.4221152403054855`}}], 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.030576710727809, 
         3.6677971129569764`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.402875651459135, 
         4.206617655166467}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         7.5092294802897115`, 4.155850833215487}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.826626790601779, 
         4.124531057816174}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.182830794179319, 
         4.711163026407839}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.909356644316942, 
         3.531218243022184}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.940971265755323, 
         4.7371375157582545`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.051834577147967, 
         4.623993472853848}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.979285916089861, 
         4.202026505373777}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.765187881582182, 
         4.849704246674317}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         7.1647163047764835`, 3.6052812946290684`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.256449545263353, 
         4.602101352336273}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.450823132744214, 
         4.3296976212458285`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         6.7332729528748025`, 4.739823640833926}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.073475795754592, 
         3.3446634144767353`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.243126257987642, 
         4.3742895738521925`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         6.5865952470127995`, 4.480947617956097}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.813630168216543, 
         3.719486279249364}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.082709938405188, 
         3.811335885439358}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         6.7900103730083154`, 3.3864915489480705`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.726461226363466, 
         4.580391401353141}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.271976368383317, 
         4.217171575296142}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.417303205744281, 
         3.641247907462545}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.889499163828672, 
         4.854877707567038}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.436827334648331, 
         3.776543704867336}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.36669655127135, 
         4.539807801375816}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.487593683926255, 
         3.8913864754248957`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.568781576929737, 
         4.791634583666779}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.282482328252882, 2.6005783515765297`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.4170792677831248`, 2.6217310114520327`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.5522851918905665`, 2.6429793766507057`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.6868821314208198`, 2.664132036547722}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.8599702749246174`, 2.3521203348251003`}, {2.4780412190946257`, 
         3.04953873904153}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.199374124206088, 2.7149627772180787`}, {2.4780412190946257`, 
         3.04953873904153}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.1406310129966992`, 2.198975366915549}, {2.8936735482897027`, 
         2.6065550216699744`}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.8936735482897027`, 2.6065550216699744`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.3343457153291007`, 2.4251240277550856`}, {2.8936735482897027`, 
         2.6065550216699744`}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.7321852594693112`, 1.9274867347286038`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.79498175958685, 2.4130676050820368`}, {2.3969266456918503`, 
         3.1981103616770197`}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.3969266456918503`, 3.1981103616770197`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.183248066141095, 2.8025871295897247`}, {2.3969266456918503`, 
         3.1981103616770197`}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8075104349989717`, 2.6243579693144916`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.421474358397713, 2.190761571584863}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {3.70864795419601,
          2.615078784679503}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.5143437045371493`, 2.631688889708302}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.4992849318150934`, 2.332952353797486}, {3.620491637143561, 
         2.635471976196063}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.620491637143561, 2.635471976196063}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.70250988536456, 2.320063995422512}, {3.620491637143561, 
         2.635471976196063}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.2521088624868315`, 2.7009640096630276`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.086947054882777, 1.519870605989537}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {4.18209667336294,
          1.4140793613221037`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.925138690548266, 1.4347354403711694`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8679255336938736`, 1.2632213976747777`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.979849145266797, 1.6416616732844578`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {4.46363350817925,
          1.8072214144657355`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.349911798840048, 1.7078513085738685`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.471555947280286, 1.068618203063001}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.295671362053043, 1.5656152959568475`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.026224270844277, 1.194980682649728}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.9434906982274556`, 1.9432700046139215`}, {4.19088866799243, 
         1.6685142500137031`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8287011498010797`, 1.7427886183891481`}, {4.19088866799243, 
         1.6685142500137031`}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8432883078061626`, 1.6652882090850187`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.274060087359451, 1.3715767941168013`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.7164694653507095`, 1.2254168366564895`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.025537181086292, 1.3306997299521077`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.437201726066682, 1.4788486729610324`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.272361280221109, 1.8734433678623728`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.5869571021565627`, 1.5841419622038597`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.403274340812292, 1.4813956224851554`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.124709468232238, 1.8263122936120195`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.6289533279741266`, 1.2779280947152851`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.455341129301084, 1.628651384177883}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.4177692935803883`, 1.2962703706061052`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.6759923074530665`, 1.446008295597642}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.310076412808286, 1.3736411898265515`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8058864883790147`, 1.1742553557001956`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.377534460488725, 1.9508173489446283`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.5908997950331663`, 1.1746006289113988`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8167824403242876`, 1.41118222984997}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.184505427359471, 1.2669661240102115`}}, 0.05570143050888991], 
        ArrowBox[{{4.471555947280286, 1.068618203063001}, {5.047638369107941, 
         0.4111912972831533}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.133147154561208, 2.1482538366307278`}, {3.6909004173798046`, 
         3.0661122801603264`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.786832454129947, 1.9963693816692503`}, {3.6909004173798046`, 
         3.0661122801603264`}}], 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         4.240273969422595, 3.294538442130717}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.7321852594693112`, 1.9274867347286038`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.47854069729822, 2.8454206567419718`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.421474358397713, 2.190761571584863}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.2033776710043345`, 1.2324405583106968`}, {3.274060087359451, 
         1.3715767941168013`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.299761607666473, 1.2176471740010286`}, {3.274060087359451, 
         1.3715767941168013`}}], 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.529183377782783, 0.3459540572094859}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.855260453944898, 0.3303523773370447}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.632165776231189, 0.11103641985856338`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.623085392018389, 0.24813975997412197`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.691707167723954, 0.5505356231454419}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.189233266615462, 0.25849377658537387`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.0191831405526632`, 0.4113205932000388}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3710776248337075`, 0.2999523784538045}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.167773717230054, 0.4385212239551035}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.7716537203514955`, 0.4302322473870501}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3108059160742314`, 0.15061590799352498`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.967013800042194, 0.17293923908540476`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.834010241282577, 1.990508425310403}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.8663225857892227`, 0.3162379741460035}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.033793051399473, 0.27333934580722286`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.1533319156711497`, 0.12824719894068837`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.901323876584327, 0.46408514083271557`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.5778245924135943`, 0.4688222282786785}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.5170786709362716`, 0.04384570570227053}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.733477488615379, 0.3594720657048902}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.764343642195909, 0.2002421538590511}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3889215317152495`, 0.03714367247629635}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.852030977769403, 0.09540886872204357}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.8913260505315477`, 0.5169506416851912}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.2711795821890868`, 0.}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.4757292291894126`, 0.17919497776812854`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.131451414038333, 0.017911701145744807`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.62996839398561, 0.3358079206113249}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.760508776801317, 0.5082595388835616}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.57736217973407, 0.4804479081603814}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3532423647517455`, 0.4616839528821379}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.81669742895982, 0.2197850566076167}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.687649817279081, 0.20397739499959755`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.9942706618603867`, 0.04006566250262589}}, 0.05570143050888991], 
        ArrowBox[{{2.834010241282577, 1.990508425310403}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991]}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8312252633985353`, 5.035038489761629}, 
           0.05570143050888991],
          "\"MARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.5001357454627087`, 6.002609917393925}, 
           0.05570143050888991],
          "\"FLORENCE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FLORENCE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.576053100782418, 5.895842978123906}, 0.05570143050888991],
          "\"JEAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9482352292499296`, 6.097613755961862}, 
           0.05570143050888991],
          "\"JULIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JULIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9151738067450674`, 5.438187776093255}, 
           0.05570143050888991],
          "\"CLAIRE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLAIRE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9567074804668376`, 5.823109470968475}, 
           0.05570143050888991],
          "\"LAURA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LAURA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4311982915193564`, 5.6103629903875545`}, 
           0.05570143050888991],
          "\"DORIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DORIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.6547283295530573`, 5.470141876035472}, 
           0.05570143050888991],
          "\"JOAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3291315986460237`, 5.564923358575424}, 
           0.05570143050888991],
          "\"CHRISTINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHRISTINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.785953480575827, 4.792650979773929}, 0.05570143050888991],
          "\"KAREN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KAREN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.241668688810895, 5.4646874707731214`}, 
           0.05570143050888991],
          "\"NICOLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NICOLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.6086243433705767`, 5.696340227043807}, 
           0.05570143050888991],
          "\"DOROTHY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DOROTHY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.358444073478961, 5.720908552907942}, 0.05570143050888991],
          "\"JOYCE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOYCE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.104039957029104, 5.853325291739553}, 0.05570143050888991],
          "\"JACQUELINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JACQUELINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.4086328226038205`, 3.4233982178356124`}, 
           0.05570143050888991],
          "\"EMMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EMMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3880612796376046`, 3.247166015126839}, 
           0.05570143050888991],
          "\"KATHLEEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATHLEEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.058154943199654, 6.028434144407518}, 0.05570143050888991],
          "\"JANET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JANET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.911581255082521, 5.666345199323741}, 0.05570143050888991],
          "\"LISA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LISA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.268654685620686, 5.835784189884132}, 0.05570143050888991],
          "\"ANNIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.740113935424552, 5.607079548351958}, 0.05570143050888991],
          "\"SHEILA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHEILA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.067717251909292, 5.577496225407183}, 0.05570143050888991],
          "\"ANN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1901160987714365`, 5.367156079183836}, 
           0.05570143050888991],
          "\"JOANNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOANNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.464302487648301, 5.810836314891446}, 0.05570143050888991],
          "\"ELSIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELSIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.352267967999519, 3.8957326391109772`}, 
           0.05570143050888991],
          "\"BARBARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BARBARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5019330232187524`, 5.409922858738638}, 
           0.05570143050888991],
          "\"CAROL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CAROL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2683486202440615`, 6.000228186556448}, 
           0.05570143050888991],
          "\"JANE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JANE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.4965891867976207`, 5.591165272469905}, 
           0.05570143050888991],
          "\"MICHELLE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MICHELLE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.5973121055785473`, 6.06625200222989}, 
           0.05570143050888991],
          "\"VICTORIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VICTORIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.546530712831092, 5.573524194826402}, 0.05570143050888991],
          "\"ALICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8188699679133604`, 6.085705867024174}, 
           0.05570143050888991],
          "\"IRENE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IRENE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3210376704601803`, 5.334694823182663}, 
           0.05570143050888991],
          "\"HELEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HELEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.782379851104637, 5.965672351271724}, 0.05570143050888991],
          "\"SAMANTHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SAMANTHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.254307918443584, 5.5496448155168885`}, 
           0.05570143050888991],
          "\"JUNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JUNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6909004173798046`, 3.0661122801603264`}, 
           0.05570143050888991],
          "\"MAUREEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAUREEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8480168639532184`, 4.371045396255162}, 
           0.05570143050888991],
          "\"DIANE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DIANE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.47628317627636, 5.3971524682153955`}, 
           0.05570143050888991],
          "\"RACHEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RACHEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.7028347408065194`, 6.093244776759786}, 
           0.05570143050888991],
          "\"WINIFRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WINIFRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.015069443528973, 3.528774386330581}, 0.05570143050888991],
          "\"EILEEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EILEEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.4780412190946257`, 3.04953873904153}, 
           0.05570143050888991],
          "\"SHIRLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHIRLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3055152107392, 5.888803933863012}, 0.05570143050888991],
          "\"ANNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.331821291441601, 5.716887595061483}, 0.05570143050888991],
          "\"SHARON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHARON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4857107529680147`, 5.738563878031519}, 
           0.05570143050888991],
          "\"AMY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AMY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4013526182698466`, 5.880377038950135}, 
           0.05570143050888991],
          "\"GLADYS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLADYS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.354722758719908, 5.3840968980770985`}, 
           0.05570143050888991],
          "\"BETTY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BETTY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2825463330866027`, 3.986538935106582}, 
           0.05570143050888991],
          "\"VALERIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VALERIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3862080289961396`, 5.96445637275853}, 
           0.05570143050888991],
          "\"AMANDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AMANDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1661911124691793`, 6.017348842219756}, 
           0.05570143050888991],
          "\"JENNIFER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JENNIFER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.679605445673041, 5.812763152337811}, 0.05570143050888991],
          "\"ANGELA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANGELA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.240273969422595, 3.294538442130717}, 0.05570143050888991],
          "\"ETHEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ETHEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.150490349131523, 5.706038430596417}, 0.05570143050888991],
          "\"SANDRA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SANDRA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.810332911515744, 5.814005780601199}, 0.05570143050888991],
          "\"LOUISE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LOUISE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.220199677819779, 5.776796601251533}, 0.05570143050888991],
          "\"KATIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9578274128557434`, 5.954294043242812}, 
           0.05570143050888991],
          "\"HILDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HILDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.1861620991869795`, 5.63598141436367}, 
           0.05570143050888991],
          "\"PHYLLIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PHYLLIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.188557496372201, 5.486614363414871}, 0.05570143050888991],
          "\"DOREEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DOREEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.420836415944293, 2.2431093533062914`}, 
           0.05570143050888991],
          "\"PAULINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAULINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.0858918689478205`, 1.3686553831522517`}, 
           0.05570143050888991],
          "\"LILIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LILIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.158130764593345, 1.687858510106223}, 0.05570143050888991],
          "\"AUDREY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AUDREY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.7872134804660247`, 1.501120672851946}, 
           0.05570143050888991],
          "\"CLARE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLARE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8217485775752578`, 1.6835647125534663`}, 
           0.05570143050888991],
          "\"KELLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KELLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2997933320975226`, 1.6206871164841348`}, 
           0.05570143050888991],
          "\"IVY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IVY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.708578448660259, 1.6276896036343267`}, 
           0.05570143050888991],
          "\"VERA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VERA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.0194579833936253`, 1.769213485184401}, 
           0.05570143050888991],
          "\"BRENDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BRENDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.116707127932865, 1.5251410737698965`}, 
           0.05570143050888991],
          "\"GILLIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GILLIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8676771058475212`, 1.8258680307398885`}, 
           0.05570143050888991],
          "\"NATALIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NATALIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9178189325188169`, 1.391703535041099}, 
           0.05570143050888991],
          "\"VIOLET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VIOLET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9785572225889283`, 1.4912482384743169`}, 
           0.05570143050888991],
          "\"PAMELA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAMELA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.518440375008683, 3.1045688674195313`}, 
           0.05570143050888991],
          "\"SYLVIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SYLVIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.528800617824225, 3.4153936059804266`}, 
           0.05570143050888991],
          "\"ELAINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELAINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8936735482897027`, 2.6065550216699744`}, 
           0.05570143050888991],
          "\"ELLEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELLEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2328261514407464`, 1.4084201232941602`}, 
           0.05570143050888991],
          "\"LESLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LESLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.7321852594693112`, 1.9274867347286038`}, 
           0.05570143050888991],
          "\"CATHERINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CATHERINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.597638796308375, 2.822580191656698}, 0.05570143050888991],
          "\"HAYLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HAYLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9423447173186847`, 1.6152319259806995`}, 
           0.05570143050888991],
          "\"LILY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LILY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3763239273976744`, 1.5033353754050143`}, 
           0.05570143050888991],
          "\"EDNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3188303280332685`, 4.388954662649468}, 
           0.05570143050888991],
          "\"HANNAH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HANNAH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.40785500153673926`, 4.976406801699863}, 
           0.05570143050888991],
          "\"NELLIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NELLIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9721685574452104, 4.878482660544747}, 
           0.05570143050888991],
          "\"BERYL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BERYL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3348605704734469`, 4.957690588079347}, 
           0.05570143050888991],
          "\"WENDY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WENDY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8356128503657425, 4.7757653239935305`}, 
           0.05570143050888991],
          "\"LUCY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LUCY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.3115427379293525, 4.389448564296204}, 
           0.05570143050888991],
          "\"ADA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ADA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.34047356613598767`, 4.867129181171479}, 
           0.05570143050888991],
          "\"DAWN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DAWN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6915615283338803, 5.016260087063726}, 
           0.05570143050888991],
          "\"DONNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DONNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5955992707905655, 5.196042024112448}, 
           0.05570143050888991],
          "\"BEATRICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BEATRICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8526101898675127, 4.630801060380589}, 
           0.05570143050888991],
          "\"OLIVE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "OLIVE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.7973218127784216, 5.309327189878359}, 
           0.05570143050888991],
          "\"CAROLE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CAROLE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.4761450601789994, 4.616543958931642}, 
           0.05570143050888991],
          "\"DANIELLE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DANIELLE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6456923969659738, 4.297023158634975}, 
           0.05570143050888991],
          "\"MAY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5121956560123038, 4.912632616901693}, 
           0.05570143050888991],
          "\"EVELYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EVELYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1335695410431113`, 5.308978399644691}, 
           0.05570143050888991],
          "\"ROSE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROSE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0882241249858984`, 4.718258641356753}, 
           0.05570143050888991],
          "\"MAVIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAVIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5751836336992446, 5.05690184501653}, 0.05570143050888991],
          "\"SALLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SALLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.469824124602396, 5.104041355271252}, 0.05570143050888991],
          "\"KATHERINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATHERINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8111154356254753, 4.307441482229554}, 
           0.05570143050888991],
          "\"IRIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IRIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9639135195187563, 5.351582525329796}, 
           0.05570143050888991],
          "\"JUDITH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JUDITH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5245821466388976, 4.1755742699901655`}, 
           0.05570143050888991],
          "\"MARIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1570296631032222`, 4.93157558571205}, 
           0.05570143050888991],
          "\"ZOE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ZOE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.28107756110461724`, 4.53044812328401}, 
           0.05570143050888991],
          "\"KERRY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KERRY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.4743370203504087, 4.770891969196664}, 
           0.05570143050888991],
          "\"DEBRA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DEBRA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2700113959364694`, 5.216234865895061}, 
           0.05570143050888991],
          "\"MELANIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MELANIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.42525919744296914`, 4.487389538446732}, 
           0.05570143050888991],
          "\"STACEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STACEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.122124740619637, 5.126947335427426}, 0.05570143050888991],
          "\"GERTRUDE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GERTRUDE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6549332117216733, 4.5921800581849155`}, 
           0.05570143050888991],
          "\"MURIEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MURIEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8205650367556543, 4.937147459315856}, 
           0.05570143050888991],
          "\"PAULA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAULA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.7146891851664909, 4.132475827523839}, 
           0.05570143050888991],
          "\"LAUREN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LAUREN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.34263158638482816`, 4.636992912800938}, 
           0.05570143050888991],
          "\"MARION\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARION", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3969266456918503`, 3.1981103616770197`}, 
           0.05570143050888991],
          "\"JOANNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOANNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.3075950641940195, 4.746511591063642}, 
           0.05570143050888991],
          "\"MARINA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARINA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.47854069729822, 2.8454206567419718`}, 
           0.05570143050888991],
          "\"JANICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JANICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6547419541326955, 4.863807700351988}, 
           0.05570143050888991],
          "\"LORRAINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LORRAINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.49381208403271515`, 4.375955918345492}, 
           0.05570143050888991],
          "\"JESSIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JESSIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8840158256227015, 5.228855102061041}, 
           0.05570143050888991],
          "\"PEGGY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PEGGY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.4153070868230553, 4.270270166834985}, 
           0.05570143050888991],
          "\"ROSEMARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROSEMARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.7045673804419805, 5.219838233621284}, 
           0.05570143050888991],
          "\"LYNN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYNN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8761205997475692, 4.462482997072011}, 
           0.05570143050888991],
          "\"ANDREA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANDREA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6299052385371002, 4.714382051200481}, 
           0.05570143050888991],
          "\"FRANCES\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRANCES", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2630543941416832`, 5.08193444559997}, 
           0.05570143050888991],
          "\"SUZANNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SUZANNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8072815412905161, 5.104601698173099}, 
           0.05570143050888991],
          "\"GRACE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GRACE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6318581063100894, 4.462220058202436}, 
           0.05570143050888991],
          "\"JOSEPHINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOSEPHINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9556190288915065, 5.060575878942867}, 
           0.05570143050888991],
          "\"YVONNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "YVONNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.4880864554634101`, 3.5849160660106336`}, 
           0.05570143050888991],
          "\"SOPHIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SOPHIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0179552862225605`, 5.218444329525832}, 
           0.05570143050888991],
          "\"LYNNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYNNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3911945670759331`, 3.5449209449397725`}, 
           0.05570143050888991],
          "\"ANNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2021617590475486`, 3.8687370380391304`}, 
           0.05570143050888991],
          "\"EVA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EVA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.430511042091697, 4.473728563866835}, 0.05570143050888991],
          "\"GWENDOLINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GWENDOLINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.981213223955975, 5.0445610970507975`}, 
           0.05570143050888991],
          "\"JESSICA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JESSICA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.250815849483389, 3.5696337399653917`}, 
           0.05570143050888991],
          "\"NORMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.142566988890562, 3.1686275723500845`}, 
           0.05570143050888991],
          "\"BEVERLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BEVERLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.780141837132228, 3.0186312033407585`}, 
           0.05570143050888991],
          "\"KIRSTY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIRSTY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.093822430629724, 2.906375517885318}, 0.05570143050888991],
          "\"KIMBERLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIMBERLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8310392015705985`, 3.940500392214558}, 
           0.05570143050888991],
          "\"HAZEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HAZEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.9424344226979815`, 4.1837777970750905`}, 
           0.05570143050888991],
          "\"FIONA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FIONA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8075104349989717`, 2.6243579693144916`}, 
           0.05570143050888991],
          "\"MARIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.08749027015602, 3.657082668658042}, 0.05570143050888991],
          
          "\"JENNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JENNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.867566821905859, 5.1563861762750385`}, 
           0.05570143050888991],
          "\"MARILYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARILYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.977474783878852, 4.049251013933451}, 0.05570143050888991],
          "\"DAISY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DAISY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.695603974218695, 3.101816580844254}, 0.05570143050888991],
          "\"NORA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.121059226743537, 3.171509965025869}, 0.05570143050888991],
          "\"NATASHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NATASHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.089215577985817, 3.727051939623592}, 0.05570143050888991],
          "\"MINNIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MINNIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.421474358397713, 2.190761571584863}, 0.05570143050888991],
          "\"FREDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FREDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.894149394496038, 3.1689813972080367`}, 
           0.05570143050888991],
          "\"MANDY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MANDY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.70864795419601, 2.615078784679503}, 0.05570143050888991],
          
          "\"RACHAEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RACHAEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.10375792406919, 3.464526110277083}, 0.05570143050888991],
          
          "\"KATHRYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATHRYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9173987331348583`, 2.7659584969191062`}, 
           0.05570143050888991],
          "\"NANCY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NANCY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5143437045371493`, 2.631688889708302}, 
           0.05570143050888991],
          "\"RUTH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RUTH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8937742888023044`, 3.511704774846602}, 
           0.05570143050888991],
          "\"JAYNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JAYNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.480532646954007, 3.898639297232747}, 0.05570143050888991],
          "\"DIANA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DIANA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.271285278493838, 3.080504665143418}, 0.05570143050888991],
          "\"MARIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5936973336907365`, 4.134567590393875}, 
           0.05570143050888991],
          "\"ELEANOR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELEANOR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.383769973042954, 3.1431328987805087`}, 
           0.05570143050888991],
          "\"VERONICA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VERONICA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.66708201965197, 3.919179018307792}, 0.05570143050888991],
          
          "\"SARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.7999915408060856`, 4.0944452232614905`}, 
           0.05570143050888991],
          "\"ALEXANDRA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALEXANDRA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.135393023043709, 4.073502578805177}, 0.05570143050888991],
          "\"LOUISA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LOUISA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.280637293984499, 3.4155044991217074`}, 
           0.05570143050888991],
          "\"JODIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JODIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.9939189361277716`, 3.3272009351431175`}, 
           0.05570143050888991],
          "\"DORA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DORA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.405503519385941, 3.270043524053674}, 0.05570143050888991],
          "\"DAPHNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DAPHNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.070678820145944, 3.9323075706675006`}, 
           0.05570143050888991],
          "\"TERESA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TERESA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.239001584183471, 3.956164829537265}, 0.05570143050888991],
          "\"JULIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JULIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.42975593123907, 3.530715126116566}, 0.05570143050888991],
          
          "\"NORAH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORAH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5308128083228962`, 3.684012744192402}, 
           0.05570143050888991],
          "\"HEATHER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HEATHER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.620491637143561, 2.635471976196063}, 0.05570143050888991],
          "\"KIM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.727779462485876, 4.205311459421361}, 0.05570143050888991],
          "\"JEMMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEMMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.164943754401822, 3.796129407611249}, 0.05570143050888991],
          "\"THELMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "THELMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2435476242779595`, 3.6993666739913427`}, 
           0.05570143050888991],
          "\"CARLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CARLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.3237636738212215`, 3.7328502920809923`}, 
           0.05570143050888991],
          "\"IDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.401750579498126, 3.6513262470434413`}, 
           0.05570143050888991],
          "\"CLARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.9698408995471217`, 3.8055730640819547`}, 
           0.05570143050888991],
          "\"GLORIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLORIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.448791131927424, 4.090933904285507}, 0.05570143050888991],
          "\"HOLLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HOLLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8550673799758357`, 2.9392153854630445`}, 
           0.05570143050888991],
          "\"HILARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HILARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9310109034488097`, 3.135898153365598}, 
           0.05570143050888991],
          "\"MELISSA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MELISSA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.942715326111345, 3.3644759808467883`}, 
           0.05570143050888991],
          "\"MARTHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARTHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.312071324715001, 3.8538501104467087`}, 
           0.05570143050888991],
          "\"CYNTHIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CYNTHIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.2407252861086775`, 2.959539268956114}, 
           0.05570143050888991],
          "\"BERTHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BERTHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.7884955443447814`, 3.699892149571761}, 
           0.05570143050888991],
          "\"KATY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.45271978013659, 3.3929475838811536`}, 
           0.05570143050888991],
          "\"LILLIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LILLIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.011991317923822, 3.036747773860446}, 0.05570143050888991],
          "\"CHERYL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHERYL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.969792695888759, 3.226794349488862}, 0.05570143050888991],
          "\"RUBY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RUBY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.303747585734906, 4.009134785783969}, 0.05570143050888991],
          "\"NAOMI\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NAOMI", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.0523930015783991, 3.706412131116615}, 
           0.05570143050888991],
          "\"BESSIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BESSIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.2573432638898039, 3.024065950763953}, 
           0.05570143050888991],
          "\"GAIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GAIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.979892822619038, 3.311264616838231}, 0.05570143050888991],
          "\"MILDRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MILDRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.149534950406232, 3.104895596389688}, 0.05570143050888991],
          "\"PENELOPE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PENELOPE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.16375040268722163`, 3.277185090685656}, 
           0.05570143050888991],
          "\"CHARLENE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHARLENE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.32390662595910724`, 3.4694697204244216`}, 
           0.05570143050888991],
          "\"JADE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JADE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2521088624868315`, 2.7009640096630276`}, 
           0.05570143050888991],
          "\"CHRISTINA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHRISTINA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.12229625603424887`, 3.787375236833959}, 
           0.05570143050888991],
          "\"ANNETTE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNETTE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.10083672655948739`, 3.601472315531462}, 
           0.05570143050888991],
          "\"JEANETTE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEANETTE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[DiskBox[{0., 3.502118652485}, 0.05570143050888991],
          "\"ESTHER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ESTHER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.175365870848454, 3.080538658374356}, 0.05570143050888991],
          "\"CAROLYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CAROLYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.2612918723690236, 3.712739580181321}, 
           0.05570143050888991],
          "\"HARRIET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HARRIET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.3113085352775964, 3.298363826840268}, 
           0.05570143050888991],
          "\"ANITA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANITA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.14917822500752154`, 3.4254397730806256`}, 
           0.05570143050888991],
          "\"GERALDINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GERALDINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.049757259634716, 3.2075581295494073`}, 
           0.05570143050888991],
          "\"BRIDGET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BRIDGET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.32668261120661146`, 3.155053482431751}, 
           0.05570143050888991],
          "\"GEORGINA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GEORGINA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.2283345869280864, 3.57572093998461}, 0.05570143050888991],
          "\"LINDSEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LINDSEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.0020333003880268485`, 3.36159621491312}, 
           0.05570143050888991],
          "\"KAY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KAY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0774078703579866`, 2.762021135226445}, 
           0.05570143050888991],
          "\"STELLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STELLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.5671950887519348`, 2.2865173398017777`}, 
           0.05570143050888991],
          "\"GEMMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GEMMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1777948334100428`, 2.6217420157641214`}, 
           0.05570143050888991],
          "\"NICHOLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NICHOLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3803050652017146`, 2.477758651764651}, 
           0.05570143050888991],
          "\"AIMEE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AIMEE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.109385498151434, 2.4917851013821215`}, 
           0.05570143050888991],
          "\"HEIDI\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HEIDI", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1688366839844044`, 2.8533041468787195`}, 
           0.05570143050888991],
          "\"MILLICENT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MILLICENT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3442796757106674`, 2.620655965758532}, 
           0.05570143050888991],
          "\"MONICA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MONICA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0093171896476711`, 2.342119382412407}, 
           0.05570143050888991],
          "\"THERESA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "THERESA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.654812508403634, 2.1482345319902834`}, 
           0.05570143050888991],
          "\"MARGERY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARGERY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.136379271804913, 2.10179967534156}, 0.05570143050888991],
          
          "\"MAXINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAXINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.398893722561458, 2.337537030955006}, 0.05570143050888991],
          "\"TANYA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TANYA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0445336068141367`, 2.2145012697976156`}, 
           0.05570143050888991],
          "\"CARLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CARLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.5178886194675658`, 2.070324688298257}, 
           0.05570143050888991],
          "\"FANNY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FANNY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.392985116128974, 2.0172300490268786`}, 
           0.05570143050888991],
          "\"JOY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2701560228774893`, 2.170868016397018}, 
           0.05570143050888991],
          "\"LYDIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYDIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3975982075832798`, 2.18479886837523}, 
           0.05570143050888991],
          "\"ALMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0010160736343976`, 2.6224015147170086`}, 
           0.05570143050888991],
          "\"GLENYS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLENYS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2584534476124616`, 2.0186966525050893`}, 
           0.05570143050888991],
          "\"DEBBIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DEBBIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9660759676933837, 2.472803415911055}, 
           0.05570143050888991],
          "\"JENNY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JENNY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.307329914043703, 2.8190553153022355`}, 
           0.05570143050888991],
          "\"BLANCHE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BLANCHE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2203116837267625`, 2.403725156264022}, 
           0.05570143050888991],
          "\"VIVIENNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VIVIENNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9521184939841647`, 2.973042113831754}, 
           0.05570143050888991],
          "\"TARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.0648042207302373`, 2.715105008020585}, 
           0.05570143050888991],
          "\"MIRIAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MIRIAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1743389460149922`, 2.274227348673222}, 
           0.05570143050888991],
          "\"GLYNIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLYNIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.449660611658213, 4.002162346020976}, 0.05570143050888991],
          "\"CLAIR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLAIR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.07605019362437, 4.7921768996926755`}, 
           0.05570143050888991],
          "\"LYNDSEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYNDSEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.108569302428034, 4.289256406799745}, 0.05570143050888991],
          "\"SONIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SONIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.162718825972419, 4.485721789141594}, 0.05570143050888991],
          "\"MOLLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MOLLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.217602994975898, 3.9554024603260465`}, 
           0.05570143050888991],
          "\"ELLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.069766489239364, 3.4849957919804195`}, 
           0.05570143050888991],
          "\"CHLOE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHLOE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.839643628137155, 4.449570510691226}, 0.05570143050888991],
          "\"SYBIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SYBIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.339445919688016, 4.06213114401514}, 0.05570143050888991],
          
          "\"LEAH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LEAH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.930031394773706, 3.334106453459885}, 0.05570143050888991],
          "\"TONI\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TONI", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.29515948689261, 3.6711682743193585`}, 
           0.05570143050888991],
          "\"WILLIAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WILLIAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.384969987960359, 4.4221485605780035`}, 
           0.05570143050888991],
          "\"JOHN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOHN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.497997598777275, 4.020280573460792}, 0.05570143050888991],
          "\"PAUL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAUL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.157390138415499, 4.132924398807478}, 0.05570143050888991],
          "\"MARK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.202438494892904, 3.420668394795633}, 0.05570143050888991],
          "\"JAMES\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JAMES", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.722960004274572, 4.310322961527341}, 0.05570143050888991],
          "\"MICHAEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MICHAEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.920383828516393, 4.5673503536250575`}, 
           0.05570143050888991],
          "\"STEPHEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STEPHEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.348361489395701, 3.913040092783218}, 0.05570143050888991],
          "\"ANDREW\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANDREW", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.724336630874012, 3.5382502837181464`}, 
           0.05570143050888991],
          "\"DANIEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DANIEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.04286578353353, 3.992902738035645}, 0.05570143050888991],
          
          "\"ARTHUR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ARTHUR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.313344466056199, 3.511235759908192}, 0.05570143050888991],
          "\"ROBERT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROBERT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.246250065585384, 3.7936881591370293`}, 
           0.05570143050888991],
          "\"RICHARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RICHARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.49221300887856, 4.6428349632936685`}, 
           0.05570143050888991],
          "\"RONALD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RONALD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.872934999963933, 3.9116529007241962`}, 
           0.05570143050888991],
          "\"ANTHONY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANTHONY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.99589646107202, 4.4221152403054855`}, 
           0.05570143050888991],
          "\"MATTHEW\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MATTHEW", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.030576710727809, 3.6677971129569764`}, 
           0.05570143050888991],
          "\"CHARLES\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHARLES", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.402875651459135, 4.206617655166467}, 0.05570143050888991],
          "\"FREDERICK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FREDERICK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.5092294802897115`, 4.155850833215487}, 
           0.05570143050888991],
          "\"KENNETH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KENNETH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.826626790601779, 4.124531057816174}, 0.05570143050888991],
          "\"ALBERT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALBERT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.182830794179319, 4.711163026407839}, 0.05570143050888991],
          "\"ALAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.909356644316942, 3.531218243022184}, 0.05570143050888991],
          "\"IAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.940971265755323, 4.7371375157582545`}, 
           0.05570143050888991],
          "\"SIMON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SIMON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.051834577147967, 4.623993472853848}, 0.05570143050888991],
          "\"ERNEST\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ERNEST", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.979285916089861, 4.202026505373777}, 0.05570143050888991],
          "\"ALFRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALFRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.765187881582182, 4.849704246674317}, 0.05570143050888991],
          "\"EDWARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDWARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.1647163047764835`, 3.6052812946290684`}, 
           0.05570143050888991],
          "\"JOSEPH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOSEPH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.256449545263353, 4.602101352336273}, 0.05570143050888991],
          "\"LEE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LEE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.450823132744214, 4.3296976212458285`}, 
           0.05570143050888991],
          "\"ADAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ADAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.7332729528748025`, 4.739823640833926}, 
           0.05570143050888991],
          "\"ROGER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROGER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.073475795754592, 3.3446634144767353`}, 
           0.05570143050888991],
          "\"HAROLD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HAROLD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.243126257987642, 4.3742895738521925`}, 
           0.05570143050888991],
          "\"DEREK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DEREK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.5865952470127995`, 4.480947617956097}, 
           0.05570143050888991],
          "\"KEITH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KEITH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.813630168216543, 3.719486279249364}, 0.05570143050888991],
          "\"FRANK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRANK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.082709938405188, 3.811335885439358}, 0.05570143050888991],
          "\"LESLIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LESLIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.7900103730083154`, 3.3864915489480705`}, 
           0.05570143050888991],
          "\"RAYMOND\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RAYMOND", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.726461226363466, 4.580391401353141}, 0.05570143050888991],
          "\"COLIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "COLIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.271976368383317, 4.217171575296142}, 0.05570143050888991],
          "\"KEVIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KEVIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.417303205744281, 3.641247907462545}, 0.05570143050888991],
          "\"DARREN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DARREN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.889499163828672, 4.854877707567038}, 0.05570143050888991],
          "\"HENRY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HENRY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.436827334648331, 3.776543704867336}, 0.05570143050888991],
          "\"PHILIP\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PHILIP", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.36669655127135, 4.539807801375816}, 0.05570143050888991],
          
          "\"GARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.487593683926255, 3.8913864754248957`}, 
           0.05570143050888991],
          "\"BENJAMIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BENJAMIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.568781576929737, 4.791634583666779}, 0.05570143050888991],
          "\"STANLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STANLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5813031800360937`, 2.017544372999396}, 
           0.05570143050888991],
          "\"STEVEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STEVEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.086947054882777, 1.519870605989537}, 0.05570143050888991],
          "\"ERIC\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ERIC", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.18209667336294, 1.4140793613221037`}, 
           0.05570143050888991],
          "\"MARTIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARTIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.925138690548266, 1.4347354403711694`}, 
           0.05570143050888991],
          "\"WALTER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WALTER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8679255336938736`, 1.2632213976747777`}, 
           0.05570143050888991],
          "\"GRAHAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GRAHAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.979849145266797, 1.6416616732844578`}, 
           0.05570143050888991],
          "\"NICHOLAS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NICHOLAS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.46363350817925, 1.8072214144657355`}, 
           0.05570143050888991],
          "\"LEONARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LEONARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.349911798840048, 1.7078513085738685`}, 
           0.05570143050888991],
          "\"BARRY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BARRY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.471555947280286, 1.068618203063001}, 0.05570143050888991],
          "\"HERBERT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HERBERT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.295671362053043, 1.5656152959568475`}, 
           0.05570143050888991],
          "\"GORDON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GORDON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.026224270844277, 1.194980682649728}, 0.05570143050888991],
          "\"NORMAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORMAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.19088866799243, 1.6685142500137031`}, 
           0.05570143050888991],
          "\"NEIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NEIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8432883078061626`, 1.6652882090850187`}, 
           0.05570143050888991],
          "\"NIGEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NIGEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.274060087359451, 1.3715767941168013`}, 
           0.05570143050888991],
          "\"MALCOLM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MALCOLM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.7164694653507095`, 1.2254168366564895`}, 
           0.05570143050888991],
          "\"TIMOTHY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TIMOTHY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.047638369107941, 0.4111912972831533}, 
           0.05570143050888991],
          "\"STUART\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STUART", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.025537181086292, 1.3306997299521077`}, 
           0.05570143050888991],
          "\"GEOFFREY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GEOFFREY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.437201726066682, 1.4788486729610324`}, 
           0.05570143050888991],
          "\"ALEXANDER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALEXANDER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.272361280221109, 1.8734433678623728`}, 
           0.05570143050888991],
          "\"CYRIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CYRIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5869571021565627`, 1.5841419622038597`}, 
           0.05570143050888991],
          "\"SIDNEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SIDNEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.403274340812292, 1.4813956224851554`}, 
           0.05570143050888991],
          "\"FRANCIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRANCIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.124709468232238, 1.8263122936120195`}, 
           0.05570143050888991],
          "\"RYAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RYAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6289533279741266`, 1.2779280947152851`}, 
           0.05570143050888991],
          "\"PERCY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PERCY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.455341129301084, 1.628651384177883}, 0.05570143050888991],
          "\"LUKE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LUKE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4177692935803883`, 1.2962703706061052`}, 
           0.05570143050888991],
          "\"JACK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JACK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6759923074530665`, 1.446008295597642}, 
           0.05570143050888991],
          "\"TREVOR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TREVOR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.310076412808286, 1.3736411898265515`}, 
           0.05570143050888991],
          "\"ADRIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ADRIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8058864883790147`, 1.1742553557001956`}, 
           0.05570143050888991],
          "\"JAMIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JAMIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.377534460488725, 1.9508173489446283`}, 
           0.05570143050888991],
          "\"WILFRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WILFRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5908997950331663`, 1.1746006289113988`}, 
           0.05570143050888991],
          "\"PATRICK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PATRICK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8167824403242876`, 1.41118222984997}, 
           0.05570143050888991],
          "\"SCOTT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SCOTT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.184505427359471, 1.2669661240102115`}, 
           0.05570143050888991],
          "\"SAMUEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SAMUEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2290791913113557`, 1.0785109381376787`}, 
           0.05570143050888991],
          "\"WAYNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WAYNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.529183377782783, 0.3459540572094859}, 
           0.05570143050888991],
          "\"CECIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CECIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.855260453944898, 0.3303523773370447}, 
           0.05570143050888991],
          "\"GARETH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GARETH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.632165776231189, 0.11103641985856338`}, 
           0.05570143050888991],
          "\"SEAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SEAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.623085392018389, 0.24813975997412197`}, 
           0.05570143050888991],
          "\"HORACE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HORACE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.691707167723954, 0.5505356231454419}, 
           0.05570143050888991],
          "\"BERNARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BERNARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.189233266615462, 0.25849377658537387`}, 
           0.05570143050888991],
          "\"FRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.0191831405526632`, 0.4113205932000388}, 
           0.05570143050888991],
          "\"EDWIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDWIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3710776248337075`, 0.2999523784538045}, 
           0.05570143050888991],
          "\"GERALD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GERALD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.167773717230054, 0.4385212239551035}, 
           0.05570143050888991],
          "\"SHAUN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHAUN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.7716537203514955`, 0.4302322473870501}, 
           0.05570143050888991],
          "\"CLIFFORD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLIFFORD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3108059160742314`, 0.15061590799352498`}, 
           0.05570143050888991],
          "\"MAURICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAURICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.967013800042194, 0.17293923908540476`}, 
           0.05570143050888991],
          "\"CLIVE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLIVE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.834010241282577, 1.990508425310403}, 0.05570143050888991],
          "\"BEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8663225857892227`, 0.3162379741460035}, 
           0.05570143050888991],
          "\"ANTONY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANTONY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.033793051399473, 0.27333934580722286`}, 
           0.05570143050888991],
          "\"VICTOR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VICTOR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1533319156711497`, 0.12824719894068837`}, 
           0.05570143050888991],
          "\"JUSTIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JUSTIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.901323876584327, 0.46408514083271557`}, 
           0.05570143050888991],
          "\"JEFFREY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEFFREY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.5778245924135943`, 0.4688222282786785}, 
           0.05570143050888991],
          "\"OLIVER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "OLIVER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5170786709362716`, 0.04384570570227053}, 
           0.05570143050888991],
          "\"EDGAR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDGAR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.733477488615379, 0.3594720657048902}, 
           0.05570143050888991],
          "\"CHRISTIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHRISTIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.764343642195909, 0.2002421538590511}, 
           0.05570143050888991],
          "\"ASHLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ASHLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3889215317152495`, 0.03714367247629635}, 
           0.05570143050888991],
          "\"KARL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KARL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.852030977769403, 0.09540886872204357}, 
           0.05570143050888991],
          "\"AARON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AARON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8913260505315477`, 0.5169506416851912}, 
           0.05570143050888991],
          "\"MARC\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARC", "Tooltip"]& ], 
        TagBox[
         TooltipBox[DiskBox[{3.2711795821890868`, 0.}, 0.05570143050888991],
          "\"MOHAMMED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MOHAMMED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4757292291894126`, 0.17919497776812854`}, 
           0.05570143050888991],
          "\"HUGH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HUGH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.131451414038333, 0.017911701145744807`}, 
           0.05570143050888991],
          "\"RUSSELL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RUSSELL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.62996839398561, 0.3358079206113249}, 0.05570143050888991],
          "\"GAVIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GAVIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.760508776801317, 0.5082595388835616}, 
           0.05570143050888991],
          "\"LAWRENCE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LAWRENCE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.57736217973407, 0.4804479081603814}, 0.05570143050888991],
          "\"LIAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LIAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3532423647517455`, 0.4616839528821379}, 
           0.05570143050888991],
          "\"ROBIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROBIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.81669742895982, 0.2197850566076167}, 0.05570143050888991],
          "\"PHILLIP\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PHILLIP", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.687649817279081, 0.20397739499959755`}, 
           0.05570143050888991],
          "\"NATHAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NATHAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9942706618603867`, 0.04006566250262589}, 
           0.05570143050888991],
          "\"DENIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DENIS", "Tooltip"]& ]}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Input",
 CellChangeTimes->{{3.67782319724261*^9, 
  3.677823209395069*^9}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell["\<\
Use the option VertexLabels to place the name of each vertex as a tooltip for \
the vertex - you will likely need to refer to the documentation for this. \
Store the output of this expression against an appropriately named symbol for \
use later on.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.6762619537846413`*^9, 3.676262025794293*^9}, {
  3.6762624396293507`*^9, 3.676262462354598*^9}}],

Cell["\<\
While the multiple edges between nodes do provide extremely useful \
information (that are multiple interactions in a dyad), multigraph are not \
thoroughly supported throughout Mathematica at present and the legibility of \
the graph is reduced.\
\>", "Text",
 CellChangeTimes->{{3.6762621482632103`*^9, 3.676262251708001*^9}, {
  3.676262467060316*^9, 3.6762624829086733`*^9}}],

Cell["\<\
Use SimpleGraph to remove multiple edges between individuals and store this \
against another symbol, note that you will need to reinsert the VertexLabels.\
\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676262493833435*^9, 3.6762625133628902`*^9}, {
  3.676262586591743*^9, 3.676262598559265*^9}, {3.676267332405549*^9, 
  3.676267346590473*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Communities in the Network", "Title",
 CellChangeTimes->{{3.6761935218185587`*^9, 3.6761935242931232`*^9}, {
  3.676193721983591*^9, 3.676193724154065*^9}, {3.676262337872819*^9, 
  3.676262348438691*^9}}],

Cell["\<\
CommunityGraphPlot is a powerful visualisations function for graph objects \
that provides information about the communities within a graph.\
\>", "Text",
 CellChangeTimes->{{3.6762626146145697`*^9, 3.676262657534191*^9}}],

Cell["\<\
Create a grid of CommunityGraphPlot mapped to the following Graph:\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676262666231559*^9, 3.676262709237899*^9}}],

Cell[BoxData[GridBox[{
   {"\"\<Directed Multigraph\>\"", "\"\<Directed SimpleGraph\>\""},
   {"\"\<Undirected Multigraph\>\"", "\"\<Undirected Multigraph\>\""}
  }]], "Input",
 CellChangeTimes->{{3.676262724063085*^9, 3.676262801492675*^9}}],

Cell["\<\
What do these visualisations tell you about the network, and about the \
properties of the different types of graph?\
\>", "Text",
 CellChangeTimes->{{3.676262807373581*^9, 3.67626283804077*^9}}],

Cell["\<\
CommunityGraphPlot uses the FindGraphCommunities function to find communities \
in the graph and then undertakes shenanigans to place the nodes nicely in a \
graphic. Find the largest community from FindGraphCommunities and use \
HighlightGraph to highlight these nodes purple in the Graph.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.67626284337527*^9, 3.676262870689744*^9}, {
  3.676262916513743*^9, 3.676262919515717*^9}, {3.676263116574044*^9, 
  3.676263159121811*^9}, {3.67626319472771*^9, 3.676263262295495*^9}}],

Cell["\<\
NOTE: Some of the theory of FindGraphCommunities is provided in the \
documentation, but you will need to consult elsewhere for a thorough \
explanation of how graph are paritioned into communities.\
\>", "Text",
 CellChangeTimes->{{3.676263314589699*^9, 3.676263377608508*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["VertexCentralities", "Title",
 CellChangeTimes->{{3.6761935218185587`*^9, 3.6761935242931232`*^9}, {
  3.676193721983591*^9, 3.676193724154065*^9}, {3.6762633942957077`*^9, 
  3.676263398703472*^9}}],

Cell["\<\
There are many *Centrality measures that mean are useful for a variety of \
graph analyses, VertexDegree is a useful one for the directed  SimpleGraph as \
it allows us to find those individuals in the network who are only \
\[OpenCurlyDoubleQuote]secondary participants\[CloseCurlyDoubleQuote].\
\>", "Text",
 CellChangeTimes->{{3.676263402475811*^9, 3.6762634682630863`*^9}, {
  3.67626363181885*^9, 3.676263660891073*^9}}],

Cell["\<\
In this exercise you will colour those vertices that are only appear as \
\[OpenCurlyDoubleQuote]secondary participants\[CloseCurlyDoubleQuote] in red.\
\
\>", "Text",
 CellChangeTimes->{{3.676263905926063*^9, 3.676263934141942*^9}}],

Cell[CellGroupData[{

Cell["\<\
Find the number of edges directed away from a vertex with DegreeCentrality \
(deliberately tricky language is used in this question)\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676263670125341*^9, 3.676263709894294*^9}, {
   3.6762637448925457`*^9, 3.676263751046131*^9}, 3.6762640850060463`*^9}],

Cell["\<\
Use PropertyValue to update the VertexStyle of those nodes with a zero out \
degree to be red, all other nodes should remain unchanged.\[LineSeparator]\
\[LineSeparator]Note that there are a number of different ways to achieve \
this and your problem solving skills will be needed.\[LineSeparator]\
\[LineSeparator]As a reminder, a template for PropertyValue is provided below:\
\>", "ItemNumbered",
 CellChangeTimes->{{3.6762638246351767`*^9, 3.676263882864512*^9}, {
  3.676263941331484*^9, 3.676263945358872*^9}, {3.676264060078969*^9, 
  3.676264195505653*^9}}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"graph", "=", 
   RowBox[{"CompleteGraph", "[", 
    RowBox[{"4", ",", 
     RowBox[{"VertexLabels", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", "\[Rule]", "\"\<one\>\""}], "}"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"PropertyValue", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"graph", ",", "1"}], "}"}], ",", "VertexLabels"}], "]"}], "=", 
   "\"\<New Label\>\""}], ";"}], "\[IndentingNewLine]", "graph"}], "Input",
 CellChangeTimes->{{3.676264025774899*^9, 3.676264031726461*^9}, {
  3.676264199627211*^9, 3.6762642613810453`*^9}}],

Cell[TextData[{
 "Individuals who have a zero out degree are not listed as ",
 StyleBox["primary participants",
  FontSlant->"Italic"],
 ", there are few individuals who have a non-zero out degree. It\
\[CloseCurlyQuote]s interesting to look at these individuals in some detail, \
however they were prolific in their interactions - one individual was listed \
as the primary participant in an interaction 60 times. We may need to reduce \
the dataset at times to extract meaning."
}], "Text",
 CellChangeTimes->{{3.6762668423128567`*^9, 3.67626689023979*^9}, {
  3.676266928198257*^9, 3.676267037536796*^9}, {3.676267258760688*^9, 
  3.6762672737232533`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Return a list of the vertices where the out degree is greater than zero\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676264354549551*^9, 3.676264364415959*^9}, {
  3.676266118831254*^9, 3.676266127446845*^9}, {3.6762661904832897`*^9, 
  3.676266217132533*^9}, {3.676267418928969*^9, 3.6762674196930733`*^9}}],

Cell["\<\
Use SubGraph to visualise the interactions of only these individuals, use the \
argument VertexLabels to insert labels as either tooltips or labels (there \
are so few vertices labels will be legible!)\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676267129261814*^9, 3.6762671305206213`*^9}, {
  3.676267286088029*^9, 3.6762672933552322`*^9}, {3.676267427040051*^9, 
  3.676267472603764*^9}}],

Cell[TextData[{
 "Select those rows from your list of associations where the \
\[OpenCurlyDoubleQuote]Secondary.Participant.Name\[CloseCurlyDoubleQuote] \
belongs to the output of step 3 (i.e. the value is a ",
 StyleBox["member",
  FontWeight->"Bold"],
 " of the list from step 3).\[LineSeparator]\[LineSeparator]Note that this \
will require a Query as you are operating on a list of Associations, store \
the output for use in Step 5."
}], "ItemNumbered",
 CellChangeTimes->{{3.676266226033101*^9, 3.676266229294284*^9}, {
  3.67626627854844*^9, 3.676266352764571*^9}, {3.676266498567348*^9, 
  3.676266540822094*^9}, {3.676267495305518*^9, 3.676267497364832*^9}}],

Cell["\<\
Display this data in the form of a Grid, with appropriate column headings.\
\[LineSeparator]\[LineSeparator]Hint: Use ItemSize\[Rule]Full to ensure line \
breaks are not inserted.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676266560396649*^9, 3.6762666070076*^9}, {
  3.6762666537645073`*^9, 3.676266671548641*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Interactive Networks", "Title",
 CellChangeTimes->{{3.6761935218185587`*^9, 3.6761935242931232`*^9}, {
  3.676193721983591*^9, 3.676193724154065*^9}, {3.6762633942957077`*^9, 
  3.676263398703472*^9}, {3.676264468976424*^9, 3.676264476376086*^9}, {
  3.676265117060472*^9, 3.676265119130563*^9}, {3.676267603366243*^9, 
  3.676267605996387*^9}}],

Cell["When building a graph there are two choices:", "Text",
 CellChangeTimes->{{3.676267624716247*^9, 3.67626763648318*^9}}],

Cell[CellGroupData[{

Cell["\<\
Build a basic graph with edges and vertices only, and add properties \
afterwards\
\>", "Item",
 CellChangeTimes->{{3.676267643212533*^9, 3.6762676658308496`*^9}}],

Cell["Build a graph with multiple properties defined to begin with", "Item",
 CellChangeTimes->{{3.676267643212533*^9, 3.6762676841833363`*^9}}]
}, Open  ]],

Cell["\<\
Thus far we have only really considered the first method of graph \
construction, but that adds a lot of complications.\
\>", "Text",
 CellChangeTimes->{{3.676267686952236*^9, 3.676267728565609*^9}}],

Cell["Graph can be constructed as follows:", "Text",
 CellChangeTimes->{{3.676269064778693*^9, 3.6762690785369177`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Graph", "[", 
   RowBox[{"vertexlist", ",", "edgelist"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Graph", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[Rule]", "2"}], ",", 
     RowBox[{"2", "\[Rule]", "1"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6762690794768467`*^9, 3.6762691126251717`*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 5}, {{{1, 2}, {2, 1}}, Null}]]}, 
    TagBox[GraphicsGroupBox[GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQXXQkqoaL4aO9tPuao8sZNuxXgNBwPpS2X5HVtOI3
w4n97HO+Mz+Z985eZXXkTYPynfuVF5Rt8zv01n5PU+fKyRt375+YUqrb++iN
/R5ZO+uyaXv38yl5PlFmeGPvwyFQvlNl//4X5/a9mCH92v6T7czjO3QP7I8y
2NNdbPrKfld2h+vnOQf2a8xXFLTxe2n/7IJs1Kn7B/Z7vJeOr057Yd/mY1Qk
9u3A/t8u81Rija/D+dZPJx24nXwVrv7modjTOVMvw83b0xohqHTyIty+gvvO
UjwMF+xdoO65suUaf3HZGfstUPf2Hbv4Ouf7CfstUP/8vnZ2q3jrUXsZqH/Z
r0P4CT2/j1dpzNo/E6qeQc+m/b3dxP33oeYxtFxuOBXWvL8Mah/DPoHOQ5Oy
9x+Cuochq/pbQ0eY/T2oexsmt/zO7yy2d4T6h8HSsC/oSbU9oyvEvwxrD0y4
urbO3hsaHjC+DjS8YOpjoeEJM+81NLxh9glC44NhP8Q9U6Dx5QB1rxo0PhWg
/uGCxncD1L8AhPEeqg==
       "], {
        {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[Medium], 
         ArrowBox[BezierCurveBox[{
          1, {0.5625100000000007, -0.2269507471831215}, 2}], 0.01273], 
         ArrowBox[BezierCurveBox[{
          2, {0.5625100000000005, 0.10193074718311719`}, 1}], 0.01273]}, 
        {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
         DiskBox[1, 0.01273], DiskBox[2, 0.01273], DiskBox[3, 0.01273]}}]],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{3.676269113056428*^9}]
}, Open  ]],

Cell["\<\
This allows for properties to be added to vertices and edges before the graph \
has been constructed:\
\>", "Text",
 CellChangeTimes->{{3.6762691224923477`*^9, 3.6762691389614897`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Property", "[", 
     RowBox[{
      RowBox[{"1", "\[Rule]", "2"}], ",", 
      RowBox[{"EdgeStyle", "\[Rule]", "Red"}]}], "]"}], ",", 
    RowBox[{"2", "\[Rule]", "1"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.676269167892889*^9, 3.6762692267897463`*^9}, {
  3.676270411663514*^9, 3.676270414713463*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2}, {{{1, 2}, {2, 1}}, Null}, {
      EdgeStyle -> {DirectedEdge[1, 2] -> RGBColor[1, 0, 0]}}]]}, 
    TagBox[GraphicsGroupBox[GraphicsComplexBox[CompressedData["
1:eJxV0L1KA0EUBeDBZquFJYVVFDSQFIIEEdRCTyqxEPGnMdtoghbaWFhYKAhL
tBLWVhJ8g0CwiSjmuKAkeYJgIQRRxERlHkHD3C3mwjAzMMw93x0rHqzvDiml
xv/XYDeloazSjE+L6dLw9fwXvJafSfzc8GQyOD4sfSJ3dNfsFOr066d7+ukD
uWqqX5m458ZUpjOi3rEdNIuppQadi0TXmXlDa/q83fYf2Vtx0w/7XWxe7jwv
zEX08rVCZfYVNT/8/W5EDK8G9QK9djt61o9YNnfG96R5z/i9Nv8x/s81/Rj3
y5s8XJU8WyYvs5I3MB5mxbNsvFTiFT/FD/FT/BA/xQ/xU/xw7Dzo2Xnh2R6E
thdlex5I2vOCtucJ1543xA/xQ/wQP8QP8UP8ED/+ADqSCu8=
       "], {
        {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[Medium], 
         {RGBColor[1, 0, 0], 
          ArrowBox[BezierCurveBox[{1, {0., -0.32888149436623376`}, 2}], 
           0.02261146496815286]}, 
         ArrowBox[BezierCurveBox[{2, {0., 0.32888149436623376`}, 1}], 
          0.02261146496815286]}, 
        {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
         DiskBox[1, 0.02261146496815286], DiskBox[2, 0.02261146496815286]}}]],
     
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{{3.676269212362996*^9, 3.676269227153564*^9}, 
   3.676270415091167*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Creating the Graph", "Section",
 CellChangeTimes->{{3.6762703834279633`*^9, 3.6762703922135973`*^9}}],

Cell["\<\
Contained within the data folder is another file \
\[OpenCurlyDoubleQuote]interaction_tallies\[CloseCurlyDoubleQuote] where the \
interactions between individuals have been tallied by the event category \
column:\
\>", "Text",
 CellChangeTimes->{{3.676268682038452*^9, 3.676268712153852*^9}, {
  3.676268743946643*^9, 3.676268784391241*^9}, {3.676269605223727*^9, 
  3.676269643123637*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"interactionTallies", "=", 
   RowBox[{"Import", "[", "\"\<interaction_tallies.csv\>\"", "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"interactionTallies$Associations", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"AssociationThread", "[", 
       RowBox[{
        RowBox[{"interactionTallies", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", "#"}], "]"}], "&"}], ",", 
     
     RowBox[{"interactionTallies", "[", 
      RowBox[{"[", 
       RowBox[{"2", ";;"}], "]"}], "]"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.676268286149037*^9, 3.67626831364515*^9}, {
   3.676268344714223*^9, 3.676268346603284*^9}, 3.676268790366938*^9}],

Cell["\<\
Unfortunately, the edges are detailed in terms of the EMLO_id rather than \
name of the individual - as the code for generating the tally was written in \
R where vertex indices are important. But we can fix that using the other \
datafile:\
\>", "Text",
 CellChangeTimes->{{3.67626965659134*^9, 3.67626971976099*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"people$info", "=", 
   RowBox[{"Import", "[", "\"\<people-info.csv\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"people$Associations", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"AssociationThread", "[", 
       RowBox[{
        RowBox[{"people$info", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", "#"}], "]"}], "&"}], ",", 
     
     RowBox[{"people$info", "[", 
      RowBox[{"[", 
       RowBox[{"2", ";;"}], "]"}], "]"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.676269758992466*^9, 3.676269770781001*^9}, {
  3.676269805408258*^9, 3.67626982108012*^9}}],

Cell[CellGroupData[{

Cell["\<\
Use ReplaceAll (/.) to replace the emlo ids in \
interactionTallies$Associations with the names from people$Associations. \
Consider how this might be achieved using Apply.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676269842095829*^9, 3.67626986944309*^9}, {
  3.6762699511436977`*^9, 3.676269996423822*^9}, {3.6762700268720837`*^9, 
  3.676270067884365*^9}}],

Cell["\<\
Use Map to construct a list of edges formed form the \
\[OpenCurlyDoubleQuote]Primary.Emlo_ID\[CloseCurlyDoubleQuote] and \
\[CloseCurlyDoubleQuote]Secondary.Emlo_ID\[CloseCurlyDoubleQuote] columns \
with the \[OpenCurlyDoubleQuote]Total.Connections\[CloseCurlyDoubleQuote] set \
as the EdgeWeight. The properties should look like this:\[LineSeparator]\
\[LineSeparator]Property[1\[DirectedEdge]2, EdgeWeight\[Rule]2]\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676270426458746*^9, 3.676270526867463*^9}}],

Cell["\<\
Provide these edges to Graph, and remember to display the vertex labels as \
tooltips, store the graph as a symbol for using in the next exercise.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676270426458746*^9, 3.6762704446512423`*^9}, {
  3.676270548100168*^9, 3.676270589270948*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Filtering Graph", "Section",
 CellChangeTimes->{{3.676270595978644*^9, 3.6762705980682783`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Return the list of EdgeWeights from the above graph using PropertyValue\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676270607333343*^9, 3.676270620230999*^9}, {
  3.6762709366877127`*^9, 3.6762709435157337`*^9}}],

Cell["\<\
Use Subgraph to view only those edges where the EdgeWeight is greater than 1:\
\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676270978853116*^9, 3.676271038838369*^9}}],

Cell["\<\
Note that the EdgeWeights have been removed from the Subgraph - in order to \
retain them you would need to follow a more complicated route - \
http://mathematica.stackexchange.com/a/26223/1952.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676271180658208*^9, 3.676271204001034*^9}, {
  3.676271392645278*^9, 3.676271422343728*^9}, {3.676271452574134*^9, 
  3.676271458681254*^9}}],

Cell["\<\
Build a Manipulate that allows you to filter the graph according to the edge \
weights:\
\>", "ItemNumbered",
 CellChangeTimes->{{3.67627146799815*^9, 3.67627151176016*^9}}]
}, Open  ]],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`minWeight$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`minWeight$$], 1, "Minimum Number of Interactions"}, {
      1, 2, 3, 4, 5, 6, 7}}}, Typeset`size$$ = {360., {133., 138.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`minWeight$1128$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`minWeight$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`minWeight$$, $CellContext`minWeight$1128$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Subgraph[$CellContext`tallyGraph, 
        Pick[
         EdgeList[$CellContext`tallyGraph], $CellContext`edgeWeights, 
         Condition[
          Pattern[$CellContext`q$, 
           Blank[]], $CellContext`q$ >= $CellContext`minWeight$$]], 
        VertexLabels -> Placed["Name", Tooltip]], 
      "Specifications" :> {{{$CellContext`minWeight$$, 1, 
          "Minimum Number of Interactions"}, {1, 2, 3, 4, 5, 6, 7}, 
         ControlType -> Setter}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{405., {176., 181.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`tallyGraph = 
       Graph[{"MARY", 2, 3, "JEAN", "FLORENCE", 6, 7, "JULIE", "CLAIRE", 
          "LAURA", "DORIS", "JOAN", "JVGDNT", "KAREN", "URQUAX", "GEMMA", 17, 
          "DOROTHY", 19, "JACQUELINE", "MFETPC", "KATHLEEN", "JANET", 24, 
          "LISA", 26, "ANNIE", 28, "ANN", 30, 31, "ELSIE", "BARBARA", 
          "UQVRUY", "JANE", "MICHELLE", "VICTORIA", "ALICE", "IRENE", 
          "DOREEN", 41, "HELEN", "SAMANTHA", "JUNE", "YAKZCN", "DIANE", 
          "LBDVHJ", "WINIFRED", "EILEEN", "SHIRLEY", "ANNE", "SHARON", "AMY", 
          "AWWUMI", "CPYYFX", "VALERIE", 57, "AMANDA", "JENNIFER", "ANGELA", 
          "ETHEL", 62, "SANDRA", "LOUISE", "KATIE", 66, "PHYLLIS", "PAULINE", 
          69, "LILIAN", "AUDREY", 72, "CLARE", "KELLY", "IVY", "VERA", 
          "BRENDA", "LJNWXX", "NATALIE", "VIOLET", "JUNMZV", "SYLVIA", 
          "ELAINE", "LWHQYG", "LACFLA", "CATHERINE", "HAYLEY", "LILY", "EDNA",
           "HANNAH", "NELLIE", "BERYL", 93, 94, "SUCNHY", 96, "LUCY", "ADA", 
          "DAWN", "LYNN", "BEATRICE", "ZLXPBT", 103, 104, "CAROLE", "HFKAHK", 
          "MAY", "EVELYN", "ROSE", "MAVIS", 111, "SALLY", "KATHERINE", "IRIS",
           "CKYGWZ", "MARIA", "ZOE", "KERRY", "DEBRA", "MELANIE", "STACEY", 
          "GERTRUDE", "MURIEL", "PAULA", "LAUREN", "MARION", "JOANNA", 129, 
          130, "MARINA", "JANICE", "LORRAINE", "JESSIE", "PEGGY", "ROSEMARY", 
          "ANDREA", "FRANCES", "XFGSKJ", "GRACE", "JOSEPHINE", "YVONNE", 
          "SOPHIE", "LYNNE", "ANNA", "EVA", "GWENDOLINE", "JESSICA", 149, 
          "NORMA", "BEVERLEY", "KIRSTY", "KIMBERLEY", "HAZEL", "FIONA", 
          "KATE", "MARIE", "JENNA", "MARILYN", "DAISY", "NORA", "NATASHA", 
          "MINNIE", "FREDA", "MANDY", "RACHAEL", "TVKHRF", "CHRISTOPHER", 169,
           "KATHRYN", "NANCY", "RUTH", "JAYNE", "DIANA", "MARIAN", "ELEANOR", 
          "VERONICA", "SARA", "ALEXANDRA", "LOUISA", "MSRGUQ", "DORA", 
          "DAPHNE", "TERESA", "JULIA", "NORAH", "HEATHER", "KIM", "JEMMA", 
          "THELMA", "CARLY", "IDA", "CLARA", "GLORIA", "HOLLY", "HILARY", 
          "MELISSA", "MARTHA", "CYNTHIA", "BERTHA", "LPYGMD", "LILLIAN", 
          "CHERYL", "IZRDSO", "NAOMI", 207, "BESSIE", "GAIL", "JADE", 
          "PENELOPE", "CHARLENE", 213, "CHRISTINA", "ANNETTE", 216, "QCBGCO", 
          "ESTHER", "CAROLYN", "HARRIET", "ANITA", "GERALDINE", "BRIDGET", 
          "GEORGINA", "LINDSEY", "KAY", 227, "STELLA", 229, 230, "NICHOLA", 
          232, 233, "AIMEE", "HEIDI", "MILLICENT", "MONICA", "THERESA", 
          "MARGERY", "MAXINE", "TANYA", "CARLA", "FANNY", "JOY", "LYDIA", 
          "QSJBJN", "GLENYS", "DEBBIE", "JENNY", "UQSBBO", "VIVIENNE", "TARA",
           "MIRIAM", "YDYBEJ", "CLAIR", "LYNDSEY", "SONIA", "MOLLY", 259, 260,
           "ELLA", "CHLOE", "SYBIL", "DAGTLQ", "TONI", "WILLIAM", "PZZJBB", 
          268, "PAUL", 270, "MARK", "JAMES", 273, "ZPINSB", "VYISWO", 
          "ANDREW", 277, 278, "DANIEL", "ARTHUR", "KKMNQK", "RICHARD", 
          "ADLDLW", "ANTHONY", "MATTHEW", "CHARLES", "FREDERICK", "KENNETH", 
          "ALBERT", "ALAN", 291, "SIMON", "ERNEST", "ALFRED", "EDWARD", 
          "JOSEPH", "LEE", "ADAM", "ROGER", "HAROLD", "QUQJHK", "KEITH", 
          "FRANK", "ACVRVL", "RAYMOND", "COLIN", "WRMHHQ", "DARREN", "HENRY", 
          "PHILIP", "GARY", "BENJAMIN", "STANLEY", 314, "STEVEN", 316, "ERIC",
           318, 319, "MARTIN", 321, 322, "WALTER", 324, "NUHUTJ", "NICHOLAS", 
          327, "LEONARD", "BARRY", "NKMUGR", "GORDON", "NORMAN", "NEIL", 
          "NIGEL", "MALCOLM", "TIMOTHY", "STUART", "GEOFFREY", "ALEXANDER", 
          "CYRIL", "SIDNEY", "MBHDDP", "RYAN", "KCVFLP", "LUKE", "JACK", 
          "TREVOR", "UNKPWV", "AJRODZ", "WILFRED", "PATRICK", "KIRZZH", 
          "SAMUEL", "WAYNE", "VRADXE", "GARETH", 357, "SEAN", "HORACE", 
          "BERNARD", 361, 362, "FRED", "EDWIN", "FZCFTO", "SHAUN", "CLIFFORD",
           "MAURICE", "CLIVE", "BEN", "ANTONY", "MXOUPI", 373, "JUSTIN", 375, 
          "JEFFREY", "OLIVER", "EDGAR", "CHRISTIAN", "ASHLEY", "KARL", 
          "AARON", "MARC", "MOHAMMED", "PEYHIE", "RUSSELL", "GAVIN", "VIVVLG",
           "LIAM", "ROBIN", "PHILLIP", "NATHAN", "DENIS"}, {
          DirectedEdge["MARY", 2], 
          DirectedEdge["MARY", 3], 
          DirectedEdge["JEAN", 3], 
          DirectedEdge["MARY", "FLORENCE"], 
          DirectedEdge["FLORENCE", "JEAN"], 
          DirectedEdge["MARY", 6], 
          DirectedEdge["MARY", 7], 
          DirectedEdge["MARY", "JULIE"], 
          DirectedEdge["MARY", "CLAIRE"], 
          DirectedEdge["MARY", "LAURA"], 
          DirectedEdge["MARY", "DORIS"], 
          DirectedEdge["MARY", "JOAN"], 
          DirectedEdge["MARY", "JVGDNT"], 
          DirectedEdge["MARY", "KAREN"], 
          DirectedEdge["URQUAX", "KAREN"], 
          DirectedEdge["MARY", "GEMMA"], 
          DirectedEdge["MARY", 17], 
          DirectedEdge["MARY", "DOROTHY"], 
          DirectedEdge["MARY", 19], 
          DirectedEdge["MARY", "JACQUELINE"], 
          DirectedEdge["MARY", "MFETPC"], 
          DirectedEdge["MARY", "KATHLEEN"], 
          DirectedEdge["MARY", "JANET"], 
          DirectedEdge["MARY", 24], 
          DirectedEdge["MARY", "LISA"], 
          DirectedEdge["MARY", 26], 
          DirectedEdge["MARY", "ANNIE"], 
          DirectedEdge["MARY", 28], 
          DirectedEdge["MARY", "ANN"], 
          DirectedEdge["MARY", 30], 
          DirectedEdge["MARY", 31], 
          DirectedEdge["MARY", "ELSIE"], 
          DirectedEdge["MARY", "BARBARA"], 
          DirectedEdge["MARY", "UQVRUY"], 
          DirectedEdge["MARY", "JANE"], 
          DirectedEdge["MARY", "MICHELLE"], 
          DirectedEdge["MARY", "VICTORIA"], 
          DirectedEdge["MARY", "ALICE"], 
          DirectedEdge["MARY", "IRENE"], 
          DirectedEdge["DOREEN", 30], 
          DirectedEdge[41, 30], 
          DirectedEdge["MARY", "HELEN"], 
          DirectedEdge["MARY", "SAMANTHA"], 
          DirectedEdge["MARY", "JUNE"], 
          DirectedEdge["MARY", "YAKZCN"], 
          DirectedEdge["MARY", "DIANE"], 
          DirectedEdge["MARY", "LBDVHJ"], 
          DirectedEdge["MARY", "WINIFRED"], 
          DirectedEdge["MARY", "EILEEN"], 
          DirectedEdge["MARY", "SHIRLEY"], 
          DirectedEdge["MARY", "ANNE"], 
          DirectedEdge["MARY", "JEAN"], 
          DirectedEdge["MARY", "SHARON"], 
          DirectedEdge["MARY", "AMY"], 
          DirectedEdge["MARY", "AWWUMI"], 
          DirectedEdge["MARY", "CPYYFX"], 
          DirectedEdge["VALERIE", 57], 
          DirectedEdge["MARY", "VALERIE"], 
          DirectedEdge["VALERIE", 17], 
          DirectedEdge["MARY", "AMANDA"], 
          DirectedEdge["AMANDA", 17], 
          DirectedEdge["MARY", "JENNIFER"], 
          DirectedEdge["MARY", "ANGELA"], 
          DirectedEdge["MARY", "ETHEL"], 
          DirectedEdge["MARY", 62], 
          DirectedEdge["MARY", "SANDRA"], 
          DirectedEdge["MARY", "LOUISE"], 
          DirectedEdge["MARY", "KATIE"], 
          DirectedEdge["MARY", 66], 
          DirectedEdge["MARY", "PHYLLIS"], 
          DirectedEdge["MARY", "DOREEN"], 
          DirectedEdge["PAULINE", 69], 
          DirectedEdge["PAULINE", "LILIAN"], 
          DirectedEdge["PAULINE", "KATHLEEN"], 
          DirectedEdge["PAULINE", "AUDREY"], 
          DirectedEdge["PAULINE", 72], 
          DirectedEdge["PAULINE", "CLARE"], 
          DirectedEdge["PAULINE", "KELLY"], 
          DirectedEdge["PAULINE", "IVY"], 
          DirectedEdge["PAULINE", "YAKZCN"], 
          DirectedEdge["PAULINE", "SHIRLEY"], 
          DirectedEdge["PAULINE", "VERA"], 
          DirectedEdge["PAULINE", "BRENDA"], 
          DirectedEdge["PAULINE", "LJNWXX"], 
          DirectedEdge["PAULINE", "NATALIE"], 
          DirectedEdge["PAULINE", "VIOLET"], 
          DirectedEdge["PAULINE", "JUNMZV"], 
          DirectedEdge["PAULINE", "MFETPC"], 
          DirectedEdge["PAULINE", "SYLVIA"], 
          DirectedEdge["PAULINE", "ELAINE"], 
          DirectedEdge["PAULINE", "LWHQYG"], 
          DirectedEdge["PAULINE", "LACFLA"], 
          DirectedEdge["PAULINE", "CATHERINE"], 
          DirectedEdge["PAULINE", "HAYLEY"], 
          DirectedEdge["PAULINE", "LILY"], 
          DirectedEdge["PAULINE", "EDNA"], 
          DirectedEdge["HANNAH", "NELLIE"], 
          DirectedEdge["HANNAH", "BERYL"], 
          DirectedEdge["HANNAH", 93], 
          DirectedEdge["HANNAH", 94], 
          DirectedEdge["HANNAH", "SUCNHY"], 
          DirectedEdge["HANNAH", 96], 
          DirectedEdge["HANNAH", "LUCY"], 
          DirectedEdge["HANNAH", "ADA"], 
          DirectedEdge["HANNAH", "DAWN"], 
          DirectedEdge["HANNAH", "MFETPC"], 
          DirectedEdge["HANNAH", "LYNN"], 
          DirectedEdge["HANNAH", "BEATRICE"], 
          DirectedEdge["HANNAH", "ZLXPBT"], 
          DirectedEdge["HANNAH", 103], 
          DirectedEdge["HANNAH", 104], 
          DirectedEdge["HANNAH", "CAROLE"], 
          DirectedEdge["HANNAH", "HFKAHK"], 
          DirectedEdge["HANNAH", "MAY"], 
          DirectedEdge["HANNAH", "EVELYN"], 
          DirectedEdge["HANNAH", "ROSE"], 
          DirectedEdge["HANNAH", "MAVIS"], 
          DirectedEdge["HANNAH", 111], 
          DirectedEdge["HANNAH", "SALLY"], 
          DirectedEdge["HANNAH", "KATHERINE"], 
          DirectedEdge["HANNAH", "IRIS"], 
          DirectedEdge["HANNAH", "CKYGWZ"], 
          DirectedEdge["HANNAH", "MARIA"], 
          DirectedEdge["HANNAH", "ZOE"], 
          DirectedEdge["HANNAH", "KERRY"], 
          DirectedEdge["HANNAH", "DEBRA"], 
          DirectedEdge["HANNAH", "MELANIE"], 
          DirectedEdge["HANNAH", "STACEY"], 
          DirectedEdge["HANNAH", "GERTRUDE"], 
          DirectedEdge["HANNAH", "MURIEL"], 
          DirectedEdge["HANNAH", "PAULA"], 
          DirectedEdge["HANNAH", "LAUREN"], 
          DirectedEdge["HANNAH", "MARION"], 
          DirectedEdge["HANNAH", "JOANNA"], 
          DirectedEdge["HANNAH", 129], 
          DirectedEdge["HANNAH", 26], 
          DirectedEdge["HANNAH", 130], 
          DirectedEdge["HANNAH", "MARY"], 
          DirectedEdge["HANNAH", "MARINA"], 
          DirectedEdge["HANNAH", "JANICE"], 
          DirectedEdge["HANNAH", "LORRAINE"], 
          DirectedEdge["HANNAH", "JESSIE"], 
          DirectedEdge["HANNAH", "PEGGY"], 
          DirectedEdge["HANNAH", "ROSEMARY"], 
          DirectedEdge["HANNAH", "SHIRLEY"], 
          DirectedEdge["HANNAH", "SYLVIA"], 
          DirectedEdge["HANNAH", "ANDREA"], 
          DirectedEdge["HANNAH", "FRANCES"], 
          DirectedEdge["HANNAH", "KATHLEEN"], 
          DirectedEdge["HANNAH", "XFGSKJ"], 
          DirectedEdge["HANNAH", "GRACE"], 
          DirectedEdge["HANNAH", "JOSEPHINE"], 
          DirectedEdge["HANNAH", "YVONNE"], 
          DirectedEdge["HANNAH", "SOPHIE"], 
          DirectedEdge["HANNAH", "LYNNE"], 
          DirectedEdge["HANNAH", "ELAINE"], 
          DirectedEdge["HANNAH", "ANNA"], 
          DirectedEdge["ELAINE", "EVA"], 
          DirectedEdge["ELAINE", "GWENDOLINE"], 
          DirectedEdge["GWENDOLINE", "JESSICA"], 
          DirectedEdge["ELAINE", "GEMMA"], 
          DirectedEdge["ELAINE", 149], 
          DirectedEdge["ELAINE", "NORMA"], 
          DirectedEdge["ELAINE", 26], 
          DirectedEdge["ELAINE", "SHIRLEY"], 
          DirectedEdge["ELAINE", "BEVERLEY"], 
          DirectedEdge["ELAINE", "KIRSTY"], 
          DirectedEdge["ELAINE", "KIMBERLEY"], 
          DirectedEdge["ELAINE", "HAZEL"], 
          DirectedEdge["ELAINE", "FIONA"], 
          DirectedEdge["ELAINE", "KATE"], 
          DirectedEdge["ELAINE", "MARIE"], 
          DirectedEdge["ELAINE", "JENNA"], 
          DirectedEdge["GWENDOLINE", "MARILYN"], 
          DirectedEdge["ELAINE", "JANICE"], 
          DirectedEdge["ELAINE", "DAISY"], 
          DirectedEdge["ELAINE", "NORA"], 
          DirectedEdge["ELAINE", "MFETPC"], 
          DirectedEdge["ELAINE", "NATASHA"], 
          DirectedEdge["ELAINE", "MINNIE"], 
          DirectedEdge["ELAINE", "FREDA"], 
          DirectedEdge["ELAINE", "MANDY"], 
          DirectedEdge["ELAINE", "RACHAEL"], 
          DirectedEdge["ELAINE", "KATHLEEN"], 
          DirectedEdge["ELAINE", "TVKHRF"], 
          DirectedEdge["ELAINE", "CHRISTOPHER"], 
          DirectedEdge["ELAINE", 169], 
          DirectedEdge["ELAINE", "KATHRYN"], 
          DirectedEdge["ELAINE", "NANCY"], 
          DirectedEdge["ELAINE", "LWHQYG"], 
          DirectedEdge["ELAINE", "RUTH"], 
          DirectedEdge["ELAINE", "JAYNE"], 
          DirectedEdge["ELAINE", "DIANA"], 
          DirectedEdge["ELAINE", "MARIAN"], 
          DirectedEdge["ELAINE", "ELEANOR"], 
          DirectedEdge["ELAINE", "VERONICA"], 
          DirectedEdge["ELAINE", "SARA"], 
          DirectedEdge["ELAINE", "ALEXANDRA"], 
          DirectedEdge["ELAINE", "LOUISA"], 
          DirectedEdge["ELAINE", "YAKZCN"], 
          DirectedEdge["ELAINE", "SYLVIA"], 
          DirectedEdge["ELAINE", "MSRGUQ"], 
          DirectedEdge["ELAINE", "DORA"], 
          DirectedEdge["ELAINE", "DAPHNE"], 
          DirectedEdge["ELAINE", "PAULINE"], 
          DirectedEdge["ELAINE", "TERESA"], 
          DirectedEdge["ELAINE", "JULIA"], 
          DirectedEdge["ELAINE", "NORAH"], 
          DirectedEdge["ELAINE", "HEATHER"], 
          DirectedEdge["ELAINE", "KIM"], 
          DirectedEdge["ELAINE", "JEMMA"], 
          DirectedEdge["ELAINE", "THELMA"], 
          DirectedEdge["ELAINE", "CARLY"], 
          DirectedEdge["ELAINE", "IDA"], 
          DirectedEdge["ELAINE", "CLARA"], 
          DirectedEdge["KIRSTY", "BEVERLEY"], 
          DirectedEdge["ELAINE", "GLORIA"], 
          DirectedEdge["ELAINE", "HOLLY"], 
          DirectedEdge["ELAINE", "HILARY"], 
          DirectedEdge["SHIRLEY", "MELISSA"], 
          DirectedEdge["ELAINE", "MARTHA"], 
          DirectedEdge["ELAINE", "CYNTHIA"], 
          DirectedEdge["ELAINE", "BERTHA"], 
          DirectedEdge["ELAINE", "LPYGMD"], 
          DirectedEdge["ELAINE", "LILLIAN"], 
          DirectedEdge["ELAINE", "CHERYL"], 
          DirectedEdge["ELAINE", "IZRDSO"], 
          DirectedEdge["ELAINE", "NAOMI"], 
          DirectedEdge["SHIRLEY", "MARTHA"], 
          DirectedEdge["SHIRLEY", "IZRDSO"], 
          DirectedEdge["EILEEN", 207], 
          DirectedEdge["EILEEN", 93], 
          DirectedEdge["EILEEN", "GEMMA"], 
          DirectedEdge["EILEEN", "MFETPC"], 
          DirectedEdge["SHIRLEY", "MFETPC"], 
          DirectedEdge["EILEEN", "BESSIE"], 
          DirectedEdge["EILEEN", "GAIL"], 
          DirectedEdge["SHIRLEY", "JADE"], 
          DirectedEdge["EILEEN", "PENELOPE"], 
          DirectedEdge["EILEEN", "CHARLENE"], 
          DirectedEdge["EILEEN", "JADE"], 
          DirectedEdge["EILEEN", 213], 
          DirectedEdge["EILEEN", "CHRISTINA"], 
          DirectedEdge["EILEEN", "ANNETTE"], 
          DirectedEdge["EILEEN", 216], 
          DirectedEdge["EILEEN", "QCBGCO"], 
          DirectedEdge["EILEEN", "ESTHER"], 
          DirectedEdge["EILEEN", "CAROLYN"], 
          DirectedEdge["EILEEN", "HARRIET"], 
          DirectedEdge["EILEEN", "ANITA"], 
          DirectedEdge["EILEEN", "DIANE"], 
          DirectedEdge["EILEEN", "HAYLEY"], 
          DirectedEdge["EILEEN", "GERALDINE"], 
          DirectedEdge["EILEEN", "BRIDGET"], 
          DirectedEdge["EILEEN", "GEORGINA"], 
          DirectedEdge["EILEEN", "LINDSEY"], 
          DirectedEdge["EILEEN", "SHIRLEY"], 
          DirectedEdge["EILEEN", "KAY"], 
          DirectedEdge["NANCY", 227], 
          DirectedEdge["NANCY", "STELLA"], 
          DirectedEdge["NANCY", "GEMMA"], 
          DirectedEdge["NANCY", 229], 
          DirectedEdge["NANCY", 230], 
          DirectedEdge["NANCY", "NICHOLA"], 
          DirectedEdge["NANCY", 232], 
          DirectedEdge["NANCY", 233], 
          DirectedEdge["NANCY", "ELAINE"], 
          DirectedEdge["NANCY", "AIMEE"], 
          DirectedEdge["NANCY", "HEIDI"], 
          DirectedEdge["NANCY", "MILLICENT"], 
          DirectedEdge["NANCY", "MFETPC"], 
          DirectedEdge["NANCY", "MONICA"], 
          DirectedEdge["NANCY", "BARBARA"], 
          DirectedEdge["NANCY", "SYLVIA"], 
          DirectedEdge["NANCY", "VALERIE"], 
          DirectedEdge["NANCY", "THERESA"], 
          DirectedEdge["NANCY", "SHIRLEY"], 
          DirectedEdge["NANCY", "ANNA"], 
          DirectedEdge["NANCY", "MARGERY"], 
          DirectedEdge["NANCY", "MAXINE"], 
          DirectedEdge["NANCY", "YAKZCN"], 
          DirectedEdge["NANCY", "SOPHIE"], 
          DirectedEdge["NANCY", "TANYA"], 
          DirectedEdge["NANCY", "CARLA"], 
          DirectedEdge["NANCY", "FANNY"], 
          DirectedEdge["NANCY", "KATHLEEN"], 
          DirectedEdge["NANCY", "CAROLYN"], 
          DirectedEdge["NANCY", "KIRSTY"], 
          DirectedEdge["NANCY", "JOY"], 
          DirectedEdge["NANCY", "JANICE"], 
          DirectedEdge["NANCY", "LYDIA"], 
          DirectedEdge["NANCY", "QSJBJN"], 
          DirectedEdge["BARBARA", "MFETPC"], 
          DirectedEdge["NANCY", "GLENYS"], 
          DirectedEdge["NANCY", "CATHERINE"], 
          DirectedEdge["NANCY", "DEBBIE"], 
          DirectedEdge["NANCY", "NORA"], 
          DirectedEdge["NANCY", "JENNY"], 
          DirectedEdge["NANCY", "LWHQYG"], 
          DirectedEdge["NANCY", "UQSBBO"], 
          DirectedEdge["NANCY", "VIVIENNE"], 
          DirectedEdge["SHIRLEY", "TARA"], 
          DirectedEdge["NANCY", "MIRIAM"], 
          DirectedEdge["SHIRLEY", "MIRIAM"], 
          DirectedEdge["NANCY", "YDYBEJ"], 
          DirectedEdge["CLAIR", "LYNDSEY"], 
          DirectedEdge["CLAIR", "SONIA"], 
          DirectedEdge["CLAIR", "MOLLY"], 
          DirectedEdge["CLAIR", 259], 
          DirectedEdge["CLAIR", 260], 
          DirectedEdge["CLAIR", "ELLA"], 
          DirectedEdge["CLAIR", "CHLOE"], 
          DirectedEdge["CLAIR", "SYBIL"], 
          DirectedEdge["CLAIR", "DAGTLQ"], 
          DirectedEdge["CLAIR", "TONI"], 
          DirectedEdge["CLAIR", "WILLIAM"], 
          DirectedEdge["CLAIR", "ETHEL"], 
          DirectedEdge["CLAIR", "PZZJBB"], 
          DirectedEdge["CLAIR", 268], 
          DirectedEdge["CLAIR", "PAUL"], 
          DirectedEdge["CLAIR", "CHRISTOPHER"], 
          DirectedEdge["CLAIR", 270], 
          DirectedEdge["CLAIR", "MARK"], 
          DirectedEdge["CLAIR", "JAMES"], 
          DirectedEdge["CLAIR", 273], 
          DirectedEdge["CLAIR", "ZPINSB"], 
          DirectedEdge["CLAIR", "VYISWO"], 
          DirectedEdge["CLAIR", "ANDREW"], 
          DirectedEdge["CLAIR", 277], 
          DirectedEdge["CLAIR", 278], 
          DirectedEdge["CLAIR", "DANIEL"], 
          DirectedEdge["CLAIR", "ARTHUR"], 
          DirectedEdge["CLAIR", "KAREN"], 
          DirectedEdge["CLAIR", "KKMNQK"], 
          DirectedEdge["CLAIR", "MINNIE"], 
          DirectedEdge["CLAIR", "RICHARD"], 
          DirectedEdge["CLAIR", "ADLDLW"], 
          DirectedEdge["CLAIR", "KATHLEEN"], 
          DirectedEdge["CLAIR", "ANTHONY"], 
          DirectedEdge["CLAIR", "MATTHEW"], 
          DirectedEdge["CLAIR", "CHARLES"], 
          DirectedEdge["CLAIR", "FREDERICK"], 
          DirectedEdge["CLAIR", "KENNETH"], 
          DirectedEdge["CLAIR", "ALBERT"], 
          DirectedEdge["CLAIR", "ALAN"], 
          DirectedEdge["CLAIR", 291], 
          DirectedEdge["CLAIR", "SIMON"], 
          DirectedEdge["CLAIR", "ERNEST"], 
          DirectedEdge["CLAIR", "ALFRED"], 
          DirectedEdge["CLAIR", "EDWARD"], 
          DirectedEdge["CLAIR", "JOSEPH"], 
          DirectedEdge["CLAIR", "LEE"], 
          DirectedEdge["CLAIR", "ADAM"], 
          DirectedEdge["CLAIR", "ROGER"], 
          DirectedEdge["CLAIR", "HAROLD"], 
          DirectedEdge["CLAIR", "QUQJHK"], 
          DirectedEdge["CLAIR", "KEITH"], 
          DirectedEdge["CLAIR", "FRANK"], 
          DirectedEdge["CLAIR", "ACVRVL"], 
          DirectedEdge["CLAIR", "YAKZCN"], 
          DirectedEdge["CLAIR", "RAYMOND"], 
          DirectedEdge["CLAIR", "COLIN"], 
          DirectedEdge["CLAIR", "WRMHHQ"], 
          DirectedEdge["CLAIR", "DARREN"], 
          DirectedEdge["CLAIR", "HENRY"], 
          DirectedEdge["CLAIR", "PHILIP"], 
          DirectedEdge["CLAIR", "GARY"], 
          DirectedEdge["CLAIR", "BENJAMIN"], 
          DirectedEdge["CLAIR", "STANLEY"], 
          DirectedEdge["CLAIR", 314], 
          DirectedEdge["STEVEN", 316], 
          DirectedEdge["STEVEN", "ERIC"], 
          DirectedEdge["STEVEN", 26], 
          DirectedEdge["STEVEN", "LWHQYG"], 
          DirectedEdge["STEVEN", "YAKZCN"], 
          DirectedEdge["STEVEN", 318], 
          DirectedEdge["STEVEN", "KATHLEEN"], 
          DirectedEdge["STEVEN", 319], 
          DirectedEdge["STEVEN", "MARTIN"], 
          DirectedEdge["STEVEN", "SHIRLEY"], 
          DirectedEdge["STEVEN", 321], 
          DirectedEdge["STEVEN", 322], 
          DirectedEdge["STEVEN", "WALTER"], 
          DirectedEdge["STEVEN", 324], 
          DirectedEdge["STEVEN", "NUHUTJ"], 
          DirectedEdge["STEVEN", "NICHOLAS"], 
          DirectedEdge["WALTER", 327], 
          DirectedEdge["STEVEN", "LEONARD"], 
          DirectedEdge["STEVEN", "BARRY"], 
          DirectedEdge["STEVEN", "NKMUGR"], 
          DirectedEdge["STEVEN", "GORDON"], 
          DirectedEdge["STEVEN", "NORMAN"], 
          DirectedEdge["NICHOLAS", 321], 
          DirectedEdge["STEVEN", "NEIL"], 
          DirectedEdge["STEVEN", "NIGEL"], 
          DirectedEdge["STEVEN", "MALCOLM"], 
          DirectedEdge["STEVEN", "TIMOTHY"], 
          DirectedEdge["NKMUGR", "STUART"], 
          DirectedEdge["STEVEN", "MFETPC"], 
          DirectedEdge["STEVEN", "KIM"], 
          DirectedEdge["STEVEN", "FREDA"], 
          DirectedEdge["STEVEN", "GEOFFREY"], 
          DirectedEdge["STEVEN", "RACHAEL"], 
          DirectedEdge["STEVEN", "ALEXANDER"], 
          DirectedEdge["STEVEN", "CATHERINE"], 
          DirectedEdge["STEVEN", "SYLVIA"], 
          DirectedEdge["STEVEN", "RUTH"], 
          DirectedEdge["STEVEN", "CYRIL"], 
          DirectedEdge["STEVEN", "SIDNEY"], 
          DirectedEdge["STEVEN", "MARIE"], 
          DirectedEdge["STEVEN", "JOANNA"], 
          DirectedEdge["STEVEN", "CHRISTINA"], 
          DirectedEdge["STEVEN", "MBHDDP"], 
          DirectedEdge["STEVEN", "RYAN"], 
          DirectedEdge["STEVEN", "KCVFLP"], 
          DirectedEdge["STEVEN", "LUKE"], 
          DirectedEdge["STEVEN", "JACK"], 
          DirectedEdge["STEVEN", "TREVOR"], 
          DirectedEdge["STEVEN", "UNKPWV"], 
          DirectedEdge["STEVEN", "AJRODZ"], 
          DirectedEdge["STEVEN", "WILFRED"], 
          DirectedEdge["STEVEN", "PATRICK"], 
          DirectedEdge["STEVEN", "KIRZZH"], 
          DirectedEdge["STEVEN", "SAMUEL"], 
          DirectedEdge["WAYNE", "VRADXE"], 
          DirectedEdge["WAYNE", "GARETH"], 
          DirectedEdge["WAYNE", 357], 
          DirectedEdge["WAYNE", "SEAN"], 
          DirectedEdge["WAYNE", "HORACE"], 
          DirectedEdge["WAYNE", "BERNARD"], 
          DirectedEdge["WAYNE", 361], 
          DirectedEdge["WAYNE", 362], 
          DirectedEdge["WAYNE", "FRED"], 
          DirectedEdge["WAYNE", "EDWIN"], 
          DirectedEdge["WAYNE", "FZCFTO"], 
          DirectedEdge["WAYNE", "SHAUN"], 
          DirectedEdge["WAYNE", "CLIFFORD"], 
          DirectedEdge["WAYNE", "MAURICE"], 
          DirectedEdge["WAYNE", "CLIVE"], 
          DirectedEdge["WAYNE", "BEN"], 
          DirectedEdge["WAYNE", "ANTONY"], 
          DirectedEdge["WAYNE", "CHRISTOPHER"], 
          DirectedEdge["WAYNE", "MXOUPI"], 
          DirectedEdge["WAYNE", "MALCOLM"], 
          DirectedEdge["WAYNE", 373], 
          DirectedEdge["WAYNE", "JUSTIN"], 
          DirectedEdge["WAYNE", 375], 
          DirectedEdge["WAYNE", "JEFFREY"], 
          DirectedEdge["WAYNE", "OLIVER"], 
          DirectedEdge["WAYNE", "EDGAR"], 
          DirectedEdge["WAYNE", "ETHEL"], 
          DirectedEdge["WAYNE", "SHIRLEY"], 
          DirectedEdge["WAYNE", "KATHLEEN"], 
          DirectedEdge["BEN", "SHIRLEY"], 
          DirectedEdge["WAYNE", "CHRISTIAN"], 
          DirectedEdge["WAYNE", "ASHLEY"], 
          DirectedEdge["WAYNE", "KARL"], 
          DirectedEdge["WAYNE", "AARON"], 
          DirectedEdge["WAYNE", "MARC"], 
          DirectedEdge["WAYNE", "YAKZCN"], 
          DirectedEdge["WAYNE", "MOHAMMED"], 
          DirectedEdge["WAYNE", "PEYHIE"], 
          DirectedEdge["WAYNE", "JANICE"], 
          DirectedEdge["WAYNE", "RUSSELL"], 
          DirectedEdge["WAYNE", "GAVIN"], 
          DirectedEdge["WAYNE", "CATHERINE"], 
          DirectedEdge["WAYNE", "VIVVLG"], 
          DirectedEdge["WAYNE", "FREDA"], 
          DirectedEdge["WAYNE", "LIAM"], 
          DirectedEdge["WAYNE", "ROBIN"], 
          DirectedEdge["WAYNE", "PHILLIP"], 
          DirectedEdge["WAYNE", "NATHAN"], 
          DirectedEdge["WAYNE", "DENIS"]}, {VertexLabels -> {
            Placed["Name", Tooltip]}, EdgeWeight -> CompressedData["
1:eJyFUNsRgCAMIy3IHK7kCCzgvG4jFI8rtWI+aEhfue7lPApCCFd9oBFBLVAL
woRQp6KMBBQRbD0wHORWTUhezoC+VXoVKcXd+zvebuNZ5oWbivR0RIzjqHMt
TLD0zJZJGzDUN2H3zP8bwKAErA==
           
           "]}], $CellContext`edgeWeights = CompressedData["
1:eJyFUNsRgCAMIy3IHK7kCCzgvG4jFI8rtWI+aEhfue7lPApCCFd9oBFBLVAL
woRQp6KMBBQRbD0wHORWTUhezoC+VXoVKcXd+zvebuNZ5oWbivR0RIzjqHMt
TLD0zJZJGzDUN2H3zP8bwKAErA==
        "]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.676271572623253*^9, 3.6762716111958437`*^9}, 
   3.6762716452272882`*^9, {3.676271981486299*^9, 3.676272007077566*^9}, 
   3.6778227620033693`*^9, 3.677822959314481*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Advanced Questions", "Section",
 CellChangeTimes->{{3.6762714912388487`*^9, 3.6762714940183067`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Modify your code so that you can filter out edges by the different \
interaction types, for instance display only those connections where at least \
interaction is due to PoliticalActivity\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676271691223072*^9, 3.6762717544237843`*^9}}],

Cell["\<\
Allow the user to switch between subsetting the graph and instead just \
highlighting the interactions of interest.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676271691223072*^9, 3.676271781954151*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{840, 1005},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"10.4 for Mac OS X x86 (32-bit, 64-bit Kernel) (April 11, \
2016)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData["Comments"], CellMargins -> {{66, 210}, {7, 7}}, 
    LineSpacing -> {1, 3}, CounterIncrements -> "Text", MenuSortingValue -> 
    1400, FontFamily -> "Arial", FontSize -> 14, FontColor -> 
    RGBColor[0, 0, 1]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Section"], CellFrame -> {{0, 0}, {0, 1}}, 
       CellMargins -> {{27, Inherited}, {8, 18}}, 
       StyleKeyMapping -> {"Tab" -> "Subsection"}, 
       CellGroupingRules -> {"SectionGrouping", 30}, PageBreakBelow -> False, 
       CellFrameMargins -> 4, CellFrameColor -> GrayLevel[0.7], 
       LineSpacing -> {1, 2}, LanguageCategory -> "NaturalLanguage", 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Item", 0}, {"Subitem", 0}, {"Subsubitem", 0}, {"ItemNumbered", 0}, {
         "SubitemNumbered", 0}, {"SubsubitemNumbered", 0}}, MenuSortingValue -> 
       1250, MenuCommandKey -> "4", FontFamily -> "Gill Sans", FontSize -> 28,
        FontColor -> RGBColor[0, 0, 0]], 
      Cell[
       StyleData["Section", "Presentation"], CellFrame -> {{0, 0}, {0, 2}}, 
       CellMargins -> {{67, Inherited}, {12, 24}}, CellFrameMargins -> 8, 
       LineSpacing -> {1, 10}, FontSize -> 40], 
      Cell[
       StyleData["Section", "SlideShow"], 
       CellMargins -> {{
         0.06 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}], 0.04 
          FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]}, {
         12, 0.06 FrontEnd`AbsoluteCurrentValue[{WindowSize, 2}]}}, 
       LineSpacing -> {1, 2}, FontSize -> 40], 
      Cell[
       StyleData["Section", "Condensed"], 
       CellMargins -> {{18, Inherited}, {6, 12}}, FontSize -> 12], 
      Cell[
       StyleData["Section", "Printout"], 
       CellMargins -> {{10, Inherited}, {8, 18}}], 
      Cell[
       StyleData["Section", "PrintoutGray"], 
       CellMargins -> {{10, Inherited}, {8, 18}}, FontColor -> 
       GrayLevel[0.2]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Subsection"], CellMargins -> {{50.34765625, 3.}, {8., 12.}},
        StyleKeyMapping -> {
        "Tab" -> "Subsubsection", "Backspace" -> "Section", 
         KeyEvent["Tab", Modifiers -> {Shift}] -> "Section"}, 
       CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> False, 
       LanguageCategory -> "NaturalLanguage", CounterIncrements -> 
       "Subsection", 
       CounterAssignments -> {{"Subsubsection", 0}, {"Item", 0}, {
         "Subitem", 0}, {"Subsubitem", 0}, {"ItemNumbered", 0}, {
         "SubitemNumbered", 0}, {"SubsubitemNumbered", 0}}, MenuSortingValue -> 
       1300, MenuCommandKey -> "5", FontFamily -> "Gill Sans", FontSize -> 20,
        FontColor -> RGBColor[0, 0, 0]], 
      Cell[
       StyleData["Subsection", "Presentation"], 
       CellMargins -> {{100, Inherited}, {12, 18}}, LineSpacing -> {1, 10}, 
       FontSize -> 28], 
      Cell[
       StyleData["Subsection", "SlideShow"], 
       CellMargins -> {{
         0.1 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}], 0.02 
          FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]}, {
         12, 0.046 FrontEnd`AbsoluteCurrentValue[{WindowSize, 2}]}}, 
       LineSpacing -> {1, 2}, FontSize -> 32], 
      Cell[
       StyleData["Subsection", "Condensed"], 
       CellMargins -> {{18, Inherited}, {6, 12}}, FontSize -> 11], 
      Cell[
       StyleData["Subsection", "Printout"], 
       CellMargins -> {{30, Inherited}, {8., 16}}], 
      Cell[
       StyleData["Subsection", "PrintoutGray"], 
       CellMargins -> {{30, Inherited}, {8., 16}}, FontColor -> 
       GrayLevel[0.3]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Subsubsection"], CellMargins -> {{66, Inherited}, {2, 10}}, 
       StyleKeyMapping -> {
        "Tab" -> "Subsubsubsection", "Backspace" -> "Subsection", 
         KeyEvent["Tab", Modifiers -> {Shift}] -> "Subsection"}, 
       CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> False, 
       LanguageCategory -> "NaturalLanguage", CounterIncrements -> 
       "Subsubsection", 
       CounterAssignments -> {{"Subsubsubsection", 0}, {"Item", 0}, {
         "Subitem", 0}, {"Subsubitem", 0}, {"ItemNumbered", 0}, {
         "SubitemNumbered", 0}, {"SubsubitemNumbered", 0}}, MenuSortingValue -> 
       1350, MenuCommandKey -> "6", FontFamily -> "Gill Sans", FontSize -> 19,
        FontColor -> RGBColor[0, 0, 0]], 
      Cell[
       StyleData["Subsubsection", "Presentation"], 
       CellMargins -> {{100, Inherited}, {3, 15}}, LineSpacing -> {1, 6}, 
       FontSize -> 24], 
      Cell[
       StyleData["Subsubsection", "SlideShow"], 
       CellMargins -> {{
         0.135 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}], 0.03 
          FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]}, {3, 15}}, 
       LineSpacing -> {1, 2}, FontSize -> 28], 
      Cell[
       StyleData["Subsubsection", "Condensed"], 
       CellMargins -> {{18, Inherited}, {6, 12}}, FontSize -> 11], 
      Cell[
       StyleData["Subsubsection", "Printout"], 
       CellMargins -> {{49, Inherited}, {6, 16}}], 
      Cell[
       StyleData["Subsubsection", "PrintoutGray"], 
       CellMargins -> {{49, Inherited}, {6, 16}}, FontColor -> 
       GrayLevel[0.3]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Subsubsubsection"], 
       CellMargins -> {{66, Inherited}, {2, 10}}, 
       StyleKeyMapping -> {
        "Tab" -> "Subsubsubsubsection", "Backspace" -> "Subsubsection", 
         KeyEvent["Tab", Modifiers -> {Shift}] -> "Subsubsection"}, 
       CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> False, 
       LanguageCategory -> "NaturalLanguage", CounterIncrements -> 
       "Subsubsubsection", 
       CounterAssignments -> {{"Subsubsubsubsection", 0}, {"Item", 0}, {
         "Subitem", 0}, {"Subsubitem", 0}, {"ItemNumbered", 0}, {
         "SubitemNumbered", 0}, {"SubsubitemNumbered", 0}}, MenuSortingValue -> 
       None, FontFamily -> "Arial", FontSize -> 14, FontWeight -> "Bold", 
       FontColor -> RGBColor[0, 0, 0]], 
      Cell[
       StyleData["Subsubsubsection", "Presentation"], 
       CellMargins -> {{100, Inherited}, {3, 15}}, LineSpacing -> {1, 7}, 
       FontSize -> 24], 
      Cell[
       StyleData["Subsubsubsection", "SlideShow"], 
       CellMargins -> {{
         0.135 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}], 0.03 
          FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]}, {3, 15}}, 
       LineSpacing -> {1, 2}, FontFamily -> "Arial", FontSize -> 22], 
      Cell[
       StyleData["Subsubsubsection", "Condensed"], 
       CellMargins -> {{18, Inherited}, {6, 12}}, FontSize -> 10], 
      Cell[
       StyleData["Subsubsubsection", "Printout"], 
       CellMargins -> {{49, Inherited}, {6, 14}}], 
      Cell[
       StyleData["Subsubsubsection", "PrintoutGray"], 
       CellMargins -> {{49, Inherited}, {6, 14}}, FontColor -> 
       GrayLevel[0.4]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Subsubsubsubsection"], 
       CellMargins -> {{66, Inherited}, {2, 10}}, 
       StyleKeyMapping -> {
        "Backspace" -> "Subsubsubsection", 
         KeyEvent["Tab", Modifiers -> {Shift}] -> "Subsubsubsection"}, 
       CellGroupingRules -> {"SectionGrouping", 70}, PageBreakBelow -> False, 
       LanguageCategory -> "NaturalLanguage", CounterIncrements -> 
       "Subsubsubsubsection", 
       CounterAssignments -> {{"Item", 0}, {"Subitem", 0}, {
         "Subsubitem", 0}, {"ItemNumbered", 0}, {"SubitemNumbered", 0}, {
         "SubsubitemNumbered", 0}}, MenuSortingValue -> None, FontFamily -> 
       "Arial", FontSize -> 14, FontColor -> RGBColor[0, 0, 0]], 
      Cell[
       StyleData["Subsubsubsubsection", "Presentation"], 
       CellMargins -> {{100, Inherited}, {3, 15}}, LineSpacing -> {1, 7}, 
       FontSize -> 24], 
      Cell[
       StyleData["Subsubsubsubsection", "SlideShow"], 
       CellMargins -> {{
         0.135 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}], 0.03 
          FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]}, {3, 15}}, 
       LineSpacing -> {1, 2}, FontSize -> 22], 
      Cell[
       StyleData["Subsubsubsubsection", "Condensed"], 
       CellMargins -> {{18, Inherited}, {6, 12}}, FontSize -> 10], 
      Cell[
       StyleData["Subsubsubsubsection", "Printout"], 
       CellMargins -> {{49, Inherited}, {6, 14}}], 
      Cell[
       StyleData["Subsubsubsubsection", "PrintoutGray"], 
       CellMargins -> {{49, Inherited}, {6, 14}}, FontColor -> 
       GrayLevel[0.3]]}, Closed]]}, Visible -> False, FrontEndVersion -> 
  "10.4 for Mac OS X x86 (32-bit, 64-bit Kernel) (April 11, 2016)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "SlideShowHeader"->{
  Cell[936, 29, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[5620, 116, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[8098, 185, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[29165, 747, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[406255, 8642, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[408249, 8693, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[413195, 8815, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"SlideShowHeader", 460608, 9889}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 353, 5, 148, "Title"],
Cell[CellGroupData[{
Cell[936, 29, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[1003, 32, 84, 1, 92, "Title"],
Cell[1090, 35, 512, 11, 49, "Text"],
Cell[1605, 48, 790, 16, 68, "Text"],
Cell[2398, 66, 155, 2, 30, "Text"],
Cell[2556, 70, 3027, 41, 714, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5620, 116, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[5687, 119, 140, 2, 92, "Title"],
Cell[5830, 123, 371, 6, 49, "Text"],
Cell[6204, 131, 346, 7, 87, "Text"],
Cell[CellGroupData[{
Cell[6575, 142, 96, 1, 28, "Item"],
Cell[6674, 145, 230, 4, 45, "Item"]
}, Open  ]],
Cell[6919, 152, 748, 19, 80, "Input"],
Cell[7670, 173, 391, 7, 45, "Item"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8098, 185, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[8165, 188, 93, 1, 92, "Title"],
Cell[8261, 191, 363, 10, 144, "Text"],
Cell[8627, 203, 267, 5, 49, "Text"],
Cell[8897, 210, 342, 6, 49, "ItemNumbered"],
Cell[9242, 218, 193, 2, 30, "Text"],
Cell[9438, 222, 368, 9, 46, "Input"],
Cell[9809, 233, 133, 1, 30, "Text"],
Cell[9945, 236, 193, 4, 30, "ItemNumbered"],
Cell[10141, 242, 346, 6, 49, "Text"],
Cell[CellGroupData[{
Cell[10512, 252, 101, 1, 64, "Section"],
Cell[10616, 255, 192, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[10833, 263, 287, 7, 28, "Input"],
Cell[11123, 272, 237, 6, 28, "Output"]
}, Open  ]],
Cell[11375, 281, 319, 6, 49, "ItemNumbered"],
Cell[11697, 289, 132, 1, 30, "Text"],
Cell[11832, 292, 709, 15, 63, "Input"],
Cell[12544, 309, 221, 5, 30, "Text"],
Cell[12768, 316, 405, 11, 28, "Input"],
Cell[13176, 329, 697, 11, 106, "ItemNumbered"],
Cell[13876, 342, 170, 4, 28, "Input"],
Cell[14049, 348, 290, 5, 41, "SubitemNumbered"],
Cell[14342, 355, 405, 7, 49, "ItemNumbered"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14784, 367, 106, 1, 64, "Section"],
Cell[14893, 370, 201, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[15119, 378, 237, 4, 49, "ItemNumbered"],
Cell[15359, 384, 247, 5, 30, "ItemNumbered"]
}, Open  ]],
Cell[15621, 392, 13495, 349, 184, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[29165, 747, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[29232, 750, 210, 3, 92, "Title"],
Cell[29445, 755, 344, 6, 30, "Text"],
Cell[29792, 763, 142383, 3188, 311, "Input"],
Cell[CellGroupData[{
Cell[172200, 3955, 404, 8, 49, "ItemNumbered"],
Cell[172607, 3965, 446, 8, 68, "ItemNumbered"]
}, Open  ]],
Cell[173068, 3976, 231997, 4634, 311, 157127, 3405, "CachedBoxData", \
"BoxData", "Input"],
Cell[405068, 8612, 400, 7, 68, "ItemNumbered"],
Cell[405471, 8621, 389, 7, 68, "Text"],
Cell[405863, 8630, 355, 7, 49, "ItemNumbered"]
}, Open  ]],
Cell[CellGroupData[{
Cell[406255, 8642, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[406322, 8645, 211, 3, 92, "Title"],
Cell[406536, 8650, 232, 4, 49, "Text"],
Cell[406771, 8656, 164, 3, 30, "ItemNumbered"],
Cell[406938, 8661, 242, 4, 47, "Input"],
Cell[407183, 8667, 205, 4, 30, "Text"],
Cell[407391, 8673, 530, 8, 68, "ItemNumbered"],
Cell[407924, 8683, 288, 5, 49, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[408249, 8693, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[408316, 8696, 205, 3, 92, "Title"],
Cell[408524, 8701, 435, 7, 68, "Text"],
Cell[408962, 8710, 243, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[409230, 8719, 306, 5, 49, "ItemNumbered"],
Cell[409539, 8726, 575, 9, 144, "ItemNumbered"]
}, Open  ]],
Cell[410129, 8738, 610, 17, 63, "Input"],
Cell[410742, 8757, 659, 12, 87, "Text"],
Cell[CellGroupData[{
Cell[411426, 8773, 317, 5, 30, "ItemNumbered"],
Cell[411746, 8780, 401, 7, 49, "ItemNumbered"],
Cell[412150, 8789, 667, 12, 106, "ItemNumbered"],
Cell[412820, 8803, 326, 6, 68, "ItemNumbered"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[413195, 8815, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[413262, 8818, 351, 5, 92, "Title"],
Cell[413616, 8825, 125, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[413766, 8830, 173, 4, 28, "Item"],
Cell[413942, 8836, 144, 1, 28, "Item"]
}, Open  ]],
Cell[414101, 8840, 209, 4, 30, "Text"],
Cell[414313, 8846, 120, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[414458, 8851, 445, 13, 46, "Input"],
Cell[414906, 8866, 1528, 30, 140, "Output"]
}, Open  ]],
Cell[416449, 8899, 195, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[416669, 8907, 392, 10, 28, "Input"],
Cell[417064, 8919, 1521, 31, 141, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[418622, 8955, 107, 1, 64, "Section"],
Cell[418732, 8958, 400, 8, 49, "Text"],
Cell[419135, 8968, 716, 19, 63, "Input"],
Cell[419854, 8989, 328, 6, 49, "Text"],
Cell[420185, 8997, 669, 19, 46, "Input"],
Cell[CellGroupData[{
Cell[420879, 9020, 371, 7, 49, "ItemNumbered"],
Cell[421253, 9029, 515, 8, 87, "ItemNumbered"],
Cell[421771, 9039, 295, 5, 49, "ItemNumbered"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[422115, 9050, 102, 1, 64, "Section"],
Cell[CellGroupData[{
Cell[422242, 9055, 222, 4, 30, "ItemNumbered"],
Cell[422467, 9061, 177, 4, 30, "ItemNumbered"],
Cell[422647, 9067, 390, 7, 49, "ItemNumbered"],
Cell[423040, 9076, 183, 4, 30, "ItemNumbered"]
}, Open  ]],
Cell[423238, 9083, 27550, 582, 374, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[450825, 9670, 107, 1, 64, "Section"],
Cell[CellGroupData[{
Cell[450957, 9675, 288, 5, 49, "ItemNumbered"],
Cell[451248, 9682, 213, 4, 49, "ItemNumbered"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

