(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.4' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1222984,      25508]
NotebookOptionsPosition[   1205356,      25059]
NotebookOutlinePosition[   1215197,      25280]
CellTagsIndexPosition[   1215115,      25275]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Prosopographical Networks - Guided Workshop", "Title",
 CellChangeTimes->{
  3.6695419383340187`*^9, {3.6695436273978767`*^9, 3.669543635518165*^9}, {
   3.673077547116518*^9, 3.673077571043455*^9}, {3.673080175394973*^9, 
   3.673080187779351*^9}, {3.673080228269444*^9, 3.673080230384207*^9}, {
   3.6762728255778418`*^9, 3.676272833200596*^9}}],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Prosopographical Networks", "Title",
 CellChangeTimes->{3.676272209036519*^9}],

Cell[TextData[{
 "For this evening\[CloseCurlyQuote]s session I woud like to invite you to \
form into three groups of four to study a dataset from the ",
 ButtonBox["Cultures of Knowledge",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://www.culturesofknowledge.org/"], None},
  ButtonNote->"http://www.culturesofknowledge.org/"],
 " project, concerning the prosopography of a number of the individuals in \
their dataset."
}], "Text",
 CellChangeTimes->{{3.676272212092185*^9, 3.676272302744831*^9}}],

Cell[TextData[{
 "As I\[CloseCurlyQuote]m not a digital humanities researcher, I will bow to \
Arno Bosse and Robin Buning for an explanation of the topic and data - but I \
can show off what I\[CloseCurlyQuote]ve built for them: ",
 ButtonBox["http://drupal-pilot-livedata.it.ox.ac.uk/article/prosopographical-\
network-samuel-hartlib-ii",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://drupal-pilot-livedata.it.ox.ac.uk/article/prosopographical-\
network-samuel-hartlib-ii"], None},
  ButtonNote->
   "http://drupal-pilot-livedata.it.ox.ac.uk/article/prosopographical-network-\
samuel-hartlib-ii"]
}], "Text",
 CellChangeTimes->{{3.6762723046226587`*^9, 3.676272321116435*^9}, {
  3.676272420254191*^9, 3.6762724362728863`*^9}, {3.676272542251534*^9, 
  3.676272561224519*^9}}],

Cell[TextData[StyleBox["NOTE: Data has been anonymised",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.6778196969034967`*^9, 3.677819705846488*^9}}],

Cell[TextData[StyleBox["\[OpenCurlyDoubleQuote]Prosopography, or collective \
biography, is concerned with identifying patterns of activity and \
connectivity in large quantities of data that may be missed using synthetic \
approaches. It is a potentially useful method for gaining insight into the \
large and sometimes complex networks that constituted the \
\[OpenCurlyQuote]Republic of Letters\[CloseCurlyQuote], the intellectual \
community of 16\[Dash]19th-century Europe. The prosopographical approach \
consists of collecting relevant quantities of biographical data of all \
members of a well-defined group according to pre-selected categories, which \
are then analyzed in different ways.\n\nThe modules included in this \
application aim to provide a powerful and easy-to-use tool for \
prosopographical data visualization and analysis.\n\nThe network of Samuel \
Hartlib was chosen, together with the complementary network of John Amos \
Comenius (1592\[Dash]1670), as case studies, because they represent the \
intricate networks one should be able to unravel with the use of the \
prosopographical tool. The members of these networks were widely dispersed, \
highly mobile, and included some well-known figures, but many more figures \
about whom little is known.\n\nThe conceptual data model underlying the \
prosopographical tool is event-based and person-centred. It was designed to \
facilitate capturing the broad range of relationships and activities typical \
of an early modern intellectual, with a focus on contact and location \
history. The data were originally captured in spreadsheets, each revolving \
around a member of Hartlib\[CloseCurlyQuote]s circle who is entered as the \
\[OpenCurlyQuote]primary participant\[CloseCurlyQuote]. The people and \
organizations connected to the primary participant are entered in his \
spreadsheet as \[OpenCurlyQuote]secondary participants\[CloseCurlyQuote]. To \
date (May 2016) the complete Hartlib dataset contains the prosopographical \
data of 130 people, numbering over 6,000 events in total.\n\nFor these proof \
of concepts a representative subset of eleven spreadsheets was selected, \
combining the most populated spreadsheets and spreadsheets of people who were \
at the centre of Hartlib\[CloseCurlyQuote]s network, and taking into account \
geographical distribution and varying social positions. The selection \
consists of:\n\nJohann Heinrich Alting (1618\[Dash]1679)\nHeinrich Appelius \
(fl. 1628\[Dash]1658)\nNicholas Arnold (1618\[Dash]1680)\nTheodor Haak (1605\
\[Dash]1690)\nGeorg Hartlib (d. 1651)\nSamuel Hartlib (c.1600\[Dash]1662)\n\
Goddofred Hotton (1596\[Dash]1656)\nThomas Roe (1581\[Dash]1644)\nJohann \
Friedrich Schlezer (1610\[Dash]1673)\nCaspar Streso (1603\[Dash]1664)\n\
William Waller (1598\[Dash]1668)\[CloseCurlyDoubleQuote]",
 FontSlant->"Italic"]], "Text",
 CellChangeTimes->{
  3.676272202208538*^9, 3.67627243943392*^9, {3.676272475321886*^9, 
   3.676272475824065*^9}, {3.6762725111311197`*^9, 3.67627251892951*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Workshop/Guided Data Exploration", "Title",
 CellChangeTimes->{
  3.676272209036519*^9, {3.676272603484109*^9, 3.676272611829893*^9}}],

Cell["\<\
Please separate into three groups of four to work on these exercises together \
- there are a number of new subjects/functions introduced in this workshop \
and we would like you to build skills together, and learn how to debug.\
\>", "Text",
 CellChangeTimes->{{3.676194546120261*^9, 3.6761945747074757`*^9}, {
  3.676195321913344*^9, 3.6761953772770042`*^9}}],

Cell["\<\
We will be wandering out to help you with your code and will take the \
opportunity at times to speak to the entire workshop on a particular subject.

Please consider the following advice before starting:\
\>", "Text",
 CellChangeTimes->{{3.6761953788182487`*^9, 3.67619542114191*^9}, {
  3.6761964287166433`*^9, 3.676196468507123*^9}}],

Cell[CellGroupData[{

Cell["Save regularly", "Item",
 CellChangeTimes->{{3.676196474885923*^9, 3.676196477164884*^9}}],

Cell["\<\
Write an explanation of what your code does, the best explanations are \
written as text cells - but comments can easily be included in code.\
\>", "Item",
 CellChangeTimes->{{3.676196474885923*^9, 3.67619651078575*^9}}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"2", "+", "2"}], "<", "5"}], 
    RowBox[{"(*", 
     RowBox[{"the", " ", "test"}], "*)"}], ",", "\[IndentingNewLine]", 
    "\"\<Truth\>\"", ",", 
    RowBox[{"(*", 
     RowBox[{
     "return", " ", "if", " ", "the", " ", "test", " ", "yields", " ", 
      "true"}], "*)"}], ",", "\[IndentingNewLine]", "\"\<False\>\""}], 
   RowBox[{"(*", 
    RowBox[{
    "return", " ", "if", " ", "the", " ", "test", " ", "yields", " ", 
     "false"}], "*)"}], "\[IndentingNewLine]", "]"}], " "}]], "Input",
 CellChangeTimes->{{3.6761965159464283`*^9, 3.676196529245915*^9}, {
  3.676196603486597*^9, 3.676196631634961*^9}, {3.6761966669057617`*^9, 
  3.67619668460151*^9}}],

Cell["\<\
Try things together and insolation, but work together on understanding and \
fixing each other\[CloseCurlyQuote]s code. Learning to program requires that \
you learn how other people approach a problem\
\>", "Item",
 CellChangeTimes->{{3.676196701692339*^9, 3.676196742832221*^9}, {
  3.676272645209642*^9, 3.676272691323285*^9}, {3.676272785094593*^9, 
  3.6762728006307373`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Data Import", "Title",
 CellChangeTimes->{{3.676198782006147*^9, 3.67619878343435*^9}}],

Cell["\<\
The dataset you\[CloseCurlyQuote]ll be working with is provided in a \
subfolder of the folder where this notebook is stored, the folders look like \
this:

thisFolder/
------------- thisNotebook.nb
------------- /data
--------------------- master_life _events _sheet.csv\
\>", "Text",
 CellChangeTimes->{{3.676195432122506*^9, 3.6761955375101147`*^9}}],

Cell["\<\
Mathematica has a \[OpenCurlyDoubleQuote]working directory\
\[CloseCurlyDoubleQuote] where it looks for files for importing - this is \
modified using the function SetDirectory.\
\>", "Text",
 CellChangeTimes->{{3.676195543378767*^9, 3.676195578735024*^9}}],

Cell["\<\
Use the functions NotebookDirectory and SetDirectory to change the current \
working directory to the \[OpenCurlyDoubleQuote]data\[CloseCurlyDoubleQuote] \
folder of the file tree set out above\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676195582820417*^9, 3.676195622899311*^9}, {
  3.676195670852845*^9, 3.6761957207806997`*^9}}],

Cell["You will know this has worked if the following yields true", "Text",
 CellChangeTimes->{{3.676195726416465*^9, 3.6761957397824507`*^9}, {
  3.6761958387291594`*^9, 3.676195857639531*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", 
  RowBox[{
   RowBox[{"NotebookDirectory", "[", "]"}], "<>", "\"\<Exercises/Data\>\""}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.676192327334527*^9, 3.676192341373432*^9}, {
  3.6775859408730373`*^9, 3.6775859420307007`*^9}}],

Cell[BoxData["\<\"/Users/martinjohnhadley/Google Drive/Shared_Folders/DHOxSS \
Mathematica Workshop/02_Tuesday_Text&Networks/Evening/Exercises/data\"\>"], \
"Output",
 CellChangeTimes->{
  3.676192341700399*^9, 3.676261862727014*^9, 3.67627182124509*^9, {
   3.677585933622375*^9, 3.677585942296187*^9}, 3.67782125412479*^9, 
   3.6778228733248568`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"FileNames", "[", "\"\<*.csv\>\"", "]"}], "==", 
  RowBox[{"{", 
   RowBox[{
   "\"\<interaction_tallies.csv\>\"", ",", 
    "\"\<master_life_events_sheet.csv\>\"", ",", "\"\<people-info.csv\>\""}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.676195740647111*^9, 3.67619576368143*^9}, 
   3.676195832219305*^9, 3.676271844398509*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.676261864241106*^9, 3.676271845248775*^9, 
  3.67758594387431*^9, 3.677821256449115*^9, 3.677822876243474*^9}]
}, Open  ]],

Cell["Based on that, what does the function FileNames do?", "Text",
 CellChangeTimes->{{3.676195859901044*^9, 3.676195868496026*^9}}],

Cell["\<\
Import the master_life_events_sheet.csv file and store the data against an \
appropriate symbol\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676195882290853*^9, 3.676195904302414*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"lifeevents$import", "=", 
   RowBox[{"Import", "[", "\"\<master_life_events_sheet.csv\>\"", "]"}]}], 
  ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{"lifeevents$import", "[", 
   RowBox[{"[", 
    RowBox[{";;", "5"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.6775859511144953`*^9, 3.677585957152368*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"Category\"\>", "\<\"Primary.Participant.Emlo_ID\"\>", \
"\<\"Primary.Participant.Name\"\>", "\<\"Secondary.Participant.Emlo_ID\"\>", \
"\<\"Secondary.Participant.Name\"\>", "\<\"Secondary.Participant.Type\"\>"},
    {"\<\"BasicData\"\>", 
     "1", "\<\"MARY\"\>", "\<\"NA\"\>", "\<\"-\"\>", "\<\"\"\>"},
    {"\<\"BasicData\"\>", 
     "1", "\<\"MARY\"\>", "\<\"NA\"\>", "\<\"-\"\>", "\<\"\"\>"},
    {"\<\"Education\"\>", "1", "\<\"MARY\"\>", 
     "2", "\<\"MARGARET\"\>", "\<\"Organisation\"\>"},
    {"\<\"Education\"\>", "1", "\<\"MARY\"\>", 
     "3", "\<\"SUSAN\"\>", "\<\"Organisation\"\>"}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.677585957568828*^9, 3.6778212592461653`*^9, 
  3.677822879464719*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Question", "Section",
 CellChangeTimes->{{3.677586592235134*^9, 3.677586593110099*^9}}],

Cell["\<\
There are too many columns for us to reasonably handle the data as a list of \
lists - we must convert the data into Associations.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676195882290853*^9, 3.676195939935041*^9}, 
   3.676198373294202*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"lifeevents$Associations", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"AssociationThread", "[", 
       RowBox[{
        RowBox[{"lifeevents$import", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", "#"}], "]"}], "&"}], ",", 
     
     RowBox[{"lifeevents$import", "[", 
      RowBox[{"[", 
       RowBox[{"2", ";;"}], "]"}], "]"}]}], "]"}]}], ";"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["AssocationThread", "Section",
 CellChangeTimes->{{3.676195942117484*^9, 3.676195944942113*^9}}],

Cell["\<\
Lists of associations can be easily constructed with the function \
AssociationThread, for instance:\
\>", "Text",
 CellChangeTimes->{{3.676195972201304*^9, 3.6761959968724117`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AssociationThread", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\"\<Key 1\>\"", ",", "\"\<Key 2\>\""}], "}"}], "\[Rule]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.676195997763034*^9, 3.676196014141762*^9}}],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"\<\"Key 1\"\>", "\[Rule]", "1"}], ",", 
   RowBox[{"\<\"Key 2\"\>", "\[Rule]", "2"}]}], 
  "\[RightAssociation]"}]], "Output",
 CellChangeTimes->{3.676196014552053*^9, 3.6778228845681753`*^9}]
}, Open  ]],

Cell["\<\
Use AssociationThread and Map to construct a list of associations containing \
the data from the datafile you imported.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.6761960215793533`*^9, 3.676196045484956*^9}, {
  3.676196355535255*^9, 3.676196357795003*^9}, {3.6761963985181093`*^9, 
  3.676196404717133*^9}}],

Cell["The associations will individually look like this:", "Text",
 CellChangeTimes->{{3.676196406798375*^9, 3.676196413885996*^9}}],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"\"\<Event.Label\>\"", "\[Rule]", "6"}], ",", 
   RowBox[{"\"\<Category\>\"", "\[Rule]", "\"\<BasicData\>\""}], ",", 
   RowBox[{
   "\"\<Event.or.Relationship.Type\>\"", "\[Rule]", 
    "\"\<FamilyRelationships\>\""}], ",", 
   RowBox[{"\"\<Event.Name.or.Description\>\"", "\[Rule]", "\"\<\>\""}], ",", 
   "...", ",", 
   RowBox[{"\"\<Who.Entered.Data\>\"", "\[Rule]", "\"\<Robin Buning\>\""}], 
   ",", 
   RowBox[{"\"\<Whose.Notes\>\"", "\[Rule]", "\"\<\>\""}], ",", 
   RowBox[{"\"\<Additional.Notes\>\"", "\[Rule]", "\"\<\>\""}]}], 
  "\[RightAssociation]"}]], "Input",
 CellChangeTimes->{{3.676196378191931*^9, 3.676196393264283*^9}}],

Cell["\<\
You will know that the data your output is correct if the following yields \
true:\
\>", "Text",
 CellChangeTimes->{{3.676196417081533*^9, 3.676196421851451*^9}, {
  3.676196785079638*^9, 3.676196819457255*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Dimensions", "[", "yourSymbol", "]"}], "==", 
   RowBox[{"{", "813", "}"}]}], "&&", 
  RowBox[{"AllTrue", "[", 
   RowBox[{
    RowBox[{"Map", "[", 
     RowBox[{"AssociationQ", ",", "yourSymbol"}], "]"}], ",", "TrueQ"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.676196841703506*^9, 3.67619686363721*^9}, {
  3.676196917879393*^9, 3.676196920709096*^9}}],

Cell["\<\
Each entry is a description of a relationship between a \
\[OpenCurlyDoubleQuote]Primary.Participant.Emlo_ID\[CloseCurlyDoubleQuote] \
and \[OpenCurlyDoubleQuote]Secondary.Participant.Emlo_ID\
\[CloseCurlyDoubleQuote] - but the secondary participant is not necessarily a \
person.\[LineSeparator]\[LineSeparator]Extract the \
\[OpenCurlyDoubleQuote]Secondary.Participant.Type\[CloseCurlyDoubleQuote] key \
from your list of associations and list just the unique values, if you\
\[CloseCurlyQuote]ve done this correct the following will yield True\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676196957681127*^9, 3.6761970757262697`*^9}, {
  3.676198107219685*^9, 3.6761981358147182`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Length", "[", "yourEventTypes", "]"}], "\[Equal]", "4"}]], "Input",\

 CellChangeTimes->{{3.676198141347348*^9, 3.676198184101687*^9}, {
  3.6775868501908913`*^9, 3.67758685159367*^9}}],

Cell["\<\
OPTIONAL: Look into the event type \[OpenCurlyDoubleQuote]\
\[OpenCurlyDoubleQuote] - what kind of events do these relate to, are they \
important for analysing who corresponds with whom?\
\>", "SubitemNumbered",
 CellChangeTimes->{{3.6761981897599792`*^9, 3.676198278806046*^9}}],

Cell["\<\
Use Query to select only those elements where the secondary participant type \
is \[OpenCurlyDoubleQuote]Person\[CloseCurlyDoubleQuote] - store this list of \
assocations against the symbol \[OpenCurlyDoubleQuote]multiPersonEvents\
\[CloseCurlyDoubleQuote]\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676196957681127*^9, 3.676197040625785*^9}, {
  3.676198288200897*^9, 3.6761983413901587`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"multiPersonEvents", "=", 
   RowBox[{
    RowBox[{"Query", "[", 
     RowBox[{"Select", "[", 
      RowBox[{
       RowBox[{
       "#\"Secondary.Participant.Type\"", "\[Equal]", "\"\<Person\>\""}], 
       "&"}], "]"}], "]"}], "@", "lifeevents$Associations"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{3.676261872836747*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summarising the Data", "Section",
 CellChangeTimes->{{3.67619847536856*^9, 3.6761984816475153`*^9}}],

Cell["\<\
Before converting the data into a Graph - it\[CloseCurlyQuote]s useful to \
have a feel for how the data looks.\
\>", "Text",
 CellChangeTimes->{{3.676198547935608*^9, 3.676198570512807*^9}}],

Cell["\<\
Use Tally to calculate the distribution of life events in the \
multiPersonEvents symbol between the different categories of interaction:\
\>", "ItemNumbered",
 CellChangeTimes->{{3.6761985736633043`*^9, 3.676198614659358*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Tally", "[", 
  RowBox[{"multiPersonEvents", "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", "\"\<Category\>\""}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.676198496296348*^9, 3.676198510042404*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"BasicData\"\>", ",", "72"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"SocialContacts\"\>", ",", "338"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Education\"\>", ",", "32"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"EcclesiasticActivity\"\>", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"LearnedActivity\"\>", ",", "11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"ProfessionalActivity\"\>", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"HierarchicalRelationship\"\>", ",", "9"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.676198501498321*^9, 3.676198510504855*^9}, 
   3.676261876114452*^9, 3.676271890658065*^9, 3.6775868654676037`*^9, 
   3.677821301079047*^9, 3.67782289157334*^9}]
}, Open  ]],

Cell["\<\
For the last time this week, I\[CloseCurlyQuote]ll ask you to convert the \
Tally into a BarChart:\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676198620362824*^9, 3.676198634830284*^9}, {
  3.6761987418798027`*^9, 3.676198745284683*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"categoryTally", "=", 
   RowBox[{"Tally", "[", 
    RowBox[{"multiPersonEvents", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "\"\<Category\>\""}], "]"}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"categoryTally", "=", 
   RowBox[{"SortBy", "[", 
    RowBox[{"categoryTally", ",", "Last"}], "]"}]}], ";"}], "\n", 
 RowBox[{"BarChart", "[", 
  RowBox[{
   RowBox[{"categoryTally", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
   RowBox[{"ChartLabels", "\[Rule]", 
    RowBox[{"categoryTally", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "1"}], "]"}], "]"}]}], ",", 
   RowBox[{"BarOrigin", "\[Rule]", "Left"}], ",", 
   RowBox[{"GridLines", "\[Rule]", "Automatic"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.676198638115617*^9, 3.6761987537019978`*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {Opacity[0], PointBox[{0., 0.40424519670631287`}]}, {{}, 
    {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.651], 
     Thickness[Small]}], 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.651], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 0.5425434583714547}, {1., 1.4574565416285452`}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{109.75, 110.93714285714286`}, {
           42.816640377114624`, 62.15994850301434}}],
         StatusArea[#, 1]& ,
         TagBoxNote->"1"],
        StyleBox["1", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[1, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.651], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 1.5425434583714546`}, {6., 2.457456541628545}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{109.75, 114.37285714285714`}, {
           22.220904595506234`, 41.56421272140595}}],
         StatusArea[#, 6]& ,
         TagBoxNote->"6"],
        StyleBox["6", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[6, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.651], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 2.542543458371455}, {9., 3.457456541628545}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{109.75, 116.43428571428572`}, {
           1.6251688138978437`, 20.968476939797554`}}],
         StatusArea[#, 9]& ,
         TagBoxNote->"9"],
        StyleBox["9", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[9, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.651], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 3.542543458371455}, {11., 4.457456541628545}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{109.75, 
           117.80857142857143`}, {-18.970566967710553`, 0.3727411581891573}}],
         
         StatusArea[#, 11]& ,
         TagBoxNote->"11"],
        StyleBox["11", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[11, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.651], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 4.542543458371455}, {32., 5.457456541628545}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{109.75, 
           132.23857142857142`}, {-39.56630274931895, -20.22299462341924}}],
         StatusArea[#, 32]& ,
         TagBoxNote->"32"],
        StyleBox["32", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[32, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.651], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 5.542543458371455}, {72., 6.457456541628545}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{109.75, 
           159.7242857142857}, {-60.16203853092735, -40.81873040502762}}],
         StatusArea[#, 72]& ,
         TagBoxNote->"72"],
        StyleBox["72", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[72, {}], "Tooltip"]& ]}, 
     {RGBColor[0.982864, 0.7431472, 0.3262672], EdgeForm[{Opacity[0.651], 
      Thickness[Small]}], 
      TagBox[
       TooltipBox[
        TagBox[
         DynamicBox[{
           FEPrivate`If[
            CurrentValue["MouseOver"], 
            EdgeForm[{
              GrayLevel[0.5], 
              AbsoluteThickness[1.5], 
              Opacity[0.66]}], {}, {}], 
           
           RectangleBox[{0., 6.542543458371455}, {338., 7.457456541628545}, 
            "RoundingRadius" -> 0]},
          
          ImageSizeCache->{{109.75, 
           342.50428571428574`}, {-80.75777431253574, -61.414466186636034`}}],
         
         StatusArea[#, 338]& ,
         TagBoxNote->"338"],
        StyleBox["338", {}, StripOnInput -> False]],
       Annotation[#, 
        Style[338, {}], "Tooltip"]& ]}}, {}, {}}, {}, {}, 
   StyleBox[
    StyleBox[{
      {Thickness[Tiny], 
       LineBox[{{0., 0.40424519670631287`}, {0., 7.598520768526989}}], 
       StyleBox[{}, "GraphicsLabel",
        StripOnInput->False]}, 
      StyleBox[{
        {Thickness[Tiny], 
         LineBox[{{0., 0.5425434583714547}, 
           Offset[{-6., 0.}, {0., 0.5425434583714547}]}], 
         LineBox[{{0., 7.457456541628544}, 
           Offset[{-6., 0.}, {0., 
            7.457456541628544}]}], {{}, {}, {}, {}, {}, {}, {}, {
           LineBox[{{0., 1.4574565416285452`}, 
             Offset[{-4., 0.}, {0., 1.4574565416285452`}]}], 
           LineBox[{{0., 1.5425434583714546`}, 
             Offset[{-4., 0.}, {0., 1.5425434583714546`}]}], 
           LineBox[{{0., 2.457456541628545}, 
             Offset[{-4., 0.}, {0., 2.457456541628545}]}], 
           LineBox[{{0., 2.5425434583714543`}, 
             Offset[{-4., 0.}, {0., 2.5425434583714543`}]}], 
           LineBox[{{0., 3.4574565416285448`}, 
             Offset[{-4., 0.}, {0., 3.4574565416285448`}]}], 
           LineBox[{{0., 3.5425434583714543`}, 
             Offset[{-4., 0.}, {0., 3.5425434583714543`}]}], 
           LineBox[{{0., 4.457456541628544}, 
             Offset[{-4., 0.}, {0., 4.457456541628544}]}], 
           LineBox[{{0., 4.542543458371454}, 
             Offset[{-4., 0.}, {0., 4.542543458371454}]}], 
           LineBox[{{0., 5.457456541628544}, 
             Offset[{-4., 0.}, {0., 5.457456541628544}]}], 
           LineBox[{{0., 5.542543458371454}, 
             Offset[{-4., 0.}, {0., 5.542543458371454}]}], 
           LineBox[{{0., 6.457456541628544}, 
             Offset[{-4., 0.}, {0., 6.457456541628544}]}], 
           LineBox[{{0., 6.542543458371454}, 
             Offset[{-4., 0.}, {0., 6.542543458371454}]}]}, {}}}, 
        StyleBox[
         {Thickness[Tiny], 
          InsetBox["\<\"EcclesiasticActivity\"\>", 
           Offset[{-1.9999999999999998`, 0.}, {0., 0.9999999999999999}], {1, 0},
            Automatic, {1, 0}], 
          InsetBox["\<\"ProfessionalActivity\"\>", 
           Offset[{-1.9999999999999998`, 0.}, {0., 1.9999999999999996`}], {1, 0},
            Automatic, {1, 0}], 
          InsetBox["\<\"HierarchicalRelationship\"\>", 
           Offset[{-1.9999999999999998`, 0.}, {0., 2.9999999999999996`}], {1, 0},
            Automatic, {1, 0}], 
          InsetBox["\<\"LearnedActivity\"\>", 
           Offset[{-1.9999999999999998`, 0.}, {0., 3.9999999999999996`}], {1, 0},
            Automatic, {1, 0}], 
          InsetBox["\<\"Education\"\>", 
           Offset[{-1.9999999999999998`, 0.}, {0., 4.999999999999999}], {1, 0},
            Automatic, {1, 0}], 
          InsetBox["\<\"BasicData\"\>", 
           Offset[{-1.9999999999999998`, 0.}, {0., 5.999999999999999}], {1, 0},
            Automatic, {1, 0}], 
          InsetBox["\<\"SocialContacts\"\>", 
           Offset[{-1.9999999999999998`, 0.}, {0., 6.999999999999999}], {1, 0},
            Automatic, {1, 0}]}, "GraphicsLabel",
         StripOnInput->False]}, "GraphicsTicks",
       StripOnInput->False]},
     Antialiasing->False], "GraphicsAxes",
    StripOnInput->False]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, False},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.40424519670631287`},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Identity[
       Part[#, 1]], 
      Identity[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Identity[
       Part[#, 1]], 
      Identity[
       Part[#, 2]]}& )},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{{{1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {1., 
       FormBox["\"EcclesiasticActivity\"", TraditionalForm], 0}, {2., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
       FormBox["\"ProfessionalActivity\"", TraditionalForm], 0}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
       FormBox["\"HierarchicalRelationship\"", TraditionalForm], 0}, {4., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
       FormBox["\"LearnedActivity\"", TraditionalForm], 0}, {5., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
       FormBox["\"Education\"", TraditionalForm], 0}, {6., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
       FormBox["\"BasicData\"", TraditionalForm], 0}, {7., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
       FormBox["\"SocialContacts\"", TraditionalForm], 0}}, {{1., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {2., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {3., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {4., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {5., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {6., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}, {7., 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0, 0}, BaselinePosition -> Baseline], 
          "CacheGraphics" -> False], 
         Spacer[0]], TraditionalForm], {0.004, 0}}}}, {Automatic, Automatic}},
  
  GridLines->{Automatic, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{All, All}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.05]}, {
     Scaled[0.02], 
     Scaled[0.02]}},
  Ticks->{Automatic, None}]], "Output",
 CellChangeTimes->{{3.676198666691237*^9, 3.676198754151697*^9}, 
   3.6762618788437567`*^9, 3.6762718935555973`*^9, 3.677586872204857*^9, 
   3.6775869655810966`*^9, 3.677821303519822*^9, 3.677822892959396*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Visualising the Multigraph", "Title",
 CellChangeTimes->{{3.676198470768581*^9, 3.676198472590466*^9}, {
  3.67619879619456*^9, 3.6761987983857603`*^9}, {3.6762618027094793`*^9, 
  3.676261810307352*^9}}],

Cell["\<\
After these exercises you\[CloseCurlyQuote]ll have a multigraph that looks \
like this (hover over vertices)\
\>", "Text",
 CellChangeTimes->{{3.676192667822947*^9, 3.676192669588736*^9}, {
  3.676192707929297*^9, 3.676192722880842*^9}, {3.6761988011138973`*^9, 
  3.676198834634193*^9}, {3.676261814617209*^9, 3.676261819602014*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "MARY", "FLORENCE", "JEAN", "JULIE", "CLAIRE", "LAURA", "DORIS", "JOAN",
        "CHRISTINE", "KAREN", "NICOLA", "DOROTHY", "JOYCE", "JACQUELINE", 
       "EMMA", "KATHLEEN", "JANET", "LISA", "ANNIE", "SHEILA", "ANN", 
       "JOANNE", "ELSIE", "BARBARA", "CAROL", "JANE", "MICHELLE", "VICTORIA", 
       "ALICE", "IRENE", "HELEN", "SAMANTHA", "JUNE", "MAUREEN", "DIANE", 
       "RACHEL", "WINIFRED", "EILEEN", "SHIRLEY", "ANNE", "SHARON", "AMY", 
       "GLADYS", "BETTY", "VALERIE", "AMANDA", "JENNIFER", "ANGELA", "ETHEL", 
       "SANDRA", "LOUISE", "KATIE", "HILDA", "PHYLLIS", "DOREEN", "PAULINE", 
       "LILIAN", "AUDREY", "CLARE", "KELLY", "IVY", "VERA", "BRENDA", 
       "GILLIAN", "NATALIE", "VIOLET", "PAMELA", "SYLVIA", "ELAINE", "ELLEN", 
       "LESLEY", "CATHERINE", "HAYLEY", "LILY", "EDNA", "HANNAH", "NELLIE", 
       "BERYL", "WENDY", "LUCY", "ADA", "DAWN", "DONNA", "BEATRICE", "OLIVE", 
       "CAROLE", "DANIELLE", "MAY", "EVELYN", "ROSE", "MAVIS", "SALLY", 
       "KATHERINE", "IRIS", "JUDITH", "MARIA", "ZOE", "KERRY", "DEBRA", 
       "MELANIE", "STACEY", "GERTRUDE", "MURIEL", "PAULA", "LAUREN", "MARION",
        "JOANNA", "MARINA", "JANICE", "LORRAINE", "JESSIE", "PEGGY", 
       "ROSEMARY", "LYNN", "ANDREA", "FRANCES", "SUZANNE", "GRACE", 
       "JOSEPHINE", "YVONNE", "SOPHIE", "LYNNE", "ANNA", "EVA", "GWENDOLINE", 
       "JESSICA", "NORMA", "BEVERLEY", "KIRSTY", "KIMBERLEY", "HAZEL", 
       "FIONA", "MARIE", "JENNA", "MARILYN", "DAISY", "NORA", "NATASHA", 
       "MINNIE", "FREDA", "MANDY", "RACHAEL", "KATHRYN", "NANCY", "RUTH", 
       "JAYNE", "DIANA", "MARIAN", "ELEANOR", "VERONICA", "SARA", "ALEXANDRA",
        "LOUISA", "JODIE", "DORA", "DAPHNE", "TERESA", "JULIA", "NORAH", 
       "HEATHER", "KIM", "JEMMA", "THELMA", "CARLY", "IDA", "CLARA", "GLORIA",
        "HOLLY", "HILARY", "MELISSA", "MARTHA", "CYNTHIA", "BERTHA", "KATY", 
       "LILLIAN", "CHERYL", "RUBY", "NAOMI", "BESSIE", "GAIL", "MILDRED", 
       "PENELOPE", "CHARLENE", "JADE", "CHRISTINA", "ANNETTE", "JEANETTE", 
       "ESTHER", "CAROLYN", "HARRIET", "ANITA", "GERALDINE", "BRIDGET", 
       "GEORGINA", "LINDSEY", "KAY", "STELLA", "GEMMA", "NICHOLA", "AIMEE", 
       "HEIDI", "MILLICENT", "MONICA", "THERESA", "MARGERY", "MAXINE", 
       "TANYA", "CARLA", "FANNY", "JOY", "LYDIA", "ALMA", "GLENYS", "DEBBIE", 
       "JENNY", "BLANCHE", "VIVIENNE", "TARA", "MIRIAM", "GLYNIS", "CLAIR", 
       "LYNDSEY", "SONIA", "MOLLY", "ELLA", "CHLOE", "SYBIL", "LEAH", "TONI", 
       "WILLIAM", "JOHN", "PAUL", "MARK", "JAMES", "MICHAEL", "STEPHEN", 
       "ANDREW", "DANIEL", "ARTHUR", "ROBERT", "RICHARD", "RONALD", "ANTHONY",
        "MATTHEW", "CHARLES", "FREDERICK", "KENNETH", "ALBERT", "ALAN", "IAN",
        "SIMON", "ERNEST", "ALFRED", "EDWARD", "JOSEPH", "LEE", "ADAM", 
       "ROGER", "HAROLD", "DEREK", "KEITH", "FRANK", "LESLIE", "RAYMOND", 
       "COLIN", "KEVIN", "DARREN", "HENRY", "PHILIP", "GARY", "BENJAMIN", 
       "STANLEY", "STEVEN", "ERIC", "MARTIN", "WALTER", "GRAHAM", "NICHOLAS", 
       "LEONARD", "BARRY", "HERBERT", "GORDON", "NORMAN", "NEIL", "NIGEL", 
       "MALCOLM", "TIMOTHY", "STUART", "GEOFFREY", "ALEXANDER", "CYRIL", 
       "SIDNEY", "FRANCIS", "RYAN", "PERCY", "LUKE", "JACK", "TREVOR", 
       "ADRIAN", "JAMIE", "WILFRED", "PATRICK", "SCOTT", "SAMUEL", "WAYNE", 
       "CECIL", "GARETH", "SEAN", "HORACE", "BERNARD", "FRED", "EDWIN", 
       "GERALD", "SHAUN", "CLIFFORD", "MAURICE", "CLIVE", "BEN", "ANTONY", 
       "VICTOR", "JUSTIN", "JEFFREY", "OLIVER", "EDGAR", "CHRISTIAN", 
       "ASHLEY", "KARL", "AARON", "MARC", "MOHAMMED", "HUGH", "RUSSELL", 
       "GAVIN", "LAWRENCE", "LIAM", "ROBIN", "PHILLIP", "NATHAN", 
       "DENIS"}, {CompressedData["
1:eJxd1Wd0FFUYBuANnVB26aEFsoEsLUDoNbQkJHSCvYtdDNgVsaGiIhHF3hW7
Yu+o2Htv2LD33nvf0WcO6/3xnee8d+58986d2bNF8xfVLmyQSCTW5yUSkVn+
NaqGciM2ZhM2ZTM2Z36OLXJyS7ZiayYDU2zDtmzH9uzAjsG6nVjAzuzCruzG
7kEuZA/2ZFFgOthnMXuxN0uYYZ/AeL/xefdlP/YP9j2ApRwYOChYfzDLgnMY
wqEcxuEcwZE55zsqW6OZ4pggh44N8jiOZ5oZlnMCJ3ISJ3MKk6xgJas4ldXB
OvF+ajgtuD49WzOyNZOzOJtzOJe1THIeN+Gm3IybB+NbcEtuxa25DbcN7ovd
jttzB+7I+cH8nbgzd+Gu3I27cw/uyQXM416s40Iu4t7ch/sywwrux/2Z4gHB
/AN5EA/mYh7CSi7JeT/R2KE8TB0uH8EMj+RSHsWjeQyX8Vj9jpPreDyXM97H
CVwRrFPPEwNXMsWTeHKwjyqu4ik8lafxdJ7BM3kWz2Y6sILnBPlcnpfY+FvM
vX4+L+CFvIireTEv4aW8jJc7q/j9XMEreVXOOUTv8mp5Da/htbyO1/MG3sib
9FnDaLzEe8wwyjfzFuO3yrfx9sA7uJZ38i7ezXW8h/eymDW8j/fzAT7ITDD+
UOK/b+dhPsJHExu/qcjH+DifYJJPsoAVLOVTzHAJn+YzTHMxn+VzfJ4pruNS
vsA6vsiX7C3eb+x6VvPloH/scr7CqqBP/Dzxfl7la575dXmDvEF+I1tvZust
vs13+C7f4/v8gB/yI5YFfhzkT/gpP+Pn/IJf8it+zfygX5i/4Qp+y++Y4vf8
gT/yJ/4cXI/v+4W/Bn1+4+/8g3/yL/7N6I8rMo8N2JCN2JhN2JRpfZrJzZnP
FmzJVmzNJFNZ22SrLaPvKjLNFNu5npHbyx3YkZ1YwM7swq55/+8bG/etCuxm
fncWsofePeWk+asD61kUrLsyWDfterVcEfRZxWLzenFZsM8F8lr2Nl4Snx/7
sC/7sT8HsDToOzDIg+TB2SrL1hAO5TAO5wiO5CiO5hiO5TiOZzkncCILOSnI
kzmFFYx+r2XOv8x7Kc/JleZVcSqrWcO0+dPk6awzPkOeGd9vfFZwfz1nG5/D
uazlvGz9A6CXPuY=
       "], Null}, {VertexLabels -> {
         Placed["Name", Tooltip]}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[0.018544322907928002`], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.5001357454627087`, 6.002609917393925}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.576053100782418, 5.895842978123906}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9482352292499296`, 6.097613755961862}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9151738067450674`, 5.438187776093255}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9567074804668376`, 5.823109470968475}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.4311982915193564`, 5.6103629903875545`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.6547283295530573`, 5.470141876035472}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.3291315986460237`, 5.564923358575424}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.8484477552373964`, 5.23528170334823}, {4.785953480575827, 
         4.792650979773929}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.8219155148254793`, 5.021313091663652}, {4.785953480575827, 
         4.792650979773929}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.795263229149113, 4.806376377871383}, {4.785953480575827, 
         4.792650979773929}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.768730988736946, 4.592407766202326}, {4.785953480575827, 
         4.792650979773929}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.6086243433705767`, 5.696340227043807}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.358444073478961, 5.720908552907942}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.104039957029104, 5.853325291739553}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.8849483735070924`, 4.159726937075257}, {2.4086328226038205`, 
         3.4233982178356124`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.354909712495269, 4.298709770518417}, {2.4086328226038205`, 
         3.4233982178356124`}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.781335379600659, 5.569052803189472}, {3.058154943199654, 
         6.028434144407518}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.1080448269975265`, 5.4944198310299175`}, {3.058154943199654, 
         6.028434144407518}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.911581255082521, 5.666345199323741}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.268654685620686, 5.835784189884132}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.740113935424552, 5.607079548351958}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.067717251909292, 5.577496225407183}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.1901160987714365`, 5.367156079183836}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.520191101496037, 5.362600346886898}, {2.464302487648301, 
         5.810836314891446}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.7753366495508, 5.483274457665864}, {2.464302487648301, 
         5.810836314891446}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.352267967999519, 3.8957326391109772`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.5019330232187524`, 5.409922858738638}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.891070426906905, 5.589514229585345}, {3.2683486202440615`, 
         6.000228186556448}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.208503456735674, 5.445752446748563}, {3.2683486202440615`, 
         6.000228186556448}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.572457321420985, 5.258074074588143}, {2.4965891867976207`, 
         5.591165272469905}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.7553571287751715`, 5.368129687605624}, {2.4965891867976207`, 
         5.591165272469905}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.5446951639929356`, 5.512180391519053}, {2.5973121055785473`, 
         6.06625200222989}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.8838422049841435`, 5.589110100505191}, {2.5973121055785473`, 
         6.06625200222989}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.546530712831092, 5.573524194826402}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.8188699679133604`, 6.085705867024174}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.3210376704601803`, 5.334694823182663}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.782379851104637, 5.965672351271724}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.958144342208718, 5.361913680577685}, {3.254307918443584, 
         5.5496448155168885`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.1273888396334026`, 5.222769624771382}, {3.254307918443584, 
         5.5496448155168885`}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         1.8480168639532184`, 4.371045396255162}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {2.47628317627636,
          5.3971524682153955`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.5930177695946828`, 5.543028999812309}, {2.7028347408065194`, 
         6.093244776759786}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9410422346103724`, 5.5852542667406775`}, {2.7028347408065194`, 
         6.093244776759786}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         1.015069443528973, 3.528774386330581}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.4279764095217113`, 5.3754730579667935`}, {2.3055152107392, 
         5.888803933863012}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.7087640646160263`, 5.548369365598673}, {2.3055152107392, 
         5.888803933863012}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.331821291441601, 5.716887595061483}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.4857107529680147`, 5.738563878031519}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.4013526182698466`, 5.880377038950135}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.354722758719908, 5.3840968980770985`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.2825463330866027`, 3.986538935106582}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.455882475071982, 5.426568464653732}, {2.3862080289961396`, 
         5.96445637275853}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.7615508173227004`, 5.5729263977756505`}, {2.3862080289961396`, 
         5.96445637275853}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.1661911124691793`, 6.017348842219756}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.679605445673041, 5.812763152337811}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         4.240273969422595, 3.294538442130717}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.150490349131523, 5.706038430596417}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.810332911515744, 5.814005780601199}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.220199677819779, 5.776796601251533}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9578274128557434`, 5.954294043242812}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.1861620991869795`, 5.63598141436367}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.188557496372201, 5.486614363414871}}, 0.05570143050888991], 
        ArrowBox[{{2.5001357454627087`, 6.002609917393925}, {
         2.576053100782418, 5.895842978123906}}, 0.05570143050888991], 
        ArrowBox[{{5.241668688810895, 5.4646874707731214`}, {
         4.785953480575827, 4.792650979773929}}, 0.05570143050888991], 
        ArrowBox[{{2.352267967999519, 3.8957326391109772`}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         1.8480168639532184`, 4.371045396255162}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {1.597638796308375, 
         2.822580191656698}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.0523930015783991,
          3.706412131116615}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.2573432638898039,
          3.024065950763953}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.149534950406232, 
         3.104895596389688}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.015069443528973, 3.528774386330581}, {
         0.6307814548672267, 3.2629881993466556`}, {0.16375040268722163`, 
         3.277185090685656}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.015069443528973, 3.528774386330581}, {
         0.5480383913489689, 3.542971277682385}, {0.16375040268722163`, 
         3.277185090685656}}], 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.32390662595910724`, 3.4694697204244216`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         2.2521088624868315`, 2.7009640096630276`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.12229625603424887`, 3.787375236833959}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.10083672655948739`, 3.601472315531462}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0., 
         3.502118652485}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {1.175365870848454, 
         3.080538658374356}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.2612918723690236,
          3.712739580181321}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.3113085352775964,
          3.298363826840268}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.14917822500752154`, 3.4254397730806256`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.049757259634716, 
         3.2075581295494073`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.015069443528973, 3.528774386330581}, {
         0.7323309720428639, 3.2287150893303744`}, {0.32668261120661146`, 
         3.155053482431751}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.015069443528973, 3.528774386330581}, {
         0.6094210826927068, 3.4551127794321226`}, {0.32668261120661146`, 
         3.155053482431751}}], 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.2283345869280864,
          3.57572093998461}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.0020333003880268485`, 3.36159621491312}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {
         1.9310109034488097`, 3.135898153365598}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {2.942715326111345,
          3.3644759808467883`}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {2.969792695888759,
          3.226794349488862}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {1.979892822619038,
          3.311264616838231}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {
         1.9521184939841647`, 2.973042113831754}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {
         2.0648042207302373`, 2.715105008020585}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.739341020106996, 2.9041888634933355`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.8051710924460034`, 2.8407736348909403`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.871319615308519, 2.777051637452472}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.9375780802734237`, 2.713223730970225}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         3.0037266031359064`, 2.6495017335537403`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         3.069556675474905, 2.586086504936254}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.3168289667787323`, 2.6557308467518714`}, {2.4780412190946257`, 
         3.04953873904153}}], 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.582048668260187, 2.636917245603628}, {2.4780412190946257`, 
         3.04953873904153}}], 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.0858918689478205`, 1.3686553831522517`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.158130764593345, 1.687858510106223}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.7872134804660247`, 1.501120672851946}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.8217485775752578`, 1.6835647125534663`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.2997933320975226`, 1.6206871164841348`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.708578448660259, 1.6276896036343267`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.0194579833936253`, 1.769213485184401}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.116707127932865, 1.5251410737698965`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.8676771058475212`, 1.8258680307398885`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.9178189325188169`, 1.391703535041099}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.9785572225889283`, 1.4912482384743169`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.7820472184635174`, 3.011445940856201}, {3.528800617824225, 
         3.4153936059804266`}}], 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.8936735482897027`, 2.6065550216699744`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.2328261514407464`, 1.4084201232941602`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.7321852594693112`, 1.9274867347286038`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.597638796308375, 2.822580191656698}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.9423447173186847`, 1.6152319259806995`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.3763239273976744`, 1.5033353754050143`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.6672865997969786`, 3.267408755140863}, {3.6909004173798046`, 
         3.0661122801603264`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5524144354070515`, 3.214097130898387}, {3.6909004173798046`, 
         3.0661122801603264`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.1675898153049924`, 2.6470570184353863`}, {2.420836415944293, 
         2.2431093533062914`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.0747327486684077`, 3.0938368434498473`}, {2.518440375008683, 
         3.1045688674195313`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.972508244164518, 3.4261256299514575`}, {2.518440375008683, 
         3.1045688674195313`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.344243104211506, 2.906533543959526}, {2.8936735482897027`, 
         2.6065550216699744`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.078231061902422, 3.1154150837058654`}, {2.8936735482897027`, 
         2.6065550216699744`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {2.47854069729822,
          2.8454206567419718`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.2021617590475486`, 3.8687370380391304`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.430511042091697, 4.473728563866835}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.250815849483389, 3.5696337399653917`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.142566988890562, 3.1686275723500845`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.2197151334224667`, 3.09390239538722}, {2.780141837132228, 
         3.0186312033407585`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.08922732153398, 3.340122413972776}, {2.780141837132228, 
         3.0186312033407585`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.093822430629724, 2.906375517885318}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.8310392015705985`, 3.940500392214558}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.9424344226979815`, 4.1837777970750905`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.7982340175534173`, 3.0657070382494767`}, {3.8075104349989717`, 
         2.6243579693144916`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5380770352697803`, 2.97404453705058}, {3.8075104349989717`, 
         2.6243579693144916`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {4.08749027015602,
          3.657082668658042}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.977474783878852, 4.049251013933451}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.695603974218695, 3.101816580844254}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.121059226743537, 3.171509965025869}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         5.089215577985817, 3.727051939623592}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.421474358397713, 2.190761571584863}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.751995213885709, 3.352265727245333}, {3.894149394496038, 
         3.1689813972080367`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.6709547984345567`, 3.2321092757899734`}, {3.894149394496038, 
         3.1689813972080367`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {3.70864795419601,
          2.615078784679503}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {4.10375792406919,
          3.464526110277083}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.829893270060526, 2.825695921522285}, {1.9173987331348583`, 
         2.7659584969191062`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5143437045371493`, 2.631688889708302}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.8937742888023044`, 3.511704774846602}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.480532646954007, 3.898639297232747}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.271285278493838, 3.080504665143418}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5936973336907365`, 4.134567590393875}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.383769973042954, 3.1431328987805087`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {3.66708201965197,
          3.919179018307792}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.7999915408060856`, 4.0944452232614905`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.135393023043709, 4.073502578805177}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.280637293984499, 3.4155044991217074`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.9939189361277716`, 3.3272009351431175`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.405503519385941, 3.270043524053674}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.070678820145944, 3.9323075706675006`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.239001584183471, 3.956164829537265}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {4.42975593123907,
          3.530715126116566}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5308128083228962`, 3.684012744192402}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.620491637143561, 2.635471976196063}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.727779462485876, 4.205311459421361}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.164943754401822, 3.796129407611249}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.2435476242779595`, 3.6993666739913427`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.3237636738212215`, 3.7328502920809923`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.401750579498126, 3.6513262470434413`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.9698408995471217`, 3.8055730640819547`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.448791131927424, 4.090933904285507}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.8550673799758357`, 2.9392153854630445`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.942715326111345, 3.3644759808467883`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.312071324715001, 3.8538501104467087`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.2407252861086775`, 2.959539268956114}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.7884955443447814`, 3.699892149571761}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {4.45271978013659,
          3.3929475838811536`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.011991317923822, 3.036747773860446}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.969792695888759, 3.226794349488862}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.303747585734906, 4.009134785783969}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.8312252633985353`, 5.035038489761629}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.02250839855121, 4.085384376734948}, {2.4086328226038205`, 
         3.4233982178356124`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.7049547520858848`, 3.7269685037551326`}, {2.4086328226038205`, 
         3.4233982178356124`}}], 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.1186903288310046`, 3.9098682059113075`}, {2.4780412190946257`, 
         3.04953873904153}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.6781812182968945`, 3.5286251957755383`}, {2.4780412190946257`, 
         3.04953873904153}}], 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         3.528800617824225, 3.4153936059804266`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.40785500153673926`, 4.976406801699863}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.9721685574452104, 4.878482660544747}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.3348605704734469`, 4.957690588079347}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8356128503657425, 4.7757653239935305`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.3115427379293525, 4.389448564296204}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.34047356613598767`, 4.867129181171479}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6915615283338803, 5.016260087063726}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.5955992707905655, 5.196042024112448}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.0459508566039295`, 4.433212273658721}, {0.8526101898675127, 
         4.630801060380589}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.065785259520211, 4.471448104883598}, {0.8526101898675127, 
         4.630801060380589}}], 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8526101898675127, 4.630801060380589}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.1056552583805983`, 4.548307618050227}, {0.8526101898675127, 
         4.630801060380589}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.125489661296848, 4.58654344936516}, {0.8526101898675127, 
         4.630801060380589}}], 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.7973218127784216, 5.309327189878359}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.4761450601789994, 4.616543958931642}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6456923969659738, 4.297023158634975}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.5121956560123038, 4.912632616901693}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.1335695410431113`, 5.308978399644691}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.0882241249858984`, 4.718258641356753}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.5751836336992446, 5.05690184501653}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.469824124602396, 5.104041355271252}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8111154356254753, 4.307441482229554}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.9639135195187563, 5.351582525329796}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.5245821466388976, 4.1755742699901655`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.1570296631032222`, 4.93157558571205}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.28107756110461724`, 4.53044812328401}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.4743370203504087, 4.770891969196664}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.2700113959364694`, 5.216234865895061}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.42525919744296914`, 4.487389538446732}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.122124740619637, 5.126947335427426}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6549332117216733, 4.5921800581849155`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8205650367556543, 4.937147459315856}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.7146891851664909, 4.132475827523839}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.34263158638482816`, 4.636992912800938}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.3969266456918503`, 3.1981103616770197`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.3075950641940195, 4.746511591063642}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {2.47854069729822,
          2.8454206567419718`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6547419541326955, 4.863807700351988}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.49381208403271515`, 4.375955918345492}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8840158256227015, 5.228855102061041}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.4153070868230553, 4.270270166834985}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.7045673804419805, 5.219838233621284}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8761205997475692, 4.462482997072011}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6299052385371002, 4.714382051200481}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.2630543941416832`, 5.08193444559997}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8072815412905161, 5.104601698173099}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6318581063100894, 4.462220058202436}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.9556190288915065, 5.060575878942867}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.4880864554634101`, 3.5849160660106336`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.0179552862225605`, 5.218444329525832}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.3911945670759331`, 3.5449209449397725`}}, 0.05570143050888991], 
        ArrowBox[{{4.430511042091697, 4.473728563866835}, {4.981213223955975, 
         5.0445610970507975`}}, 0.05570143050888991], 
        ArrowBox[{{4.430511042091697, 4.473728563866835}, {4.867566821905859, 
         5.1563861762750385`}}, 0.05570143050888991], 
        ArrowBox[{{2.780141837132228, 3.0186312033407585`}, {
         3.142566988890562, 3.1686275723500845`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.0549058989339706`, 3.175457258094726}, {2.4086328226038205`, 
         3.4233982178356124`}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.271125656804717, 3.01389945667147}, {2.4086328226038205`, 
         3.4233982178356124`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.5735998825420134`, 3.2483991040245725`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.7318601302304497`, 2.7647254080153565`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.352267967999519, 3.8957326391109772`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.2825463330866027`, 3.986538935106582}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.6163060808985588`, 3.3556561813862746`}, {3.528800617824225, 
         3.4153936059804266`}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.8936735482897027`, 2.6065550216699744`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.7321852594693112`, 1.9274867347286038`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.47854069729822, 2.8454206567419718`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.4880864554634101`, 3.5849160660106336`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.5262034831252875`, 3.0689103146972503`}, {1.3911945670759331`, 
         3.5449209449397725`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.7823898170855064`, 3.2419691271574425`}, {1.3911945670759331`, 
         3.5449209449397725`}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.780141837132228, 3.0186312033407585`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.695603974218695, 3.101816580844254}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.4946525051929707`, 2.8012281393391385`}, {1.175365870848454, 
         3.080538658374356}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.5981120987903408`, 3.045269015956232}, {1.175365870848454, 
         3.080538658374356}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.0774078703579866`, 2.762021135226445}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.5671950887519348`, 2.2865173398017777`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.1777948334100428`, 2.6217420157641214`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.3803050652017146`, 2.477758651764651}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.109385498151434, 2.4917851013821215`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.1688366839844044`, 2.8533041468787195`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.3442796757106674`, 2.620655965758532}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.0093171896476711`, 2.342119382412407}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.654812508403634, 2.1482345319902834`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.136379271804913, 2.10179967534156}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.398893722561458, 2.337537030955006}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.0445336068141367`, 2.2145012697976156`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.5178886194675658`, 2.070324688298257}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.392985116128974, 2.0172300490268786`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.2701560228774893`, 2.170868016397018}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.3975982075832798`, 2.18479886837523}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.0010160736343976`, 2.6224015147170086`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.2584534476124616`, 2.0186966525050893`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         0.9660759676933837, 2.472803415911055}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.307329914043703, 2.8190553153022355`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.2203116837267625`, 2.403725156264022}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.0648042207302373`, 2.715105008020585}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.1743389460149922`, 2.274227348673222}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.487818504542941, 4.123825419169118}, {4.785953480575827, 
         4.792650979773929}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.7477955876911, 4.670987906612375}, {4.785953480575827, 
         4.792650979773929}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.043013106420663, 3.1212124988415524`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         4.794708784875165, 4.128115862303972}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.461329494020754, 3.285037203814879}, {4.240273969422595, 
         3.294538442130717}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.403295561100528, 3.46623429946399}, {4.240273969422595, 
         3.294538442130717}}], 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {4.240273969422595, 
         3.294538442130717}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.286639019980282, 3.8304664886949586`}, {4.240273969422595, 
         3.294538442130717}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.228605087060059, 4.011663584345868}, {4.240273969422595, 
         3.294538442130717}}], 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {5.089215577985817, 
         3.727051939623592}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.07605019362437, 
         4.7921768996926755`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.108569302428034, 
         4.289256406799745}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.162718825972419, 
         4.485721789141594}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.217602994975898, 
         3.9554024603260465`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.069766489239364, 
         3.4849957919804195`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.839643628137155, 
         4.449570510691226}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.339445919688016, 
         4.06213114401514}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.930031394773706, 
         3.334106453459885}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.29515948689261, 
         3.6711682743193585`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.384969987960359, 
         4.4221485605780035`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.497997598777275, 
         4.020280573460792}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.157390138415499, 
         4.132924398807478}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.202438494892904, 
         3.420668394795633}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.722960004274572, 
         4.310322961527341}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.920383828516393, 
         4.5673503536250575`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.348361489395701, 
         3.913040092783218}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.724336630874012, 
         3.5382502837181464`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.04286578353353, 
         3.992902738035645}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.313344466056199, 
         3.511235759908192}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.246250065585384, 
         3.7936881591370293`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.49221300887856, 
         4.6428349632936685`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         6.676181246622793, 4.0265111802172}, {6.872934999963933, 
         3.9116529007241962`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         6.646414364999324, 3.8873040670134915`}, {6.872934999963933, 
         3.9116529007241962`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         6.653721168647265, 4.301962224361364}, {6.99589646107202, 
         4.4221152403054855`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         6.79183590408297, 4.122315361915772}, {6.99589646107202, 
         4.4221152403054855`}}], 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.030576710727809, 
         3.6677971129569764`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.402875651459135, 
         4.206617655166467}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         7.5092294802897115`, 4.155850833215487}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.826626790601779, 
         4.124531057816174}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.182830794179319, 
         4.711163026407839}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.909356644316942, 
         3.531218243022184}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.940971265755323, 
         4.7371375157582545`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.051834577147967, 
         4.623993472853848}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.979285916089861, 
         4.202026505373777}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.765187881582182, 
         4.849704246674317}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         7.1647163047764835`, 3.6052812946290684`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.256449545263353, 
         4.602101352336273}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.450823132744214, 
         4.3296976212458285`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         6.7332729528748025`, 4.739823640833926}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.073475795754592, 
         3.3446634144767353`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.243126257987642, 
         4.3742895738521925`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         6.5865952470127995`, 4.480947617956097}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.813630168216543, 
         3.719486279249364}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.082709938405188, 
         3.811335885439358}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         6.7900103730083154`, 3.3864915489480705`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.726461226363466, 
         4.580391401353141}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.271976368383317, 
         4.217171575296142}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.417303205744281, 
         3.641247907462545}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.889499163828672, 
         4.854877707567038}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.436827334648331, 
         3.776543704867336}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.36669655127135, 
         4.539807801375816}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.487593683926255, 
         3.8913864754248957`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.568781576929737, 
         4.791634583666779}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.282482328252882, 2.6005783515765297`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.4170792677831248`, 2.6217310114520327`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.5522851918905665`, 2.6429793766507057`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.6868821314208198`, 2.664132036547722}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.8599702749246174`, 2.3521203348251003`}, {2.4780412190946257`, 
         3.04953873904153}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.199374124206088, 2.7149627772180787`}, {2.4780412190946257`, 
         3.04953873904153}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.1406310129966992`, 2.198975366915549}, {2.8936735482897027`, 
         2.6065550216699744`}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.8936735482897027`, 2.6065550216699744`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.3343457153291007`, 2.4251240277550856`}, {2.8936735482897027`, 
         2.6065550216699744`}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.7321852594693112`, 1.9274867347286038`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.79498175958685, 2.4130676050820368`}, {2.3969266456918503`, 
         3.1981103616770197`}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.3969266456918503`, 3.1981103616770197`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.183248066141095, 2.8025871295897247`}, {2.3969266456918503`, 
         3.1981103616770197`}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8075104349989717`, 2.6243579693144916`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.421474358397713, 2.190761571584863}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {3.70864795419601,
          2.615078784679503}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.5143437045371493`, 2.631688889708302}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.4992849318150934`, 2.332952353797486}, {3.620491637143561, 
         2.635471976196063}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.620491637143561, 2.635471976196063}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.70250988536456, 2.320063995422512}, {3.620491637143561, 
         2.635471976196063}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.2521088624868315`, 2.7009640096630276`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.086947054882777, 1.519870605989537}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {4.18209667336294,
          1.4140793613221037`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.925138690548266, 1.4347354403711694`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8679255336938736`, 1.2632213976747777`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.979849145266797, 1.6416616732844578`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {4.46363350817925,
          1.8072214144657355`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.349911798840048, 1.7078513085738685`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.471555947280286, 1.068618203063001}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.295671362053043, 1.5656152959568475`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.026224270844277, 1.194980682649728}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.9434906982274556`, 1.9432700046139215`}, {4.19088866799243, 
         1.6685142500137031`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8287011498010797`, 1.7427886183891481`}, {4.19088866799243, 
         1.6685142500137031`}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8432883078061626`, 1.6652882090850187`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.274060087359451, 1.3715767941168013`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.7164694653507095`, 1.2254168366564895`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.025537181086292, 1.3306997299521077`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.437201726066682, 1.4788486729610324`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.272361280221109, 1.8734433678623728`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.5869571021565627`, 1.5841419622038597`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.403274340812292, 1.4813956224851554`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.124709468232238, 1.8263122936120195`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.6289533279741266`, 1.2779280947152851`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.455341129301084, 1.628651384177883}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.4177692935803883`, 1.2962703706061052`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.6759923074530665`, 1.446008295597642}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.310076412808286, 1.3736411898265515`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8058864883790147`, 1.1742553557001956`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.377534460488725, 1.9508173489446283`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.5908997950331663`, 1.1746006289113988`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8167824403242876`, 1.41118222984997}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.184505427359471, 1.2669661240102115`}}, 0.05570143050888991], 
        ArrowBox[{{4.471555947280286, 1.068618203063001}, {5.047638369107941, 
         0.4111912972831533}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.133147154561208, 2.1482538366307278`}, {3.6909004173798046`, 
         3.0661122801603264`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.786832454129947, 1.9963693816692503`}, {3.6909004173798046`, 
         3.0661122801603264`}}], 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         4.240273969422595, 3.294538442130717}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.7321852594693112`, 1.9274867347286038`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.47854069729822, 2.8454206567419718`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.421474358397713, 2.190761571584863}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.2033776710043345`, 1.2324405583106968`}, {3.274060087359451, 
         1.3715767941168013`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.299761607666473, 1.2176471740010286`}, {3.274060087359451, 
         1.3715767941168013`}}], 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.529183377782783, 0.3459540572094859}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.855260453944898, 0.3303523773370447}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.632165776231189, 0.11103641985856338`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.623085392018389, 0.24813975997412197`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.691707167723954, 0.5505356231454419}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.189233266615462, 0.25849377658537387`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.0191831405526632`, 0.4113205932000388}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3710776248337075`, 0.2999523784538045}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.167773717230054, 0.4385212239551035}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.7716537203514955`, 0.4302322473870501}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3108059160742314`, 0.15061590799352498`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.967013800042194, 0.17293923908540476`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.834010241282577, 1.990508425310403}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.8663225857892227`, 0.3162379741460035}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.033793051399473, 0.27333934580722286`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.1533319156711497`, 0.12824719894068837`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.901323876584327, 0.46408514083271557`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.5778245924135943`, 0.4688222282786785}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.5170786709362716`, 0.04384570570227053}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.733477488615379, 0.3594720657048902}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.764343642195909, 0.2002421538590511}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3889215317152495`, 0.03714367247629635}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.852030977769403, 0.09540886872204357}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.8913260505315477`, 0.5169506416851912}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.2711795821890868`, 0.}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.4757292291894126`, 0.17919497776812854`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.131451414038333, 0.017911701145744807`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.62996839398561, 0.3358079206113249}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.760508776801317, 0.5082595388835616}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.57736217973407, 0.4804479081603814}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3532423647517455`, 0.4616839528821379}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.81669742895982, 0.2197850566076167}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.687649817279081, 0.20397739499959755`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.9942706618603867`, 0.04006566250262589}}, 0.05570143050888991], 
        ArrowBox[{{2.834010241282577, 1.990508425310403}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991]}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8312252633985353`, 5.035038489761629}, 
           0.05570143050888991],
          "\"MARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.5001357454627087`, 6.002609917393925}, 
           0.05570143050888991],
          "\"FLORENCE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FLORENCE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.576053100782418, 5.895842978123906}, 0.05570143050888991],
          "\"JEAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9482352292499296`, 6.097613755961862}, 
           0.05570143050888991],
          "\"JULIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JULIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9151738067450674`, 5.438187776093255}, 
           0.05570143050888991],
          "\"CLAIRE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLAIRE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9567074804668376`, 5.823109470968475}, 
           0.05570143050888991],
          "\"LAURA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LAURA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4311982915193564`, 5.6103629903875545`}, 
           0.05570143050888991],
          "\"DORIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DORIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.6547283295530573`, 5.470141876035472}, 
           0.05570143050888991],
          "\"JOAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3291315986460237`, 5.564923358575424}, 
           0.05570143050888991],
          "\"CHRISTINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHRISTINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.785953480575827, 4.792650979773929}, 0.05570143050888991],
          "\"KAREN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KAREN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.241668688810895, 5.4646874707731214`}, 
           0.05570143050888991],
          "\"NICOLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NICOLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.6086243433705767`, 5.696340227043807}, 
           0.05570143050888991],
          "\"DOROTHY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DOROTHY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.358444073478961, 5.720908552907942}, 0.05570143050888991],
          "\"JOYCE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOYCE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.104039957029104, 5.853325291739553}, 0.05570143050888991],
          "\"JACQUELINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JACQUELINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.4086328226038205`, 3.4233982178356124`}, 
           0.05570143050888991],
          "\"EMMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EMMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3880612796376046`, 3.247166015126839}, 
           0.05570143050888991],
          "\"KATHLEEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATHLEEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.058154943199654, 6.028434144407518}, 0.05570143050888991],
          "\"JANET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JANET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.911581255082521, 5.666345199323741}, 0.05570143050888991],
          "\"LISA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LISA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.268654685620686, 5.835784189884132}, 0.05570143050888991],
          "\"ANNIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.740113935424552, 5.607079548351958}, 0.05570143050888991],
          "\"SHEILA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHEILA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.067717251909292, 5.577496225407183}, 0.05570143050888991],
          "\"ANN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1901160987714365`, 5.367156079183836}, 
           0.05570143050888991],
          "\"JOANNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOANNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.464302487648301, 5.810836314891446}, 0.05570143050888991],
          "\"ELSIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELSIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.352267967999519, 3.8957326391109772`}, 
           0.05570143050888991],
          "\"BARBARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BARBARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5019330232187524`, 5.409922858738638}, 
           0.05570143050888991],
          "\"CAROL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CAROL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2683486202440615`, 6.000228186556448}, 
           0.05570143050888991],
          "\"JANE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JANE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.4965891867976207`, 5.591165272469905}, 
           0.05570143050888991],
          "\"MICHELLE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MICHELLE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.5973121055785473`, 6.06625200222989}, 
           0.05570143050888991],
          "\"VICTORIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VICTORIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.546530712831092, 5.573524194826402}, 0.05570143050888991],
          "\"ALICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8188699679133604`, 6.085705867024174}, 
           0.05570143050888991],
          "\"IRENE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IRENE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3210376704601803`, 5.334694823182663}, 
           0.05570143050888991],
          "\"HELEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HELEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.782379851104637, 5.965672351271724}, 0.05570143050888991],
          "\"SAMANTHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SAMANTHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.254307918443584, 5.5496448155168885`}, 
           0.05570143050888991],
          "\"JUNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JUNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6909004173798046`, 3.0661122801603264`}, 
           0.05570143050888991],
          "\"MAUREEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAUREEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8480168639532184`, 4.371045396255162}, 
           0.05570143050888991],
          "\"DIANE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DIANE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.47628317627636, 5.3971524682153955`}, 
           0.05570143050888991],
          "\"RACHEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RACHEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.7028347408065194`, 6.093244776759786}, 
           0.05570143050888991],
          "\"WINIFRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WINIFRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.015069443528973, 3.528774386330581}, 0.05570143050888991],
          "\"EILEEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EILEEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.4780412190946257`, 3.04953873904153}, 
           0.05570143050888991],
          "\"SHIRLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHIRLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3055152107392, 5.888803933863012}, 0.05570143050888991],
          "\"ANNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.331821291441601, 5.716887595061483}, 0.05570143050888991],
          "\"SHARON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHARON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4857107529680147`, 5.738563878031519}, 
           0.05570143050888991],
          "\"AMY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AMY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4013526182698466`, 5.880377038950135}, 
           0.05570143050888991],
          "\"GLADYS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLADYS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.354722758719908, 5.3840968980770985`}, 
           0.05570143050888991],
          "\"BETTY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BETTY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2825463330866027`, 3.986538935106582}, 
           0.05570143050888991],
          "\"VALERIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VALERIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3862080289961396`, 5.96445637275853}, 
           0.05570143050888991],
          "\"AMANDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AMANDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1661911124691793`, 6.017348842219756}, 
           0.05570143050888991],
          "\"JENNIFER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JENNIFER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.679605445673041, 5.812763152337811}, 0.05570143050888991],
          "\"ANGELA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANGELA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.240273969422595, 3.294538442130717}, 0.05570143050888991],
          "\"ETHEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ETHEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.150490349131523, 5.706038430596417}, 0.05570143050888991],
          "\"SANDRA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SANDRA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.810332911515744, 5.814005780601199}, 0.05570143050888991],
          "\"LOUISE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LOUISE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.220199677819779, 5.776796601251533}, 0.05570143050888991],
          "\"KATIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9578274128557434`, 5.954294043242812}, 
           0.05570143050888991],
          "\"HILDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HILDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.1861620991869795`, 5.63598141436367}, 
           0.05570143050888991],
          "\"PHYLLIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PHYLLIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.188557496372201, 5.486614363414871}, 0.05570143050888991],
          "\"DOREEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DOREEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.420836415944293, 2.2431093533062914`}, 
           0.05570143050888991],
          "\"PAULINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAULINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.0858918689478205`, 1.3686553831522517`}, 
           0.05570143050888991],
          "\"LILIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LILIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.158130764593345, 1.687858510106223}, 0.05570143050888991],
          "\"AUDREY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AUDREY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.7872134804660247`, 1.501120672851946}, 
           0.05570143050888991],
          "\"CLARE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLARE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8217485775752578`, 1.6835647125534663`}, 
           0.05570143050888991],
          "\"KELLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KELLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2997933320975226`, 1.6206871164841348`}, 
           0.05570143050888991],
          "\"IVY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IVY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.708578448660259, 1.6276896036343267`}, 
           0.05570143050888991],
          "\"VERA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VERA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.0194579833936253`, 1.769213485184401}, 
           0.05570143050888991],
          "\"BRENDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BRENDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.116707127932865, 1.5251410737698965`}, 
           0.05570143050888991],
          "\"GILLIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GILLIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8676771058475212`, 1.8258680307398885`}, 
           0.05570143050888991],
          "\"NATALIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NATALIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9178189325188169`, 1.391703535041099}, 
           0.05570143050888991],
          "\"VIOLET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VIOLET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9785572225889283`, 1.4912482384743169`}, 
           0.05570143050888991],
          "\"PAMELA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAMELA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.518440375008683, 3.1045688674195313`}, 
           0.05570143050888991],
          "\"SYLVIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SYLVIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.528800617824225, 3.4153936059804266`}, 
           0.05570143050888991],
          "\"ELAINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELAINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8936735482897027`, 2.6065550216699744`}, 
           0.05570143050888991],
          "\"ELLEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELLEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2328261514407464`, 1.4084201232941602`}, 
           0.05570143050888991],
          "\"LESLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LESLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.7321852594693112`, 1.9274867347286038`}, 
           0.05570143050888991],
          "\"CATHERINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CATHERINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.597638796308375, 2.822580191656698}, 0.05570143050888991],
          "\"HAYLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HAYLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9423447173186847`, 1.6152319259806995`}, 
           0.05570143050888991],
          "\"LILY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LILY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3763239273976744`, 1.5033353754050143`}, 
           0.05570143050888991],
          "\"EDNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3188303280332685`, 4.388954662649468}, 
           0.05570143050888991],
          "\"HANNAH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HANNAH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.40785500153673926`, 4.976406801699863}, 
           0.05570143050888991],
          "\"NELLIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NELLIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9721685574452104, 4.878482660544747}, 
           0.05570143050888991],
          "\"BERYL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BERYL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3348605704734469`, 4.957690588079347}, 
           0.05570143050888991],
          "\"WENDY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WENDY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8356128503657425, 4.7757653239935305`}, 
           0.05570143050888991],
          "\"LUCY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LUCY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.3115427379293525, 4.389448564296204}, 
           0.05570143050888991],
          "\"ADA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ADA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.34047356613598767`, 4.867129181171479}, 
           0.05570143050888991],
          "\"DAWN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DAWN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6915615283338803, 5.016260087063726}, 
           0.05570143050888991],
          "\"DONNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DONNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5955992707905655, 5.196042024112448}, 
           0.05570143050888991],
          "\"BEATRICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BEATRICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8526101898675127, 4.630801060380589}, 
           0.05570143050888991],
          "\"OLIVE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "OLIVE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.7973218127784216, 5.309327189878359}, 
           0.05570143050888991],
          "\"CAROLE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CAROLE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.4761450601789994, 4.616543958931642}, 
           0.05570143050888991],
          "\"DANIELLE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DANIELLE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6456923969659738, 4.297023158634975}, 
           0.05570143050888991],
          "\"MAY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5121956560123038, 4.912632616901693}, 
           0.05570143050888991],
          "\"EVELYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EVELYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1335695410431113`, 5.308978399644691}, 
           0.05570143050888991],
          "\"ROSE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROSE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0882241249858984`, 4.718258641356753}, 
           0.05570143050888991],
          "\"MAVIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAVIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5751836336992446, 5.05690184501653}, 0.05570143050888991],
          "\"SALLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SALLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.469824124602396, 5.104041355271252}, 0.05570143050888991],
          "\"KATHERINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATHERINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8111154356254753, 4.307441482229554}, 
           0.05570143050888991],
          "\"IRIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IRIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9639135195187563, 5.351582525329796}, 
           0.05570143050888991],
          "\"JUDITH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JUDITH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5245821466388976, 4.1755742699901655`}, 
           0.05570143050888991],
          "\"MARIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1570296631032222`, 4.93157558571205}, 
           0.05570143050888991],
          "\"ZOE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ZOE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.28107756110461724`, 4.53044812328401}, 
           0.05570143050888991],
          "\"KERRY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KERRY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.4743370203504087, 4.770891969196664}, 
           0.05570143050888991],
          "\"DEBRA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DEBRA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2700113959364694`, 5.216234865895061}, 
           0.05570143050888991],
          "\"MELANIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MELANIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.42525919744296914`, 4.487389538446732}, 
           0.05570143050888991],
          "\"STACEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STACEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.122124740619637, 5.126947335427426}, 0.05570143050888991],
          "\"GERTRUDE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GERTRUDE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6549332117216733, 4.5921800581849155`}, 
           0.05570143050888991],
          "\"MURIEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MURIEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8205650367556543, 4.937147459315856}, 
           0.05570143050888991],
          "\"PAULA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAULA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.7146891851664909, 4.132475827523839}, 
           0.05570143050888991],
          "\"LAUREN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LAUREN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.34263158638482816`, 4.636992912800938}, 
           0.05570143050888991],
          "\"MARION\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARION", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3969266456918503`, 3.1981103616770197`}, 
           0.05570143050888991],
          "\"JOANNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOANNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.3075950641940195, 4.746511591063642}, 
           0.05570143050888991],
          "\"MARINA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARINA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.47854069729822, 2.8454206567419718`}, 
           0.05570143050888991],
          "\"JANICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JANICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6547419541326955, 4.863807700351988}, 
           0.05570143050888991],
          "\"LORRAINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LORRAINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.49381208403271515`, 4.375955918345492}, 
           0.05570143050888991],
          "\"JESSIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JESSIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8840158256227015, 5.228855102061041}, 
           0.05570143050888991],
          "\"PEGGY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PEGGY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.4153070868230553, 4.270270166834985}, 
           0.05570143050888991],
          "\"ROSEMARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROSEMARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.7045673804419805, 5.219838233621284}, 
           0.05570143050888991],
          "\"LYNN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYNN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8761205997475692, 4.462482997072011}, 
           0.05570143050888991],
          "\"ANDREA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANDREA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6299052385371002, 4.714382051200481}, 
           0.05570143050888991],
          "\"FRANCES\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRANCES", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2630543941416832`, 5.08193444559997}, 
           0.05570143050888991],
          "\"SUZANNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SUZANNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8072815412905161, 5.104601698173099}, 
           0.05570143050888991],
          "\"GRACE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GRACE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6318581063100894, 4.462220058202436}, 
           0.05570143050888991],
          "\"JOSEPHINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOSEPHINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9556190288915065, 5.060575878942867}, 
           0.05570143050888991],
          "\"YVONNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "YVONNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.4880864554634101`, 3.5849160660106336`}, 
           0.05570143050888991],
          "\"SOPHIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SOPHIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0179552862225605`, 5.218444329525832}, 
           0.05570143050888991],
          "\"LYNNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYNNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3911945670759331`, 3.5449209449397725`}, 
           0.05570143050888991],
          "\"ANNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2021617590475486`, 3.8687370380391304`}, 
           0.05570143050888991],
          "\"EVA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EVA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.430511042091697, 4.473728563866835}, 0.05570143050888991],
          "\"GWENDOLINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GWENDOLINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.981213223955975, 5.0445610970507975`}, 
           0.05570143050888991],
          "\"JESSICA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JESSICA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.250815849483389, 3.5696337399653917`}, 
           0.05570143050888991],
          "\"NORMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.142566988890562, 3.1686275723500845`}, 
           0.05570143050888991],
          "\"BEVERLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BEVERLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.780141837132228, 3.0186312033407585`}, 
           0.05570143050888991],
          "\"KIRSTY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIRSTY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.093822430629724, 2.906375517885318}, 0.05570143050888991],
          "\"KIMBERLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIMBERLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8310392015705985`, 3.940500392214558}, 
           0.05570143050888991],
          "\"HAZEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HAZEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.9424344226979815`, 4.1837777970750905`}, 
           0.05570143050888991],
          "\"FIONA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FIONA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8075104349989717`, 2.6243579693144916`}, 
           0.05570143050888991],
          "\"MARIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.08749027015602, 3.657082668658042}, 0.05570143050888991],
          
          "\"JENNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JENNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.867566821905859, 5.1563861762750385`}, 
           0.05570143050888991],
          "\"MARILYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARILYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.977474783878852, 4.049251013933451}, 0.05570143050888991],
          "\"DAISY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DAISY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.695603974218695, 3.101816580844254}, 0.05570143050888991],
          "\"NORA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.121059226743537, 3.171509965025869}, 0.05570143050888991],
          "\"NATASHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NATASHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.089215577985817, 3.727051939623592}, 0.05570143050888991],
          "\"MINNIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MINNIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.421474358397713, 2.190761571584863}, 0.05570143050888991],
          "\"FREDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FREDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.894149394496038, 3.1689813972080367`}, 
           0.05570143050888991],
          "\"MANDY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MANDY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.70864795419601, 2.615078784679503}, 0.05570143050888991],
          
          "\"RACHAEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RACHAEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.10375792406919, 3.464526110277083}, 0.05570143050888991],
          
          "\"KATHRYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATHRYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9173987331348583`, 2.7659584969191062`}, 
           0.05570143050888991],
          "\"NANCY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NANCY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5143437045371493`, 2.631688889708302}, 
           0.05570143050888991],
          "\"RUTH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RUTH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8937742888023044`, 3.511704774846602}, 
           0.05570143050888991],
          "\"JAYNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JAYNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.480532646954007, 3.898639297232747}, 0.05570143050888991],
          "\"DIANA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DIANA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.271285278493838, 3.080504665143418}, 0.05570143050888991],
          "\"MARIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5936973336907365`, 4.134567590393875}, 
           0.05570143050888991],
          "\"ELEANOR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELEANOR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.383769973042954, 3.1431328987805087`}, 
           0.05570143050888991],
          "\"VERONICA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VERONICA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.66708201965197, 3.919179018307792}, 0.05570143050888991],
          
          "\"SARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.7999915408060856`, 4.0944452232614905`}, 
           0.05570143050888991],
          "\"ALEXANDRA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALEXANDRA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.135393023043709, 4.073502578805177}, 0.05570143050888991],
          "\"LOUISA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LOUISA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.280637293984499, 3.4155044991217074`}, 
           0.05570143050888991],
          "\"JODIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JODIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.9939189361277716`, 3.3272009351431175`}, 
           0.05570143050888991],
          "\"DORA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DORA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.405503519385941, 3.270043524053674}, 0.05570143050888991],
          "\"DAPHNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DAPHNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.070678820145944, 3.9323075706675006`}, 
           0.05570143050888991],
          "\"TERESA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TERESA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.239001584183471, 3.956164829537265}, 0.05570143050888991],
          "\"JULIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JULIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.42975593123907, 3.530715126116566}, 0.05570143050888991],
          
          "\"NORAH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORAH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5308128083228962`, 3.684012744192402}, 
           0.05570143050888991],
          "\"HEATHER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HEATHER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.620491637143561, 2.635471976196063}, 0.05570143050888991],
          "\"KIM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.727779462485876, 4.205311459421361}, 0.05570143050888991],
          "\"JEMMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEMMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.164943754401822, 3.796129407611249}, 0.05570143050888991],
          "\"THELMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "THELMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2435476242779595`, 3.6993666739913427`}, 
           0.05570143050888991],
          "\"CARLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CARLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.3237636738212215`, 3.7328502920809923`}, 
           0.05570143050888991],
          "\"IDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.401750579498126, 3.6513262470434413`}, 
           0.05570143050888991],
          "\"CLARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.9698408995471217`, 3.8055730640819547`}, 
           0.05570143050888991],
          "\"GLORIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLORIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.448791131927424, 4.090933904285507}, 0.05570143050888991],
          "\"HOLLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HOLLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8550673799758357`, 2.9392153854630445`}, 
           0.05570143050888991],
          "\"HILARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HILARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9310109034488097`, 3.135898153365598}, 
           0.05570143050888991],
          "\"MELISSA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MELISSA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.942715326111345, 3.3644759808467883`}, 
           0.05570143050888991],
          "\"MARTHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARTHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.312071324715001, 3.8538501104467087`}, 
           0.05570143050888991],
          "\"CYNTHIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CYNTHIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.2407252861086775`, 2.959539268956114}, 
           0.05570143050888991],
          "\"BERTHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BERTHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.7884955443447814`, 3.699892149571761}, 
           0.05570143050888991],
          "\"KATY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.45271978013659, 3.3929475838811536`}, 
           0.05570143050888991],
          "\"LILLIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LILLIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.011991317923822, 3.036747773860446}, 0.05570143050888991],
          "\"CHERYL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHERYL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.969792695888759, 3.226794349488862}, 0.05570143050888991],
          "\"RUBY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RUBY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.303747585734906, 4.009134785783969}, 0.05570143050888991],
          "\"NAOMI\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NAOMI", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.0523930015783991, 3.706412131116615}, 
           0.05570143050888991],
          "\"BESSIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BESSIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.2573432638898039, 3.024065950763953}, 
           0.05570143050888991],
          "\"GAIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GAIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.979892822619038, 3.311264616838231}, 0.05570143050888991],
          "\"MILDRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MILDRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.149534950406232, 3.104895596389688}, 0.05570143050888991],
          "\"PENELOPE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PENELOPE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.16375040268722163`, 3.277185090685656}, 
           0.05570143050888991],
          "\"CHARLENE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHARLENE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.32390662595910724`, 3.4694697204244216`}, 
           0.05570143050888991],
          "\"JADE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JADE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2521088624868315`, 2.7009640096630276`}, 
           0.05570143050888991],
          "\"CHRISTINA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHRISTINA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.12229625603424887`, 3.787375236833959}, 
           0.05570143050888991],
          "\"ANNETTE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNETTE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.10083672655948739`, 3.601472315531462}, 
           0.05570143050888991],
          "\"JEANETTE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEANETTE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[DiskBox[{0., 3.502118652485}, 0.05570143050888991],
          "\"ESTHER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ESTHER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.175365870848454, 3.080538658374356}, 0.05570143050888991],
          "\"CAROLYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CAROLYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.2612918723690236, 3.712739580181321}, 
           0.05570143050888991],
          "\"HARRIET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HARRIET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.3113085352775964, 3.298363826840268}, 
           0.05570143050888991],
          "\"ANITA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANITA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.14917822500752154`, 3.4254397730806256`}, 
           0.05570143050888991],
          "\"GERALDINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GERALDINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.049757259634716, 3.2075581295494073`}, 
           0.05570143050888991],
          "\"BRIDGET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BRIDGET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.32668261120661146`, 3.155053482431751}, 
           0.05570143050888991],
          "\"GEORGINA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GEORGINA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.2283345869280864, 3.57572093998461}, 0.05570143050888991],
          "\"LINDSEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LINDSEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.0020333003880268485`, 3.36159621491312}, 
           0.05570143050888991],
          "\"KAY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KAY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0774078703579866`, 2.762021135226445}, 
           0.05570143050888991],
          "\"STELLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STELLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.5671950887519348`, 2.2865173398017777`}, 
           0.05570143050888991],
          "\"GEMMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GEMMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1777948334100428`, 2.6217420157641214`}, 
           0.05570143050888991],
          "\"NICHOLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NICHOLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3803050652017146`, 2.477758651764651}, 
           0.05570143050888991],
          "\"AIMEE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AIMEE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.109385498151434, 2.4917851013821215`}, 
           0.05570143050888991],
          "\"HEIDI\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HEIDI", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1688366839844044`, 2.8533041468787195`}, 
           0.05570143050888991],
          "\"MILLICENT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MILLICENT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3442796757106674`, 2.620655965758532}, 
           0.05570143050888991],
          "\"MONICA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MONICA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0093171896476711`, 2.342119382412407}, 
           0.05570143050888991],
          "\"THERESA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "THERESA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.654812508403634, 2.1482345319902834`}, 
           0.05570143050888991],
          "\"MARGERY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARGERY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.136379271804913, 2.10179967534156}, 0.05570143050888991],
          
          "\"MAXINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAXINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.398893722561458, 2.337537030955006}, 0.05570143050888991],
          "\"TANYA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TANYA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0445336068141367`, 2.2145012697976156`}, 
           0.05570143050888991],
          "\"CARLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CARLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.5178886194675658`, 2.070324688298257}, 
           0.05570143050888991],
          "\"FANNY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FANNY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.392985116128974, 2.0172300490268786`}, 
           0.05570143050888991],
          "\"JOY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2701560228774893`, 2.170868016397018}, 
           0.05570143050888991],
          "\"LYDIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYDIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3975982075832798`, 2.18479886837523}, 
           0.05570143050888991],
          "\"ALMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0010160736343976`, 2.6224015147170086`}, 
           0.05570143050888991],
          "\"GLENYS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLENYS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2584534476124616`, 2.0186966525050893`}, 
           0.05570143050888991],
          "\"DEBBIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DEBBIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9660759676933837, 2.472803415911055}, 
           0.05570143050888991],
          "\"JENNY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JENNY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.307329914043703, 2.8190553153022355`}, 
           0.05570143050888991],
          "\"BLANCHE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BLANCHE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2203116837267625`, 2.403725156264022}, 
           0.05570143050888991],
          "\"VIVIENNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VIVIENNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9521184939841647`, 2.973042113831754}, 
           0.05570143050888991],
          "\"TARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.0648042207302373`, 2.715105008020585}, 
           0.05570143050888991],
          "\"MIRIAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MIRIAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1743389460149922`, 2.274227348673222}, 
           0.05570143050888991],
          "\"GLYNIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLYNIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.449660611658213, 4.002162346020976}, 0.05570143050888991],
          "\"CLAIR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLAIR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.07605019362437, 4.7921768996926755`}, 
           0.05570143050888991],
          "\"LYNDSEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYNDSEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.108569302428034, 4.289256406799745}, 0.05570143050888991],
          "\"SONIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SONIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.162718825972419, 4.485721789141594}, 0.05570143050888991],
          "\"MOLLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MOLLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.217602994975898, 3.9554024603260465`}, 
           0.05570143050888991],
          "\"ELLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.069766489239364, 3.4849957919804195`}, 
           0.05570143050888991],
          "\"CHLOE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHLOE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.839643628137155, 4.449570510691226}, 0.05570143050888991],
          "\"SYBIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SYBIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.339445919688016, 4.06213114401514}, 0.05570143050888991],
          
          "\"LEAH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LEAH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.930031394773706, 3.334106453459885}, 0.05570143050888991],
          "\"TONI\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TONI", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.29515948689261, 3.6711682743193585`}, 
           0.05570143050888991],
          "\"WILLIAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WILLIAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.384969987960359, 4.4221485605780035`}, 
           0.05570143050888991],
          "\"JOHN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOHN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.497997598777275, 4.020280573460792}, 0.05570143050888991],
          "\"PAUL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAUL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.157390138415499, 4.132924398807478}, 0.05570143050888991],
          "\"MARK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.202438494892904, 3.420668394795633}, 0.05570143050888991],
          "\"JAMES\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JAMES", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.722960004274572, 4.310322961527341}, 0.05570143050888991],
          "\"MICHAEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MICHAEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.920383828516393, 4.5673503536250575`}, 
           0.05570143050888991],
          "\"STEPHEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STEPHEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.348361489395701, 3.913040092783218}, 0.05570143050888991],
          "\"ANDREW\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANDREW", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.724336630874012, 3.5382502837181464`}, 
           0.05570143050888991],
          "\"DANIEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DANIEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.04286578353353, 3.992902738035645}, 0.05570143050888991],
          
          "\"ARTHUR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ARTHUR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.313344466056199, 3.511235759908192}, 0.05570143050888991],
          "\"ROBERT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROBERT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.246250065585384, 3.7936881591370293`}, 
           0.05570143050888991],
          "\"RICHARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RICHARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.49221300887856, 4.6428349632936685`}, 
           0.05570143050888991],
          "\"RONALD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RONALD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.872934999963933, 3.9116529007241962`}, 
           0.05570143050888991],
          "\"ANTHONY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANTHONY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.99589646107202, 4.4221152403054855`}, 
           0.05570143050888991],
          "\"MATTHEW\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MATTHEW", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.030576710727809, 3.6677971129569764`}, 
           0.05570143050888991],
          "\"CHARLES\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHARLES", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.402875651459135, 4.206617655166467}, 0.05570143050888991],
          "\"FREDERICK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FREDERICK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.5092294802897115`, 4.155850833215487}, 
           0.05570143050888991],
          "\"KENNETH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KENNETH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.826626790601779, 4.124531057816174}, 0.05570143050888991],
          "\"ALBERT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALBERT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.182830794179319, 4.711163026407839}, 0.05570143050888991],
          "\"ALAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.909356644316942, 3.531218243022184}, 0.05570143050888991],
          "\"IAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.940971265755323, 4.7371375157582545`}, 
           0.05570143050888991],
          "\"SIMON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SIMON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.051834577147967, 4.623993472853848}, 0.05570143050888991],
          "\"ERNEST\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ERNEST", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.979285916089861, 4.202026505373777}, 0.05570143050888991],
          "\"ALFRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALFRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.765187881582182, 4.849704246674317}, 0.05570143050888991],
          "\"EDWARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDWARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.1647163047764835`, 3.6052812946290684`}, 
           0.05570143050888991],
          "\"JOSEPH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOSEPH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.256449545263353, 4.602101352336273}, 0.05570143050888991],
          "\"LEE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LEE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.450823132744214, 4.3296976212458285`}, 
           0.05570143050888991],
          "\"ADAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ADAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.7332729528748025`, 4.739823640833926}, 
           0.05570143050888991],
          "\"ROGER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROGER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.073475795754592, 3.3446634144767353`}, 
           0.05570143050888991],
          "\"HAROLD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HAROLD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.243126257987642, 4.3742895738521925`}, 
           0.05570143050888991],
          "\"DEREK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DEREK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.5865952470127995`, 4.480947617956097}, 
           0.05570143050888991],
          "\"KEITH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KEITH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.813630168216543, 3.719486279249364}, 0.05570143050888991],
          "\"FRANK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRANK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.082709938405188, 3.811335885439358}, 0.05570143050888991],
          "\"LESLIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LESLIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.7900103730083154`, 3.3864915489480705`}, 
           0.05570143050888991],
          "\"RAYMOND\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RAYMOND", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.726461226363466, 4.580391401353141}, 0.05570143050888991],
          "\"COLIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "COLIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.271976368383317, 4.217171575296142}, 0.05570143050888991],
          "\"KEVIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KEVIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.417303205744281, 3.641247907462545}, 0.05570143050888991],
          "\"DARREN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DARREN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.889499163828672, 4.854877707567038}, 0.05570143050888991],
          "\"HENRY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HENRY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.436827334648331, 3.776543704867336}, 0.05570143050888991],
          "\"PHILIP\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PHILIP", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.36669655127135, 4.539807801375816}, 0.05570143050888991],
          
          "\"GARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.487593683926255, 3.8913864754248957`}, 
           0.05570143050888991],
          "\"BENJAMIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BENJAMIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.568781576929737, 4.791634583666779}, 0.05570143050888991],
          "\"STANLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STANLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5813031800360937`, 2.017544372999396}, 
           0.05570143050888991],
          "\"STEVEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STEVEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.086947054882777, 1.519870605989537}, 0.05570143050888991],
          "\"ERIC\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ERIC", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.18209667336294, 1.4140793613221037`}, 
           0.05570143050888991],
          "\"MARTIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARTIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.925138690548266, 1.4347354403711694`}, 
           0.05570143050888991],
          "\"WALTER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WALTER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8679255336938736`, 1.2632213976747777`}, 
           0.05570143050888991],
          "\"GRAHAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GRAHAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.979849145266797, 1.6416616732844578`}, 
           0.05570143050888991],
          "\"NICHOLAS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NICHOLAS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.46363350817925, 1.8072214144657355`}, 
           0.05570143050888991],
          "\"LEONARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LEONARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.349911798840048, 1.7078513085738685`}, 
           0.05570143050888991],
          "\"BARRY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BARRY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.471555947280286, 1.068618203063001}, 0.05570143050888991],
          "\"HERBERT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HERBERT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.295671362053043, 1.5656152959568475`}, 
           0.05570143050888991],
          "\"GORDON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GORDON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.026224270844277, 1.194980682649728}, 0.05570143050888991],
          "\"NORMAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORMAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.19088866799243, 1.6685142500137031`}, 
           0.05570143050888991],
          "\"NEIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NEIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8432883078061626`, 1.6652882090850187`}, 
           0.05570143050888991],
          "\"NIGEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NIGEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.274060087359451, 1.3715767941168013`}, 
           0.05570143050888991],
          "\"MALCOLM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MALCOLM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.7164694653507095`, 1.2254168366564895`}, 
           0.05570143050888991],
          "\"TIMOTHY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TIMOTHY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.047638369107941, 0.4111912972831533}, 
           0.05570143050888991],
          "\"STUART\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STUART", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.025537181086292, 1.3306997299521077`}, 
           0.05570143050888991],
          "\"GEOFFREY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GEOFFREY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.437201726066682, 1.4788486729610324`}, 
           0.05570143050888991],
          "\"ALEXANDER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALEXANDER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.272361280221109, 1.8734433678623728`}, 
           0.05570143050888991],
          "\"CYRIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CYRIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5869571021565627`, 1.5841419622038597`}, 
           0.05570143050888991],
          "\"SIDNEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SIDNEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.403274340812292, 1.4813956224851554`}, 
           0.05570143050888991],
          "\"FRANCIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRANCIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.124709468232238, 1.8263122936120195`}, 
           0.05570143050888991],
          "\"RYAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RYAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6289533279741266`, 1.2779280947152851`}, 
           0.05570143050888991],
          "\"PERCY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PERCY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.455341129301084, 1.628651384177883}, 0.05570143050888991],
          "\"LUKE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LUKE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4177692935803883`, 1.2962703706061052`}, 
           0.05570143050888991],
          "\"JACK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JACK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6759923074530665`, 1.446008295597642}, 
           0.05570143050888991],
          "\"TREVOR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TREVOR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.310076412808286, 1.3736411898265515`}, 
           0.05570143050888991],
          "\"ADRIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ADRIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8058864883790147`, 1.1742553557001956`}, 
           0.05570143050888991],
          "\"JAMIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JAMIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.377534460488725, 1.9508173489446283`}, 
           0.05570143050888991],
          "\"WILFRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WILFRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5908997950331663`, 1.1746006289113988`}, 
           0.05570143050888991],
          "\"PATRICK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PATRICK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8167824403242876`, 1.41118222984997}, 
           0.05570143050888991],
          "\"SCOTT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SCOTT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.184505427359471, 1.2669661240102115`}, 
           0.05570143050888991],
          "\"SAMUEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SAMUEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2290791913113557`, 1.0785109381376787`}, 
           0.05570143050888991],
          "\"WAYNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WAYNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.529183377782783, 0.3459540572094859}, 
           0.05570143050888991],
          "\"CECIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CECIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.855260453944898, 0.3303523773370447}, 
           0.05570143050888991],
          "\"GARETH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GARETH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.632165776231189, 0.11103641985856338`}, 
           0.05570143050888991],
          "\"SEAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SEAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.623085392018389, 0.24813975997412197`}, 
           0.05570143050888991],
          "\"HORACE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HORACE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.691707167723954, 0.5505356231454419}, 
           0.05570143050888991],
          "\"BERNARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BERNARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.189233266615462, 0.25849377658537387`}, 
           0.05570143050888991],
          "\"FRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.0191831405526632`, 0.4113205932000388}, 
           0.05570143050888991],
          "\"EDWIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDWIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3710776248337075`, 0.2999523784538045}, 
           0.05570143050888991],
          "\"GERALD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GERALD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.167773717230054, 0.4385212239551035}, 
           0.05570143050888991],
          "\"SHAUN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHAUN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.7716537203514955`, 0.4302322473870501}, 
           0.05570143050888991],
          "\"CLIFFORD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLIFFORD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3108059160742314`, 0.15061590799352498`}, 
           0.05570143050888991],
          "\"MAURICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAURICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.967013800042194, 0.17293923908540476`}, 
           0.05570143050888991],
          "\"CLIVE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLIVE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.834010241282577, 1.990508425310403}, 0.05570143050888991],
          "\"BEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8663225857892227`, 0.3162379741460035}, 
           0.05570143050888991],
          "\"ANTONY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANTONY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.033793051399473, 0.27333934580722286`}, 
           0.05570143050888991],
          "\"VICTOR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VICTOR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1533319156711497`, 0.12824719894068837`}, 
           0.05570143050888991],
          "\"JUSTIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JUSTIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.901323876584327, 0.46408514083271557`}, 
           0.05570143050888991],
          "\"JEFFREY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEFFREY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.5778245924135943`, 0.4688222282786785}, 
           0.05570143050888991],
          "\"OLIVER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "OLIVER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5170786709362716`, 0.04384570570227053}, 
           0.05570143050888991],
          "\"EDGAR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDGAR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.733477488615379, 0.3594720657048902}, 
           0.05570143050888991],
          "\"CHRISTIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHRISTIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.764343642195909, 0.2002421538590511}, 
           0.05570143050888991],
          "\"ASHLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ASHLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3889215317152495`, 0.03714367247629635}, 
           0.05570143050888991],
          "\"KARL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KARL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.852030977769403, 0.09540886872204357}, 
           0.05570143050888991],
          "\"AARON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AARON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8913260505315477`, 0.5169506416851912}, 
           0.05570143050888991],
          "\"MARC\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARC", "Tooltip"]& ], 
        TagBox[
         TooltipBox[DiskBox[{3.2711795821890868`, 0.}, 0.05570143050888991],
          "\"MOHAMMED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MOHAMMED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4757292291894126`, 0.17919497776812854`}, 
           0.05570143050888991],
          "\"HUGH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HUGH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.131451414038333, 0.017911701145744807`}, 
           0.05570143050888991],
          "\"RUSSELL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RUSSELL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.62996839398561, 0.3358079206113249}, 0.05570143050888991],
          "\"GAVIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GAVIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.760508776801317, 0.5082595388835616}, 
           0.05570143050888991],
          "\"LAWRENCE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LAWRENCE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.57736217973407, 0.4804479081603814}, 0.05570143050888991],
          "\"LIAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LIAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3532423647517455`, 0.4616839528821379}, 
           0.05570143050888991],
          "\"ROBIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROBIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.81669742895982, 0.2197850566076167}, 0.05570143050888991],
          "\"PHILLIP\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PHILLIP", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.687649817279081, 0.20397739499959755`}, 
           0.05570143050888991],
          "\"NATHAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NATHAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9942706618603867`, 0.04006566250262589}, 
           0.05570143050888991],
          "\"DENIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DENIS", "Tooltip"]& ]}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Input",
 CellChangeTimes->{{3.677821322002183*^9, 
  3.677821323168272*^9}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]],

Cell["\<\
Extract only the \[OpenCurlyDoubleQuote]Primary.Participant.Name\
\[CloseCurlyDoubleQuote] and \
\[CloseCurlyDoubleQuote]Secondary.Participant.Name\[CloseCurlyDoubleQuote] \
columns from multiPersonEvents.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676198844276435*^9, 3.676198846908072*^9}, {
  3.6761988819052467`*^9, 3.676198926515267*^9}, {3.67619921509544*^9, 
  3.6761992164116173`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"justPeopleColumns", "=", 
   RowBox[{"multiPersonEvents", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Primary.Participant.Name\>\"", ",", 
        "\"\<Secondary.Participant.Name\>\""}], "}"}]}], "]"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.6761926732860394`*^9, 3.676192693877511*^9}, {
  3.676192725074675*^9, 3.676192729439249*^9}, {3.676192808140313*^9, 
  3.676192823143078*^9}}],

Cell[TextData[{
 "Use the function Apply (or the shorthand @@@) to replace the Head ",
 StyleBox["Association",
  FontWeight->"Bold"],
 " with DirectedEdge - refer to the notes from this morning for a refresher. \
Provide this output to Graph, which should generate the following object:"
}], "ItemNumbered",
 CellChangeTimes->{{3.67619894335738*^9, 3.676198978288307*^9}, 
   3.6762618315833473`*^9, {3.676261894336972*^9, 3.67626192821015*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "MARY", "FLORENCE", "JEAN", "JULIE", "CLAIRE", "LAURA", "DORIS", "JOAN",
        "CHRISTINE", "KAREN", "NICOLA", "DOROTHY", "JOYCE", "JACQUELINE", 
       "EMMA", "KATHLEEN", "JANET", "LISA", "ANNIE", "SHEILA", "ANN", 
       "JOANNE", "ELSIE", "BARBARA", "CAROL", "JANE", "MICHELLE", "VICTORIA", 
       "ALICE", "IRENE", "HELEN", "SAMANTHA", "JUNE", "MAUREEN", "DIANE", 
       "RACHEL", "WINIFRED", "EILEEN", "SHIRLEY", "ANNE", "SHARON", "AMY", 
       "GLADYS", "BETTY", "VALERIE", "AMANDA", "JENNIFER", "ANGELA", "ETHEL", 
       "SANDRA", "LOUISE", "KATIE", "HILDA", "PHYLLIS", "DOREEN", "PAULINE", 
       "LILIAN", "AUDREY", "CLARE", "KELLY", "IVY", "VERA", "BRENDA", 
       "GILLIAN", "NATALIE", "VIOLET", "PAMELA", "SYLVIA", "ELAINE", "ELLEN", 
       "LESLEY", "CATHERINE", "HAYLEY", "LILY", "EDNA", "HANNAH", "NELLIE", 
       "BERYL", "WENDY", "LUCY", "ADA", "DAWN", "DONNA", "BEATRICE", "OLIVE", 
       "CAROLE", "DANIELLE", "MAY", "EVELYN", "ROSE", "MAVIS", "SALLY", 
       "KATHERINE", "IRIS", "JUDITH", "MARIA", "ZOE", "KERRY", "DEBRA", 
       "MELANIE", "STACEY", "GERTRUDE", "MURIEL", "PAULA", "LAUREN", "MARION",
        "JOANNA", "MARINA", "JANICE", "LORRAINE", "JESSIE", "PEGGY", 
       "ROSEMARY", "LYNN", "ANDREA", "FRANCES", "SUZANNE", "GRACE", 
       "JOSEPHINE", "YVONNE", "SOPHIE", "LYNNE", "ANNA", "EVA", "GWENDOLINE", 
       "JESSICA", "NORMA", "BEVERLEY", "KIRSTY", "KIMBERLEY", "HAZEL", 
       "FIONA", "MARIE", "JENNA", "MARILYN", "DAISY", "NORA", "NATASHA", 
       "MINNIE", "FREDA", "MANDY", "RACHAEL", "KATHRYN", "NANCY", "RUTH", 
       "JAYNE", "DIANA", "MARIAN", "ELEANOR", "VERONICA", "SARA", "ALEXANDRA",
        "LOUISA", "JODIE", "DORA", "DAPHNE", "TERESA", "JULIA", "NORAH", 
       "HEATHER", "KIM", "JEMMA", "THELMA", "CARLY", "IDA", "CLARA", "GLORIA",
        "HOLLY", "HILARY", "MELISSA", "MARTHA", "CYNTHIA", "BERTHA", "KATY", 
       "LILLIAN", "CHERYL", "RUBY", "NAOMI", "BESSIE", "GAIL", "MILDRED", 
       "PENELOPE", "CHARLENE", "JADE", "CHRISTINA", "ANNETTE", "JEANETTE", 
       "ESTHER", "CAROLYN", "HARRIET", "ANITA", "GERALDINE", "BRIDGET", 
       "GEORGINA", "LINDSEY", "KAY", "STELLA", "GEMMA", "NICHOLA", "AIMEE", 
       "HEIDI", "MILLICENT", "MONICA", "THERESA", "MARGERY", "MAXINE", 
       "TANYA", "CARLA", "FANNY", "JOY", "LYDIA", "ALMA", "GLENYS", "DEBBIE", 
       "JENNY", "BLANCHE", "VIVIENNE", "TARA", "MIRIAM", "GLYNIS", "CLAIR", 
       "LYNDSEY", "SONIA", "MOLLY", "ELLA", "CHLOE", "SYBIL", "LEAH", "TONI", 
       "WILLIAM", "JOHN", "PAUL", "MARK", "JAMES", "MICHAEL", "STEPHEN", 
       "ANDREW", "DANIEL", "ARTHUR", "ROBERT", "RICHARD", "RONALD", "ANTHONY",
        "MATTHEW", "CHARLES", "FREDERICK", "KENNETH", "ALBERT", "ALAN", "IAN",
        "SIMON", "ERNEST", "ALFRED", "EDWARD", "JOSEPH", "LEE", "ADAM", 
       "ROGER", "HAROLD", "DEREK", "KEITH", "FRANK", "LESLIE", "RAYMOND", 
       "COLIN", "KEVIN", "DARREN", "HENRY", "PHILIP", "GARY", "BENJAMIN", 
       "STANLEY", "STEVEN", "ERIC", "MARTIN", "WALTER", "GRAHAM", "NICHOLAS", 
       "LEONARD", "BARRY", "HERBERT", "GORDON", "NORMAN", "NEIL", "NIGEL", 
       "MALCOLM", "TIMOTHY", "STUART", "GEOFFREY", "ALEXANDER", "CYRIL", 
       "SIDNEY", "FRANCIS", "RYAN", "PERCY", "LUKE", "JACK", "TREVOR", 
       "ADRIAN", "JAMIE", "WILFRED", "PATRICK", "SCOTT", "SAMUEL", "WAYNE", 
       "CECIL", "GARETH", "SEAN", "HORACE", "BERNARD", "FRED", "EDWIN", 
       "GERALD", "SHAUN", "CLIFFORD", "MAURICE", "CLIVE", "BEN", "ANTONY", 
       "VICTOR", "JUSTIN", "JEFFREY", "OLIVER", "EDGAR", "CHRISTIAN", 
       "ASHLEY", "KARL", "AARON", "MARC", "MOHAMMED", "HUGH", "RUSSELL", 
       "GAVIN", "LAWRENCE", "LIAM", "ROBIN", "PHILLIP", "NATHAN", 
       "DENIS"}, {CompressedData["
1:eJxd1Wd0FFUYBuANnVB26aEFsoEsLUDoNbQkJHSCvYtdDNgVsaGiIhHF3hW7
Yu+o2Htv2LD33nvf0WcO6/3xnee8d+58986d2bNF8xfVLmyQSCTW5yUSkVn+
NaqGciM2ZhM2ZTM2Z36OLXJyS7ZiayYDU2zDtmzH9uzAjsG6nVjAzuzCruzG
7kEuZA/2ZFFgOthnMXuxN0uYYZ/AeL/xefdlP/YP9j2ApRwYOChYfzDLgnMY
wqEcxuEcwZE55zsqW6OZ4pggh44N8jiOZ5oZlnMCJ3ISJ3MKk6xgJas4ldXB
OvF+ajgtuD49WzOyNZOzOJtzOJe1THIeN+Gm3IybB+NbcEtuxa25DbcN7ovd
jttzB+7I+cH8nbgzd+Gu3I27cw/uyQXM416s40Iu4t7ch/sywwrux/2Z4gHB
/AN5EA/mYh7CSi7JeT/R2KE8TB0uH8EMj+RSHsWjeQyX8Vj9jpPreDyXM97H
CVwRrFPPEwNXMsWTeHKwjyqu4ik8lafxdJ7BM3kWz2Y6sILnBPlcnpfY+FvM
vX4+L+CFvIireTEv4aW8jJc7q/j9XMEreVXOOUTv8mp5Da/htbyO1/MG3sib
9FnDaLzEe8wwyjfzFuO3yrfx9sA7uJZ38i7ezXW8h/eymDW8j/fzAT7ITDD+
UOK/b+dhPsJHExu/qcjH+DifYJJPsoAVLOVTzHAJn+YzTHMxn+VzfJ4pruNS
vsA6vsiX7C3eb+x6VvPloH/scr7CqqBP/Dzxfl7la575dXmDvEF+I1tvZust
vs13+C7f4/v8gB/yI5YFfhzkT/gpP+Pn/IJf8it+zfygX5i/4Qp+y++Y4vf8
gT/yJ/4cXI/v+4W/Bn1+4+/8g3/yL/7N6I8rMo8N2JCN2JhN2JRpfZrJzZnP
FmzJVmzNJFNZ22SrLaPvKjLNFNu5npHbyx3YkZ1YwM7swq55/+8bG/etCuxm
fncWsofePeWk+asD61kUrLsyWDfterVcEfRZxWLzenFZsM8F8lr2Nl4Snx/7
sC/7sT8HsDToOzDIg+TB2SrL1hAO5TAO5wiO5CiO5hiO5TiOZzkncCILOSnI
kzmFFYx+r2XOv8x7Kc/JleZVcSqrWcO0+dPk6awzPkOeGd9vfFZwfz1nG5/D
uazlvGz9A6CXPuY=
       "], Null}, {VertexLabels -> {
         Placed["Name", Tooltip]}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[0.018544322907928002`], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.5001357454627087`, 6.002609917393925}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.576053100782418, 5.895842978123906}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9482352292499296`, 6.097613755961862}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9151738067450674`, 5.438187776093255}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9567074804668376`, 5.823109470968475}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.4311982915193564`, 5.6103629903875545`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.6547283295530573`, 5.470141876035472}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.3291315986460237`, 5.564923358575424}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.8484477552373964`, 5.23528170334823}, {4.785953480575827, 
         4.792650979773929}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.8219155148254793`, 5.021313091663652}, {4.785953480575827, 
         4.792650979773929}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.795263229149113, 4.806376377871383}, {4.785953480575827, 
         4.792650979773929}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.768730988736946, 4.592407766202326}, {4.785953480575827, 
         4.792650979773929}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.6086243433705767`, 5.696340227043807}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.358444073478961, 5.720908552907942}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.104039957029104, 5.853325291739553}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.8849483735070924`, 4.159726937075257}, {2.4086328226038205`, 
         3.4233982178356124`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.354909712495269, 4.298709770518417}, {2.4086328226038205`, 
         3.4233982178356124`}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.781335379600659, 5.569052803189472}, {3.058154943199654, 
         6.028434144407518}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.1080448269975265`, 5.4944198310299175`}, {3.058154943199654, 
         6.028434144407518}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.911581255082521, 5.666345199323741}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.268654685620686, 5.835784189884132}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.740113935424552, 5.607079548351958}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.067717251909292, 5.577496225407183}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.1901160987714365`, 5.367156079183836}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.520191101496037, 5.362600346886898}, {2.464302487648301, 
         5.810836314891446}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.7753366495508, 5.483274457665864}, {2.464302487648301, 
         5.810836314891446}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.352267967999519, 3.8957326391109772`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.5019330232187524`, 5.409922858738638}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.891070426906905, 5.589514229585345}, {3.2683486202440615`, 
         6.000228186556448}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.208503456735674, 5.445752446748563}, {3.2683486202440615`, 
         6.000228186556448}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.572457321420985, 5.258074074588143}, {2.4965891867976207`, 
         5.591165272469905}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.7553571287751715`, 5.368129687605624}, {2.4965891867976207`, 
         5.591165272469905}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.5446951639929356`, 5.512180391519053}, {2.5973121055785473`, 
         6.06625200222989}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.8838422049841435`, 5.589110100505191}, {2.5973121055785473`, 
         6.06625200222989}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.546530712831092, 5.573524194826402}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.8188699679133604`, 6.085705867024174}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.3210376704601803`, 5.334694823182663}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.782379851104637, 5.965672351271724}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.958144342208718, 5.361913680577685}, {3.254307918443584, 
         5.5496448155168885`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.1273888396334026`, 5.222769624771382}, {3.254307918443584, 
         5.5496448155168885`}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         1.8480168639532184`, 4.371045396255162}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {2.47628317627636,
          5.3971524682153955`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.5930177695946828`, 5.543028999812309}, {2.7028347408065194`, 
         6.093244776759786}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9410422346103724`, 5.5852542667406775`}, {2.7028347408065194`, 
         6.093244776759786}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         1.015069443528973, 3.528774386330581}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.4279764095217113`, 5.3754730579667935`}, {2.3055152107392, 
         5.888803933863012}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.7087640646160263`, 5.548369365598673}, {2.3055152107392, 
         5.888803933863012}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.331821291441601, 5.716887595061483}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.4857107529680147`, 5.738563878031519}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.4013526182698466`, 5.880377038950135}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.354722758719908, 5.3840968980770985`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.2825463330866027`, 3.986538935106582}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.455882475071982, 5.426568464653732}, {2.3862080289961396`, 
         5.96445637275853}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.7615508173227004`, 5.5729263977756505`}, {2.3862080289961396`, 
         5.96445637275853}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.1661911124691793`, 6.017348842219756}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.679605445673041, 5.812763152337811}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         4.240273969422595, 3.294538442130717}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.150490349131523, 5.706038430596417}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.810332911515744, 5.814005780601199}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.220199677819779, 5.776796601251533}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9578274128557434`, 5.954294043242812}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.1861620991869795`, 5.63598141436367}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.188557496372201, 5.486614363414871}}, 0.05570143050888991], 
        ArrowBox[{{2.5001357454627087`, 6.002609917393925}, {
         2.576053100782418, 5.895842978123906}}, 0.05570143050888991], 
        ArrowBox[{{5.241668688810895, 5.4646874707731214`}, {
         4.785953480575827, 4.792650979773929}}, 0.05570143050888991], 
        ArrowBox[{{2.352267967999519, 3.8957326391109772`}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         1.8480168639532184`, 4.371045396255162}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {1.597638796308375, 
         2.822580191656698}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.0523930015783991,
          3.706412131116615}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.2573432638898039,
          3.024065950763953}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.149534950406232, 
         3.104895596389688}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.015069443528973, 3.528774386330581}, {
         0.6307814548672267, 3.2629881993466556`}, {0.16375040268722163`, 
         3.277185090685656}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.015069443528973, 3.528774386330581}, {
         0.5480383913489689, 3.542971277682385}, {0.16375040268722163`, 
         3.277185090685656}}], 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.32390662595910724`, 3.4694697204244216`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         2.2521088624868315`, 2.7009640096630276`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.12229625603424887`, 3.787375236833959}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.10083672655948739`, 3.601472315531462}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0., 
         3.502118652485}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {1.175365870848454, 
         3.080538658374356}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.2612918723690236,
          3.712739580181321}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.3113085352775964,
          3.298363826840268}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.14917822500752154`, 3.4254397730806256`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.049757259634716, 
         3.2075581295494073`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.015069443528973, 3.528774386330581}, {
         0.7323309720428639, 3.2287150893303744`}, {0.32668261120661146`, 
         3.155053482431751}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.015069443528973, 3.528774386330581}, {
         0.6094210826927068, 3.4551127794321226`}, {0.32668261120661146`, 
         3.155053482431751}}], 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.2283345869280864,
          3.57572093998461}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.0020333003880268485`, 3.36159621491312}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {
         1.9310109034488097`, 3.135898153365598}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {2.942715326111345,
          3.3644759808467883`}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {2.969792695888759,
          3.226794349488862}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {1.979892822619038,
          3.311264616838231}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {
         1.9521184939841647`, 2.973042113831754}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {
         2.0648042207302373`, 2.715105008020585}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.739341020106996, 2.9041888634933355`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.8051710924460034`, 2.8407736348909403`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.871319615308519, 2.777051637452472}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.9375780802734237`, 2.713223730970225}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         3.0037266031359064`, 2.6495017335537403`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         3.069556675474905, 2.586086504936254}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.3168289667787323`, 2.6557308467518714`}, {2.4780412190946257`, 
         3.04953873904153}}], 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.582048668260187, 2.636917245603628}, {2.4780412190946257`, 
         3.04953873904153}}], 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.0858918689478205`, 1.3686553831522517`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.158130764593345, 1.687858510106223}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.7872134804660247`, 1.501120672851946}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.8217485775752578`, 1.6835647125534663`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.2997933320975226`, 1.6206871164841348`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.708578448660259, 1.6276896036343267`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.0194579833936253`, 1.769213485184401}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.116707127932865, 1.5251410737698965`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.8676771058475212`, 1.8258680307398885`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.9178189325188169`, 1.391703535041099}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.9785572225889283`, 1.4912482384743169`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.7820472184635174`, 3.011445940856201}, {3.528800617824225, 
         3.4153936059804266`}}], 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.8936735482897027`, 2.6065550216699744`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.2328261514407464`, 1.4084201232941602`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.7321852594693112`, 1.9274867347286038`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.597638796308375, 2.822580191656698}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.9423447173186847`, 1.6152319259806995`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.3763239273976744`, 1.5033353754050143`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.6672865997969786`, 3.267408755140863}, {3.6909004173798046`, 
         3.0661122801603264`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5524144354070515`, 3.214097130898387}, {3.6909004173798046`, 
         3.0661122801603264`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.1675898153049924`, 2.6470570184353863`}, {2.420836415944293, 
         2.2431093533062914`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.0747327486684077`, 3.0938368434498473`}, {2.518440375008683, 
         3.1045688674195313`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.972508244164518, 3.4261256299514575`}, {2.518440375008683, 
         3.1045688674195313`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.344243104211506, 2.906533543959526}, {2.8936735482897027`, 
         2.6065550216699744`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.078231061902422, 3.1154150837058654`}, {2.8936735482897027`, 
         2.6065550216699744`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {2.47854069729822,
          2.8454206567419718`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.2021617590475486`, 3.8687370380391304`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.430511042091697, 4.473728563866835}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.250815849483389, 3.5696337399653917`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.142566988890562, 3.1686275723500845`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.2197151334224667`, 3.09390239538722}, {2.780141837132228, 
         3.0186312033407585`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.08922732153398, 3.340122413972776}, {2.780141837132228, 
         3.0186312033407585`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.093822430629724, 2.906375517885318}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.8310392015705985`, 3.940500392214558}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.9424344226979815`, 4.1837777970750905`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.7982340175534173`, 3.0657070382494767`}, {3.8075104349989717`, 
         2.6243579693144916`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5380770352697803`, 2.97404453705058}, {3.8075104349989717`, 
         2.6243579693144916`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {4.08749027015602,
          3.657082668658042}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.977474783878852, 4.049251013933451}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.695603974218695, 3.101816580844254}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.121059226743537, 3.171509965025869}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         5.089215577985817, 3.727051939623592}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.421474358397713, 2.190761571584863}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.751995213885709, 3.352265727245333}, {3.894149394496038, 
         3.1689813972080367`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.6709547984345567`, 3.2321092757899734`}, {3.894149394496038, 
         3.1689813972080367`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {3.70864795419601,
          2.615078784679503}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {4.10375792406919,
          3.464526110277083}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.829893270060526, 2.825695921522285}, {1.9173987331348583`, 
         2.7659584969191062`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5143437045371493`, 2.631688889708302}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.8937742888023044`, 3.511704774846602}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.480532646954007, 3.898639297232747}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.271285278493838, 3.080504665143418}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5936973336907365`, 4.134567590393875}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.383769973042954, 3.1431328987805087`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {3.66708201965197,
          3.919179018307792}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.7999915408060856`, 4.0944452232614905`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.135393023043709, 4.073502578805177}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.280637293984499, 3.4155044991217074`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.9939189361277716`, 3.3272009351431175`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.405503519385941, 3.270043524053674}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.070678820145944, 3.9323075706675006`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.239001584183471, 3.956164829537265}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {4.42975593123907,
          3.530715126116566}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5308128083228962`, 3.684012744192402}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.620491637143561, 2.635471976196063}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.727779462485876, 4.205311459421361}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.164943754401822, 3.796129407611249}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.2435476242779595`, 3.6993666739913427`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.3237636738212215`, 3.7328502920809923`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.401750579498126, 3.6513262470434413`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.9698408995471217`, 3.8055730640819547`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.448791131927424, 4.090933904285507}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.8550673799758357`, 2.9392153854630445`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.942715326111345, 3.3644759808467883`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.312071324715001, 3.8538501104467087`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.2407252861086775`, 2.959539268956114}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.7884955443447814`, 3.699892149571761}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {4.45271978013659,
          3.3929475838811536`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.011991317923822, 3.036747773860446}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.969792695888759, 3.226794349488862}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.303747585734906, 4.009134785783969}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.8312252633985353`, 5.035038489761629}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.02250839855121, 4.085384376734948}, {2.4086328226038205`, 
         3.4233982178356124`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.7049547520858848`, 3.7269685037551326`}, {2.4086328226038205`, 
         3.4233982178356124`}}], 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.1186903288310046`, 3.9098682059113075`}, {2.4780412190946257`, 
         3.04953873904153}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.6781812182968945`, 3.5286251957755383`}, {2.4780412190946257`, 
         3.04953873904153}}], 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         3.528800617824225, 3.4153936059804266`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.40785500153673926`, 4.976406801699863}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.9721685574452104, 4.878482660544747}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.3348605704734469`, 4.957690588079347}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8356128503657425, 4.7757653239935305`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.3115427379293525, 4.389448564296204}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.34047356613598767`, 4.867129181171479}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6915615283338803, 5.016260087063726}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.5955992707905655, 5.196042024112448}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.0459508566039295`, 4.433212273658721}, {0.8526101898675127, 
         4.630801060380589}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.065785259520211, 4.471448104883598}, {0.8526101898675127, 
         4.630801060380589}}], 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8526101898675127, 4.630801060380589}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.1056552583805983`, 4.548307618050227}, {0.8526101898675127, 
         4.630801060380589}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.125489661296848, 4.58654344936516}, {0.8526101898675127, 
         4.630801060380589}}], 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.7973218127784216, 5.309327189878359}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.4761450601789994, 4.616543958931642}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6456923969659738, 4.297023158634975}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.5121956560123038, 4.912632616901693}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.1335695410431113`, 5.308978399644691}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.0882241249858984`, 4.718258641356753}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.5751836336992446, 5.05690184501653}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.469824124602396, 5.104041355271252}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8111154356254753, 4.307441482229554}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.9639135195187563, 5.351582525329796}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.5245821466388976, 4.1755742699901655`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.1570296631032222`, 4.93157558571205}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.28107756110461724`, 4.53044812328401}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.4743370203504087, 4.770891969196664}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.2700113959364694`, 5.216234865895061}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.42525919744296914`, 4.487389538446732}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.122124740619637, 5.126947335427426}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6549332117216733, 4.5921800581849155`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8205650367556543, 4.937147459315856}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.7146891851664909, 4.132475827523839}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.34263158638482816`, 4.636992912800938}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.3969266456918503`, 3.1981103616770197`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.3075950641940195, 4.746511591063642}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {2.47854069729822,
          2.8454206567419718`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6547419541326955, 4.863807700351988}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.49381208403271515`, 4.375955918345492}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8840158256227015, 5.228855102061041}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.4153070868230553, 4.270270166834985}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.7045673804419805, 5.219838233621284}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8761205997475692, 4.462482997072011}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6299052385371002, 4.714382051200481}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.2630543941416832`, 5.08193444559997}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8072815412905161, 5.104601698173099}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6318581063100894, 4.462220058202436}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.9556190288915065, 5.060575878942867}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.4880864554634101`, 3.5849160660106336`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.0179552862225605`, 5.218444329525832}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.3911945670759331`, 3.5449209449397725`}}, 0.05570143050888991], 
        ArrowBox[{{4.430511042091697, 4.473728563866835}, {4.981213223955975, 
         5.0445610970507975`}}, 0.05570143050888991], 
        ArrowBox[{{4.430511042091697, 4.473728563866835}, {4.867566821905859, 
         5.1563861762750385`}}, 0.05570143050888991], 
        ArrowBox[{{2.780141837132228, 3.0186312033407585`}, {
         3.142566988890562, 3.1686275723500845`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.0549058989339706`, 3.175457258094726}, {2.4086328226038205`, 
         3.4233982178356124`}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.271125656804717, 3.01389945667147}, {2.4086328226038205`, 
         3.4233982178356124`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.5735998825420134`, 3.2483991040245725`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.7318601302304497`, 2.7647254080153565`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.352267967999519, 3.8957326391109772`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.2825463330866027`, 3.986538935106582}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.6163060808985588`, 3.3556561813862746`}, {3.528800617824225, 
         3.4153936059804266`}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.8936735482897027`, 2.6065550216699744`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.7321852594693112`, 1.9274867347286038`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.47854069729822, 2.8454206567419718`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.4880864554634101`, 3.5849160660106336`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.5262034831252875`, 3.0689103146972503`}, {1.3911945670759331`, 
         3.5449209449397725`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.7823898170855064`, 3.2419691271574425`}, {1.3911945670759331`, 
         3.5449209449397725`}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.780141837132228, 3.0186312033407585`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.695603974218695, 3.101816580844254}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.4946525051929707`, 2.8012281393391385`}, {1.175365870848454, 
         3.080538658374356}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.5981120987903408`, 3.045269015956232}, {1.175365870848454, 
         3.080538658374356}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.0774078703579866`, 2.762021135226445}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.5671950887519348`, 2.2865173398017777`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.1777948334100428`, 2.6217420157641214`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.3803050652017146`, 2.477758651764651}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.109385498151434, 2.4917851013821215`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.1688366839844044`, 2.8533041468787195`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.3442796757106674`, 2.620655965758532}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.0093171896476711`, 2.342119382412407}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.654812508403634, 2.1482345319902834`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.136379271804913, 2.10179967534156}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.398893722561458, 2.337537030955006}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.0445336068141367`, 2.2145012697976156`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.5178886194675658`, 2.070324688298257}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.392985116128974, 2.0172300490268786`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.2701560228774893`, 2.170868016397018}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.3975982075832798`, 2.18479886837523}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.0010160736343976`, 2.6224015147170086`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.2584534476124616`, 2.0186966525050893`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         0.9660759676933837, 2.472803415911055}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.307329914043703, 2.8190553153022355`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.2203116837267625`, 2.403725156264022}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.0648042207302373`, 2.715105008020585}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.1743389460149922`, 2.274227348673222}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.487818504542941, 4.123825419169118}, {4.785953480575827, 
         4.792650979773929}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.7477955876911, 4.670987906612375}, {4.785953480575827, 
         4.792650979773929}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.043013106420663, 3.1212124988415524`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         4.794708784875165, 4.128115862303972}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.461329494020754, 3.285037203814879}, {4.240273969422595, 
         3.294538442130717}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.403295561100528, 3.46623429946399}, {4.240273969422595, 
         3.294538442130717}}], 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {4.240273969422595, 
         3.294538442130717}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.286639019980282, 3.8304664886949586`}, {4.240273969422595, 
         3.294538442130717}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.228605087060059, 4.011663584345868}, {4.240273969422595, 
         3.294538442130717}}], 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {5.089215577985817, 
         3.727051939623592}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.07605019362437, 
         4.7921768996926755`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.108569302428034, 
         4.289256406799745}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.162718825972419, 
         4.485721789141594}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.217602994975898, 
         3.9554024603260465`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.069766489239364, 
         3.4849957919804195`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.839643628137155, 
         4.449570510691226}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.339445919688016, 
         4.06213114401514}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.930031394773706, 
         3.334106453459885}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.29515948689261, 
         3.6711682743193585`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.384969987960359, 
         4.4221485605780035`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.497997598777275, 
         4.020280573460792}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.157390138415499, 
         4.132924398807478}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.202438494892904, 
         3.420668394795633}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.722960004274572, 
         4.310322961527341}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.920383828516393, 
         4.5673503536250575`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.348361489395701, 
         3.913040092783218}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.724336630874012, 
         3.5382502837181464`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.04286578353353, 
         3.992902738035645}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.313344466056199, 
         3.511235759908192}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.246250065585384, 
         3.7936881591370293`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.49221300887856, 
         4.6428349632936685`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         6.676181246622793, 4.0265111802172}, {6.872934999963933, 
         3.9116529007241962`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         6.646414364999324, 3.8873040670134915`}, {6.872934999963933, 
         3.9116529007241962`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         6.653721168647265, 4.301962224361364}, {6.99589646107202, 
         4.4221152403054855`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         6.79183590408297, 4.122315361915772}, {6.99589646107202, 
         4.4221152403054855`}}], 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.030576710727809, 
         3.6677971129569764`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.402875651459135, 
         4.206617655166467}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         7.5092294802897115`, 4.155850833215487}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.826626790601779, 
         4.124531057816174}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.182830794179319, 
         4.711163026407839}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.909356644316942, 
         3.531218243022184}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.940971265755323, 
         4.7371375157582545`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.051834577147967, 
         4.623993472853848}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.979285916089861, 
         4.202026505373777}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.765187881582182, 
         4.849704246674317}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         7.1647163047764835`, 3.6052812946290684`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.256449545263353, 
         4.602101352336273}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.450823132744214, 
         4.3296976212458285`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         6.7332729528748025`, 4.739823640833926}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.073475795754592, 
         3.3446634144767353`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.243126257987642, 
         4.3742895738521925`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         6.5865952470127995`, 4.480947617956097}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.813630168216543, 
         3.719486279249364}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.082709938405188, 
         3.811335885439358}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         6.7900103730083154`, 3.3864915489480705`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.726461226363466, 
         4.580391401353141}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.271976368383317, 
         4.217171575296142}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.417303205744281, 
         3.641247907462545}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.889499163828672, 
         4.854877707567038}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.436827334648331, 
         3.776543704867336}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.36669655127135, 
         4.539807801375816}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.487593683926255, 
         3.8913864754248957`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.568781576929737, 
         4.791634583666779}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.282482328252882, 2.6005783515765297`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.4170792677831248`, 2.6217310114520327`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.5522851918905665`, 2.6429793766507057`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.6868821314208198`, 2.664132036547722}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.8599702749246174`, 2.3521203348251003`}, {2.4780412190946257`, 
         3.04953873904153}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.199374124206088, 2.7149627772180787`}, {2.4780412190946257`, 
         3.04953873904153}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.1406310129966992`, 2.198975366915549}, {2.8936735482897027`, 
         2.6065550216699744`}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.8936735482897027`, 2.6065550216699744`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.3343457153291007`, 2.4251240277550856`}, {2.8936735482897027`, 
         2.6065550216699744`}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.7321852594693112`, 1.9274867347286038`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.79498175958685, 2.4130676050820368`}, {2.3969266456918503`, 
         3.1981103616770197`}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.3969266456918503`, 3.1981103616770197`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.183248066141095, 2.8025871295897247`}, {2.3969266456918503`, 
         3.1981103616770197`}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8075104349989717`, 2.6243579693144916`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.421474358397713, 2.190761571584863}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {3.70864795419601,
          2.615078784679503}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.5143437045371493`, 2.631688889708302}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.4992849318150934`, 2.332952353797486}, {3.620491637143561, 
         2.635471976196063}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.620491637143561, 2.635471976196063}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.70250988536456, 2.320063995422512}, {3.620491637143561, 
         2.635471976196063}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.2521088624868315`, 2.7009640096630276`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.086947054882777, 1.519870605989537}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {4.18209667336294,
          1.4140793613221037`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.925138690548266, 1.4347354403711694`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8679255336938736`, 1.2632213976747777`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.979849145266797, 1.6416616732844578`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {4.46363350817925,
          1.8072214144657355`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.349911798840048, 1.7078513085738685`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.471555947280286, 1.068618203063001}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.295671362053043, 1.5656152959568475`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.026224270844277, 1.194980682649728}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.9434906982274556`, 1.9432700046139215`}, {4.19088866799243, 
         1.6685142500137031`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8287011498010797`, 1.7427886183891481`}, {4.19088866799243, 
         1.6685142500137031`}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8432883078061626`, 1.6652882090850187`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.274060087359451, 1.3715767941168013`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.7164694653507095`, 1.2254168366564895`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.025537181086292, 1.3306997299521077`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.437201726066682, 1.4788486729610324`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.272361280221109, 1.8734433678623728`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.5869571021565627`, 1.5841419622038597`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.403274340812292, 1.4813956224851554`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.124709468232238, 1.8263122936120195`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.6289533279741266`, 1.2779280947152851`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.455341129301084, 1.628651384177883}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.4177692935803883`, 1.2962703706061052`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.6759923074530665`, 1.446008295597642}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.310076412808286, 1.3736411898265515`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8058864883790147`, 1.1742553557001956`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.377534460488725, 1.9508173489446283`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.5908997950331663`, 1.1746006289113988`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8167824403242876`, 1.41118222984997}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.184505427359471, 1.2669661240102115`}}, 0.05570143050888991], 
        ArrowBox[{{4.471555947280286, 1.068618203063001}, {5.047638369107941, 
         0.4111912972831533}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.133147154561208, 2.1482538366307278`}, {3.6909004173798046`, 
         3.0661122801603264`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.786832454129947, 1.9963693816692503`}, {3.6909004173798046`, 
         3.0661122801603264`}}], 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         4.240273969422595, 3.294538442130717}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.7321852594693112`, 1.9274867347286038`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.47854069729822, 2.8454206567419718`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.421474358397713, 2.190761571584863}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.2033776710043345`, 1.2324405583106968`}, {3.274060087359451, 
         1.3715767941168013`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.299761607666473, 1.2176471740010286`}, {3.274060087359451, 
         1.3715767941168013`}}], 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.529183377782783, 0.3459540572094859}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.855260453944898, 0.3303523773370447}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.632165776231189, 0.11103641985856338`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.623085392018389, 0.24813975997412197`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.691707167723954, 0.5505356231454419}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.189233266615462, 0.25849377658537387`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.0191831405526632`, 0.4113205932000388}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3710776248337075`, 0.2999523784538045}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.167773717230054, 0.4385212239551035}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.7716537203514955`, 0.4302322473870501}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3108059160742314`, 0.15061590799352498`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.967013800042194, 0.17293923908540476`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.834010241282577, 1.990508425310403}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.8663225857892227`, 0.3162379741460035}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.033793051399473, 0.27333934580722286`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.1533319156711497`, 0.12824719894068837`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.901323876584327, 0.46408514083271557`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.5778245924135943`, 0.4688222282786785}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.5170786709362716`, 0.04384570570227053}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.733477488615379, 0.3594720657048902}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.764343642195909, 0.2002421538590511}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3889215317152495`, 0.03714367247629635}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.852030977769403, 0.09540886872204357}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.8913260505315477`, 0.5169506416851912}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.2711795821890868`, 0.}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.4757292291894126`, 0.17919497776812854`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.131451414038333, 0.017911701145744807`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.62996839398561, 0.3358079206113249}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.760508776801317, 0.5082595388835616}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.57736217973407, 0.4804479081603814}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3532423647517455`, 0.4616839528821379}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.81669742895982, 0.2197850566076167}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.687649817279081, 0.20397739499959755`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.9942706618603867`, 0.04006566250262589}}, 0.05570143050888991], 
        ArrowBox[{{2.834010241282577, 1.990508425310403}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991]}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8312252633985353`, 5.035038489761629}, 
           0.05570143050888991],
          "\"MARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.5001357454627087`, 6.002609917393925}, 
           0.05570143050888991],
          "\"FLORENCE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FLORENCE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.576053100782418, 5.895842978123906}, 0.05570143050888991],
          "\"JEAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9482352292499296`, 6.097613755961862}, 
           0.05570143050888991],
          "\"JULIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JULIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9151738067450674`, 5.438187776093255}, 
           0.05570143050888991],
          "\"CLAIRE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLAIRE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9567074804668376`, 5.823109470968475}, 
           0.05570143050888991],
          "\"LAURA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LAURA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4311982915193564`, 5.6103629903875545`}, 
           0.05570143050888991],
          "\"DORIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DORIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.6547283295530573`, 5.470141876035472}, 
           0.05570143050888991],
          "\"JOAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3291315986460237`, 5.564923358575424}, 
           0.05570143050888991],
          "\"CHRISTINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHRISTINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.785953480575827, 4.792650979773929}, 0.05570143050888991],
          "\"KAREN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KAREN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.241668688810895, 5.4646874707731214`}, 
           0.05570143050888991],
          "\"NICOLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NICOLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.6086243433705767`, 5.696340227043807}, 
           0.05570143050888991],
          "\"DOROTHY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DOROTHY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.358444073478961, 5.720908552907942}, 0.05570143050888991],
          "\"JOYCE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOYCE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.104039957029104, 5.853325291739553}, 0.05570143050888991],
          "\"JACQUELINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JACQUELINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.4086328226038205`, 3.4233982178356124`}, 
           0.05570143050888991],
          "\"EMMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EMMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3880612796376046`, 3.247166015126839}, 
           0.05570143050888991],
          "\"KATHLEEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATHLEEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.058154943199654, 6.028434144407518}, 0.05570143050888991],
          "\"JANET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JANET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.911581255082521, 5.666345199323741}, 0.05570143050888991],
          "\"LISA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LISA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.268654685620686, 5.835784189884132}, 0.05570143050888991],
          "\"ANNIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.740113935424552, 5.607079548351958}, 0.05570143050888991],
          "\"SHEILA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHEILA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.067717251909292, 5.577496225407183}, 0.05570143050888991],
          "\"ANN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1901160987714365`, 5.367156079183836}, 
           0.05570143050888991],
          "\"JOANNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOANNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.464302487648301, 5.810836314891446}, 0.05570143050888991],
          "\"ELSIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELSIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.352267967999519, 3.8957326391109772`}, 
           0.05570143050888991],
          "\"BARBARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BARBARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5019330232187524`, 5.409922858738638}, 
           0.05570143050888991],
          "\"CAROL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CAROL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2683486202440615`, 6.000228186556448}, 
           0.05570143050888991],
          "\"JANE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JANE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.4965891867976207`, 5.591165272469905}, 
           0.05570143050888991],
          "\"MICHELLE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MICHELLE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.5973121055785473`, 6.06625200222989}, 
           0.05570143050888991],
          "\"VICTORIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VICTORIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.546530712831092, 5.573524194826402}, 0.05570143050888991],
          "\"ALICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8188699679133604`, 6.085705867024174}, 
           0.05570143050888991],
          "\"IRENE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IRENE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3210376704601803`, 5.334694823182663}, 
           0.05570143050888991],
          "\"HELEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HELEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.782379851104637, 5.965672351271724}, 0.05570143050888991],
          "\"SAMANTHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SAMANTHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.254307918443584, 5.5496448155168885`}, 
           0.05570143050888991],
          "\"JUNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JUNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6909004173798046`, 3.0661122801603264`}, 
           0.05570143050888991],
          "\"MAUREEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAUREEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8480168639532184`, 4.371045396255162}, 
           0.05570143050888991],
          "\"DIANE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DIANE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.47628317627636, 5.3971524682153955`}, 
           0.05570143050888991],
          "\"RACHEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RACHEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.7028347408065194`, 6.093244776759786}, 
           0.05570143050888991],
          "\"WINIFRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WINIFRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.015069443528973, 3.528774386330581}, 0.05570143050888991],
          "\"EILEEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EILEEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.4780412190946257`, 3.04953873904153}, 
           0.05570143050888991],
          "\"SHIRLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHIRLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3055152107392, 5.888803933863012}, 0.05570143050888991],
          "\"ANNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.331821291441601, 5.716887595061483}, 0.05570143050888991],
          "\"SHARON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHARON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4857107529680147`, 5.738563878031519}, 
           0.05570143050888991],
          "\"AMY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AMY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4013526182698466`, 5.880377038950135}, 
           0.05570143050888991],
          "\"GLADYS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLADYS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.354722758719908, 5.3840968980770985`}, 
           0.05570143050888991],
          "\"BETTY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BETTY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2825463330866027`, 3.986538935106582}, 
           0.05570143050888991],
          "\"VALERIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VALERIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3862080289961396`, 5.96445637275853}, 
           0.05570143050888991],
          "\"AMANDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AMANDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1661911124691793`, 6.017348842219756}, 
           0.05570143050888991],
          "\"JENNIFER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JENNIFER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.679605445673041, 5.812763152337811}, 0.05570143050888991],
          "\"ANGELA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANGELA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.240273969422595, 3.294538442130717}, 0.05570143050888991],
          "\"ETHEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ETHEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.150490349131523, 5.706038430596417}, 0.05570143050888991],
          "\"SANDRA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SANDRA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.810332911515744, 5.814005780601199}, 0.05570143050888991],
          "\"LOUISE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LOUISE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.220199677819779, 5.776796601251533}, 0.05570143050888991],
          "\"KATIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9578274128557434`, 5.954294043242812}, 
           0.05570143050888991],
          "\"HILDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HILDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.1861620991869795`, 5.63598141436367}, 
           0.05570143050888991],
          "\"PHYLLIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PHYLLIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.188557496372201, 5.486614363414871}, 0.05570143050888991],
          "\"DOREEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DOREEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.420836415944293, 2.2431093533062914`}, 
           0.05570143050888991],
          "\"PAULINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAULINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.0858918689478205`, 1.3686553831522517`}, 
           0.05570143050888991],
          "\"LILIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LILIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.158130764593345, 1.687858510106223}, 0.05570143050888991],
          "\"AUDREY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AUDREY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.7872134804660247`, 1.501120672851946}, 
           0.05570143050888991],
          "\"CLARE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLARE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8217485775752578`, 1.6835647125534663`}, 
           0.05570143050888991],
          "\"KELLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KELLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2997933320975226`, 1.6206871164841348`}, 
           0.05570143050888991],
          "\"IVY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IVY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.708578448660259, 1.6276896036343267`}, 
           0.05570143050888991],
          "\"VERA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VERA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.0194579833936253`, 1.769213485184401}, 
           0.05570143050888991],
          "\"BRENDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BRENDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.116707127932865, 1.5251410737698965`}, 
           0.05570143050888991],
          "\"GILLIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GILLIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8676771058475212`, 1.8258680307398885`}, 
           0.05570143050888991],
          "\"NATALIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NATALIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9178189325188169`, 1.391703535041099}, 
           0.05570143050888991],
          "\"VIOLET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VIOLET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9785572225889283`, 1.4912482384743169`}, 
           0.05570143050888991],
          "\"PAMELA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAMELA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.518440375008683, 3.1045688674195313`}, 
           0.05570143050888991],
          "\"SYLVIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SYLVIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.528800617824225, 3.4153936059804266`}, 
           0.05570143050888991],
          "\"ELAINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELAINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8936735482897027`, 2.6065550216699744`}, 
           0.05570143050888991],
          "\"ELLEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELLEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2328261514407464`, 1.4084201232941602`}, 
           0.05570143050888991],
          "\"LESLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LESLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.7321852594693112`, 1.9274867347286038`}, 
           0.05570143050888991],
          "\"CATHERINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CATHERINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.597638796308375, 2.822580191656698}, 0.05570143050888991],
          "\"HAYLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HAYLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9423447173186847`, 1.6152319259806995`}, 
           0.05570143050888991],
          "\"LILY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LILY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3763239273976744`, 1.5033353754050143`}, 
           0.05570143050888991],
          "\"EDNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3188303280332685`, 4.388954662649468}, 
           0.05570143050888991],
          "\"HANNAH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HANNAH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.40785500153673926`, 4.976406801699863}, 
           0.05570143050888991],
          "\"NELLIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NELLIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9721685574452104, 4.878482660544747}, 
           0.05570143050888991],
          "\"BERYL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BERYL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3348605704734469`, 4.957690588079347}, 
           0.05570143050888991],
          "\"WENDY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WENDY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8356128503657425, 4.7757653239935305`}, 
           0.05570143050888991],
          "\"LUCY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LUCY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.3115427379293525, 4.389448564296204}, 
           0.05570143050888991],
          "\"ADA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ADA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.34047356613598767`, 4.867129181171479}, 
           0.05570143050888991],
          "\"DAWN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DAWN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6915615283338803, 5.016260087063726}, 
           0.05570143050888991],
          "\"DONNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DONNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5955992707905655, 5.196042024112448}, 
           0.05570143050888991],
          "\"BEATRICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BEATRICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8526101898675127, 4.630801060380589}, 
           0.05570143050888991],
          "\"OLIVE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "OLIVE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.7973218127784216, 5.309327189878359}, 
           0.05570143050888991],
          "\"CAROLE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CAROLE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.4761450601789994, 4.616543958931642}, 
           0.05570143050888991],
          "\"DANIELLE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DANIELLE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6456923969659738, 4.297023158634975}, 
           0.05570143050888991],
          "\"MAY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5121956560123038, 4.912632616901693}, 
           0.05570143050888991],
          "\"EVELYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EVELYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1335695410431113`, 5.308978399644691}, 
           0.05570143050888991],
          "\"ROSE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROSE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0882241249858984`, 4.718258641356753}, 
           0.05570143050888991],
          "\"MAVIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAVIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5751836336992446, 5.05690184501653}, 0.05570143050888991],
          "\"SALLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SALLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.469824124602396, 5.104041355271252}, 0.05570143050888991],
          "\"KATHERINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATHERINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8111154356254753, 4.307441482229554}, 
           0.05570143050888991],
          "\"IRIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IRIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9639135195187563, 5.351582525329796}, 
           0.05570143050888991],
          "\"JUDITH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JUDITH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5245821466388976, 4.1755742699901655`}, 
           0.05570143050888991],
          "\"MARIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1570296631032222`, 4.93157558571205}, 
           0.05570143050888991],
          "\"ZOE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ZOE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.28107756110461724`, 4.53044812328401}, 
           0.05570143050888991],
          "\"KERRY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KERRY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.4743370203504087, 4.770891969196664}, 
           0.05570143050888991],
          "\"DEBRA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DEBRA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2700113959364694`, 5.216234865895061}, 
           0.05570143050888991],
          "\"MELANIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MELANIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.42525919744296914`, 4.487389538446732}, 
           0.05570143050888991],
          "\"STACEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STACEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.122124740619637, 5.126947335427426}, 0.05570143050888991],
          "\"GERTRUDE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GERTRUDE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6549332117216733, 4.5921800581849155`}, 
           0.05570143050888991],
          "\"MURIEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MURIEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8205650367556543, 4.937147459315856}, 
           0.05570143050888991],
          "\"PAULA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAULA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.7146891851664909, 4.132475827523839}, 
           0.05570143050888991],
          "\"LAUREN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LAUREN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.34263158638482816`, 4.636992912800938}, 
           0.05570143050888991],
          "\"MARION\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARION", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3969266456918503`, 3.1981103616770197`}, 
           0.05570143050888991],
          "\"JOANNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOANNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.3075950641940195, 4.746511591063642}, 
           0.05570143050888991],
          "\"MARINA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARINA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.47854069729822, 2.8454206567419718`}, 
           0.05570143050888991],
          "\"JANICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JANICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6547419541326955, 4.863807700351988}, 
           0.05570143050888991],
          "\"LORRAINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LORRAINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.49381208403271515`, 4.375955918345492}, 
           0.05570143050888991],
          "\"JESSIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JESSIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8840158256227015, 5.228855102061041}, 
           0.05570143050888991],
          "\"PEGGY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PEGGY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.4153070868230553, 4.270270166834985}, 
           0.05570143050888991],
          "\"ROSEMARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROSEMARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.7045673804419805, 5.219838233621284}, 
           0.05570143050888991],
          "\"LYNN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYNN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8761205997475692, 4.462482997072011}, 
           0.05570143050888991],
          "\"ANDREA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANDREA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6299052385371002, 4.714382051200481}, 
           0.05570143050888991],
          "\"FRANCES\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRANCES", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2630543941416832`, 5.08193444559997}, 
           0.05570143050888991],
          "\"SUZANNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SUZANNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8072815412905161, 5.104601698173099}, 
           0.05570143050888991],
          "\"GRACE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GRACE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6318581063100894, 4.462220058202436}, 
           0.05570143050888991],
          "\"JOSEPHINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOSEPHINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9556190288915065, 5.060575878942867}, 
           0.05570143050888991],
          "\"YVONNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "YVONNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.4880864554634101`, 3.5849160660106336`}, 
           0.05570143050888991],
          "\"SOPHIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SOPHIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0179552862225605`, 5.218444329525832}, 
           0.05570143050888991],
          "\"LYNNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYNNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3911945670759331`, 3.5449209449397725`}, 
           0.05570143050888991],
          "\"ANNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2021617590475486`, 3.8687370380391304`}, 
           0.05570143050888991],
          "\"EVA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EVA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.430511042091697, 4.473728563866835}, 0.05570143050888991],
          "\"GWENDOLINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GWENDOLINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.981213223955975, 5.0445610970507975`}, 
           0.05570143050888991],
          "\"JESSICA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JESSICA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.250815849483389, 3.5696337399653917`}, 
           0.05570143050888991],
          "\"NORMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.142566988890562, 3.1686275723500845`}, 
           0.05570143050888991],
          "\"BEVERLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BEVERLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.780141837132228, 3.0186312033407585`}, 
           0.05570143050888991],
          "\"KIRSTY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIRSTY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.093822430629724, 2.906375517885318}, 0.05570143050888991],
          "\"KIMBERLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIMBERLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8310392015705985`, 3.940500392214558}, 
           0.05570143050888991],
          "\"HAZEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HAZEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.9424344226979815`, 4.1837777970750905`}, 
           0.05570143050888991],
          "\"FIONA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FIONA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8075104349989717`, 2.6243579693144916`}, 
           0.05570143050888991],
          "\"MARIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.08749027015602, 3.657082668658042}, 0.05570143050888991],
          
          "\"JENNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JENNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.867566821905859, 5.1563861762750385`}, 
           0.05570143050888991],
          "\"MARILYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARILYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.977474783878852, 4.049251013933451}, 0.05570143050888991],
          "\"DAISY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DAISY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.695603974218695, 3.101816580844254}, 0.05570143050888991],
          "\"NORA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.121059226743537, 3.171509965025869}, 0.05570143050888991],
          "\"NATASHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NATASHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.089215577985817, 3.727051939623592}, 0.05570143050888991],
          "\"MINNIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MINNIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.421474358397713, 2.190761571584863}, 0.05570143050888991],
          "\"FREDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FREDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.894149394496038, 3.1689813972080367`}, 
           0.05570143050888991],
          "\"MANDY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MANDY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.70864795419601, 2.615078784679503}, 0.05570143050888991],
          
          "\"RACHAEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RACHAEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.10375792406919, 3.464526110277083}, 0.05570143050888991],
          
          "\"KATHRYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATHRYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9173987331348583`, 2.7659584969191062`}, 
           0.05570143050888991],
          "\"NANCY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NANCY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5143437045371493`, 2.631688889708302}, 
           0.05570143050888991],
          "\"RUTH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RUTH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8937742888023044`, 3.511704774846602}, 
           0.05570143050888991],
          "\"JAYNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JAYNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.480532646954007, 3.898639297232747}, 0.05570143050888991],
          "\"DIANA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DIANA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.271285278493838, 3.080504665143418}, 0.05570143050888991],
          "\"MARIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5936973336907365`, 4.134567590393875}, 
           0.05570143050888991],
          "\"ELEANOR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELEANOR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.383769973042954, 3.1431328987805087`}, 
           0.05570143050888991],
          "\"VERONICA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VERONICA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.66708201965197, 3.919179018307792}, 0.05570143050888991],
          
          "\"SARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.7999915408060856`, 4.0944452232614905`}, 
           0.05570143050888991],
          "\"ALEXANDRA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALEXANDRA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.135393023043709, 4.073502578805177}, 0.05570143050888991],
          "\"LOUISA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LOUISA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.280637293984499, 3.4155044991217074`}, 
           0.05570143050888991],
          "\"JODIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JODIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.9939189361277716`, 3.3272009351431175`}, 
           0.05570143050888991],
          "\"DORA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DORA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.405503519385941, 3.270043524053674}, 0.05570143050888991],
          "\"DAPHNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DAPHNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.070678820145944, 3.9323075706675006`}, 
           0.05570143050888991],
          "\"TERESA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TERESA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.239001584183471, 3.956164829537265}, 0.05570143050888991],
          "\"JULIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JULIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.42975593123907, 3.530715126116566}, 0.05570143050888991],
          
          "\"NORAH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORAH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5308128083228962`, 3.684012744192402}, 
           0.05570143050888991],
          "\"HEATHER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HEATHER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.620491637143561, 2.635471976196063}, 0.05570143050888991],
          "\"KIM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.727779462485876, 4.205311459421361}, 0.05570143050888991],
          "\"JEMMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEMMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.164943754401822, 3.796129407611249}, 0.05570143050888991],
          "\"THELMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "THELMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2435476242779595`, 3.6993666739913427`}, 
           0.05570143050888991],
          "\"CARLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CARLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.3237636738212215`, 3.7328502920809923`}, 
           0.05570143050888991],
          "\"IDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.401750579498126, 3.6513262470434413`}, 
           0.05570143050888991],
          "\"CLARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.9698408995471217`, 3.8055730640819547`}, 
           0.05570143050888991],
          "\"GLORIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLORIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.448791131927424, 4.090933904285507}, 0.05570143050888991],
          "\"HOLLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HOLLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8550673799758357`, 2.9392153854630445`}, 
           0.05570143050888991],
          "\"HILARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HILARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9310109034488097`, 3.135898153365598}, 
           0.05570143050888991],
          "\"MELISSA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MELISSA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.942715326111345, 3.3644759808467883`}, 
           0.05570143050888991],
          "\"MARTHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARTHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.312071324715001, 3.8538501104467087`}, 
           0.05570143050888991],
          "\"CYNTHIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CYNTHIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.2407252861086775`, 2.959539268956114}, 
           0.05570143050888991],
          "\"BERTHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BERTHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.7884955443447814`, 3.699892149571761}, 
           0.05570143050888991],
          "\"KATY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.45271978013659, 3.3929475838811536`}, 
           0.05570143050888991],
          "\"LILLIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LILLIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.011991317923822, 3.036747773860446}, 0.05570143050888991],
          "\"CHERYL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHERYL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.969792695888759, 3.226794349488862}, 0.05570143050888991],
          "\"RUBY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RUBY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.303747585734906, 4.009134785783969}, 0.05570143050888991],
          "\"NAOMI\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NAOMI", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.0523930015783991, 3.706412131116615}, 
           0.05570143050888991],
          "\"BESSIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BESSIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.2573432638898039, 3.024065950763953}, 
           0.05570143050888991],
          "\"GAIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GAIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.979892822619038, 3.311264616838231}, 0.05570143050888991],
          "\"MILDRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MILDRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.149534950406232, 3.104895596389688}, 0.05570143050888991],
          "\"PENELOPE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PENELOPE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.16375040268722163`, 3.277185090685656}, 
           0.05570143050888991],
          "\"CHARLENE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHARLENE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.32390662595910724`, 3.4694697204244216`}, 
           0.05570143050888991],
          "\"JADE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JADE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2521088624868315`, 2.7009640096630276`}, 
           0.05570143050888991],
          "\"CHRISTINA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHRISTINA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.12229625603424887`, 3.787375236833959}, 
           0.05570143050888991],
          "\"ANNETTE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNETTE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.10083672655948739`, 3.601472315531462}, 
           0.05570143050888991],
          "\"JEANETTE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEANETTE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[DiskBox[{0., 3.502118652485}, 0.05570143050888991],
          "\"ESTHER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ESTHER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.175365870848454, 3.080538658374356}, 0.05570143050888991],
          "\"CAROLYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CAROLYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.2612918723690236, 3.712739580181321}, 
           0.05570143050888991],
          "\"HARRIET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HARRIET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.3113085352775964, 3.298363826840268}, 
           0.05570143050888991],
          "\"ANITA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANITA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.14917822500752154`, 3.4254397730806256`}, 
           0.05570143050888991],
          "\"GERALDINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GERALDINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.049757259634716, 3.2075581295494073`}, 
           0.05570143050888991],
          "\"BRIDGET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BRIDGET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.32668261120661146`, 3.155053482431751}, 
           0.05570143050888991],
          "\"GEORGINA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GEORGINA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.2283345869280864, 3.57572093998461}, 0.05570143050888991],
          "\"LINDSEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LINDSEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.0020333003880268485`, 3.36159621491312}, 
           0.05570143050888991],
          "\"KAY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KAY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0774078703579866`, 2.762021135226445}, 
           0.05570143050888991],
          "\"STELLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STELLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.5671950887519348`, 2.2865173398017777`}, 
           0.05570143050888991],
          "\"GEMMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GEMMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1777948334100428`, 2.6217420157641214`}, 
           0.05570143050888991],
          "\"NICHOLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NICHOLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3803050652017146`, 2.477758651764651}, 
           0.05570143050888991],
          "\"AIMEE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AIMEE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.109385498151434, 2.4917851013821215`}, 
           0.05570143050888991],
          "\"HEIDI\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HEIDI", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1688366839844044`, 2.8533041468787195`}, 
           0.05570143050888991],
          "\"MILLICENT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MILLICENT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3442796757106674`, 2.620655965758532}, 
           0.05570143050888991],
          "\"MONICA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MONICA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0093171896476711`, 2.342119382412407}, 
           0.05570143050888991],
          "\"THERESA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "THERESA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.654812508403634, 2.1482345319902834`}, 
           0.05570143050888991],
          "\"MARGERY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARGERY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.136379271804913, 2.10179967534156}, 0.05570143050888991],
          
          "\"MAXINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAXINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.398893722561458, 2.337537030955006}, 0.05570143050888991],
          "\"TANYA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TANYA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0445336068141367`, 2.2145012697976156`}, 
           0.05570143050888991],
          "\"CARLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CARLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.5178886194675658`, 2.070324688298257}, 
           0.05570143050888991],
          "\"FANNY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FANNY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.392985116128974, 2.0172300490268786`}, 
           0.05570143050888991],
          "\"JOY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2701560228774893`, 2.170868016397018}, 
           0.05570143050888991],
          "\"LYDIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYDIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3975982075832798`, 2.18479886837523}, 
           0.05570143050888991],
          "\"ALMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0010160736343976`, 2.6224015147170086`}, 
           0.05570143050888991],
          "\"GLENYS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLENYS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2584534476124616`, 2.0186966525050893`}, 
           0.05570143050888991],
          "\"DEBBIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DEBBIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9660759676933837, 2.472803415911055}, 
           0.05570143050888991],
          "\"JENNY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JENNY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.307329914043703, 2.8190553153022355`}, 
           0.05570143050888991],
          "\"BLANCHE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BLANCHE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2203116837267625`, 2.403725156264022}, 
           0.05570143050888991],
          "\"VIVIENNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VIVIENNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9521184939841647`, 2.973042113831754}, 
           0.05570143050888991],
          "\"TARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.0648042207302373`, 2.715105008020585}, 
           0.05570143050888991],
          "\"MIRIAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MIRIAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1743389460149922`, 2.274227348673222}, 
           0.05570143050888991],
          "\"GLYNIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLYNIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.449660611658213, 4.002162346020976}, 0.05570143050888991],
          "\"CLAIR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLAIR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.07605019362437, 4.7921768996926755`}, 
           0.05570143050888991],
          "\"LYNDSEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYNDSEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.108569302428034, 4.289256406799745}, 0.05570143050888991],
          "\"SONIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SONIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.162718825972419, 4.485721789141594}, 0.05570143050888991],
          "\"MOLLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MOLLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.217602994975898, 3.9554024603260465`}, 
           0.05570143050888991],
          "\"ELLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.069766489239364, 3.4849957919804195`}, 
           0.05570143050888991],
          "\"CHLOE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHLOE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.839643628137155, 4.449570510691226}, 0.05570143050888991],
          "\"SYBIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SYBIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.339445919688016, 4.06213114401514}, 0.05570143050888991],
          
          "\"LEAH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LEAH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.930031394773706, 3.334106453459885}, 0.05570143050888991],
          "\"TONI\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TONI", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.29515948689261, 3.6711682743193585`}, 
           0.05570143050888991],
          "\"WILLIAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WILLIAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.384969987960359, 4.4221485605780035`}, 
           0.05570143050888991],
          "\"JOHN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOHN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.497997598777275, 4.020280573460792}, 0.05570143050888991],
          "\"PAUL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAUL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.157390138415499, 4.132924398807478}, 0.05570143050888991],
          "\"MARK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.202438494892904, 3.420668394795633}, 0.05570143050888991],
          "\"JAMES\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JAMES", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.722960004274572, 4.310322961527341}, 0.05570143050888991],
          "\"MICHAEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MICHAEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.920383828516393, 4.5673503536250575`}, 
           0.05570143050888991],
          "\"STEPHEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STEPHEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.348361489395701, 3.913040092783218}, 0.05570143050888991],
          "\"ANDREW\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANDREW", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.724336630874012, 3.5382502837181464`}, 
           0.05570143050888991],
          "\"DANIEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DANIEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.04286578353353, 3.992902738035645}, 0.05570143050888991],
          
          "\"ARTHUR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ARTHUR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.313344466056199, 3.511235759908192}, 0.05570143050888991],
          "\"ROBERT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROBERT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.246250065585384, 3.7936881591370293`}, 
           0.05570143050888991],
          "\"RICHARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RICHARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.49221300887856, 4.6428349632936685`}, 
           0.05570143050888991],
          "\"RONALD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RONALD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.872934999963933, 3.9116529007241962`}, 
           0.05570143050888991],
          "\"ANTHONY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANTHONY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.99589646107202, 4.4221152403054855`}, 
           0.05570143050888991],
          "\"MATTHEW\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MATTHEW", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.030576710727809, 3.6677971129569764`}, 
           0.05570143050888991],
          "\"CHARLES\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHARLES", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.402875651459135, 4.206617655166467}, 0.05570143050888991],
          "\"FREDERICK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FREDERICK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.5092294802897115`, 4.155850833215487}, 
           0.05570143050888991],
          "\"KENNETH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KENNETH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.826626790601779, 4.124531057816174}, 0.05570143050888991],
          "\"ALBERT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALBERT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.182830794179319, 4.711163026407839}, 0.05570143050888991],
          "\"ALAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.909356644316942, 3.531218243022184}, 0.05570143050888991],
          "\"IAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.940971265755323, 4.7371375157582545`}, 
           0.05570143050888991],
          "\"SIMON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SIMON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.051834577147967, 4.623993472853848}, 0.05570143050888991],
          "\"ERNEST\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ERNEST", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.979285916089861, 4.202026505373777}, 0.05570143050888991],
          "\"ALFRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALFRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.765187881582182, 4.849704246674317}, 0.05570143050888991],
          "\"EDWARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDWARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.1647163047764835`, 3.6052812946290684`}, 
           0.05570143050888991],
          "\"JOSEPH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOSEPH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.256449545263353, 4.602101352336273}, 0.05570143050888991],
          "\"LEE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LEE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.450823132744214, 4.3296976212458285`}, 
           0.05570143050888991],
          "\"ADAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ADAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.7332729528748025`, 4.739823640833926}, 
           0.05570143050888991],
          "\"ROGER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROGER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.073475795754592, 3.3446634144767353`}, 
           0.05570143050888991],
          "\"HAROLD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HAROLD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.243126257987642, 4.3742895738521925`}, 
           0.05570143050888991],
          "\"DEREK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DEREK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.5865952470127995`, 4.480947617956097}, 
           0.05570143050888991],
          "\"KEITH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KEITH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.813630168216543, 3.719486279249364}, 0.05570143050888991],
          "\"FRANK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRANK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.082709938405188, 3.811335885439358}, 0.05570143050888991],
          "\"LESLIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LESLIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.7900103730083154`, 3.3864915489480705`}, 
           0.05570143050888991],
          "\"RAYMOND\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RAYMOND", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.726461226363466, 4.580391401353141}, 0.05570143050888991],
          "\"COLIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "COLIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.271976368383317, 4.217171575296142}, 0.05570143050888991],
          "\"KEVIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KEVIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.417303205744281, 3.641247907462545}, 0.05570143050888991],
          "\"DARREN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DARREN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.889499163828672, 4.854877707567038}, 0.05570143050888991],
          "\"HENRY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HENRY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.436827334648331, 3.776543704867336}, 0.05570143050888991],
          "\"PHILIP\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PHILIP", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.36669655127135, 4.539807801375816}, 0.05570143050888991],
          
          "\"GARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.487593683926255, 3.8913864754248957`}, 
           0.05570143050888991],
          "\"BENJAMIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BENJAMIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.568781576929737, 4.791634583666779}, 0.05570143050888991],
          "\"STANLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STANLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5813031800360937`, 2.017544372999396}, 
           0.05570143050888991],
          "\"STEVEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STEVEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.086947054882777, 1.519870605989537}, 0.05570143050888991],
          "\"ERIC\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ERIC", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.18209667336294, 1.4140793613221037`}, 
           0.05570143050888991],
          "\"MARTIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARTIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.925138690548266, 1.4347354403711694`}, 
           0.05570143050888991],
          "\"WALTER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WALTER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8679255336938736`, 1.2632213976747777`}, 
           0.05570143050888991],
          "\"GRAHAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GRAHAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.979849145266797, 1.6416616732844578`}, 
           0.05570143050888991],
          "\"NICHOLAS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NICHOLAS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.46363350817925, 1.8072214144657355`}, 
           0.05570143050888991],
          "\"LEONARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LEONARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.349911798840048, 1.7078513085738685`}, 
           0.05570143050888991],
          "\"BARRY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BARRY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.471555947280286, 1.068618203063001}, 0.05570143050888991],
          "\"HERBERT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HERBERT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.295671362053043, 1.5656152959568475`}, 
           0.05570143050888991],
          "\"GORDON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GORDON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.026224270844277, 1.194980682649728}, 0.05570143050888991],
          "\"NORMAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORMAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.19088866799243, 1.6685142500137031`}, 
           0.05570143050888991],
          "\"NEIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NEIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8432883078061626`, 1.6652882090850187`}, 
           0.05570143050888991],
          "\"NIGEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NIGEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.274060087359451, 1.3715767941168013`}, 
           0.05570143050888991],
          "\"MALCOLM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MALCOLM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.7164694653507095`, 1.2254168366564895`}, 
           0.05570143050888991],
          "\"TIMOTHY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TIMOTHY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.047638369107941, 0.4111912972831533}, 
           0.05570143050888991],
          "\"STUART\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STUART", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.025537181086292, 1.3306997299521077`}, 
           0.05570143050888991],
          "\"GEOFFREY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GEOFFREY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.437201726066682, 1.4788486729610324`}, 
           0.05570143050888991],
          "\"ALEXANDER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALEXANDER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.272361280221109, 1.8734433678623728`}, 
           0.05570143050888991],
          "\"CYRIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CYRIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5869571021565627`, 1.5841419622038597`}, 
           0.05570143050888991],
          "\"SIDNEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SIDNEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.403274340812292, 1.4813956224851554`}, 
           0.05570143050888991],
          "\"FRANCIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRANCIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.124709468232238, 1.8263122936120195`}, 
           0.05570143050888991],
          "\"RYAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RYAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6289533279741266`, 1.2779280947152851`}, 
           0.05570143050888991],
          "\"PERCY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PERCY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.455341129301084, 1.628651384177883}, 0.05570143050888991],
          "\"LUKE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LUKE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4177692935803883`, 1.2962703706061052`}, 
           0.05570143050888991],
          "\"JACK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JACK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6759923074530665`, 1.446008295597642}, 
           0.05570143050888991],
          "\"TREVOR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TREVOR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.310076412808286, 1.3736411898265515`}, 
           0.05570143050888991],
          "\"ADRIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ADRIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8058864883790147`, 1.1742553557001956`}, 
           0.05570143050888991],
          "\"JAMIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JAMIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.377534460488725, 1.9508173489446283`}, 
           0.05570143050888991],
          "\"WILFRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WILFRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5908997950331663`, 1.1746006289113988`}, 
           0.05570143050888991],
          "\"PATRICK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PATRICK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8167824403242876`, 1.41118222984997}, 
           0.05570143050888991],
          "\"SCOTT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SCOTT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.184505427359471, 1.2669661240102115`}, 
           0.05570143050888991],
          "\"SAMUEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SAMUEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2290791913113557`, 1.0785109381376787`}, 
           0.05570143050888991],
          "\"WAYNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WAYNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.529183377782783, 0.3459540572094859}, 
           0.05570143050888991],
          "\"CECIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CECIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.855260453944898, 0.3303523773370447}, 
           0.05570143050888991],
          "\"GARETH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GARETH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.632165776231189, 0.11103641985856338`}, 
           0.05570143050888991],
          "\"SEAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SEAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.623085392018389, 0.24813975997412197`}, 
           0.05570143050888991],
          "\"HORACE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HORACE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.691707167723954, 0.5505356231454419}, 
           0.05570143050888991],
          "\"BERNARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BERNARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.189233266615462, 0.25849377658537387`}, 
           0.05570143050888991],
          "\"FRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.0191831405526632`, 0.4113205932000388}, 
           0.05570143050888991],
          "\"EDWIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDWIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3710776248337075`, 0.2999523784538045}, 
           0.05570143050888991],
          "\"GERALD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GERALD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.167773717230054, 0.4385212239551035}, 
           0.05570143050888991],
          "\"SHAUN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHAUN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.7716537203514955`, 0.4302322473870501}, 
           0.05570143050888991],
          "\"CLIFFORD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLIFFORD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3108059160742314`, 0.15061590799352498`}, 
           0.05570143050888991],
          "\"MAURICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAURICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.967013800042194, 0.17293923908540476`}, 
           0.05570143050888991],
          "\"CLIVE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLIVE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.834010241282577, 1.990508425310403}, 0.05570143050888991],
          "\"BEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8663225857892227`, 0.3162379741460035}, 
           0.05570143050888991],
          "\"ANTONY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANTONY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.033793051399473, 0.27333934580722286`}, 
           0.05570143050888991],
          "\"VICTOR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VICTOR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1533319156711497`, 0.12824719894068837`}, 
           0.05570143050888991],
          "\"JUSTIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JUSTIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.901323876584327, 0.46408514083271557`}, 
           0.05570143050888991],
          "\"JEFFREY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEFFREY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.5778245924135943`, 0.4688222282786785}, 
           0.05570143050888991],
          "\"OLIVER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "OLIVER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5170786709362716`, 0.04384570570227053}, 
           0.05570143050888991],
          "\"EDGAR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDGAR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.733477488615379, 0.3594720657048902}, 
           0.05570143050888991],
          "\"CHRISTIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHRISTIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.764343642195909, 0.2002421538590511}, 
           0.05570143050888991],
          "\"ASHLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ASHLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3889215317152495`, 0.03714367247629635}, 
           0.05570143050888991],
          "\"KARL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KARL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.852030977769403, 0.09540886872204357}, 
           0.05570143050888991],
          "\"AARON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AARON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8913260505315477`, 0.5169506416851912}, 
           0.05570143050888991],
          "\"MARC\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARC", "Tooltip"]& ], 
        TagBox[
         TooltipBox[DiskBox[{3.2711795821890868`, 0.}, 0.05570143050888991],
          "\"MOHAMMED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MOHAMMED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4757292291894126`, 0.17919497776812854`}, 
           0.05570143050888991],
          "\"HUGH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HUGH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.131451414038333, 0.017911701145744807`}, 
           0.05570143050888991],
          "\"RUSSELL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RUSSELL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.62996839398561, 0.3358079206113249}, 0.05570143050888991],
          "\"GAVIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GAVIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.760508776801317, 0.5082595388835616}, 
           0.05570143050888991],
          "\"LAWRENCE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LAWRENCE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.57736217973407, 0.4804479081603814}, 0.05570143050888991],
          "\"LIAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LIAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3532423647517455`, 0.4616839528821379}, 
           0.05570143050888991],
          "\"ROBIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROBIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.81669742895982, 0.2197850566076167}, 0.05570143050888991],
          "\"PHILLIP\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PHILLIP", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.687649817279081, 0.20397739499959755`}, 
           0.05570143050888991],
          "\"NATHAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NATHAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9942706618603867`, 0.04006566250262589}, 
           0.05570143050888991],
          "\"DENIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DENIS", "Tooltip"]& ]}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Input",
 CellChangeTimes->{{3.67782132450988*^9, 3.677821325439925*^9}}],

Cell["\<\
Use the option VertexLabels to place the name of each vertex as a tooltip for \
the vertex - you will likely need to refer to the documentation for this. \
Store the output of this expression against an appropriately named symbol for \
use later on.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.6762619537846413`*^9, 3.676262025794293*^9}, {
  3.6762624396293507`*^9, 3.676262462354598*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"g1", "=", 
  RowBox[{"Graph", "[", 
   RowBox[{
    RowBox[{"DirectedEdge", "@@@", "justPeopleColumns"}], ",", 
    RowBox[{"VertexLabels", "\[Rule]", 
     RowBox[{"Placed", "[", 
      RowBox[{"\"\<Name\>\"", ",", "Tooltip"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.676192772989875*^9, 3.676192787873229*^9}, {
  3.676262031744645*^9, 3.676262050107646*^9}, {3.6762622844460087`*^9, 
  3.67626228700975*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "MARY", "FLORENCE", "JEAN", "JULIE", "CLAIRE", "LAURA", "DORIS", "JOAN",
        "CHRISTINE", "KAREN", "NICOLA", "DOROTHY", "JOYCE", "JACQUELINE", 
       "EMMA", "KATHLEEN", "JANET", "LISA", "ANNIE", "SHEILA", "ANN", 
       "JOANNE", "ELSIE", "BARBARA", "CAROL", "JANE", "MICHELLE", "VICTORIA", 
       "ALICE", "IRENE", "HELEN", "SAMANTHA", "JUNE", "MAUREEN", "DIANE", 
       "RACHEL", "WINIFRED", "EILEEN", "SHIRLEY", "ANNE", "SHARON", "AMY", 
       "GLADYS", "BETTY", "VALERIE", "AMANDA", "JENNIFER", "ANGELA", "ETHEL", 
       "SANDRA", "LOUISE", "KATIE", "HILDA", "PHYLLIS", "DOREEN", "PAULINE", 
       "LILIAN", "AUDREY", "CLARE", "KELLY", "IVY", "VERA", "BRENDA", 
       "GILLIAN", "NATALIE", "VIOLET", "PAMELA", "SYLVIA", "ELAINE", "ELLEN", 
       "LESLEY", "CATHERINE", "HAYLEY", "LILY", "EDNA", "HANNAH", "NELLIE", 
       "BERYL", "WENDY", "LUCY", "ADA", "DAWN", "DONNA", "BEATRICE", "OLIVE", 
       "CAROLE", "DANIELLE", "MAY", "EVELYN", "ROSE", "MAVIS", "SALLY", 
       "KATHERINE", "IRIS", "JUDITH", "MARIA", "ZOE", "KERRY", "DEBRA", 
       "MELANIE", "STACEY", "GERTRUDE", "MURIEL", "PAULA", "LAUREN", "MARION",
        "JOANNA", "MARINA", "JANICE", "LORRAINE", "JESSIE", "PEGGY", 
       "ROSEMARY", "LYNN", "ANDREA", "FRANCES", "SUZANNE", "GRACE", 
       "JOSEPHINE", "YVONNE", "SOPHIE", "LYNNE", "ANNA", "EVA", "GWENDOLINE", 
       "JESSICA", "NORMA", "BEVERLEY", "KIRSTY", "KIMBERLEY", "HAZEL", 
       "FIONA", "MARIE", "JENNA", "MARILYN", "DAISY", "NORA", "NATASHA", 
       "MINNIE", "FREDA", "MANDY", "RACHAEL", "KATHRYN", "NANCY", "RUTH", 
       "JAYNE", "DIANA", "MARIAN", "ELEANOR", "VERONICA", "SARA", "ALEXANDRA",
        "LOUISA", "JODIE", "DORA", "DAPHNE", "TERESA", "JULIA", "NORAH", 
       "HEATHER", "KIM", "JEMMA", "THELMA", "CARLY", "IDA", "CLARA", "GLORIA",
        "HOLLY", "HILARY", "MELISSA", "MARTHA", "CYNTHIA", "BERTHA", "KATY", 
       "LILLIAN", "CHERYL", "RUBY", "NAOMI", "BESSIE", "GAIL", "MILDRED", 
       "PENELOPE", "CHARLENE", "JADE", "CHRISTINA", "ANNETTE", "JEANETTE", 
       "ESTHER", "CAROLYN", "HARRIET", "ANITA", "GERALDINE", "BRIDGET", 
       "GEORGINA", "LINDSEY", "KAY", "STELLA", "GEMMA", "NICHOLA", "AIMEE", 
       "HEIDI", "MILLICENT", "MONICA", "THERESA", "MARGERY", "MAXINE", 
       "TANYA", "CARLA", "FANNY", "JOY", "LYDIA", "ALMA", "GLENYS", "DEBBIE", 
       "JENNY", "BLANCHE", "VIVIENNE", "TARA", "MIRIAM", "GLYNIS", "CLAIR", 
       "LYNDSEY", "SONIA", "MOLLY", "ELLA", "CHLOE", "SYBIL", "LEAH", "TONI", 
       "WILLIAM", "JOHN", "PAUL", "MARK", "JAMES", "MICHAEL", "STEPHEN", 
       "ANDREW", "DANIEL", "ARTHUR", "ROBERT", "RICHARD", "RONALD", "ANTHONY",
        "MATTHEW", "CHARLES", "FREDERICK", "KENNETH", "ALBERT", "ALAN", "IAN",
        "SIMON", "ERNEST", "ALFRED", "EDWARD", "JOSEPH", "LEE", "ADAM", 
       "ROGER", "HAROLD", "DEREK", "KEITH", "FRANK", "LESLIE", "RAYMOND", 
       "COLIN", "KEVIN", "DARREN", "HENRY", "PHILIP", "GARY", "BENJAMIN", 
       "STANLEY", "STEVEN", "ERIC", "MARTIN", "WALTER", "GRAHAM", "NICHOLAS", 
       "LEONARD", "BARRY", "HERBERT", "GORDON", "NORMAN", "NEIL", "NIGEL", 
       "MALCOLM", "TIMOTHY", "STUART", "GEOFFREY", "ALEXANDER", "CYRIL", 
       "SIDNEY", "FRANCIS", "RYAN", "PERCY", "LUKE", "JACK", "TREVOR", 
       "ADRIAN", "JAMIE", "WILFRED", "PATRICK", "SCOTT", "SAMUEL", "WAYNE", 
       "CECIL", "GARETH", "SEAN", "HORACE", "BERNARD", "FRED", "EDWIN", 
       "GERALD", "SHAUN", "CLIFFORD", "MAURICE", "CLIVE", "BEN", "ANTONY", 
       "VICTOR", "JUSTIN", "JEFFREY", "OLIVER", "EDGAR", "CHRISTIAN", 
       "ASHLEY", "KARL", "AARON", "MARC", "MOHAMMED", "HUGH", "RUSSELL", 
       "GAVIN", "LAWRENCE", "LIAM", "ROBIN", "PHILLIP", "NATHAN", 
       "DENIS"}, {CompressedData["
1:eJxd1Wd0FFUYBuANnVB26aEFsoEsLUDoNbQkJHSCvYtdDNgVsaGiIhHF3hW7
Yu+o2Htv2LD33nvf0WcO6/3xnee8d+58986d2bNF8xfVLmyQSCTW5yUSkVn+
NaqGciM2ZhM2ZTM2Z36OLXJyS7ZiayYDU2zDtmzH9uzAjsG6nVjAzuzCruzG
7kEuZA/2ZFFgOthnMXuxN0uYYZ/AeL/xefdlP/YP9j2ApRwYOChYfzDLgnMY
wqEcxuEcwZE55zsqW6OZ4pggh44N8jiOZ5oZlnMCJ3ISJ3MKk6xgJas4ldXB
OvF+ajgtuD49WzOyNZOzOJtzOJe1THIeN+Gm3IybB+NbcEtuxa25DbcN7ovd
jttzB+7I+cH8nbgzd+Gu3I27cw/uyQXM416s40Iu4t7ch/sywwrux/2Z4gHB
/AN5EA/mYh7CSi7JeT/R2KE8TB0uH8EMj+RSHsWjeQyX8Vj9jpPreDyXM97H
CVwRrFPPEwNXMsWTeHKwjyqu4ik8lafxdJ7BM3kWz2Y6sILnBPlcnpfY+FvM
vX4+L+CFvIireTEv4aW8jJc7q/j9XMEreVXOOUTv8mp5Da/htbyO1/MG3sib
9FnDaLzEe8wwyjfzFuO3yrfx9sA7uJZ38i7ezXW8h/eymDW8j/fzAT7ITDD+
UOK/b+dhPsJHExu/qcjH+DifYJJPsoAVLOVTzHAJn+YzTHMxn+VzfJ4pruNS
vsA6vsiX7C3eb+x6VvPloH/scr7CqqBP/Dzxfl7la575dXmDvEF+I1tvZust
vs13+C7f4/v8gB/yI5YFfhzkT/gpP+Pn/IJf8it+zfygX5i/4Qp+y++Y4vf8
gT/yJ/4cXI/v+4W/Bn1+4+/8g3/yL/7N6I8rMo8N2JCN2JhN2JRpfZrJzZnP
FmzJVmzNJFNZ22SrLaPvKjLNFNu5npHbyx3YkZ1YwM7swq55/+8bG/etCuxm
fncWsofePeWk+asD61kUrLsyWDfterVcEfRZxWLzenFZsM8F8lr2Nl4Snx/7
sC/7sT8HsDToOzDIg+TB2SrL1hAO5TAO5wiO5CiO5hiO5TiOZzkncCILOSnI
kzmFFYx+r2XOv8x7Kc/JleZVcSqrWcO0+dPk6awzPkOeGd9vfFZwfz1nG5/D
uazlvGz9A6CXPuY=
       "], Null}, {VertexLabels -> {
         Placed["Name", Tooltip]}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[0.018544322907928002`], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.5001357454627087`, 6.002609917393925}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.576053100782418, 5.895842978123906}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9482352292499296`, 6.097613755961862}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9151738067450674`, 5.438187776093255}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9567074804668376`, 5.823109470968475}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.4311982915193564`, 5.6103629903875545`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.6547283295530573`, 5.470141876035472}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.3291315986460237`, 5.564923358575424}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.8484477552373964`, 5.23528170334823}, {4.785953480575827, 
         4.792650979773929}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.8219155148254793`, 5.021313091663652}, {4.785953480575827, 
         4.792650979773929}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.795263229149113, 4.806376377871383}, {4.785953480575827, 
         4.792650979773929}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.768730988736946, 4.592407766202326}, {4.785953480575827, 
         4.792650979773929}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.6086243433705767`, 5.696340227043807}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.358444073478961, 5.720908552907942}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.104039957029104, 5.853325291739553}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.8849483735070924`, 4.159726937075257}, {2.4086328226038205`, 
         3.4233982178356124`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.354909712495269, 4.298709770518417}, {2.4086328226038205`, 
         3.4233982178356124`}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.781335379600659, 5.569052803189472}, {3.058154943199654, 
         6.028434144407518}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.1080448269975265`, 5.4944198310299175`}, {3.058154943199654, 
         6.028434144407518}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.911581255082521, 5.666345199323741}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.268654685620686, 5.835784189884132}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.740113935424552, 5.607079548351958}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.067717251909292, 5.577496225407183}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.1901160987714365`, 5.367156079183836}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.520191101496037, 5.362600346886898}, {2.464302487648301, 
         5.810836314891446}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.7753366495508, 5.483274457665864}, {2.464302487648301, 
         5.810836314891446}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.352267967999519, 3.8957326391109772`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.5019330232187524`, 5.409922858738638}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.891070426906905, 5.589514229585345}, {3.2683486202440615`, 
         6.000228186556448}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.208503456735674, 5.445752446748563}, {3.2683486202440615`, 
         6.000228186556448}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.572457321420985, 5.258074074588143}, {2.4965891867976207`, 
         5.591165272469905}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.7553571287751715`, 5.368129687605624}, {2.4965891867976207`, 
         5.591165272469905}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.5446951639929356`, 5.512180391519053}, {2.5973121055785473`, 
         6.06625200222989}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.8838422049841435`, 5.589110100505191}, {2.5973121055785473`, 
         6.06625200222989}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.546530712831092, 5.573524194826402}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.8188699679133604`, 6.085705867024174}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.3210376704601803`, 5.334694823182663}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.782379851104637, 5.965672351271724}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.958144342208718, 5.361913680577685}, {3.254307918443584, 
         5.5496448155168885`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.1273888396334026`, 5.222769624771382}, {3.254307918443584, 
         5.5496448155168885`}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         1.8480168639532184`, 4.371045396255162}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {2.47628317627636,
          5.3971524682153955`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.5930177695946828`, 5.543028999812309}, {2.7028347408065194`, 
         6.093244776759786}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9410422346103724`, 5.5852542667406775`}, {2.7028347408065194`, 
         6.093244776759786}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         1.015069443528973, 3.528774386330581}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.4279764095217113`, 5.3754730579667935`}, {2.3055152107392, 
         5.888803933863012}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.7087640646160263`, 5.548369365598673}, {2.3055152107392, 
         5.888803933863012}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.331821291441601, 5.716887595061483}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.4857107529680147`, 5.738563878031519}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.4013526182698466`, 5.880377038950135}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.354722758719908, 5.3840968980770985`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.2825463330866027`, 3.986538935106582}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.455882475071982, 5.426568464653732}, {2.3862080289961396`, 
         5.96445637275853}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.7615508173227004`, 5.5729263977756505`}, {2.3862080289961396`, 
         5.96445637275853}}], 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.1661911124691793`, 6.017348842219756}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.679605445673041, 5.812763152337811}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         4.240273969422595, 3.294538442130717}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.150490349131523, 5.706038430596417}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.810332911515744, 5.814005780601199}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.220199677819779, 5.776796601251533}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9578274128557434`, 5.954294043242812}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.1861620991869795`, 5.63598141436367}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.188557496372201, 5.486614363414871}}, 0.05570143050888991], 
        ArrowBox[{{2.5001357454627087`, 6.002609917393925}, {
         2.576053100782418, 5.895842978123906}}, 0.05570143050888991], 
        ArrowBox[{{5.241668688810895, 5.4646874707731214`}, {
         4.785953480575827, 4.792650979773929}}, 0.05570143050888991], 
        ArrowBox[{{2.352267967999519, 3.8957326391109772`}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         1.8480168639532184`, 4.371045396255162}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {1.597638796308375, 
         2.822580191656698}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.0523930015783991,
          3.706412131116615}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.2573432638898039,
          3.024065950763953}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.149534950406232, 
         3.104895596389688}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.015069443528973, 3.528774386330581}, {
         0.6307814548672267, 3.2629881993466556`}, {0.16375040268722163`, 
         3.277185090685656}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.015069443528973, 3.528774386330581}, {
         0.5480383913489689, 3.542971277682385}, {0.16375040268722163`, 
         3.277185090685656}}], 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.32390662595910724`, 3.4694697204244216`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         2.2521088624868315`, 2.7009640096630276`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.12229625603424887`, 3.787375236833959}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.10083672655948739`, 3.601472315531462}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0., 
         3.502118652485}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {1.175365870848454, 
         3.080538658374356}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.2612918723690236,
          3.712739580181321}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.3113085352775964,
          3.298363826840268}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.14917822500752154`, 3.4254397730806256`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.049757259634716, 
         3.2075581295494073`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.015069443528973, 3.528774386330581}, {
         0.7323309720428639, 3.2287150893303744`}, {0.32668261120661146`, 
         3.155053482431751}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.015069443528973, 3.528774386330581}, {
         0.6094210826927068, 3.4551127794321226`}, {0.32668261120661146`, 
         3.155053482431751}}], 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.2283345869280864,
          3.57572093998461}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.0020333003880268485`, 3.36159621491312}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {
         1.9310109034488097`, 3.135898153365598}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {2.942715326111345,
          3.3644759808467883`}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {2.969792695888759,
          3.226794349488862}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {1.979892822619038,
          3.311264616838231}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {
         1.9521184939841647`, 2.973042113831754}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {
         2.0648042207302373`, 2.715105008020585}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.739341020106996, 2.9041888634933355`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.8051710924460034`, 2.8407736348909403`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.871319615308519, 2.777051637452472}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.9375780802734237`, 2.713223730970225}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         3.0037266031359064`, 2.6495017335537403`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         3.069556675474905, 2.586086504936254}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.3168289667787323`, 2.6557308467518714`}, {2.4780412190946257`, 
         3.04953873904153}}], 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.582048668260187, 2.636917245603628}, {2.4780412190946257`, 
         3.04953873904153}}], 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.0858918689478205`, 1.3686553831522517`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.158130764593345, 1.687858510106223}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.7872134804660247`, 1.501120672851946}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.8217485775752578`, 1.6835647125534663`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.2997933320975226`, 1.6206871164841348`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.708578448660259, 1.6276896036343267`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.0194579833936253`, 1.769213485184401}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.116707127932865, 1.5251410737698965`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.8676771058475212`, 1.8258680307398885`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.9178189325188169`, 1.391703535041099}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.9785572225889283`, 1.4912482384743169`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.7820472184635174`, 3.011445940856201}, {3.528800617824225, 
         3.4153936059804266`}}], 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.8936735482897027`, 2.6065550216699744`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.2328261514407464`, 1.4084201232941602`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.7321852594693112`, 1.9274867347286038`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.597638796308375, 2.822580191656698}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.9423447173186847`, 1.6152319259806995`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.3763239273976744`, 1.5033353754050143`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.6672865997969786`, 3.267408755140863}, {3.6909004173798046`, 
         3.0661122801603264`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5524144354070515`, 3.214097130898387}, {3.6909004173798046`, 
         3.0661122801603264`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.1675898153049924`, 2.6470570184353863`}, {2.420836415944293, 
         2.2431093533062914`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.0747327486684077`, 3.0938368434498473`}, {2.518440375008683, 
         3.1045688674195313`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.972508244164518, 3.4261256299514575`}, {2.518440375008683, 
         3.1045688674195313`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.344243104211506, 2.906533543959526}, {2.8936735482897027`, 
         2.6065550216699744`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.078231061902422, 3.1154150837058654`}, {2.8936735482897027`, 
         2.6065550216699744`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {2.47854069729822,
          2.8454206567419718`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.2021617590475486`, 3.8687370380391304`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.430511042091697, 4.473728563866835}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.250815849483389, 3.5696337399653917`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.142566988890562, 3.1686275723500845`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.2197151334224667`, 3.09390239538722}, {2.780141837132228, 
         3.0186312033407585`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.08922732153398, 3.340122413972776}, {2.780141837132228, 
         3.0186312033407585`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.093822430629724, 2.906375517885318}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.8310392015705985`, 3.940500392214558}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.9424344226979815`, 4.1837777970750905`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.7982340175534173`, 3.0657070382494767`}, {3.8075104349989717`, 
         2.6243579693144916`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5380770352697803`, 2.97404453705058}, {3.8075104349989717`, 
         2.6243579693144916`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {4.08749027015602,
          3.657082668658042}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.977474783878852, 4.049251013933451}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.695603974218695, 3.101816580844254}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.121059226743537, 3.171509965025869}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         5.089215577985817, 3.727051939623592}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.421474358397713, 2.190761571584863}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.751995213885709, 3.352265727245333}, {3.894149394496038, 
         3.1689813972080367`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.6709547984345567`, 3.2321092757899734`}, {3.894149394496038, 
         3.1689813972080367`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {3.70864795419601,
          2.615078784679503}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {4.10375792406919,
          3.464526110277083}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.829893270060526, 2.825695921522285}, {1.9173987331348583`, 
         2.7659584969191062`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5143437045371493`, 2.631688889708302}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.8937742888023044`, 3.511704774846602}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.480532646954007, 3.898639297232747}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.271285278493838, 3.080504665143418}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5936973336907365`, 4.134567590393875}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.383769973042954, 3.1431328987805087`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {3.66708201965197,
          3.919179018307792}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.7999915408060856`, 4.0944452232614905`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.135393023043709, 4.073502578805177}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.280637293984499, 3.4155044991217074`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.9939189361277716`, 3.3272009351431175`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.405503519385941, 3.270043524053674}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.070678820145944, 3.9323075706675006`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.239001584183471, 3.956164829537265}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {4.42975593123907,
          3.530715126116566}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5308128083228962`, 3.684012744192402}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.620491637143561, 2.635471976196063}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.727779462485876, 4.205311459421361}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.164943754401822, 3.796129407611249}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.2435476242779595`, 3.6993666739913427`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.3237636738212215`, 3.7328502920809923`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.401750579498126, 3.6513262470434413`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.9698408995471217`, 3.8055730640819547`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.448791131927424, 4.090933904285507}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.8550673799758357`, 2.9392153854630445`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.942715326111345, 3.3644759808467883`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.312071324715001, 3.8538501104467087`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.2407252861086775`, 2.959539268956114}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.7884955443447814`, 3.699892149571761}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {4.45271978013659,
          3.3929475838811536`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.011991317923822, 3.036747773860446}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.969792695888759, 3.226794349488862}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.303747585734906, 4.009134785783969}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.8312252633985353`, 5.035038489761629}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.02250839855121, 4.085384376734948}, {2.4086328226038205`, 
         3.4233982178356124`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.7049547520858848`, 3.7269685037551326`}, {2.4086328226038205`, 
         3.4233982178356124`}}], 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.1186903288310046`, 3.9098682059113075`}, {2.4780412190946257`, 
         3.04953873904153}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.6781812182968945`, 3.5286251957755383`}, {2.4780412190946257`, 
         3.04953873904153}}], 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         3.528800617824225, 3.4153936059804266`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.40785500153673926`, 4.976406801699863}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.9721685574452104, 4.878482660544747}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.3348605704734469`, 4.957690588079347}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8356128503657425, 4.7757653239935305`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.3115427379293525, 4.389448564296204}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.34047356613598767`, 4.867129181171479}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6915615283338803, 5.016260087063726}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.5955992707905655, 5.196042024112448}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.0459508566039295`, 4.433212273658721}, {0.8526101898675127, 
         4.630801060380589}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.065785259520211, 4.471448104883598}, {0.8526101898675127, 
         4.630801060380589}}], 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8526101898675127, 4.630801060380589}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.1056552583805983`, 4.548307618050227}, {0.8526101898675127, 
         4.630801060380589}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.125489661296848, 4.58654344936516}, {0.8526101898675127, 
         4.630801060380589}}], 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.7973218127784216, 5.309327189878359}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.4761450601789994, 4.616543958931642}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6456923969659738, 4.297023158634975}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.5121956560123038, 4.912632616901693}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.1335695410431113`, 5.308978399644691}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.0882241249858984`, 4.718258641356753}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.5751836336992446, 5.05690184501653}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.469824124602396, 5.104041355271252}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8111154356254753, 4.307441482229554}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.9639135195187563, 5.351582525329796}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.5245821466388976, 4.1755742699901655`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.1570296631032222`, 4.93157558571205}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.28107756110461724`, 4.53044812328401}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.4743370203504087, 4.770891969196664}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.2700113959364694`, 5.216234865895061}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.42525919744296914`, 4.487389538446732}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.122124740619637, 5.126947335427426}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6549332117216733, 4.5921800581849155`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8205650367556543, 4.937147459315856}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.7146891851664909, 4.132475827523839}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.34263158638482816`, 4.636992912800938}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.3969266456918503`, 3.1981103616770197`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.3075950641940195, 4.746511591063642}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {2.47854069729822,
          2.8454206567419718`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6547419541326955, 4.863807700351988}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.49381208403271515`, 4.375955918345492}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8840158256227015, 5.228855102061041}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.4153070868230553, 4.270270166834985}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.7045673804419805, 5.219838233621284}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8761205997475692, 4.462482997072011}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6299052385371002, 4.714382051200481}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.2630543941416832`, 5.08193444559997}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8072815412905161, 5.104601698173099}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6318581063100894, 4.462220058202436}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.9556190288915065, 5.060575878942867}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.4880864554634101`, 3.5849160660106336`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.0179552862225605`, 5.218444329525832}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.3911945670759331`, 3.5449209449397725`}}, 0.05570143050888991], 
        ArrowBox[{{4.430511042091697, 4.473728563866835}, {4.981213223955975, 
         5.0445610970507975`}}, 0.05570143050888991], 
        ArrowBox[{{4.430511042091697, 4.473728563866835}, {4.867566821905859, 
         5.1563861762750385`}}, 0.05570143050888991], 
        ArrowBox[{{2.780141837132228, 3.0186312033407585`}, {
         3.142566988890562, 3.1686275723500845`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.0549058989339706`, 3.175457258094726}, {2.4086328226038205`, 
         3.4233982178356124`}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.271125656804717, 3.01389945667147}, {2.4086328226038205`, 
         3.4233982178356124`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.5735998825420134`, 3.2483991040245725`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.7318601302304497`, 2.7647254080153565`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.352267967999519, 3.8957326391109772`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.2825463330866027`, 3.986538935106582}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.6163060808985588`, 3.3556561813862746`}, {3.528800617824225, 
         3.4153936059804266`}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.8936735482897027`, 2.6065550216699744`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.7321852594693112`, 1.9274867347286038`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.47854069729822, 2.8454206567419718`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.4880864554634101`, 3.5849160660106336`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.5262034831252875`, 3.0689103146972503`}, {1.3911945670759331`, 
         3.5449209449397725`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.7823898170855064`, 3.2419691271574425`}, {1.3911945670759331`, 
         3.5449209449397725`}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.780141837132228, 3.0186312033407585`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.695603974218695, 3.101816580844254}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.4946525051929707`, 2.8012281393391385`}, {1.175365870848454, 
         3.080538658374356}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.5981120987903408`, 3.045269015956232}, {1.175365870848454, 
         3.080538658374356}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.0774078703579866`, 2.762021135226445}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.5671950887519348`, 2.2865173398017777`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.1777948334100428`, 2.6217420157641214`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.3803050652017146`, 2.477758651764651}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.109385498151434, 2.4917851013821215`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.1688366839844044`, 2.8533041468787195`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.3442796757106674`, 2.620655965758532}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.0093171896476711`, 2.342119382412407}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.654812508403634, 2.1482345319902834`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.136379271804913, 2.10179967534156}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.398893722561458, 2.337537030955006}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.0445336068141367`, 2.2145012697976156`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.5178886194675658`, 2.070324688298257}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.392985116128974, 2.0172300490268786`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.2701560228774893`, 2.170868016397018}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.3975982075832798`, 2.18479886837523}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.0010160736343976`, 2.6224015147170086`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.2584534476124616`, 2.0186966525050893`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         0.9660759676933837, 2.472803415911055}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.307329914043703, 2.8190553153022355`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.2203116837267625`, 2.403725156264022}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.0648042207302373`, 2.715105008020585}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.1743389460149922`, 2.274227348673222}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.487818504542941, 4.123825419169118}, {4.785953480575827, 
         4.792650979773929}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.7477955876911, 4.670987906612375}, {4.785953480575827, 
         4.792650979773929}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.043013106420663, 3.1212124988415524`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         4.794708784875165, 4.128115862303972}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.461329494020754, 3.285037203814879}, {4.240273969422595, 
         3.294538442130717}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.403295561100528, 3.46623429946399}, {4.240273969422595, 
         3.294538442130717}}], 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {4.240273969422595, 
         3.294538442130717}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.286639019980282, 3.8304664886949586`}, {4.240273969422595, 
         3.294538442130717}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         5.228605087060059, 4.011663584345868}, {4.240273969422595, 
         3.294538442130717}}], 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {5.089215577985817, 
         3.727051939623592}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.07605019362437, 
         4.7921768996926755`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.108569302428034, 
         4.289256406799745}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.162718825972419, 
         4.485721789141594}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.217602994975898, 
         3.9554024603260465`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.069766489239364, 
         3.4849957919804195`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.839643628137155, 
         4.449570510691226}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.339445919688016, 
         4.06213114401514}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.930031394773706, 
         3.334106453459885}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.29515948689261, 
         3.6711682743193585`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.384969987960359, 
         4.4221485605780035`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.497997598777275, 
         4.020280573460792}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.157390138415499, 
         4.132924398807478}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.202438494892904, 
         3.420668394795633}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.722960004274572, 
         4.310322961527341}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.920383828516393, 
         4.5673503536250575`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.348361489395701, 
         3.913040092783218}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.724336630874012, 
         3.5382502837181464`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.04286578353353, 
         3.992902738035645}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.313344466056199, 
         3.511235759908192}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.246250065585384, 
         3.7936881591370293`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.49221300887856, 
         4.6428349632936685`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         6.676181246622793, 4.0265111802172}, {6.872934999963933, 
         3.9116529007241962`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         6.646414364999324, 3.8873040670134915`}, {6.872934999963933, 
         3.9116529007241962`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         6.653721168647265, 4.301962224361364}, {6.99589646107202, 
         4.4221152403054855`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{6.449660611658213, 4.002162346020976}, {
         6.79183590408297, 4.122315361915772}, {6.99589646107202, 
         4.4221152403054855`}}], 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.030576710727809, 
         3.6677971129569764`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.402875651459135, 
         4.206617655166467}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         7.5092294802897115`, 4.155850833215487}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.826626790601779, 
         4.124531057816174}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.182830794179319, 
         4.711163026407839}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.909356644316942, 
         3.531218243022184}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.940971265755323, 
         4.7371375157582545`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.051834577147967, 
         4.623993472853848}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.979285916089861, 
         4.202026505373777}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.765187881582182, 
         4.849704246674317}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         7.1647163047764835`, 3.6052812946290684`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.256449545263353, 
         4.602101352336273}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.450823132744214, 
         4.3296976212458285`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         6.7332729528748025`, 4.739823640833926}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.073475795754592, 
         3.3446634144767353`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.243126257987642, 
         4.3742895738521925`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         6.5865952470127995`, 4.480947617956097}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.813630168216543, 
         3.719486279249364}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.082709938405188, 
         3.811335885439358}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         6.7900103730083154`, 3.3864915489480705`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.726461226363466, 
         4.580391401353141}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.271976368383317, 
         4.217171575296142}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.417303205744281, 
         3.641247907462545}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.889499163828672, 
         4.854877707567038}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.436827334648331, 
         3.776543704867336}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.36669655127135, 
         4.539807801375816}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.487593683926255, 
         3.8913864754248957`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.568781576929737, 
         4.791634583666779}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.282482328252882, 2.6005783515765297`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.4170792677831248`, 2.6217310114520327`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.5522851918905665`, 2.6429793766507057`}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.6868821314208198`, 2.664132036547722}, {3.3880612796376046`, 
         3.247166015126839}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.8599702749246174`, 2.3521203348251003`}, {2.4780412190946257`, 
         3.04953873904153}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.199374124206088, 2.7149627772180787`}, {2.4780412190946257`, 
         3.04953873904153}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.1406310129966992`, 2.198975366915549}, {2.8936735482897027`, 
         2.6065550216699744`}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.8936735482897027`, 2.6065550216699744`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.3343457153291007`, 2.4251240277550856`}, {2.8936735482897027`, 
         2.6065550216699744`}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.7321852594693112`, 1.9274867347286038`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.79498175958685, 2.4130676050820368`}, {2.3969266456918503`, 
         3.1981103616770197`}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.3969266456918503`, 3.1981103616770197`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.183248066141095, 2.8025871295897247`}, {2.3969266456918503`, 
         3.1981103616770197`}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8075104349989717`, 2.6243579693144916`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.421474358397713, 2.190761571584863}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {3.70864795419601,
          2.615078784679503}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.5143437045371493`, 2.631688889708302}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.4992849318150934`, 2.332952353797486}, {3.620491637143561, 
         2.635471976196063}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.620491637143561, 2.635471976196063}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.70250988536456, 2.320063995422512}, {3.620491637143561, 
         2.635471976196063}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.2521088624868315`, 2.7009640096630276`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.086947054882777, 1.519870605989537}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {4.18209667336294,
          1.4140793613221037`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.925138690548266, 1.4347354403711694`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8679255336938736`, 1.2632213976747777`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.979849145266797, 1.6416616732844578`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {4.46363350817925,
          1.8072214144657355`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.349911798840048, 1.7078513085738685`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.471555947280286, 1.068618203063001}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.295671362053043, 1.5656152959568475`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.026224270844277, 1.194980682649728}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.9434906982274556`, 1.9432700046139215`}, {4.19088866799243, 
         1.6685142500137031`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8287011498010797`, 1.7427886183891481`}, {4.19088866799243, 
         1.6685142500137031`}}], 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8432883078061626`, 1.6652882090850187`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.274060087359451, 1.3715767941168013`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.7164694653507095`, 1.2254168366564895`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.025537181086292, 1.3306997299521077`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.437201726066682, 1.4788486729610324`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.272361280221109, 1.8734433678623728`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.5869571021565627`, 1.5841419622038597`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.403274340812292, 1.4813956224851554`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.124709468232238, 1.8263122936120195`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.6289533279741266`, 1.2779280947152851`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.455341129301084, 1.628651384177883}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.4177692935803883`, 1.2962703706061052`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.6759923074530665`, 1.446008295597642}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.310076412808286, 1.3736411898265515`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8058864883790147`, 1.1742553557001956`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.377534460488725, 1.9508173489446283`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.5908997950331663`, 1.1746006289113988`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8167824403242876`, 1.41118222984997}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.184505427359471, 1.2669661240102115`}}, 0.05570143050888991], 
        ArrowBox[{{4.471555947280286, 1.068618203063001}, {5.047638369107941, 
         0.4111912972831533}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.133147154561208, 2.1482538366307278`}, {3.6909004173798046`, 
         3.0661122801603264`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.786832454129947, 1.9963693816692503`}, {3.6909004173798046`, 
         3.0661122801603264`}}], 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         4.240273969422595, 3.294538442130717}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.7321852594693112`, 1.9274867347286038`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.47854069729822, 2.8454206567419718`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.421474358397713, 2.190761571584863}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.2033776710043345`, 1.2324405583106968`}, {3.274060087359451, 
         1.3715767941168013`}}], 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.299761607666473, 1.2176471740010286`}, {3.274060087359451, 
         1.3715767941168013`}}], 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.529183377782783, 0.3459540572094859}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.855260453944898, 0.3303523773370447}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.632165776231189, 0.11103641985856338`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.623085392018389, 0.24813975997412197`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.691707167723954, 0.5505356231454419}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.189233266615462, 0.25849377658537387`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.0191831405526632`, 0.4113205932000388}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3710776248337075`, 0.2999523784538045}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.167773717230054, 0.4385212239551035}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.7716537203514955`, 0.4302322473870501}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3108059160742314`, 0.15061590799352498`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.967013800042194, 0.17293923908540476`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.834010241282577, 1.990508425310403}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.8663225857892227`, 0.3162379741460035}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.033793051399473, 0.27333934580722286`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.1533319156711497`, 0.12824719894068837`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.901323876584327, 0.46408514083271557`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.5778245924135943`, 0.4688222282786785}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.5170786709362716`, 0.04384570570227053}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.733477488615379, 0.3594720657048902}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.764343642195909, 0.2002421538590511}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3889215317152495`, 0.03714367247629635}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.852030977769403, 0.09540886872204357}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.8913260505315477`, 0.5169506416851912}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.2711795821890868`, 0.}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.4757292291894126`, 0.17919497776812854`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.131451414038333, 0.017911701145744807`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.62996839398561, 0.3358079206113249}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.760508776801317, 0.5082595388835616}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.57736217973407, 0.4804479081603814}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3532423647517455`, 0.4616839528821379}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.81669742895982, 0.2197850566076167}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.687649817279081, 0.20397739499959755`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.9942706618603867`, 0.04006566250262589}}, 0.05570143050888991], 
        ArrowBox[{{2.834010241282577, 1.990508425310403}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991]}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8312252633985353`, 5.035038489761629}, 
           0.05570143050888991],
          "\"MARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.5001357454627087`, 6.002609917393925}, 
           0.05570143050888991],
          "\"FLORENCE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FLORENCE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.576053100782418, 5.895842978123906}, 0.05570143050888991],
          "\"JEAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9482352292499296`, 6.097613755961862}, 
           0.05570143050888991],
          "\"JULIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JULIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9151738067450674`, 5.438187776093255}, 
           0.05570143050888991],
          "\"CLAIRE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLAIRE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9567074804668376`, 5.823109470968475}, 
           0.05570143050888991],
          "\"LAURA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LAURA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4311982915193564`, 5.6103629903875545`}, 
           0.05570143050888991],
          "\"DORIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DORIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.6547283295530573`, 5.470141876035472}, 
           0.05570143050888991],
          "\"JOAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3291315986460237`, 5.564923358575424}, 
           0.05570143050888991],
          "\"CHRISTINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHRISTINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.785953480575827, 4.792650979773929}, 0.05570143050888991],
          "\"KAREN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KAREN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.241668688810895, 5.4646874707731214`}, 
           0.05570143050888991],
          "\"NICOLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NICOLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.6086243433705767`, 5.696340227043807}, 
           0.05570143050888991],
          "\"DOROTHY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DOROTHY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.358444073478961, 5.720908552907942}, 0.05570143050888991],
          "\"JOYCE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOYCE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.104039957029104, 5.853325291739553}, 0.05570143050888991],
          "\"JACQUELINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JACQUELINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.4086328226038205`, 3.4233982178356124`}, 
           0.05570143050888991],
          "\"EMMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EMMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3880612796376046`, 3.247166015126839}, 
           0.05570143050888991],
          "\"KATHLEEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATHLEEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.058154943199654, 6.028434144407518}, 0.05570143050888991],
          "\"JANET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JANET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.911581255082521, 5.666345199323741}, 0.05570143050888991],
          "\"LISA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LISA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.268654685620686, 5.835784189884132}, 0.05570143050888991],
          "\"ANNIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.740113935424552, 5.607079548351958}, 0.05570143050888991],
          "\"SHEILA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHEILA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.067717251909292, 5.577496225407183}, 0.05570143050888991],
          "\"ANN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1901160987714365`, 5.367156079183836}, 
           0.05570143050888991],
          "\"JOANNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOANNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.464302487648301, 5.810836314891446}, 0.05570143050888991],
          "\"ELSIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELSIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.352267967999519, 3.8957326391109772`}, 
           0.05570143050888991],
          "\"BARBARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BARBARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5019330232187524`, 5.409922858738638}, 
           0.05570143050888991],
          "\"CAROL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CAROL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2683486202440615`, 6.000228186556448}, 
           0.05570143050888991],
          "\"JANE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JANE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.4965891867976207`, 5.591165272469905}, 
           0.05570143050888991],
          "\"MICHELLE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MICHELLE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.5973121055785473`, 6.06625200222989}, 
           0.05570143050888991],
          "\"VICTORIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VICTORIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.546530712831092, 5.573524194826402}, 0.05570143050888991],
          "\"ALICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8188699679133604`, 6.085705867024174}, 
           0.05570143050888991],
          "\"IRENE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IRENE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3210376704601803`, 5.334694823182663}, 
           0.05570143050888991],
          "\"HELEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HELEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.782379851104637, 5.965672351271724}, 0.05570143050888991],
          "\"SAMANTHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SAMANTHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.254307918443584, 5.5496448155168885`}, 
           0.05570143050888991],
          "\"JUNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JUNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6909004173798046`, 3.0661122801603264`}, 
           0.05570143050888991],
          "\"MAUREEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAUREEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8480168639532184`, 4.371045396255162}, 
           0.05570143050888991],
          "\"DIANE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DIANE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.47628317627636, 5.3971524682153955`}, 
           0.05570143050888991],
          "\"RACHEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RACHEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.7028347408065194`, 6.093244776759786}, 
           0.05570143050888991],
          "\"WINIFRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WINIFRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.015069443528973, 3.528774386330581}, 0.05570143050888991],
          "\"EILEEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EILEEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.4780412190946257`, 3.04953873904153}, 
           0.05570143050888991],
          "\"SHIRLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHIRLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3055152107392, 5.888803933863012}, 0.05570143050888991],
          "\"ANNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.331821291441601, 5.716887595061483}, 0.05570143050888991],
          "\"SHARON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHARON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4857107529680147`, 5.738563878031519}, 
           0.05570143050888991],
          "\"AMY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AMY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4013526182698466`, 5.880377038950135}, 
           0.05570143050888991],
          "\"GLADYS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLADYS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.354722758719908, 5.3840968980770985`}, 
           0.05570143050888991],
          "\"BETTY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BETTY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2825463330866027`, 3.986538935106582}, 
           0.05570143050888991],
          "\"VALERIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VALERIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3862080289961396`, 5.96445637275853}, 
           0.05570143050888991],
          "\"AMANDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AMANDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1661911124691793`, 6.017348842219756}, 
           0.05570143050888991],
          "\"JENNIFER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JENNIFER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.679605445673041, 5.812763152337811}, 0.05570143050888991],
          "\"ANGELA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANGELA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.240273969422595, 3.294538442130717}, 0.05570143050888991],
          "\"ETHEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ETHEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.150490349131523, 5.706038430596417}, 0.05570143050888991],
          "\"SANDRA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SANDRA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.810332911515744, 5.814005780601199}, 0.05570143050888991],
          "\"LOUISE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LOUISE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.220199677819779, 5.776796601251533}, 0.05570143050888991],
          "\"KATIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9578274128557434`, 5.954294043242812}, 
           0.05570143050888991],
          "\"HILDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HILDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.1861620991869795`, 5.63598141436367}, 
           0.05570143050888991],
          "\"PHYLLIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PHYLLIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.188557496372201, 5.486614363414871}, 0.05570143050888991],
          "\"DOREEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DOREEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.420836415944293, 2.2431093533062914`}, 
           0.05570143050888991],
          "\"PAULINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAULINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.0858918689478205`, 1.3686553831522517`}, 
           0.05570143050888991],
          "\"LILIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LILIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.158130764593345, 1.687858510106223}, 0.05570143050888991],
          "\"AUDREY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AUDREY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.7872134804660247`, 1.501120672851946}, 
           0.05570143050888991],
          "\"CLARE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLARE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8217485775752578`, 1.6835647125534663`}, 
           0.05570143050888991],
          "\"KELLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KELLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2997933320975226`, 1.6206871164841348`}, 
           0.05570143050888991],
          "\"IVY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IVY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.708578448660259, 1.6276896036343267`}, 
           0.05570143050888991],
          "\"VERA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VERA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.0194579833936253`, 1.769213485184401}, 
           0.05570143050888991],
          "\"BRENDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BRENDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.116707127932865, 1.5251410737698965`}, 
           0.05570143050888991],
          "\"GILLIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GILLIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8676771058475212`, 1.8258680307398885`}, 
           0.05570143050888991],
          "\"NATALIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NATALIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9178189325188169`, 1.391703535041099}, 
           0.05570143050888991],
          "\"VIOLET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VIOLET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9785572225889283`, 1.4912482384743169`}, 
           0.05570143050888991],
          "\"PAMELA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAMELA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.518440375008683, 3.1045688674195313`}, 
           0.05570143050888991],
          "\"SYLVIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SYLVIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.528800617824225, 3.4153936059804266`}, 
           0.05570143050888991],
          "\"ELAINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELAINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8936735482897027`, 2.6065550216699744`}, 
           0.05570143050888991],
          "\"ELLEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELLEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2328261514407464`, 1.4084201232941602`}, 
           0.05570143050888991],
          "\"LESLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LESLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.7321852594693112`, 1.9274867347286038`}, 
           0.05570143050888991],
          "\"CATHERINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CATHERINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.597638796308375, 2.822580191656698}, 0.05570143050888991],
          "\"HAYLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HAYLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9423447173186847`, 1.6152319259806995`}, 
           0.05570143050888991],
          "\"LILY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LILY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3763239273976744`, 1.5033353754050143`}, 
           0.05570143050888991],
          "\"EDNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3188303280332685`, 4.388954662649468}, 
           0.05570143050888991],
          "\"HANNAH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HANNAH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.40785500153673926`, 4.976406801699863}, 
           0.05570143050888991],
          "\"NELLIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NELLIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9721685574452104, 4.878482660544747}, 
           0.05570143050888991],
          "\"BERYL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BERYL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3348605704734469`, 4.957690588079347}, 
           0.05570143050888991],
          "\"WENDY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WENDY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8356128503657425, 4.7757653239935305`}, 
           0.05570143050888991],
          "\"LUCY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LUCY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.3115427379293525, 4.389448564296204}, 
           0.05570143050888991],
          "\"ADA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ADA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.34047356613598767`, 4.867129181171479}, 
           0.05570143050888991],
          "\"DAWN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DAWN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6915615283338803, 5.016260087063726}, 
           0.05570143050888991],
          "\"DONNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DONNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5955992707905655, 5.196042024112448}, 
           0.05570143050888991],
          "\"BEATRICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BEATRICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8526101898675127, 4.630801060380589}, 
           0.05570143050888991],
          "\"OLIVE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "OLIVE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.7973218127784216, 5.309327189878359}, 
           0.05570143050888991],
          "\"CAROLE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CAROLE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.4761450601789994, 4.616543958931642}, 
           0.05570143050888991],
          "\"DANIELLE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DANIELLE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6456923969659738, 4.297023158634975}, 
           0.05570143050888991],
          "\"MAY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5121956560123038, 4.912632616901693}, 
           0.05570143050888991],
          "\"EVELYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EVELYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1335695410431113`, 5.308978399644691}, 
           0.05570143050888991],
          "\"ROSE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROSE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0882241249858984`, 4.718258641356753}, 
           0.05570143050888991],
          "\"MAVIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAVIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5751836336992446, 5.05690184501653}, 0.05570143050888991],
          "\"SALLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SALLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.469824124602396, 5.104041355271252}, 0.05570143050888991],
          "\"KATHERINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATHERINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8111154356254753, 4.307441482229554}, 
           0.05570143050888991],
          "\"IRIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IRIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9639135195187563, 5.351582525329796}, 
           0.05570143050888991],
          "\"JUDITH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JUDITH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5245821466388976, 4.1755742699901655`}, 
           0.05570143050888991],
          "\"MARIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1570296631032222`, 4.93157558571205}, 
           0.05570143050888991],
          "\"ZOE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ZOE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.28107756110461724`, 4.53044812328401}, 
           0.05570143050888991],
          "\"KERRY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KERRY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.4743370203504087, 4.770891969196664}, 
           0.05570143050888991],
          "\"DEBRA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DEBRA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2700113959364694`, 5.216234865895061}, 
           0.05570143050888991],
          "\"MELANIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MELANIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.42525919744296914`, 4.487389538446732}, 
           0.05570143050888991],
          "\"STACEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STACEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.122124740619637, 5.126947335427426}, 0.05570143050888991],
          "\"GERTRUDE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GERTRUDE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6549332117216733, 4.5921800581849155`}, 
           0.05570143050888991],
          "\"MURIEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MURIEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8205650367556543, 4.937147459315856}, 
           0.05570143050888991],
          "\"PAULA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAULA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.7146891851664909, 4.132475827523839}, 
           0.05570143050888991],
          "\"LAUREN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LAUREN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.34263158638482816`, 4.636992912800938}, 
           0.05570143050888991],
          "\"MARION\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARION", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3969266456918503`, 3.1981103616770197`}, 
           0.05570143050888991],
          "\"JOANNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOANNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.3075950641940195, 4.746511591063642}, 
           0.05570143050888991],
          "\"MARINA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARINA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.47854069729822, 2.8454206567419718`}, 
           0.05570143050888991],
          "\"JANICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JANICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6547419541326955, 4.863807700351988}, 
           0.05570143050888991],
          "\"LORRAINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LORRAINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.49381208403271515`, 4.375955918345492}, 
           0.05570143050888991],
          "\"JESSIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JESSIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8840158256227015, 5.228855102061041}, 
           0.05570143050888991],
          "\"PEGGY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PEGGY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.4153070868230553, 4.270270166834985}, 
           0.05570143050888991],
          "\"ROSEMARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROSEMARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.7045673804419805, 5.219838233621284}, 
           0.05570143050888991],
          "\"LYNN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYNN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8761205997475692, 4.462482997072011}, 
           0.05570143050888991],
          "\"ANDREA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANDREA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6299052385371002, 4.714382051200481}, 
           0.05570143050888991],
          "\"FRANCES\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRANCES", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2630543941416832`, 5.08193444559997}, 
           0.05570143050888991],
          "\"SUZANNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SUZANNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8072815412905161, 5.104601698173099}, 
           0.05570143050888991],
          "\"GRACE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GRACE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6318581063100894, 4.462220058202436}, 
           0.05570143050888991],
          "\"JOSEPHINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOSEPHINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9556190288915065, 5.060575878942867}, 
           0.05570143050888991],
          "\"YVONNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "YVONNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.4880864554634101`, 3.5849160660106336`}, 
           0.05570143050888991],
          "\"SOPHIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SOPHIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0179552862225605`, 5.218444329525832}, 
           0.05570143050888991],
          "\"LYNNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYNNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3911945670759331`, 3.5449209449397725`}, 
           0.05570143050888991],
          "\"ANNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2021617590475486`, 3.8687370380391304`}, 
           0.05570143050888991],
          "\"EVA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EVA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.430511042091697, 4.473728563866835}, 0.05570143050888991],
          "\"GWENDOLINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GWENDOLINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.981213223955975, 5.0445610970507975`}, 
           0.05570143050888991],
          "\"JESSICA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JESSICA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.250815849483389, 3.5696337399653917`}, 
           0.05570143050888991],
          "\"NORMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.142566988890562, 3.1686275723500845`}, 
           0.05570143050888991],
          "\"BEVERLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BEVERLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.780141837132228, 3.0186312033407585`}, 
           0.05570143050888991],
          "\"KIRSTY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIRSTY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.093822430629724, 2.906375517885318}, 0.05570143050888991],
          "\"KIMBERLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIMBERLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8310392015705985`, 3.940500392214558}, 
           0.05570143050888991],
          "\"HAZEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HAZEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.9424344226979815`, 4.1837777970750905`}, 
           0.05570143050888991],
          "\"FIONA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FIONA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8075104349989717`, 2.6243579693144916`}, 
           0.05570143050888991],
          "\"MARIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.08749027015602, 3.657082668658042}, 0.05570143050888991],
          
          "\"JENNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JENNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.867566821905859, 5.1563861762750385`}, 
           0.05570143050888991],
          "\"MARILYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARILYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.977474783878852, 4.049251013933451}, 0.05570143050888991],
          "\"DAISY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DAISY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.695603974218695, 3.101816580844254}, 0.05570143050888991],
          "\"NORA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.121059226743537, 3.171509965025869}, 0.05570143050888991],
          "\"NATASHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NATASHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.089215577985817, 3.727051939623592}, 0.05570143050888991],
          "\"MINNIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MINNIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.421474358397713, 2.190761571584863}, 0.05570143050888991],
          "\"FREDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FREDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.894149394496038, 3.1689813972080367`}, 
           0.05570143050888991],
          "\"MANDY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MANDY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.70864795419601, 2.615078784679503}, 0.05570143050888991],
          
          "\"RACHAEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RACHAEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.10375792406919, 3.464526110277083}, 0.05570143050888991],
          
          "\"KATHRYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATHRYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9173987331348583`, 2.7659584969191062`}, 
           0.05570143050888991],
          "\"NANCY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NANCY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5143437045371493`, 2.631688889708302}, 
           0.05570143050888991],
          "\"RUTH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RUTH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8937742888023044`, 3.511704774846602}, 
           0.05570143050888991],
          "\"JAYNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JAYNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.480532646954007, 3.898639297232747}, 0.05570143050888991],
          "\"DIANA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DIANA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.271285278493838, 3.080504665143418}, 0.05570143050888991],
          "\"MARIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5936973336907365`, 4.134567590393875}, 
           0.05570143050888991],
          "\"ELEANOR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELEANOR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.383769973042954, 3.1431328987805087`}, 
           0.05570143050888991],
          "\"VERONICA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VERONICA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.66708201965197, 3.919179018307792}, 0.05570143050888991],
          
          "\"SARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.7999915408060856`, 4.0944452232614905`}, 
           0.05570143050888991],
          "\"ALEXANDRA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALEXANDRA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.135393023043709, 4.073502578805177}, 0.05570143050888991],
          "\"LOUISA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LOUISA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.280637293984499, 3.4155044991217074`}, 
           0.05570143050888991],
          "\"JODIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JODIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.9939189361277716`, 3.3272009351431175`}, 
           0.05570143050888991],
          "\"DORA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DORA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.405503519385941, 3.270043524053674}, 0.05570143050888991],
          "\"DAPHNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DAPHNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.070678820145944, 3.9323075706675006`}, 
           0.05570143050888991],
          "\"TERESA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TERESA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.239001584183471, 3.956164829537265}, 0.05570143050888991],
          "\"JULIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JULIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.42975593123907, 3.530715126116566}, 0.05570143050888991],
          
          "\"NORAH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORAH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5308128083228962`, 3.684012744192402}, 
           0.05570143050888991],
          "\"HEATHER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HEATHER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.620491637143561, 2.635471976196063}, 0.05570143050888991],
          "\"KIM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.727779462485876, 4.205311459421361}, 0.05570143050888991],
          "\"JEMMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEMMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.164943754401822, 3.796129407611249}, 0.05570143050888991],
          "\"THELMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "THELMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2435476242779595`, 3.6993666739913427`}, 
           0.05570143050888991],
          "\"CARLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CARLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.3237636738212215`, 3.7328502920809923`}, 
           0.05570143050888991],
          "\"IDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.401750579498126, 3.6513262470434413`}, 
           0.05570143050888991],
          "\"CLARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.9698408995471217`, 3.8055730640819547`}, 
           0.05570143050888991],
          "\"GLORIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLORIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.448791131927424, 4.090933904285507}, 0.05570143050888991],
          "\"HOLLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HOLLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8550673799758357`, 2.9392153854630445`}, 
           0.05570143050888991],
          "\"HILARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HILARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9310109034488097`, 3.135898153365598}, 
           0.05570143050888991],
          "\"MELISSA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MELISSA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.942715326111345, 3.3644759808467883`}, 
           0.05570143050888991],
          "\"MARTHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARTHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.312071324715001, 3.8538501104467087`}, 
           0.05570143050888991],
          "\"CYNTHIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CYNTHIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.2407252861086775`, 2.959539268956114}, 
           0.05570143050888991],
          "\"BERTHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BERTHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.7884955443447814`, 3.699892149571761}, 
           0.05570143050888991],
          "\"KATY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.45271978013659, 3.3929475838811536`}, 
           0.05570143050888991],
          "\"LILLIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LILLIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.011991317923822, 3.036747773860446}, 0.05570143050888991],
          "\"CHERYL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHERYL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.969792695888759, 3.226794349488862}, 0.05570143050888991],
          "\"RUBY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RUBY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.303747585734906, 4.009134785783969}, 0.05570143050888991],
          "\"NAOMI\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NAOMI", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.0523930015783991, 3.706412131116615}, 
           0.05570143050888991],
          "\"BESSIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BESSIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.2573432638898039, 3.024065950763953}, 
           0.05570143050888991],
          "\"GAIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GAIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.979892822619038, 3.311264616838231}, 0.05570143050888991],
          "\"MILDRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MILDRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.149534950406232, 3.104895596389688}, 0.05570143050888991],
          "\"PENELOPE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PENELOPE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.16375040268722163`, 3.277185090685656}, 
           0.05570143050888991],
          "\"CHARLENE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHARLENE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.32390662595910724`, 3.4694697204244216`}, 
           0.05570143050888991],
          "\"JADE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JADE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2521088624868315`, 2.7009640096630276`}, 
           0.05570143050888991],
          "\"CHRISTINA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHRISTINA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.12229625603424887`, 3.787375236833959}, 
           0.05570143050888991],
          "\"ANNETTE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNETTE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.10083672655948739`, 3.601472315531462}, 
           0.05570143050888991],
          "\"JEANETTE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEANETTE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[DiskBox[{0., 3.502118652485}, 0.05570143050888991],
          "\"ESTHER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ESTHER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.175365870848454, 3.080538658374356}, 0.05570143050888991],
          "\"CAROLYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CAROLYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.2612918723690236, 3.712739580181321}, 
           0.05570143050888991],
          "\"HARRIET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HARRIET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.3113085352775964, 3.298363826840268}, 
           0.05570143050888991],
          "\"ANITA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANITA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.14917822500752154`, 3.4254397730806256`}, 
           0.05570143050888991],
          "\"GERALDINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GERALDINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.049757259634716, 3.2075581295494073`}, 
           0.05570143050888991],
          "\"BRIDGET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BRIDGET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.32668261120661146`, 3.155053482431751}, 
           0.05570143050888991],
          "\"GEORGINA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GEORGINA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.2283345869280864, 3.57572093998461}, 0.05570143050888991],
          "\"LINDSEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LINDSEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.0020333003880268485`, 3.36159621491312}, 
           0.05570143050888991],
          "\"KAY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KAY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0774078703579866`, 2.762021135226445}, 
           0.05570143050888991],
          "\"STELLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STELLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.5671950887519348`, 2.2865173398017777`}, 
           0.05570143050888991],
          "\"GEMMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GEMMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1777948334100428`, 2.6217420157641214`}, 
           0.05570143050888991],
          "\"NICHOLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NICHOLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3803050652017146`, 2.477758651764651}, 
           0.05570143050888991],
          "\"AIMEE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AIMEE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.109385498151434, 2.4917851013821215`}, 
           0.05570143050888991],
          "\"HEIDI\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HEIDI", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1688366839844044`, 2.8533041468787195`}, 
           0.05570143050888991],
          "\"MILLICENT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MILLICENT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3442796757106674`, 2.620655965758532}, 
           0.05570143050888991],
          "\"MONICA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MONICA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0093171896476711`, 2.342119382412407}, 
           0.05570143050888991],
          "\"THERESA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "THERESA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.654812508403634, 2.1482345319902834`}, 
           0.05570143050888991],
          "\"MARGERY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARGERY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.136379271804913, 2.10179967534156}, 0.05570143050888991],
          
          "\"MAXINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAXINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.398893722561458, 2.337537030955006}, 0.05570143050888991],
          "\"TANYA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TANYA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0445336068141367`, 2.2145012697976156`}, 
           0.05570143050888991],
          "\"CARLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CARLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.5178886194675658`, 2.070324688298257}, 
           0.05570143050888991],
          "\"FANNY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FANNY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.392985116128974, 2.0172300490268786`}, 
           0.05570143050888991],
          "\"JOY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2701560228774893`, 2.170868016397018}, 
           0.05570143050888991],
          "\"LYDIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYDIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3975982075832798`, 2.18479886837523}, 
           0.05570143050888991],
          "\"ALMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0010160736343976`, 2.6224015147170086`}, 
           0.05570143050888991],
          "\"GLENYS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLENYS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2584534476124616`, 2.0186966525050893`}, 
           0.05570143050888991],
          "\"DEBBIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DEBBIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9660759676933837, 2.472803415911055}, 
           0.05570143050888991],
          "\"JENNY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JENNY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.307329914043703, 2.8190553153022355`}, 
           0.05570143050888991],
          "\"BLANCHE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BLANCHE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2203116837267625`, 2.403725156264022}, 
           0.05570143050888991],
          "\"VIVIENNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VIVIENNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9521184939841647`, 2.973042113831754}, 
           0.05570143050888991],
          "\"TARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.0648042207302373`, 2.715105008020585}, 
           0.05570143050888991],
          "\"MIRIAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MIRIAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1743389460149922`, 2.274227348673222}, 
           0.05570143050888991],
          "\"GLYNIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLYNIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.449660611658213, 4.002162346020976}, 0.05570143050888991],
          "\"CLAIR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLAIR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.07605019362437, 4.7921768996926755`}, 
           0.05570143050888991],
          "\"LYNDSEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYNDSEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.108569302428034, 4.289256406799745}, 0.05570143050888991],
          "\"SONIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SONIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.162718825972419, 4.485721789141594}, 0.05570143050888991],
          "\"MOLLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MOLLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.217602994975898, 3.9554024603260465`}, 
           0.05570143050888991],
          "\"ELLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.069766489239364, 3.4849957919804195`}, 
           0.05570143050888991],
          "\"CHLOE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHLOE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.839643628137155, 4.449570510691226}, 0.05570143050888991],
          "\"SYBIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SYBIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.339445919688016, 4.06213114401514}, 0.05570143050888991],
          
          "\"LEAH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LEAH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.930031394773706, 3.334106453459885}, 0.05570143050888991],
          "\"TONI\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TONI", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.29515948689261, 3.6711682743193585`}, 
           0.05570143050888991],
          "\"WILLIAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WILLIAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.384969987960359, 4.4221485605780035`}, 
           0.05570143050888991],
          "\"JOHN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOHN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.497997598777275, 4.020280573460792}, 0.05570143050888991],
          "\"PAUL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAUL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.157390138415499, 4.132924398807478}, 0.05570143050888991],
          "\"MARK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.202438494892904, 3.420668394795633}, 0.05570143050888991],
          "\"JAMES\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JAMES", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.722960004274572, 4.310322961527341}, 0.05570143050888991],
          "\"MICHAEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MICHAEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.920383828516393, 4.5673503536250575`}, 
           0.05570143050888991],
          "\"STEPHEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STEPHEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.348361489395701, 3.913040092783218}, 0.05570143050888991],
          "\"ANDREW\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANDREW", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.724336630874012, 3.5382502837181464`}, 
           0.05570143050888991],
          "\"DANIEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DANIEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.04286578353353, 3.992902738035645}, 0.05570143050888991],
          
          "\"ARTHUR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ARTHUR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.313344466056199, 3.511235759908192}, 0.05570143050888991],
          "\"ROBERT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROBERT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.246250065585384, 3.7936881591370293`}, 
           0.05570143050888991],
          "\"RICHARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RICHARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.49221300887856, 4.6428349632936685`}, 
           0.05570143050888991],
          "\"RONALD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RONALD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.872934999963933, 3.9116529007241962`}, 
           0.05570143050888991],
          "\"ANTHONY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANTHONY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.99589646107202, 4.4221152403054855`}, 
           0.05570143050888991],
          "\"MATTHEW\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MATTHEW", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.030576710727809, 3.6677971129569764`}, 
           0.05570143050888991],
          "\"CHARLES\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHARLES", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.402875651459135, 4.206617655166467}, 0.05570143050888991],
          "\"FREDERICK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FREDERICK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.5092294802897115`, 4.155850833215487}, 
           0.05570143050888991],
          "\"KENNETH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KENNETH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.826626790601779, 4.124531057816174}, 0.05570143050888991],
          "\"ALBERT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALBERT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.182830794179319, 4.711163026407839}, 0.05570143050888991],
          "\"ALAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.909356644316942, 3.531218243022184}, 0.05570143050888991],
          "\"IAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.940971265755323, 4.7371375157582545`}, 
           0.05570143050888991],
          "\"SIMON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SIMON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.051834577147967, 4.623993472853848}, 0.05570143050888991],
          "\"ERNEST\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ERNEST", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.979285916089861, 4.202026505373777}, 0.05570143050888991],
          "\"ALFRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALFRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.765187881582182, 4.849704246674317}, 0.05570143050888991],
          "\"EDWARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDWARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.1647163047764835`, 3.6052812946290684`}, 
           0.05570143050888991],
          "\"JOSEPH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOSEPH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.256449545263353, 4.602101352336273}, 0.05570143050888991],
          "\"LEE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LEE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.450823132744214, 4.3296976212458285`}, 
           0.05570143050888991],
          "\"ADAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ADAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.7332729528748025`, 4.739823640833926}, 
           0.05570143050888991],
          "\"ROGER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROGER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.073475795754592, 3.3446634144767353`}, 
           0.05570143050888991],
          "\"HAROLD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HAROLD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.243126257987642, 4.3742895738521925`}, 
           0.05570143050888991],
          "\"DEREK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DEREK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.5865952470127995`, 4.480947617956097}, 
           0.05570143050888991],
          "\"KEITH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KEITH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.813630168216543, 3.719486279249364}, 0.05570143050888991],
          "\"FRANK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRANK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.082709938405188, 3.811335885439358}, 0.05570143050888991],
          "\"LESLIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LESLIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.7900103730083154`, 3.3864915489480705`}, 
           0.05570143050888991],
          "\"RAYMOND\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RAYMOND", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.726461226363466, 4.580391401353141}, 0.05570143050888991],
          "\"COLIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "COLIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.271976368383317, 4.217171575296142}, 0.05570143050888991],
          "\"KEVIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KEVIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.417303205744281, 3.641247907462545}, 0.05570143050888991],
          "\"DARREN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DARREN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.889499163828672, 4.854877707567038}, 0.05570143050888991],
          "\"HENRY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HENRY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.436827334648331, 3.776543704867336}, 0.05570143050888991],
          "\"PHILIP\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PHILIP", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.36669655127135, 4.539807801375816}, 0.05570143050888991],
          
          "\"GARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.487593683926255, 3.8913864754248957`}, 
           0.05570143050888991],
          "\"BENJAMIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BENJAMIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.568781576929737, 4.791634583666779}, 0.05570143050888991],
          "\"STANLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STANLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5813031800360937`, 2.017544372999396}, 
           0.05570143050888991],
          "\"STEVEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STEVEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.086947054882777, 1.519870605989537}, 0.05570143050888991],
          "\"ERIC\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ERIC", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.18209667336294, 1.4140793613221037`}, 
           0.05570143050888991],
          "\"MARTIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARTIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.925138690548266, 1.4347354403711694`}, 
           0.05570143050888991],
          "\"WALTER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WALTER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8679255336938736`, 1.2632213976747777`}, 
           0.05570143050888991],
          "\"GRAHAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GRAHAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.979849145266797, 1.6416616732844578`}, 
           0.05570143050888991],
          "\"NICHOLAS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NICHOLAS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.46363350817925, 1.8072214144657355`}, 
           0.05570143050888991],
          "\"LEONARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LEONARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.349911798840048, 1.7078513085738685`}, 
           0.05570143050888991],
          "\"BARRY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BARRY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.471555947280286, 1.068618203063001}, 0.05570143050888991],
          "\"HERBERT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HERBERT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.295671362053043, 1.5656152959568475`}, 
           0.05570143050888991],
          "\"GORDON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GORDON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.026224270844277, 1.194980682649728}, 0.05570143050888991],
          "\"NORMAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORMAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.19088866799243, 1.6685142500137031`}, 
           0.05570143050888991],
          "\"NEIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NEIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8432883078061626`, 1.6652882090850187`}, 
           0.05570143050888991],
          "\"NIGEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NIGEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.274060087359451, 1.3715767941168013`}, 
           0.05570143050888991],
          "\"MALCOLM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MALCOLM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.7164694653507095`, 1.2254168366564895`}, 
           0.05570143050888991],
          "\"TIMOTHY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TIMOTHY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.047638369107941, 0.4111912972831533}, 
           0.05570143050888991],
          "\"STUART\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STUART", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.025537181086292, 1.3306997299521077`}, 
           0.05570143050888991],
          "\"GEOFFREY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GEOFFREY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.437201726066682, 1.4788486729610324`}, 
           0.05570143050888991],
          "\"ALEXANDER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALEXANDER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.272361280221109, 1.8734433678623728`}, 
           0.05570143050888991],
          "\"CYRIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CYRIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5869571021565627`, 1.5841419622038597`}, 
           0.05570143050888991],
          "\"SIDNEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SIDNEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.403274340812292, 1.4813956224851554`}, 
           0.05570143050888991],
          "\"FRANCIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRANCIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.124709468232238, 1.8263122936120195`}, 
           0.05570143050888991],
          "\"RYAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RYAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6289533279741266`, 1.2779280947152851`}, 
           0.05570143050888991],
          "\"PERCY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PERCY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.455341129301084, 1.628651384177883}, 0.05570143050888991],
          "\"LUKE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LUKE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4177692935803883`, 1.2962703706061052`}, 
           0.05570143050888991],
          "\"JACK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JACK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6759923074530665`, 1.446008295597642}, 
           0.05570143050888991],
          "\"TREVOR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TREVOR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.310076412808286, 1.3736411898265515`}, 
           0.05570143050888991],
          "\"ADRIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ADRIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8058864883790147`, 1.1742553557001956`}, 
           0.05570143050888991],
          "\"JAMIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JAMIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.377534460488725, 1.9508173489446283`}, 
           0.05570143050888991],
          "\"WILFRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WILFRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5908997950331663`, 1.1746006289113988`}, 
           0.05570143050888991],
          "\"PATRICK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PATRICK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8167824403242876`, 1.41118222984997}, 
           0.05570143050888991],
          "\"SCOTT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SCOTT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.184505427359471, 1.2669661240102115`}, 
           0.05570143050888991],
          "\"SAMUEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SAMUEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2290791913113557`, 1.0785109381376787`}, 
           0.05570143050888991],
          "\"WAYNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WAYNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.529183377782783, 0.3459540572094859}, 
           0.05570143050888991],
          "\"CECIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CECIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.855260453944898, 0.3303523773370447}, 
           0.05570143050888991],
          "\"GARETH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GARETH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.632165776231189, 0.11103641985856338`}, 
           0.05570143050888991],
          "\"SEAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SEAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.623085392018389, 0.24813975997412197`}, 
           0.05570143050888991],
          "\"HORACE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HORACE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.691707167723954, 0.5505356231454419}, 
           0.05570143050888991],
          "\"BERNARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BERNARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.189233266615462, 0.25849377658537387`}, 
           0.05570143050888991],
          "\"FRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.0191831405526632`, 0.4113205932000388}, 
           0.05570143050888991],
          "\"EDWIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDWIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3710776248337075`, 0.2999523784538045}, 
           0.05570143050888991],
          "\"GERALD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GERALD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.167773717230054, 0.4385212239551035}, 
           0.05570143050888991],
          "\"SHAUN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHAUN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.7716537203514955`, 0.4302322473870501}, 
           0.05570143050888991],
          "\"CLIFFORD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLIFFORD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3108059160742314`, 0.15061590799352498`}, 
           0.05570143050888991],
          "\"MAURICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAURICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.967013800042194, 0.17293923908540476`}, 
           0.05570143050888991],
          "\"CLIVE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLIVE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.834010241282577, 1.990508425310403}, 0.05570143050888991],
          "\"BEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8663225857892227`, 0.3162379741460035}, 
           0.05570143050888991],
          "\"ANTONY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANTONY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.033793051399473, 0.27333934580722286`}, 
           0.05570143050888991],
          "\"VICTOR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VICTOR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1533319156711497`, 0.12824719894068837`}, 
           0.05570143050888991],
          "\"JUSTIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JUSTIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.901323876584327, 0.46408514083271557`}, 
           0.05570143050888991],
          "\"JEFFREY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEFFREY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.5778245924135943`, 0.4688222282786785}, 
           0.05570143050888991],
          "\"OLIVER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "OLIVER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5170786709362716`, 0.04384570570227053}, 
           0.05570143050888991],
          "\"EDGAR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDGAR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.733477488615379, 0.3594720657048902}, 
           0.05570143050888991],
          "\"CHRISTIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHRISTIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.764343642195909, 0.2002421538590511}, 
           0.05570143050888991],
          "\"ASHLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ASHLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3889215317152495`, 0.03714367247629635}, 
           0.05570143050888991],
          "\"KARL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KARL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.852030977769403, 0.09540886872204357}, 
           0.05570143050888991],
          "\"AARON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AARON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8913260505315477`, 0.5169506416851912}, 
           0.05570143050888991],
          "\"MARC\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARC", "Tooltip"]& ], 
        TagBox[
         TooltipBox[DiskBox[{3.2711795821890868`, 0.}, 0.05570143050888991],
          "\"MOHAMMED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MOHAMMED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4757292291894126`, 0.17919497776812854`}, 
           0.05570143050888991],
          "\"HUGH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HUGH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.131451414038333, 0.017911701145744807`}, 
           0.05570143050888991],
          "\"RUSSELL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RUSSELL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.62996839398561, 0.3358079206113249}, 0.05570143050888991],
          "\"GAVIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GAVIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.760508776801317, 0.5082595388835616}, 
           0.05570143050888991],
          "\"LAWRENCE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LAWRENCE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.57736217973407, 0.4804479081603814}, 0.05570143050888991],
          "\"LIAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LIAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3532423647517455`, 0.4616839528821379}, 
           0.05570143050888991],
          "\"ROBIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROBIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.81669742895982, 0.2197850566076167}, 0.05570143050888991],
          "\"PHILLIP\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PHILLIP", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.687649817279081, 0.20397739499959755`}, 
           0.05570143050888991],
          "\"NATHAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NATHAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9942706618603867`, 0.04006566250262589}, 
           0.05570143050888991],
          "\"DENIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DENIS", "Tooltip"]& ]}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{3.676262288071928*^9, 3.676271903307333*^9, 
  3.6775868839898643`*^9, 3.677586971971512*^9, 3.677821312467638*^9, 
  3.677822900405477*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell["\<\
While the multiple edges between nodes do provide extremely useful \
information (that are multiple interactions in a dyad), multigraph are not \
thoroughly supported throughout Mathematica at present and the legibility of \
the graph is reduced.\
\>", "Text",
 CellChangeTimes->{{3.6762621482632103`*^9, 3.676262251708001*^9}, {
  3.676262467060316*^9, 3.6762624829086733`*^9}}],

Cell["\<\
Use SimpleGraph to remove multiple edges between individuals and store this \
against another symbol, note that you will need to reinsert the VertexLabels.\
\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676262493833435*^9, 3.6762625133628902`*^9}, {
  3.676262586591743*^9, 3.676262598559265*^9}, {3.676267332405549*^9, 
  3.676267346590473*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"simpleDirected", "=", 
  RowBox[{"SimpleGraph", "[", 
   RowBox[{"g1", ",", 
    RowBox[{"VertexLabels", "\[Rule]", 
     RowBox[{"Placed", "[", 
      RowBox[{"\"\<Name\>\"", ",", "Tooltip"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.676263765561439*^9, 3.6762637732094507`*^9}, {
  3.676267310523295*^9, 3.6762673279516077`*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "MARY", "FLORENCE", "JEAN", "JULIE", "CLAIRE", "LAURA", "DORIS", "JOAN",
        "CHRISTINE", "KAREN", "NICOLA", "DOROTHY", "JOYCE", "JACQUELINE", 
       "EMMA", "KATHLEEN", "JANET", "LISA", "ANNIE", "SHEILA", "ANN", 
       "JOANNE", "ELSIE", "BARBARA", "CAROL", "JANE", "MICHELLE", "VICTORIA", 
       "ALICE", "IRENE", "HELEN", "SAMANTHA", "JUNE", "MAUREEN", "DIANE", 
       "RACHEL", "WINIFRED", "EILEEN", "SHIRLEY", "ANNE", "SHARON", "AMY", 
       "GLADYS", "BETTY", "VALERIE", "AMANDA", "JENNIFER", "ANGELA", "ETHEL", 
       "SANDRA", "LOUISE", "KATIE", "HILDA", "PHYLLIS", "DOREEN", "PAULINE", 
       "LILIAN", "AUDREY", "CLARE", "KELLY", "IVY", "VERA", "BRENDA", 
       "GILLIAN", "NATALIE", "VIOLET", "PAMELA", "SYLVIA", "ELAINE", "ELLEN", 
       "LESLEY", "CATHERINE", "HAYLEY", "LILY", "EDNA", "HANNAH", "NELLIE", 
       "BERYL", "WENDY", "LUCY", "ADA", "DAWN", "DONNA", "BEATRICE", "OLIVE", 
       "CAROLE", "DANIELLE", "MAY", "EVELYN", "ROSE", "MAVIS", "SALLY", 
       "KATHERINE", "IRIS", "JUDITH", "MARIA", "ZOE", "KERRY", "DEBRA", 
       "MELANIE", "STACEY", "GERTRUDE", "MURIEL", "PAULA", "LAUREN", "MARION",
        "JOANNA", "MARINA", "JANICE", "LORRAINE", "JESSIE", "PEGGY", 
       "ROSEMARY", "LYNN", "ANDREA", "FRANCES", "SUZANNE", "GRACE", 
       "JOSEPHINE", "YVONNE", "SOPHIE", "LYNNE", "ANNA", "EVA", "GWENDOLINE", 
       "JESSICA", "NORMA", "BEVERLEY", "KIRSTY", "KIMBERLEY", "HAZEL", 
       "FIONA", "MARIE", "JENNA", "MARILYN", "DAISY", "NORA", "NATASHA", 
       "MINNIE", "FREDA", "MANDY", "RACHAEL", "KATHRYN", "NANCY", "RUTH", 
       "JAYNE", "DIANA", "MARIAN", "ELEANOR", "VERONICA", "SARA", "ALEXANDRA",
        "LOUISA", "JODIE", "DORA", "DAPHNE", "TERESA", "JULIA", "NORAH", 
       "HEATHER", "KIM", "JEMMA", "THELMA", "CARLY", "IDA", "CLARA", "GLORIA",
        "HOLLY", "HILARY", "MELISSA", "MARTHA", "CYNTHIA", "BERTHA", "KATY", 
       "LILLIAN", "CHERYL", "RUBY", "NAOMI", "BESSIE", "GAIL", "MILDRED", 
       "PENELOPE", "CHARLENE", "JADE", "CHRISTINA", "ANNETTE", "JEANETTE", 
       "ESTHER", "CAROLYN", "HARRIET", "ANITA", "GERALDINE", "BRIDGET", 
       "GEORGINA", "LINDSEY", "KAY", "STELLA", "GEMMA", "NICHOLA", "AIMEE", 
       "HEIDI", "MILLICENT", "MONICA", "THERESA", "MARGERY", "MAXINE", 
       "TANYA", "CARLA", "FANNY", "JOY", "LYDIA", "ALMA", "GLENYS", "DEBBIE", 
       "JENNY", "BLANCHE", "VIVIENNE", "TARA", "MIRIAM", "GLYNIS", "CLAIR", 
       "LYNDSEY", "SONIA", "MOLLY", "ELLA", "CHLOE", "SYBIL", "LEAH", "TONI", 
       "WILLIAM", "JOHN", "PAUL", "MARK", "JAMES", "MICHAEL", "STEPHEN", 
       "ANDREW", "DANIEL", "ARTHUR", "ROBERT", "RICHARD", "RONALD", "ANTHONY",
        "MATTHEW", "CHARLES", "FREDERICK", "KENNETH", "ALBERT", "ALAN", "IAN",
        "SIMON", "ERNEST", "ALFRED", "EDWARD", "JOSEPH", "LEE", "ADAM", 
       "ROGER", "HAROLD", "DEREK", "KEITH", "FRANK", "LESLIE", "RAYMOND", 
       "COLIN", "KEVIN", "DARREN", "HENRY", "PHILIP", "GARY", "BENJAMIN", 
       "STANLEY", "STEVEN", "ERIC", "MARTIN", "WALTER", "GRAHAM", "NICHOLAS", 
       "LEONARD", "BARRY", "HERBERT", "GORDON", "NORMAN", "NEIL", "NIGEL", 
       "MALCOLM", "TIMOTHY", "STUART", "GEOFFREY", "ALEXANDER", "CYRIL", 
       "SIDNEY", "FRANCIS", "RYAN", "PERCY", "LUKE", "JACK", "TREVOR", 
       "ADRIAN", "JAMIE", "WILFRED", "PATRICK", "SCOTT", "SAMUEL", "WAYNE", 
       "CECIL", "GARETH", "SEAN", "HORACE", "BERNARD", "FRED", "EDWIN", 
       "GERALD", "SHAUN", "CLIFFORD", "MAURICE", "CLIVE", "BEN", "ANTONY", 
       "VICTOR", "JUSTIN", "JEFFREY", "OLIVER", "EDGAR", "CHRISTIAN", 
       "ASHLEY", "KARL", "AARON", "MARC", "MOHAMMED", "HUGH", "RUSSELL", 
       "GAVIN", "LAWRENCE", "LIAM", "ROBIN", "PHILLIP", "NATHAN", 
       "DENIS"}, {CompressedData["
1:eJxN1WV4FUcUANBdgtt7eIIE8gJ5WIDgrklIcELdS700UG8ppW3qlJRChbp7
qVE36u5ulLq7u+2y533w434n986d2Z3ZSVI0f1HNwgZBEKwOgyC2IopjeAHX
8gqmeEIUbaJ5HcLEfKbUc+MLmA2TeSfL28mPl7eXV8orPedans5jjQ/Uv1z9
TN7Ien318uvlg7xnKTuxPwdY94YoNkTxLt/jB/yQH/ETfsav+C2/53L+wJ/4
M3/hb/yTf/MfhmFiAzZkC7Zia6bs62LncXYUM6KYyVmczblMcQtuyW25PXfg
TtyZu3A37s49uRf35j5cwIU8hIfycB7BCnEqb1HfSn61fOso8oNN9/hE55nn
nBo5p4x6xr3J5X/wyyiyUVzHtUxxvedlPSdrnVx+Ci9Vj10ZxWN8nBV8kk/x
aab4DPNZyiyfZ4Yv8EW+xHV8ma/wVb7G1/kGK/kW1/OdzfYQu5rnOcev+atz
KAyT3ip5lT28bd7NzvUA895nc+OXy78zv2uY9G+j3sT3PV/e1Hdvpm+Rdc7w
nP30BeZdZt0++g+S3x1Z4nvE3so7eCfvYq7/Ht7Hdbyfxazmg3yYjzDLR733
Eme+RP0B9e242Phi71/iHL4wXmPfZcZ7RjHe/Y3HDwyS/xl5+v7V1zdMnnev
c1yhvsK8+VHUBZv+z9R5jzrrpJ3zOfKW1ntI/5HW2cO6xf5ud/Q95hg/LIqR
UYziaI7hWI5jhllO4ERO4mROYYoVrORUVrGa0zfrjV1m/8vsp5vv8Kn6m/az
r/6z9PW27yL93+jbVd9V8beLxgaHiUM4lMM4giM5mmM4luM5gRNZyEmczCks
Z5n3ybJSfSqrWM2Mvmny6ZzBmbl5+uo5W30uazgvTM683DmVO6dy51zuXHP1
K6MoiPIezrmAbd3P03zD8Z5bEW78E7HxdyK2IRuxMZuwKZuxOVuyFVNsw7bs
wI7sxHwWsDO7sCu7sZDd2YNFzLCYPVnCLHszj33Yl/1ZygEcyEEs42AO4VAO
5wjfMf45vv+f8y/fb413WyM/Wn67Of30/2j8Il7oHnSOYmn081FB4knGl5r3
u+fvqH6NemP3pDt7hclZ3RYk92SOehf3pZf3aWd8lPt1iXWPM54OkvuW9ty0
8diV3MB4/bT10ua3Nn+a+Qeb96x1bpI/YbxWvVa91no5Z4X+79pPxu/ZOA6P
okWQ3Ou47z/rzrPuueofq+/vPdtzmL5V9rPKezwn7xfF/7iKHnY=
       "], Null}, {
      VertexLabels -> {
         Placed["Name", Tooltip]}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[0.018544322907928002`], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.5001357454627087`, 6.002609917393925}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.576053100782418, 5.895842978123906}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9482352292499296`, 6.097613755961862}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9151738067450674`, 5.438187776093255}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9567074804668376`, 5.823109470968475}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.4311982915193564`, 5.6103629903875545`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.6547283295530573`, 5.470141876035472}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.3291315986460237`, 5.564923358575424}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         4.785953480575827, 4.792650979773929}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.6086243433705767`, 5.696340227043807}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.358444073478961, 5.720908552907942}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.104039957029104, 5.853325291739553}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.058154943199654, 6.028434144407518}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.911581255082521, 5.666345199323741}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.268654685620686, 5.835784189884132}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.740113935424552, 5.607079548351958}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.067717251909292, 5.577496225407183}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.1901160987714365`, 5.367156079183836}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.464302487648301, 5.810836314891446}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.352267967999519, 3.8957326391109772`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.5019330232187524`, 5.409922858738638}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.2683486202440615`, 6.000228186556448}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.4965891867976207`, 5.591165272469905}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.5973121055785473`, 6.06625200222989}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.546530712831092, 5.573524194826402}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.8188699679133604`, 6.085705867024174}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.3210376704601803`, 5.334694823182663}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.782379851104637, 5.965672351271724}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.254307918443584, 5.5496448155168885`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         1.8480168639532184`, 4.371045396255162}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {2.47628317627636,
          5.3971524682153955`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.7028347408065194`, 6.093244776759786}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         1.015069443528973, 3.528774386330581}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {2.3055152107392, 
         5.888803933863012}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.331821291441601, 5.716887595061483}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.4857107529680147`, 5.738563878031519}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.4013526182698466`, 5.880377038950135}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.354722758719908, 5.3840968980770985`}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.2825463330866027`, 3.986538935106582}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.3862080289961396`, 5.96445637275853}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.1661911124691793`, 6.017348842219756}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.679605445673041, 5.812763152337811}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         4.240273969422595, 3.294538442130717}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         3.150490349131523, 5.706038430596417}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.810332911515744, 5.814005780601199}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.220199677819779, 5.776796601251533}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.9578274128557434`, 5.954294043242812}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.1861620991869795`, 5.63598141436367}}, 0.05570143050888991], 
        ArrowBox[{{2.8312252633985353`, 5.035038489761629}, {
         2.188557496372201, 5.486614363414871}}, 0.05570143050888991], 
        ArrowBox[{{2.5001357454627087`, 6.002609917393925}, {
         2.576053100782418, 5.895842978123906}}, 0.05570143050888991], 
        ArrowBox[{{5.241668688810895, 5.4646874707731214`}, {
         4.785953480575827, 4.792650979773929}}, 0.05570143050888991], 
        ArrowBox[{{2.352267967999519, 3.8957326391109772`}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         1.8480168639532184`, 4.371045396255162}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {1.597638796308375, 
         2.822580191656698}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.0523930015783991,
          3.706412131116615}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.2573432638898039,
          3.024065950763953}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.149534950406232, 
         3.104895596389688}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.16375040268722163`, 3.277185090685656}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.32390662595910724`, 3.4694697204244216`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         2.2521088624868315`, 2.7009640096630276`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.12229625603424887`, 3.787375236833959}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.10083672655948739`, 3.601472315531462}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0., 
         3.502118652485}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {1.175365870848454, 
         3.080538658374356}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.2612918723690236,
          3.712739580181321}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.3113085352775964,
          3.298363826840268}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.14917822500752154`, 3.4254397730806256`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.049757259634716, 
         3.2075581295494073`}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.32668261120661146`, 3.155053482431751}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {0.2283345869280864,
          3.57572093998461}}, 0.05570143050888991], 
        ArrowBox[{{1.015069443528973, 3.528774386330581}, {
         0.0020333003880268485`, 3.36159621491312}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {
         1.9310109034488097`, 3.135898153365598}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {2.942715326111345,
          3.3644759808467883`}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {2.969792695888759,
          3.226794349488862}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {1.979892822619038,
          3.311264616838231}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {
         1.9521184939841647`, 2.973042113831754}}, 0.05570143050888991], 
        ArrowBox[{{2.4780412190946257`, 3.04953873904153}, {
         2.0648042207302373`, 2.715105008020585}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.0858918689478205`, 1.3686553831522517`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.158130764593345, 1.687858510106223}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.7872134804660247`, 1.501120672851946}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.8217485775752578`, 1.6835647125534663`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.2997933320975226`, 1.6206871164841348`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.708578448660259, 1.6276896036343267`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.0194579833936253`, 1.769213485184401}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.116707127932865, 1.5251410737698965`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.8676771058475212`, 1.8258680307398885`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.9178189325188169`, 1.391703535041099}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.9785572225889283`, 1.4912482384743169`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.7820472184635174`, 3.011445940856201}, {3.528800617824225, 
         3.4153936059804266`}}], 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.8936735482897027`, 2.6065550216699744`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.2328261514407464`, 1.4084201232941602`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.7321852594693112`, 1.9274867347286038`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.597638796308375, 2.822580191656698}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         1.9423447173186847`, 1.6152319259806995`}}, 0.05570143050888991], 
        ArrowBox[{{2.420836415944293, 2.2431093533062914`}, {
         2.3763239273976744`, 1.5033353754050143`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.1675898153049924`, 2.6470570184353863`}, {2.420836415944293, 
         2.2431093533062914`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.8936735482897027`, 2.6065550216699744`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {2.47854069729822,
          2.8454206567419718`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.2021617590475486`, 3.8687370380391304`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.430511042091697, 4.473728563866835}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.250815849483389, 3.5696337399653917`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.142566988890562, 3.1686275723500845`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.780141837132228, 3.0186312033407585`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.093822430629724, 2.906375517885318}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.8310392015705985`, 3.940500392214558}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.9424344226979815`, 4.1837777970750905`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.8075104349989717`, 2.6243579693144916`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {4.08749027015602,
          3.657082668658042}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.977474783878852, 4.049251013933451}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.695603974218695, 3.101816580844254}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.121059226743537, 3.171509965025869}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         5.089215577985817, 3.727051939623592}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.421474358397713, 2.190761571584863}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.894149394496038, 3.1689813972080367`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {3.70864795419601,
          2.615078784679503}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {4.10375792406919,
          3.464526110277083}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.829893270060526, 2.825695921522285}, {1.9173987331348583`, 
         2.7659584969191062`}}], 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5143437045371493`, 2.631688889708302}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.8937742888023044`, 3.511704774846602}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.480532646954007, 3.898639297232747}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.271285278493838, 3.080504665143418}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5936973336907365`, 4.134567590393875}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.383769973042954, 3.1431328987805087`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {3.66708201965197,
          3.919179018307792}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.7999915408060856`, 4.0944452232614905`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.135393023043709, 4.073502578805177}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.280637293984499, 3.4155044991217074`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.9939189361277716`, 3.3272009351431175`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.405503519385941, 3.270043524053674}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.070678820145944, 3.9323075706675006`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.239001584183471, 3.956164829537265}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {4.42975593123907,
          3.530715126116566}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.5308128083228962`, 3.684012744192402}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.620491637143561, 2.635471976196063}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.727779462485876, 4.205311459421361}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.164943754401822, 3.796129407611249}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.2435476242779595`, 3.6993666739913427`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.3237636738212215`, 3.7328502920809923`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.401750579498126, 3.6513262470434413`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.9698408995471217`, 3.8055730640819547`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.448791131927424, 4.090933904285507}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.8550673799758357`, 2.9392153854630445`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.942715326111345, 3.3644759808467883`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.312071324715001, 3.8538501104467087`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.2407252861086775`, 2.959539268956114}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.7884955443447814`, 3.699892149571761}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {4.45271978013659,
          3.3929475838811536`}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         4.011991317923822, 3.036747773860446}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         2.969792695888759, 3.226794349488862}}, 0.05570143050888991], 
        ArrowBox[{{3.528800617824225, 3.4153936059804266`}, {
         3.303747585734906, 4.009134785783969}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.8312252633985353`, 5.035038489761629}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         3.528800617824225, 3.4153936059804266`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.40785500153673926`, 4.976406801699863}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.9721685574452104, 4.878482660544747}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.3348605704734469`, 4.957690588079347}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8356128503657425, 4.7757653239935305`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.3115427379293525, 4.389448564296204}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.34047356613598767`, 4.867129181171479}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6915615283338803, 5.016260087063726}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.5955992707905655, 5.196042024112448}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8526101898675127, 4.630801060380589}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.7973218127784216, 5.309327189878359}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.4761450601789994, 4.616543958931642}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6456923969659738, 4.297023158634975}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.5121956560123038, 4.912632616901693}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.1335695410431113`, 5.308978399644691}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.0882241249858984`, 4.718258641356753}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.5751836336992446, 5.05690184501653}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.469824124602396, 5.104041355271252}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8111154356254753, 4.307441482229554}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.9639135195187563, 5.351582525329796}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.5245821466388976, 4.1755742699901655`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.1570296631032222`, 4.93157558571205}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.28107756110461724`, 4.53044812328401}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.4743370203504087, 4.770891969196664}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.2700113959364694`, 5.216234865895061}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.42525919744296914`, 4.487389538446732}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.122124740619637, 5.126947335427426}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6549332117216733, 4.5921800581849155`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8205650367556543, 4.937147459315856}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.7146891851664909, 4.132475827523839}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.34263158638482816`, 4.636992912800938}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         2.3969266456918503`, 3.1981103616770197`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.3075950641940195, 4.746511591063642}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {2.47854069729822,
          2.8454206567419718`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6547419541326955, 4.863807700351988}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.49381208403271515`, 4.375955918345492}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8840158256227015, 5.228855102061041}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.4153070868230553, 4.270270166834985}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.7045673804419805, 5.219838233621284}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8761205997475692, 4.462482997072011}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6299052385371002, 4.714382051200481}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.2630543941416832`, 5.08193444559997}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.8072815412905161, 5.104601698173099}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.6318581063100894, 4.462220058202436}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         0.9556190288915065, 5.060575878942867}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.4880864554634101`, 3.5849160660106336`}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.0179552862225605`, 5.218444329525832}}, 0.05570143050888991], 
        ArrowBox[{{1.3188303280332685`, 4.388954662649468}, {
         1.3911945670759331`, 3.5449209449397725`}}, 0.05570143050888991], 
        ArrowBox[{{4.430511042091697, 4.473728563866835}, {4.981213223955975, 
         5.0445610970507975`}}, 0.05570143050888991], 
        ArrowBox[{{4.430511042091697, 4.473728563866835}, {4.867566821905859, 
         5.1563861762750385`}}, 0.05570143050888991], 
        ArrowBox[{{2.780141837132228, 3.0186312033407585`}, {
         3.142566988890562, 3.1686275723500845`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.352267967999519, 3.8957326391109772`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.2825463330866027`, 3.986538935106582}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[BezierCurveBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.6163060808985588`, 3.3556561813862746`}, {3.528800617824225, 
         3.4153936059804266`}}], 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.8936735482897027`, 2.6065550216699744`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.7321852594693112`, 1.9274867347286038`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.47854069729822, 2.8454206567419718`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.4880864554634101`, 3.5849160660106336`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.3911945670759331`, 3.5449209449397725`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.780141837132228, 3.0186312033407585`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.695603974218695, 3.101816580844254}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.175365870848454, 3.080538658374356}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.0774078703579866`, 2.762021135226445}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.5671950887519348`, 2.2865173398017777`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.1777948334100428`, 2.6217420157641214`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.3803050652017146`, 2.477758651764651}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.109385498151434, 2.4917851013821215`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.1688366839844044`, 2.8533041468787195`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.3442796757106674`, 2.620655965758532}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.0093171896476711`, 2.342119382412407}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.654812508403634, 2.1482345319902834`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.136379271804913, 2.10179967534156}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.398893722561458, 2.337537030955006}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.0445336068141367`, 2.2145012697976156`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.5178886194675658`, 2.070324688298257}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.392985116128974, 2.0172300490268786`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.2701560228774893`, 2.170868016397018}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.3975982075832798`, 2.18479886837523}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.0010160736343976`, 2.6224015147170086`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.2584534476124616`, 2.0186966525050893`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         0.9660759676933837, 2.472803415911055}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.307329914043703, 2.8190553153022355`}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.2203116837267625`, 2.403725156264022}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         2.0648042207302373`, 2.715105008020585}}, 0.05570143050888991], 
        ArrowBox[{{1.9173987331348583`, 2.7659584969191062`}, {
         1.1743389460149922`, 2.274227348673222}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {4.785953480575827, 
         4.792650979773929}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {4.240273969422595, 
         3.294538442130717}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {5.089215577985817, 
         3.727051939623592}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.07605019362437, 
         4.7921768996926755`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.108569302428034, 
         4.289256406799745}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.162718825972419, 
         4.485721789141594}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.217602994975898, 
         3.9554024603260465`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.069766489239364, 
         3.4849957919804195`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.839643628137155, 
         4.449570510691226}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.339445919688016, 
         4.06213114401514}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.930031394773706, 
         3.334106453459885}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.29515948689261, 
         3.6711682743193585`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.384969987960359, 
         4.4221485605780035`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.497997598777275, 
         4.020280573460792}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.157390138415499, 
         4.132924398807478}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.202438494892904, 
         3.420668394795633}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.722960004274572, 
         4.310322961527341}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.920383828516393, 
         4.5673503536250575`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.348361489395701, 
         3.913040092783218}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.724336630874012, 
         3.5382502837181464`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.04286578353353, 
         3.992902738035645}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.313344466056199, 
         3.511235759908192}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.246250065585384, 
         3.7936881591370293`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.49221300887856, 
         4.6428349632936685`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.872934999963933, 
         3.9116529007241962`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.99589646107202, 
         4.4221152403054855`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.030576710727809, 
         3.6677971129569764`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.402875651459135, 
         4.206617655166467}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         7.5092294802897115`, 4.155850833215487}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.826626790601779, 
         4.124531057816174}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.182830794179319, 
         4.711163026407839}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.909356644316942, 
         3.531218243022184}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.940971265755323, 
         4.7371375157582545`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.051834577147967, 
         4.623993472853848}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.979285916089861, 
         4.202026505373777}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.765187881582182, 
         4.849704246674317}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         7.1647163047764835`, 3.6052812946290684`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.256449545263353, 
         4.602101352336273}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.450823132744214, 
         4.3296976212458285`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         6.7332729528748025`, 4.739823640833926}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.073475795754592, 
         3.3446634144767353`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.243126257987642, 
         4.3742895738521925`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         6.5865952470127995`, 4.480947617956097}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.813630168216543, 
         3.719486279249364}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.082709938405188, 
         3.811335885439358}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {
         6.7900103730083154`, 3.3864915489480705`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.726461226363466, 
         4.580391401353141}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.271976368383317, 
         4.217171575296142}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.417303205744281, 
         3.641247907462545}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.889499163828672, 
         4.854877707567038}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.436827334648331, 
         3.776543704867336}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.36669655127135, 
         4.539807801375816}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {7.487593683926255, 
         3.8913864754248957`}}, 0.05570143050888991], 
        ArrowBox[{{6.449660611658213, 4.002162346020976}, {6.568781576929737, 
         4.791634583666779}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.4086328226038205`, 3.4233982178356124`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.518440375008683, 3.1045688674195313`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.8936735482897027`, 2.6065550216699744`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.7321852594693112`, 1.9274867347286038`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.3969266456918503`, 3.1981103616770197`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8075104349989717`, 2.6243579693144916`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.421474358397713, 2.190761571584863}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {3.70864795419601,
          2.615078784679503}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.5143437045371493`, 2.631688889708302}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.620491637143561, 2.635471976196063}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         2.2521088624868315`, 2.7009640096630276`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.086947054882777, 1.519870605989537}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {4.18209667336294,
          1.4140793613221037`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.925138690548266, 1.4347354403711694`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8679255336938736`, 1.2632213976747777`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.979849145266797, 1.6416616732844578`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {4.46363350817925,
          1.8072214144657355`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.349911798840048, 1.7078513085738685`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.471555947280286, 1.068618203063001}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.295671362053043, 1.5656152959568475`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.026224270844277, 1.194980682649728}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {4.19088866799243,
          1.6685142500137031`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8432883078061626`, 1.6652882090850187`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.274060087359451, 1.3715767941168013`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.7164694653507095`, 1.2254168366564895`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.025537181086292, 1.3306997299521077`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.437201726066682, 1.4788486729610324`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.272361280221109, 1.8734433678623728`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.5869571021565627`, 1.5841419622038597`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.403274340812292, 1.4813956224851554`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.124709468232238, 1.8263122936120195`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.6289533279741266`, 1.2779280947152851`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.455341129301084, 1.628651384177883}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.4177692935803883`, 1.2962703706061052`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.6759923074530665`, 1.446008295597642}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.310076412808286, 1.3736411898265515`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8058864883790147`, 1.1742553557001956`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.377534460488725, 1.9508173489446283`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.5908997950331663`, 1.1746006289113988`}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         3.8167824403242876`, 1.41118222984997}}, 0.05570143050888991], 
        ArrowBox[{{3.5813031800360937`, 2.017544372999396}, {
         4.184505427359471, 1.2669661240102115`}}, 0.05570143050888991], 
        ArrowBox[{{4.471555947280286, 1.068618203063001}, {5.047638369107941, 
         0.4111912972831533}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3880612796376046`, 3.247166015126839}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.6909004173798046`, 3.0661122801603264`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         4.240273969422595, 3.294538442130717}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.7321852594693112`, 1.9274867347286038`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.47854069729822, 2.8454206567419718`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.421474358397713, 2.190761571584863}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.274060087359451, 1.3715767941168013`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.529183377782783, 0.3459540572094859}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.855260453944898, 0.3303523773370447}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.632165776231189, 0.11103641985856338`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.623085392018389, 0.24813975997412197`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.691707167723954, 0.5505356231454419}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.189233266615462, 0.25849377658537387`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.0191831405526632`, 0.4113205932000388}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3710776248337075`, 0.2999523784538045}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.167773717230054, 0.4385212239551035}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.7716537203514955`, 0.4302322473870501}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3108059160742314`, 0.15061590799352498`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.967013800042194, 0.17293923908540476`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.834010241282577, 1.990508425310403}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.8663225857892227`, 0.3162379741460035}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.033793051399473, 0.27333934580722286`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.1533319156711497`, 0.12824719894068837`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.901323876584327, 0.46408514083271557`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.5778245924135943`, 0.4688222282786785}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.5170786709362716`, 0.04384570570227053}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.733477488615379, 0.3594720657048902}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.764343642195909, 0.2002421538590511}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3889215317152495`, 0.03714367247629635}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.852030977769403, 0.09540886872204357}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.8913260505315477`, 0.5169506416851912}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.2711795821890868`, 0.}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.4757292291894126`, 0.17919497776812854`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.131451414038333, 0.017911701145744807`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.62996839398561, 0.3358079206113249}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.760508776801317, 0.5082595388835616}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.57736217973407, 0.4804479081603814}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         3.3532423647517455`, 0.4616839528821379}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.81669742895982, 0.2197850566076167}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.687649817279081, 0.20397739499959755`}}, 0.05570143050888991], 
        ArrowBox[{{3.2290791913113557`, 1.0785109381376787`}, {
         2.9942706618603867`, 0.04006566250262589}}, 0.05570143050888991], 
        ArrowBox[{{2.834010241282577, 1.990508425310403}, {
         2.4780412190946257`, 3.04953873904153}}, 0.05570143050888991]}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8312252633985353`, 5.035038489761629}, 
           0.05570143050888991],
          "\"MARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.5001357454627087`, 6.002609917393925}, 
           0.05570143050888991],
          "\"FLORENCE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FLORENCE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.576053100782418, 5.895842978123906}, 0.05570143050888991],
          "\"JEAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9482352292499296`, 6.097613755961862}, 
           0.05570143050888991],
          "\"JULIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JULIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9151738067450674`, 5.438187776093255}, 
           0.05570143050888991],
          "\"CLAIRE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLAIRE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9567074804668376`, 5.823109470968475}, 
           0.05570143050888991],
          "\"LAURA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LAURA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4311982915193564`, 5.6103629903875545`}, 
           0.05570143050888991],
          "\"DORIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DORIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.6547283295530573`, 5.470141876035472}, 
           0.05570143050888991],
          "\"JOAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3291315986460237`, 5.564923358575424}, 
           0.05570143050888991],
          "\"CHRISTINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHRISTINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.785953480575827, 4.792650979773929}, 0.05570143050888991],
          "\"KAREN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KAREN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.241668688810895, 5.4646874707731214`}, 
           0.05570143050888991],
          "\"NICOLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NICOLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.6086243433705767`, 5.696340227043807}, 
           0.05570143050888991],
          "\"DOROTHY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DOROTHY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.358444073478961, 5.720908552907942}, 0.05570143050888991],
          "\"JOYCE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOYCE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.104039957029104, 5.853325291739553}, 0.05570143050888991],
          "\"JACQUELINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JACQUELINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.4086328226038205`, 3.4233982178356124`}, 
           0.05570143050888991],
          "\"EMMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EMMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3880612796376046`, 3.247166015126839}, 
           0.05570143050888991],
          "\"KATHLEEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATHLEEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.058154943199654, 6.028434144407518}, 0.05570143050888991],
          "\"JANET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JANET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.911581255082521, 5.666345199323741}, 0.05570143050888991],
          "\"LISA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LISA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.268654685620686, 5.835784189884132}, 0.05570143050888991],
          "\"ANNIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.740113935424552, 5.607079548351958}, 0.05570143050888991],
          "\"SHEILA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHEILA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.067717251909292, 5.577496225407183}, 0.05570143050888991],
          "\"ANN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1901160987714365`, 5.367156079183836}, 
           0.05570143050888991],
          "\"JOANNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOANNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.464302487648301, 5.810836314891446}, 0.05570143050888991],
          "\"ELSIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELSIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.352267967999519, 3.8957326391109772`}, 
           0.05570143050888991],
          "\"BARBARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BARBARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5019330232187524`, 5.409922858738638}, 
           0.05570143050888991],
          "\"CAROL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CAROL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2683486202440615`, 6.000228186556448}, 
           0.05570143050888991],
          "\"JANE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JANE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.4965891867976207`, 5.591165272469905}, 
           0.05570143050888991],
          "\"MICHELLE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MICHELLE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.5973121055785473`, 6.06625200222989}, 
           0.05570143050888991],
          "\"VICTORIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VICTORIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.546530712831092, 5.573524194826402}, 0.05570143050888991],
          "\"ALICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8188699679133604`, 6.085705867024174}, 
           0.05570143050888991],
          "\"IRENE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IRENE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3210376704601803`, 5.334694823182663}, 
           0.05570143050888991],
          "\"HELEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HELEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.782379851104637, 5.965672351271724}, 0.05570143050888991],
          "\"SAMANTHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SAMANTHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.254307918443584, 5.5496448155168885`}, 
           0.05570143050888991],
          "\"JUNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JUNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6909004173798046`, 3.0661122801603264`}, 
           0.05570143050888991],
          "\"MAUREEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAUREEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8480168639532184`, 4.371045396255162}, 
           0.05570143050888991],
          "\"DIANE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DIANE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.47628317627636, 5.3971524682153955`}, 
           0.05570143050888991],
          "\"RACHEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RACHEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.7028347408065194`, 6.093244776759786}, 
           0.05570143050888991],
          "\"WINIFRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WINIFRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.015069443528973, 3.528774386330581}, 0.05570143050888991],
          "\"EILEEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EILEEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.4780412190946257`, 3.04953873904153}, 
           0.05570143050888991],
          "\"SHIRLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHIRLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3055152107392, 5.888803933863012}, 0.05570143050888991],
          "\"ANNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.331821291441601, 5.716887595061483}, 0.05570143050888991],
          "\"SHARON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHARON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4857107529680147`, 5.738563878031519}, 
           0.05570143050888991],
          "\"AMY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AMY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4013526182698466`, 5.880377038950135}, 
           0.05570143050888991],
          "\"GLADYS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLADYS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.354722758719908, 5.3840968980770985`}, 
           0.05570143050888991],
          "\"BETTY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BETTY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2825463330866027`, 3.986538935106582}, 
           0.05570143050888991],
          "\"VALERIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VALERIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3862080289961396`, 5.96445637275853}, 
           0.05570143050888991],
          "\"AMANDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AMANDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1661911124691793`, 6.017348842219756}, 
           0.05570143050888991],
          "\"JENNIFER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JENNIFER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.679605445673041, 5.812763152337811}, 0.05570143050888991],
          "\"ANGELA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANGELA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.240273969422595, 3.294538442130717}, 0.05570143050888991],
          "\"ETHEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ETHEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.150490349131523, 5.706038430596417}, 0.05570143050888991],
          "\"SANDRA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SANDRA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.810332911515744, 5.814005780601199}, 0.05570143050888991],
          "\"LOUISE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LOUISE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.220199677819779, 5.776796601251533}, 0.05570143050888991],
          "\"KATIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9578274128557434`, 5.954294043242812}, 
           0.05570143050888991],
          "\"HILDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HILDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.1861620991869795`, 5.63598141436367}, 
           0.05570143050888991],
          "\"PHYLLIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PHYLLIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.188557496372201, 5.486614363414871}, 0.05570143050888991],
          "\"DOREEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DOREEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.420836415944293, 2.2431093533062914`}, 
           0.05570143050888991],
          "\"PAULINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAULINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.0858918689478205`, 1.3686553831522517`}, 
           0.05570143050888991],
          "\"LILIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LILIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.158130764593345, 1.687858510106223}, 0.05570143050888991],
          "\"AUDREY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AUDREY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.7872134804660247`, 1.501120672851946}, 
           0.05570143050888991],
          "\"CLARE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLARE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8217485775752578`, 1.6835647125534663`}, 
           0.05570143050888991],
          "\"KELLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KELLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2997933320975226`, 1.6206871164841348`}, 
           0.05570143050888991],
          "\"IVY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IVY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.708578448660259, 1.6276896036343267`}, 
           0.05570143050888991],
          "\"VERA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VERA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.0194579833936253`, 1.769213485184401}, 
           0.05570143050888991],
          "\"BRENDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BRENDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.116707127932865, 1.5251410737698965`}, 
           0.05570143050888991],
          "\"GILLIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GILLIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8676771058475212`, 1.8258680307398885`}, 
           0.05570143050888991],
          "\"NATALIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NATALIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9178189325188169`, 1.391703535041099}, 
           0.05570143050888991],
          "\"VIOLET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VIOLET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9785572225889283`, 1.4912482384743169`}, 
           0.05570143050888991],
          "\"PAMELA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAMELA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.518440375008683, 3.1045688674195313`}, 
           0.05570143050888991],
          "\"SYLVIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SYLVIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.528800617824225, 3.4153936059804266`}, 
           0.05570143050888991],
          "\"ELAINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELAINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8936735482897027`, 2.6065550216699744`}, 
           0.05570143050888991],
          "\"ELLEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELLEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2328261514407464`, 1.4084201232941602`}, 
           0.05570143050888991],
          "\"LESLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LESLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.7321852594693112`, 1.9274867347286038`}, 
           0.05570143050888991],
          "\"CATHERINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CATHERINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.597638796308375, 2.822580191656698}, 0.05570143050888991],
          "\"HAYLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HAYLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9423447173186847`, 1.6152319259806995`}, 
           0.05570143050888991],
          "\"LILY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LILY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3763239273976744`, 1.5033353754050143`}, 
           0.05570143050888991],
          "\"EDNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3188303280332685`, 4.388954662649468}, 
           0.05570143050888991],
          "\"HANNAH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HANNAH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.40785500153673926`, 4.976406801699863}, 
           0.05570143050888991],
          "\"NELLIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NELLIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9721685574452104, 4.878482660544747}, 
           0.05570143050888991],
          "\"BERYL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BERYL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3348605704734469`, 4.957690588079347}, 
           0.05570143050888991],
          "\"WENDY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WENDY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8356128503657425, 4.7757653239935305`}, 
           0.05570143050888991],
          "\"LUCY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LUCY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.3115427379293525, 4.389448564296204}, 
           0.05570143050888991],
          "\"ADA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ADA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.34047356613598767`, 4.867129181171479}, 
           0.05570143050888991],
          "\"DAWN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DAWN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6915615283338803, 5.016260087063726}, 
           0.05570143050888991],
          "\"DONNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DONNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5955992707905655, 5.196042024112448}, 
           0.05570143050888991],
          "\"BEATRICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BEATRICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8526101898675127, 4.630801060380589}, 
           0.05570143050888991],
          "\"OLIVE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "OLIVE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.7973218127784216, 5.309327189878359}, 
           0.05570143050888991],
          "\"CAROLE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CAROLE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.4761450601789994, 4.616543958931642}, 
           0.05570143050888991],
          "\"DANIELLE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DANIELLE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6456923969659738, 4.297023158634975}, 
           0.05570143050888991],
          "\"MAY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5121956560123038, 4.912632616901693}, 
           0.05570143050888991],
          "\"EVELYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EVELYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1335695410431113`, 5.308978399644691}, 
           0.05570143050888991],
          "\"ROSE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROSE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0882241249858984`, 4.718258641356753}, 
           0.05570143050888991],
          "\"MAVIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAVIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5751836336992446, 5.05690184501653}, 0.05570143050888991],
          "\"SALLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SALLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.469824124602396, 5.104041355271252}, 0.05570143050888991],
          "\"KATHERINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATHERINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8111154356254753, 4.307441482229554}, 
           0.05570143050888991],
          "\"IRIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IRIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9639135195187563, 5.351582525329796}, 
           0.05570143050888991],
          "\"JUDITH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JUDITH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5245821466388976, 4.1755742699901655`}, 
           0.05570143050888991],
          "\"MARIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1570296631032222`, 4.93157558571205}, 
           0.05570143050888991],
          "\"ZOE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ZOE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.28107756110461724`, 4.53044812328401}, 
           0.05570143050888991],
          "\"KERRY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KERRY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.4743370203504087, 4.770891969196664}, 
           0.05570143050888991],
          "\"DEBRA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DEBRA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2700113959364694`, 5.216234865895061}, 
           0.05570143050888991],
          "\"MELANIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MELANIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.42525919744296914`, 4.487389538446732}, 
           0.05570143050888991],
          "\"STACEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STACEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.122124740619637, 5.126947335427426}, 0.05570143050888991],
          "\"GERTRUDE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GERTRUDE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6549332117216733, 4.5921800581849155`}, 
           0.05570143050888991],
          "\"MURIEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MURIEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8205650367556543, 4.937147459315856}, 
           0.05570143050888991],
          "\"PAULA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAULA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.7146891851664909, 4.132475827523839}, 
           0.05570143050888991],
          "\"LAUREN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LAUREN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.34263158638482816`, 4.636992912800938}, 
           0.05570143050888991],
          "\"MARION\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARION", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3969266456918503`, 3.1981103616770197`}, 
           0.05570143050888991],
          "\"JOANNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOANNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.3075950641940195, 4.746511591063642}, 
           0.05570143050888991],
          "\"MARINA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARINA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.47854069729822, 2.8454206567419718`}, 
           0.05570143050888991],
          "\"JANICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JANICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6547419541326955, 4.863807700351988}, 
           0.05570143050888991],
          "\"LORRAINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LORRAINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.49381208403271515`, 4.375955918345492}, 
           0.05570143050888991],
          "\"JESSIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JESSIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8840158256227015, 5.228855102061041}, 
           0.05570143050888991],
          "\"PEGGY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PEGGY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.4153070868230553, 4.270270166834985}, 
           0.05570143050888991],
          "\"ROSEMARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROSEMARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.7045673804419805, 5.219838233621284}, 
           0.05570143050888991],
          "\"LYNN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYNN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8761205997475692, 4.462482997072011}, 
           0.05570143050888991],
          "\"ANDREA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANDREA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6299052385371002, 4.714382051200481}, 
           0.05570143050888991],
          "\"FRANCES\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRANCES", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2630543941416832`, 5.08193444559997}, 
           0.05570143050888991],
          "\"SUZANNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SUZANNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8072815412905161, 5.104601698173099}, 
           0.05570143050888991],
          "\"GRACE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GRACE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6318581063100894, 4.462220058202436}, 
           0.05570143050888991],
          "\"JOSEPHINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOSEPHINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9556190288915065, 5.060575878942867}, 
           0.05570143050888991],
          "\"YVONNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "YVONNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.4880864554634101`, 3.5849160660106336`}, 
           0.05570143050888991],
          "\"SOPHIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SOPHIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0179552862225605`, 5.218444329525832}, 
           0.05570143050888991],
          "\"LYNNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYNNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3911945670759331`, 3.5449209449397725`}, 
           0.05570143050888991],
          "\"ANNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2021617590475486`, 3.8687370380391304`}, 
           0.05570143050888991],
          "\"EVA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EVA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.430511042091697, 4.473728563866835}, 0.05570143050888991],
          "\"GWENDOLINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GWENDOLINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.981213223955975, 5.0445610970507975`}, 
           0.05570143050888991],
          "\"JESSICA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JESSICA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.250815849483389, 3.5696337399653917`}, 
           0.05570143050888991],
          "\"NORMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.142566988890562, 3.1686275723500845`}, 
           0.05570143050888991],
          "\"BEVERLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BEVERLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.780141837132228, 3.0186312033407585`}, 
           0.05570143050888991],
          "\"KIRSTY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIRSTY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.093822430629724, 2.906375517885318}, 0.05570143050888991],
          "\"KIMBERLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIMBERLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8310392015705985`, 3.940500392214558}, 
           0.05570143050888991],
          "\"HAZEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HAZEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.9424344226979815`, 4.1837777970750905`}, 
           0.05570143050888991],
          "\"FIONA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FIONA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8075104349989717`, 2.6243579693144916`}, 
           0.05570143050888991],
          "\"MARIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.08749027015602, 3.657082668658042}, 0.05570143050888991],
          
          "\"JENNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JENNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.867566821905859, 5.1563861762750385`}, 
           0.05570143050888991],
          "\"MARILYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARILYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.977474783878852, 4.049251013933451}, 0.05570143050888991],
          "\"DAISY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DAISY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.695603974218695, 3.101816580844254}, 0.05570143050888991],
          "\"NORA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.121059226743537, 3.171509965025869}, 0.05570143050888991],
          "\"NATASHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NATASHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.089215577985817, 3.727051939623592}, 0.05570143050888991],
          "\"MINNIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MINNIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.421474358397713, 2.190761571584863}, 0.05570143050888991],
          "\"FREDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FREDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.894149394496038, 3.1689813972080367`}, 
           0.05570143050888991],
          "\"MANDY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MANDY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.70864795419601, 2.615078784679503}, 0.05570143050888991],
          
          "\"RACHAEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RACHAEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.10375792406919, 3.464526110277083}, 0.05570143050888991],
          
          "\"KATHRYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATHRYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9173987331348583`, 2.7659584969191062`}, 
           0.05570143050888991],
          "\"NANCY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NANCY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5143437045371493`, 2.631688889708302}, 
           0.05570143050888991],
          "\"RUTH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RUTH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8937742888023044`, 3.511704774846602}, 
           0.05570143050888991],
          "\"JAYNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JAYNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.480532646954007, 3.898639297232747}, 0.05570143050888991],
          "\"DIANA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DIANA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.271285278493838, 3.080504665143418}, 0.05570143050888991],
          "\"MARIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5936973336907365`, 4.134567590393875}, 
           0.05570143050888991],
          "\"ELEANOR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELEANOR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.383769973042954, 3.1431328987805087`}, 
           0.05570143050888991],
          "\"VERONICA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VERONICA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.66708201965197, 3.919179018307792}, 0.05570143050888991],
          
          "\"SARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.7999915408060856`, 4.0944452232614905`}, 
           0.05570143050888991],
          "\"ALEXANDRA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALEXANDRA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.135393023043709, 4.073502578805177}, 0.05570143050888991],
          "\"LOUISA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LOUISA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.280637293984499, 3.4155044991217074`}, 
           0.05570143050888991],
          "\"JODIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JODIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.9939189361277716`, 3.3272009351431175`}, 
           0.05570143050888991],
          "\"DORA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DORA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.405503519385941, 3.270043524053674}, 0.05570143050888991],
          "\"DAPHNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DAPHNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.070678820145944, 3.9323075706675006`}, 
           0.05570143050888991],
          "\"TERESA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TERESA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.239001584183471, 3.956164829537265}, 0.05570143050888991],
          "\"JULIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JULIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.42975593123907, 3.530715126116566}, 0.05570143050888991],
          
          "\"NORAH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORAH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5308128083228962`, 3.684012744192402}, 
           0.05570143050888991],
          "\"HEATHER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HEATHER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.620491637143561, 2.635471976196063}, 0.05570143050888991],
          "\"KIM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.727779462485876, 4.205311459421361}, 0.05570143050888991],
          "\"JEMMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEMMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.164943754401822, 3.796129407611249}, 0.05570143050888991],
          "\"THELMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "THELMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2435476242779595`, 3.6993666739913427`}, 
           0.05570143050888991],
          "\"CARLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CARLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.3237636738212215`, 3.7328502920809923`}, 
           0.05570143050888991],
          "\"IDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.401750579498126, 3.6513262470434413`}, 
           0.05570143050888991],
          "\"CLARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.9698408995471217`, 3.8055730640819547`}, 
           0.05570143050888991],
          "\"GLORIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLORIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.448791131927424, 4.090933904285507}, 0.05570143050888991],
          "\"HOLLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HOLLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8550673799758357`, 2.9392153854630445`}, 
           0.05570143050888991],
          "\"HILARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HILARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9310109034488097`, 3.135898153365598}, 
           0.05570143050888991],
          "\"MELISSA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MELISSA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.942715326111345, 3.3644759808467883`}, 
           0.05570143050888991],
          "\"MARTHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARTHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.312071324715001, 3.8538501104467087`}, 
           0.05570143050888991],
          "\"CYNTHIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CYNTHIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.2407252861086775`, 2.959539268956114}, 
           0.05570143050888991],
          "\"BERTHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BERTHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.7884955443447814`, 3.699892149571761}, 
           0.05570143050888991],
          "\"KATY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.45271978013659, 3.3929475838811536`}, 
           0.05570143050888991],
          "\"LILLIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LILLIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.011991317923822, 3.036747773860446}, 0.05570143050888991],
          "\"CHERYL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHERYL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.969792695888759, 3.226794349488862}, 0.05570143050888991],
          "\"RUBY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RUBY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.303747585734906, 4.009134785783969}, 0.05570143050888991],
          "\"NAOMI\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NAOMI", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.0523930015783991, 3.706412131116615}, 
           0.05570143050888991],
          "\"BESSIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BESSIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.2573432638898039, 3.024065950763953}, 
           0.05570143050888991],
          "\"GAIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GAIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.979892822619038, 3.311264616838231}, 0.05570143050888991],
          "\"MILDRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MILDRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.149534950406232, 3.104895596389688}, 0.05570143050888991],
          "\"PENELOPE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PENELOPE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.16375040268722163`, 3.277185090685656}, 
           0.05570143050888991],
          "\"CHARLENE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHARLENE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.32390662595910724`, 3.4694697204244216`}, 
           0.05570143050888991],
          "\"JADE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JADE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.2521088624868315`, 2.7009640096630276`}, 
           0.05570143050888991],
          "\"CHRISTINA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHRISTINA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.12229625603424887`, 3.787375236833959}, 
           0.05570143050888991],
          "\"ANNETTE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNETTE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.10083672655948739`, 3.601472315531462}, 
           0.05570143050888991],
          "\"JEANETTE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEANETTE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[DiskBox[{0., 3.502118652485}, 0.05570143050888991],
          "\"ESTHER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ESTHER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.175365870848454, 3.080538658374356}, 0.05570143050888991],
          "\"CAROLYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CAROLYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.2612918723690236, 3.712739580181321}, 
           0.05570143050888991],
          "\"HARRIET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HARRIET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.3113085352775964, 3.298363826840268}, 
           0.05570143050888991],
          "\"ANITA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANITA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.14917822500752154`, 3.4254397730806256`}, 
           0.05570143050888991],
          "\"GERALDINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GERALDINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.049757259634716, 3.2075581295494073`}, 
           0.05570143050888991],
          "\"BRIDGET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BRIDGET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.32668261120661146`, 3.155053482431751}, 
           0.05570143050888991],
          "\"GEORGINA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GEORGINA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.2283345869280864, 3.57572093998461}, 0.05570143050888991],
          "\"LINDSEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LINDSEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.0020333003880268485`, 3.36159621491312}, 
           0.05570143050888991],
          "\"KAY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KAY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0774078703579866`, 2.762021135226445}, 
           0.05570143050888991],
          "\"STELLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STELLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.5671950887519348`, 2.2865173398017777`}, 
           0.05570143050888991],
          "\"GEMMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GEMMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1777948334100428`, 2.6217420157641214`}, 
           0.05570143050888991],
          "\"NICHOLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NICHOLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3803050652017146`, 2.477758651764651}, 
           0.05570143050888991],
          "\"AIMEE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AIMEE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.109385498151434, 2.4917851013821215`}, 
           0.05570143050888991],
          "\"HEIDI\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HEIDI", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1688366839844044`, 2.8533041468787195`}, 
           0.05570143050888991],
          "\"MILLICENT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MILLICENT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3442796757106674`, 2.620655965758532}, 
           0.05570143050888991],
          "\"MONICA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MONICA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0093171896476711`, 2.342119382412407}, 
           0.05570143050888991],
          "\"THERESA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "THERESA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.654812508403634, 2.1482345319902834`}, 
           0.05570143050888991],
          "\"MARGERY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARGERY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.136379271804913, 2.10179967534156}, 0.05570143050888991],
          
          "\"MAXINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAXINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.398893722561458, 2.337537030955006}, 0.05570143050888991],
          "\"TANYA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TANYA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0445336068141367`, 2.2145012697976156`}, 
           0.05570143050888991],
          "\"CARLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CARLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.5178886194675658`, 2.070324688298257}, 
           0.05570143050888991],
          "\"FANNY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FANNY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.392985116128974, 2.0172300490268786`}, 
           0.05570143050888991],
          "\"JOY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2701560228774893`, 2.170868016397018}, 
           0.05570143050888991],
          "\"LYDIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYDIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3975982075832798`, 2.18479886837523}, 
           0.05570143050888991],
          "\"ALMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0010160736343976`, 2.6224015147170086`}, 
           0.05570143050888991],
          "\"GLENYS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLENYS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2584534476124616`, 2.0186966525050893`}, 
           0.05570143050888991],
          "\"DEBBIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DEBBIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9660759676933837, 2.472803415911055}, 
           0.05570143050888991],
          "\"JENNY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JENNY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.307329914043703, 2.8190553153022355`}, 
           0.05570143050888991],
          "\"BLANCHE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BLANCHE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2203116837267625`, 2.403725156264022}, 
           0.05570143050888991],
          "\"VIVIENNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VIVIENNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9521184939841647`, 2.973042113831754}, 
           0.05570143050888991],
          "\"TARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.0648042207302373`, 2.715105008020585}, 
           0.05570143050888991],
          "\"MIRIAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MIRIAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1743389460149922`, 2.274227348673222}, 
           0.05570143050888991],
          "\"GLYNIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLYNIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.449660611658213, 4.002162346020976}, 0.05570143050888991],
          "\"CLAIR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLAIR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.07605019362437, 4.7921768996926755`}, 
           0.05570143050888991],
          "\"LYNDSEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYNDSEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.108569302428034, 4.289256406799745}, 0.05570143050888991],
          "\"SONIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SONIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.162718825972419, 4.485721789141594}, 0.05570143050888991],
          "\"MOLLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MOLLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.217602994975898, 3.9554024603260465`}, 
           0.05570143050888991],
          "\"ELLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.069766489239364, 3.4849957919804195`}, 
           0.05570143050888991],
          "\"CHLOE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHLOE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.839643628137155, 4.449570510691226}, 0.05570143050888991],
          "\"SYBIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SYBIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.339445919688016, 4.06213114401514}, 0.05570143050888991],
          
          "\"LEAH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LEAH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.930031394773706, 3.334106453459885}, 0.05570143050888991],
          "\"TONI\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TONI", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.29515948689261, 3.6711682743193585`}, 
           0.05570143050888991],
          "\"WILLIAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WILLIAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.384969987960359, 4.4221485605780035`}, 
           0.05570143050888991],
          "\"JOHN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOHN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.497997598777275, 4.020280573460792}, 0.05570143050888991],
          "\"PAUL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAUL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.157390138415499, 4.132924398807478}, 0.05570143050888991],
          "\"MARK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.202438494892904, 3.420668394795633}, 0.05570143050888991],
          "\"JAMES\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JAMES", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.722960004274572, 4.310322961527341}, 0.05570143050888991],
          "\"MICHAEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MICHAEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.920383828516393, 4.5673503536250575`}, 
           0.05570143050888991],
          "\"STEPHEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STEPHEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.348361489395701, 3.913040092783218}, 0.05570143050888991],
          "\"ANDREW\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANDREW", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.724336630874012, 3.5382502837181464`}, 
           0.05570143050888991],
          "\"DANIEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DANIEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.04286578353353, 3.992902738035645}, 0.05570143050888991],
          
          "\"ARTHUR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ARTHUR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.313344466056199, 3.511235759908192}, 0.05570143050888991],
          "\"ROBERT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROBERT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.246250065585384, 3.7936881591370293`}, 
           0.05570143050888991],
          "\"RICHARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RICHARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.49221300887856, 4.6428349632936685`}, 
           0.05570143050888991],
          "\"RONALD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RONALD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.872934999963933, 3.9116529007241962`}, 
           0.05570143050888991],
          "\"ANTHONY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANTHONY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.99589646107202, 4.4221152403054855`}, 
           0.05570143050888991],
          "\"MATTHEW\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MATTHEW", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.030576710727809, 3.6677971129569764`}, 
           0.05570143050888991],
          "\"CHARLES\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHARLES", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.402875651459135, 4.206617655166467}, 0.05570143050888991],
          "\"FREDERICK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FREDERICK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.5092294802897115`, 4.155850833215487}, 
           0.05570143050888991],
          "\"KENNETH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KENNETH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.826626790601779, 4.124531057816174}, 0.05570143050888991],
          "\"ALBERT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALBERT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.182830794179319, 4.711163026407839}, 0.05570143050888991],
          "\"ALAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.909356644316942, 3.531218243022184}, 0.05570143050888991],
          "\"IAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.940971265755323, 4.7371375157582545`}, 
           0.05570143050888991],
          "\"SIMON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SIMON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.051834577147967, 4.623993472853848}, 0.05570143050888991],
          "\"ERNEST\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ERNEST", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.979285916089861, 4.202026505373777}, 0.05570143050888991],
          "\"ALFRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALFRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.765187881582182, 4.849704246674317}, 0.05570143050888991],
          "\"EDWARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDWARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.1647163047764835`, 3.6052812946290684`}, 
           0.05570143050888991],
          "\"JOSEPH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOSEPH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.256449545263353, 4.602101352336273}, 0.05570143050888991],
          "\"LEE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LEE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.450823132744214, 4.3296976212458285`}, 
           0.05570143050888991],
          "\"ADAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ADAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.7332729528748025`, 4.739823640833926}, 
           0.05570143050888991],
          "\"ROGER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROGER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.073475795754592, 3.3446634144767353`}, 
           0.05570143050888991],
          "\"HAROLD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HAROLD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.243126257987642, 4.3742895738521925`}, 
           0.05570143050888991],
          "\"DEREK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DEREK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.5865952470127995`, 4.480947617956097}, 
           0.05570143050888991],
          "\"KEITH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KEITH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.813630168216543, 3.719486279249364}, 0.05570143050888991],
          "\"FRANK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRANK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.082709938405188, 3.811335885439358}, 0.05570143050888991],
          "\"LESLIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LESLIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.7900103730083154`, 3.3864915489480705`}, 
           0.05570143050888991],
          "\"RAYMOND\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RAYMOND", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.726461226363466, 4.580391401353141}, 0.05570143050888991],
          "\"COLIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "COLIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.271976368383317, 4.217171575296142}, 0.05570143050888991],
          "\"KEVIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KEVIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.417303205744281, 3.641247907462545}, 0.05570143050888991],
          "\"DARREN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DARREN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.889499163828672, 4.854877707567038}, 0.05570143050888991],
          "\"HENRY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HENRY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.436827334648331, 3.776543704867336}, 0.05570143050888991],
          "\"PHILIP\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PHILIP", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.36669655127135, 4.539807801375816}, 0.05570143050888991],
          
          "\"GARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.487593683926255, 3.8913864754248957`}, 
           0.05570143050888991],
          "\"BENJAMIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BENJAMIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.568781576929737, 4.791634583666779}, 0.05570143050888991],
          "\"STANLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STANLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5813031800360937`, 2.017544372999396}, 
           0.05570143050888991],
          "\"STEVEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STEVEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.086947054882777, 1.519870605989537}, 0.05570143050888991],
          "\"ERIC\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ERIC", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.18209667336294, 1.4140793613221037`}, 
           0.05570143050888991],
          "\"MARTIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARTIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.925138690548266, 1.4347354403711694`}, 
           0.05570143050888991],
          "\"WALTER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WALTER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8679255336938736`, 1.2632213976747777`}, 
           0.05570143050888991],
          "\"GRAHAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GRAHAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.979849145266797, 1.6416616732844578`}, 
           0.05570143050888991],
          "\"NICHOLAS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NICHOLAS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.46363350817925, 1.8072214144657355`}, 
           0.05570143050888991],
          "\"LEONARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LEONARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.349911798840048, 1.7078513085738685`}, 
           0.05570143050888991],
          "\"BARRY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BARRY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.471555947280286, 1.068618203063001}, 0.05570143050888991],
          "\"HERBERT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HERBERT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.295671362053043, 1.5656152959568475`}, 
           0.05570143050888991],
          "\"GORDON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GORDON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.026224270844277, 1.194980682649728}, 0.05570143050888991],
          "\"NORMAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORMAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.19088866799243, 1.6685142500137031`}, 
           0.05570143050888991],
          "\"NEIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NEIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8432883078061626`, 1.6652882090850187`}, 
           0.05570143050888991],
          "\"NIGEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NIGEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.274060087359451, 1.3715767941168013`}, 
           0.05570143050888991],
          "\"MALCOLM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MALCOLM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.7164694653507095`, 1.2254168366564895`}, 
           0.05570143050888991],
          "\"TIMOTHY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TIMOTHY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.047638369107941, 0.4111912972831533}, 
           0.05570143050888991],
          "\"STUART\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STUART", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.025537181086292, 1.3306997299521077`}, 
           0.05570143050888991],
          "\"GEOFFREY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GEOFFREY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.437201726066682, 1.4788486729610324`}, 
           0.05570143050888991],
          "\"ALEXANDER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALEXANDER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.272361280221109, 1.8734433678623728`}, 
           0.05570143050888991],
          "\"CYRIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CYRIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5869571021565627`, 1.5841419622038597`}, 
           0.05570143050888991],
          "\"SIDNEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SIDNEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.403274340812292, 1.4813956224851554`}, 
           0.05570143050888991],
          "\"FRANCIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRANCIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.124709468232238, 1.8263122936120195`}, 
           0.05570143050888991],
          "\"RYAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RYAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6289533279741266`, 1.2779280947152851`}, 
           0.05570143050888991],
          "\"PERCY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PERCY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.455341129301084, 1.628651384177883}, 0.05570143050888991],
          "\"LUKE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LUKE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4177692935803883`, 1.2962703706061052`}, 
           0.05570143050888991],
          "\"JACK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JACK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6759923074530665`, 1.446008295597642}, 
           0.05570143050888991],
          "\"TREVOR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TREVOR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.310076412808286, 1.3736411898265515`}, 
           0.05570143050888991],
          "\"ADRIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ADRIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8058864883790147`, 1.1742553557001956`}, 
           0.05570143050888991],
          "\"JAMIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JAMIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.377534460488725, 1.9508173489446283`}, 
           0.05570143050888991],
          "\"WILFRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WILFRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5908997950331663`, 1.1746006289113988`}, 
           0.05570143050888991],
          "\"PATRICK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PATRICK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8167824403242876`, 1.41118222984997}, 
           0.05570143050888991],
          "\"SCOTT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SCOTT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.184505427359471, 1.2669661240102115`}, 
           0.05570143050888991],
          "\"SAMUEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SAMUEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2290791913113557`, 1.0785109381376787`}, 
           0.05570143050888991],
          "\"WAYNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WAYNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.529183377782783, 0.3459540572094859}, 
           0.05570143050888991],
          "\"CECIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CECIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.855260453944898, 0.3303523773370447}, 
           0.05570143050888991],
          "\"GARETH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GARETH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.632165776231189, 0.11103641985856338`}, 
           0.05570143050888991],
          "\"SEAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SEAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.623085392018389, 0.24813975997412197`}, 
           0.05570143050888991],
          "\"HORACE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HORACE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.691707167723954, 0.5505356231454419}, 
           0.05570143050888991],
          "\"BERNARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BERNARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.189233266615462, 0.25849377658537387`}, 
           0.05570143050888991],
          "\"FRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.0191831405526632`, 0.4113205932000388}, 
           0.05570143050888991],
          "\"EDWIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDWIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3710776248337075`, 0.2999523784538045}, 
           0.05570143050888991],
          "\"GERALD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GERALD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.167773717230054, 0.4385212239551035}, 
           0.05570143050888991],
          "\"SHAUN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHAUN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.7716537203514955`, 0.4302322473870501}, 
           0.05570143050888991],
          "\"CLIFFORD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLIFFORD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3108059160742314`, 0.15061590799352498`}, 
           0.05570143050888991],
          "\"MAURICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAURICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.967013800042194, 0.17293923908540476`}, 
           0.05570143050888991],
          "\"CLIVE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLIVE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.834010241282577, 1.990508425310403}, 0.05570143050888991],
          "\"BEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8663225857892227`, 0.3162379741460035}, 
           0.05570143050888991],
          "\"ANTONY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANTONY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.033793051399473, 0.27333934580722286`}, 
           0.05570143050888991],
          "\"VICTOR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VICTOR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1533319156711497`, 0.12824719894068837`}, 
           0.05570143050888991],
          "\"JUSTIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JUSTIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.901323876584327, 0.46408514083271557`}, 
           0.05570143050888991],
          "\"JEFFREY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEFFREY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.5778245924135943`, 0.4688222282786785}, 
           0.05570143050888991],
          "\"OLIVER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "OLIVER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5170786709362716`, 0.04384570570227053}, 
           0.05570143050888991],
          "\"EDGAR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDGAR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.733477488615379, 0.3594720657048902}, 
           0.05570143050888991],
          "\"CHRISTIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHRISTIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.764343642195909, 0.2002421538590511}, 
           0.05570143050888991],
          "\"ASHLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ASHLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3889215317152495`, 0.03714367247629635}, 
           0.05570143050888991],
          "\"KARL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KARL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.852030977769403, 0.09540886872204357}, 
           0.05570143050888991],
          "\"AARON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AARON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8913260505315477`, 0.5169506416851912}, 
           0.05570143050888991],
          "\"MARC\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARC", "Tooltip"]& ], 
        TagBox[
         TooltipBox[DiskBox[{3.2711795821890868`, 0.}, 0.05570143050888991],
          "\"MOHAMMED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MOHAMMED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4757292291894126`, 0.17919497776812854`}, 
           0.05570143050888991],
          "\"HUGH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HUGH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.131451414038333, 0.017911701145744807`}, 
           0.05570143050888991],
          "\"RUSSELL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RUSSELL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.62996839398561, 0.3358079206113249}, 0.05570143050888991],
          "\"GAVIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GAVIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.760508776801317, 0.5082595388835616}, 
           0.05570143050888991],
          "\"LAWRENCE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LAWRENCE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.57736217973407, 0.4804479081603814}, 0.05570143050888991],
          "\"LIAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LIAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3532423647517455`, 0.4616839528821379}, 
           0.05570143050888991],
          "\"ROBIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROBIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.81669742895982, 0.2197850566076167}, 0.05570143050888991],
          "\"PHILLIP\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PHILLIP", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.687649817279081, 0.20397739499959755`}, 
           0.05570143050888991],
          "\"NATHAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NATHAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9942706618603867`, 0.04006566250262589}, 
           0.05570143050888991],
          "\"DENIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DENIS", "Tooltip"]& ]}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{
  3.676263773807106*^9, {3.6762673171384478`*^9, 3.676267329041534*^9}, 
   3.676271906851449*^9, 3.677821329213537*^9, 
   3.6778229039959307`*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Communities in the Network", "Title",
 CellChangeTimes->{{3.6761935218185587`*^9, 3.6761935242931232`*^9}, {
  3.676193721983591*^9, 3.676193724154065*^9}, {3.676262337872819*^9, 
  3.676262348438691*^9}}],

Cell["\<\
CommunityGraphPlot is a powerful visualisations function for graph objects \
that provides information about the communities within a graph.\
\>", "Text",
 CellChangeTimes->{{3.6762626146145697`*^9, 3.676262657534191*^9}}],

Cell["\<\
Create a grid of CommunityGraphPlot mapped to the following Graph:\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676262666231559*^9, 3.676262709237899*^9}}],

Cell[BoxData[GridBox[{
   {"\"\<Directed Multigraph\>\"", "\"\<Directed SimpleGraph\>\""},
   {"\"\<Undirected Multigraph\>\"", "\"\<Undirected Multigraph\>\""}
  }]], "Input",
 CellChangeTimes->{{3.676262724063085*^9, 3.676262801492675*^9}}],

Cell["\<\
What do these visualisations tell you about the network, and about the \
properties of the different types of graph?\
\>", "Text",
 CellChangeTimes->{{3.676262807373581*^9, 3.67626283804077*^9}}],

Cell["\<\
CommunityGraphPlot uses the FindGraphCommunities function to find communities \
in the graph and then undertakes shenanigans to place the nodes nicely in a \
graphic. Find the largest community from FindGraphCommunities and use \
HighlightGraph to highlight these nodes purple in the Graph.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.67626284337527*^9, 3.676262870689744*^9}, {
  3.676262916513743*^9, 3.676262919515717*^9}, {3.676263116574044*^9, 
  3.676263159121811*^9}, {3.67626319472771*^9, 3.676263262295495*^9}}],

Cell["\<\
NOTE: Some of the theory of FindGraphCommunities is provided in the \
documentation, but you will need to consult elsewhere for a thorough \
explanation of how graph are paritioned into communities.\
\>", "Text",
 CellChangeTimes->{{3.676263314589699*^9, 3.676263377608508*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["VertexCentralities", "Title",
 CellChangeTimes->{{3.6761935218185587`*^9, 3.6761935242931232`*^9}, {
  3.676193721983591*^9, 3.676193724154065*^9}, {3.6762633942957077`*^9, 
  3.676263398703472*^9}}],

Cell["\<\
There are many *Centrality measures that mean are useful for a variety of \
graph analyses, VertexDegree is a useful one for the directed  SimpleGraph as \
it allows us to find those individuals in the network who are only \
\[OpenCurlyDoubleQuote]secondary participants\[CloseCurlyDoubleQuote].\
\>", "Text",
 CellChangeTimes->{{3.676263402475811*^9, 3.6762634682630863`*^9}, {
  3.67626363181885*^9, 3.676263660891073*^9}}],

Cell["\<\
In this exercise you will colour those vertices that are only appear as \
\[OpenCurlyDoubleQuote]secondary participants\[CloseCurlyDoubleQuote] in red.\
\
\>", "Text",
 CellChangeTimes->{{3.676263905926063*^9, 3.676263934141942*^9}}],

Cell["\<\
Find the number of edges directed away from a vertex with DegreeCentrality \
(deliberately tricky language is used in this question)\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676263670125341*^9, 3.676263709894294*^9}, {
   3.6762637448925457`*^9, 3.676263751046131*^9}, 3.6762640850060463`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"outDegrees", "=", 
  RowBox[{"DegreeCentrality", "[", 
   RowBox[{"simpleDirected", ",", "\"\<Out\>\""}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6762637111440287`*^9, 3.676263719096422*^9}, {
  3.676263754043914*^9, 3.676263799080607*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "53", ",", "1", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "1", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "1", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "21",
    ",", "7", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",",
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
    ",", "0", ",", "0", ",", "23", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "60", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
    ",", "53", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "2", ",", "0", ",", "0", 
   ",", "0", ",", "1", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "39", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",",
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
    ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",",
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
    ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",",
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
    ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",",
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
    ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",",
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
    ",", "0", ",", "0", ",", "0", ",", "56", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "44", ",", "0", ",", "0", ",", "0", ",",
    "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", "0", ",", "0", ",", "0",
    ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",",
    "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0",
    ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "42", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.676263786894973*^9, 3.6762637995399103`*^9}, 
   3.6762719118295393`*^9, 3.677821336617125*^9, 3.6778229154648848`*^9}]
}, Open  ]],

Cell["\<\
Use PropertyValue to update the VertexStyle of those nodes with a zero out \
degree to be red, all other nodes should remain unchanged.\[LineSeparator]\
\[LineSeparator]Note that there are a number of different ways to achieve \
this and your problem solving skills will be needed.\[LineSeparator]\
\[LineSeparator]As a reminder, a template for PropertyValue is provided below:\
\>", "ItemNumbered",
 CellChangeTimes->{{3.6762638246351767`*^9, 3.676263882864512*^9}, {
  3.676263941331484*^9, 3.676263945358872*^9}, {3.676264060078969*^9, 
  3.676264195505653*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"graph", "=", 
   RowBox[{"CompleteGraph", "[", 
    RowBox[{"4", ",", 
     RowBox[{"VertexLabels", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"1", "\[Rule]", "\"\<one\>\""}], "}"}]}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"PropertyValue", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"graph", ",", "1"}], "}"}], ",", "VertexLabels"}], "]"}], "=", 
   "\"\<New Label\>\""}], ";"}], "\[IndentingNewLine]", "graph"}], "Input",
 CellChangeTimes->{{3.676264025774899*^9, 3.676264031726461*^9}, {
  3.676264199627211*^9, 3.6762642613810453`*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4}, {Null, 
       SparseArray[
       Automatic, {4, 4}, 0, {
        1, {{0, 3, 6, 9, 12}, {{2}, {3}, {4}, {1}, {3}, {4}, {1}, {2}, {4}, {
          1}, {2}, {3}}}, Pattern}]}, {
      GraphLayout -> "StarEmbedding", VertexLabels -> {1 -> "New Label"}}]]}, 
    
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
        {Arrowheads[0.], 
         ArrowBox[{{0., 0.}, {0.8660254037844389, -0.5000000000000012}}, 
          0.020399597244776413`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{0., 0.}, {1.8369701987210297`*^-16, 1.}}, 
          0.020399597244776413`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{0., 0.}, {-0.8660254037844386, -0.49999999999999917`}}, 
          0.020399597244776413`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{0.8660254037844389, -0.5000000000000012}, {
          1.8369701987210297`*^-16, 1.}}, 0.020399597244776413`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{
          0.8660254037844389, -0.5000000000000012}, {-0.8660254037844386, \
-0.49999999999999917`}}, 0.020399597244776413`]}, 
        {Arrowheads[0.], 
         ArrowBox[{{1.8369701987210297`*^-16, 
          1.}, {-0.8660254037844386, -0.49999999999999917`}}, 
          0.020399597244776413`]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {DiskBox[{0., 0.}, 0.020399597244776413`], 
         InsetBox["\<\"New Label\"\>", 
          Offset[{2, 2}, {0.020399597244776413`, 0.020399597244776413`}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, 
        DiskBox[{0.8660254037844389, -0.5000000000000012}, 
         0.020399597244776413`], 
        DiskBox[{1.8369701987210297`*^-16, 1.}, 0.020399597244776413`], 
        DiskBox[{-0.8660254037844386, -0.49999999999999917`}, 
         0.020399597244776413`]}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{{3.6762642191347237`*^9, 3.676264262298421*^9}, 
   3.676271913580082*^9, 3.67782133911714*^9, 3.67782291756036*^9}]
}, Open  ]],

Cell[TextData[{
 "Individuals who have a zero out degree are not listed as ",
 StyleBox["primary participants",
  FontSlant->"Italic"],
 ", there are few individuals who have a non-zero out degree. It\
\[CloseCurlyQuote]s interesting to look at these individuals in some detail, \
however they were prolific in their interactions - one individual was listed \
as the primary participant in an interaction 60 times. We may need to reduce \
the dataset at times to extract meaning."
}], "Text",
 CellChangeTimes->{{3.6762668423128567`*^9, 3.67626689023979*^9}, {
  3.676266928198257*^9, 3.676267037536796*^9}, {3.676267258760688*^9, 
  3.6762672737232533`*^9}}],

Cell["\<\
Return a list of the vertices where the out degree is greater than zero\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676264354549551*^9, 3.676264364415959*^9}, {
  3.676266118831254*^9, 3.676266127446845*^9}, {3.6762661904832897`*^9, 
  3.676266217132533*^9}, {3.676267418928969*^9, 3.6762674196930733`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zeroOutDegree", "=", 
  RowBox[{"Pick", "[", 
   RowBox[{
    RowBox[{"VertexList", "[", "simpleDirected", "]"}], ",", "outDegrees", 
    ",", 
    RowBox[{"q_", "/;", 
     RowBox[{"q", ">", "0"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6762643990335083`*^9, 3.676264413431238*^9}, {
   3.676266129776414*^9, 3.6762661765200357`*^9}, {3.676266236654125*^9, 
   3.6762662456747437`*^9}, 3.6762719246906157`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"MARY\"\>", ",", "\<\"FLORENCE\"\>", ",", "\<\"NICOLA\"\>", 
   ",", "\<\"BARBARA\"\>", ",", "\<\"EILEEN\"\>", ",", "\<\"SHIRLEY\"\>", 
   ",", "\<\"PAULINE\"\>", ",", "\<\"ELAINE\"\>", ",", "\<\"HANNAH\"\>", 
   ",", "\<\"GWENDOLINE\"\>", ",", "\<\"KIRSTY\"\>", ",", "\<\"NANCY\"\>", 
   ",", "\<\"CLAIR\"\>", ",", "\<\"STEVEN\"\>", ",", "\<\"HERBERT\"\>", 
   ",", "\<\"WAYNE\"\>", ",", "\<\"BEN\"\>"}], "}"}]], "Output",
 CellChangeTimes->{
  3.676264413861073*^9, 3.676266176964965*^9, 3.676266247304084*^9, 
   3.676267354295248*^9, 3.676267421929193*^9, {3.6762719154503183`*^9, 
   3.676271925574491*^9}, 3.677821342606183*^9, 3.677822920084*^9}]
}, Open  ]],

Cell["\<\
Use SubGraph to visualise the interactions of only these individuals, use the \
argument VertexLabels to insert labels as either tooltips or labels (there \
are so few vertices labels will be legible!)\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676267129261814*^9, 3.6762671305206213`*^9}, {
  3.676267286088029*^9, 3.6762672933552322`*^9}, {3.676267427040051*^9, 
  3.676267472603764*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Subgraph", "[", 
  RowBox[{"simpleDirected", ",", "zeroOutDegree", ",", 
   RowBox[{"VertexLabels", "\[Rule]", 
    RowBox[{"Placed", "[", 
     RowBox[{"\"\<Name\>\"", ",", "Tooltip"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.676267166768927*^9, 3.676267207764909*^9}, {
  3.676267365571754*^9, 3.676267374602853*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "MARY", "FLORENCE", "NICOLA", "BARBARA", "EILEEN", "SHIRLEY", "PAULINE",
        "ELAINE", "HANNAH", "GWENDOLINE", "KIRSTY", "NANCY", "CLAIR", 
       "STEVEN", "HERBERT", "WAYNE", "BEN"}, {{{1, 2}, {1, 4}, {1, 5}, {5, 
       6}, {1, 6}, {7, 6}, {8, 6}, {8, 7}, {7, 8}, {9, 8}, {9, 6}, {9, 1}, {8,
        10}, {8, 11}, {12, 8}, {12, 4}, {12, 6}, {12, 11}, {8, 12}, {14, 6}, {
       14, 15}, {16, 6}, {17, 6}, {16, 17}}, Null}, {VertexLabels -> {
         Placed["Name", Tooltip]}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[Medium], 
        ArrowBox[{{1.1284533397533383`, -3.1795073223303825`}, {
         0.34014085743889133`, -4.007928387155946}}, 0.040081825033336876`], 
        ArrowBox[{{1.1284533397533383`, -3.1795073223303825`}, {
         0.4299921900212669, -2.5543724498326412`}}, 0.040081825033336876`], 
        ArrowBox[{{1.1284533397533383`, -3.1795073223303825`}, {
         1.7768289240137447`, -3.5293860394538665`}}, 0.040081825033336876`], 
        ArrowBox[{{1.1284533397533383`, -3.1795073223303825`}, {
         2.280413922387078, -2.6152121146920653`}}, 0.040081825033336876`], 
        ArrowBox[{{1.7768289240137447`, -3.5293860394538665`}, {
         2.280413922387078, -2.6152121146920653`}}, 0.040081825033336876`], 
        ArrowBox[{{2.5451428047575138`, -1.6728430292002545`}, {
         2.280413922387078, -2.6152121146920653`}}, 0.040081825033336876`], 
        ArrowBox[BezierCurveBox[{{
         2.5451428047575138`, -1.6728430292002545`}, {
         2.1356542479706673`, -1.709289602352339}, {
         1.7844692467548298`, -1.4955647190193857`}}], 0.040081825033336876`],
         ArrowBox[{{1.7844692467548298`, -1.4955647190193857`}, {
         2.280413922387078, -2.6152121146920653`}}, 0.040081825033336876`], 
        ArrowBox[BezierCurveBox[{{
         1.7844692467548298`, -1.4955647190193857`}, {
         2.1939578035416725`, -1.4591181458741131`}, {
         2.5451428047575138`, -1.6728430292002545`}}], 0.040081825033336876`],
         ArrowBox[{{1.7844692467548298`, -1.4955647190193857`}, {
         1.8533818695745994`, -0.3401408574388909}}, 0.040081825033336876`], 
        ArrowBox[{{1.7844692467548298`, -1.4955647190193857`}, {
         0.9768735347821809, -1.0712562553341405`}}, 0.040081825033336876`], 
        ArrowBox[BezierCurveBox[{{
         1.7844692467548298`, -1.4955647190193857`}, {
         1.5550766257620086`, -1.8037272887859028`}, {
         1.187550605180886, -1.915574363692445}}], 0.040081825033336876`], 
        ArrowBox[{{1.5905534587643932`, -2.432377306359699}, {
         1.1284533397533383`, -3.1795073223303825`}}, 0.040081825033336876`], 
        ArrowBox[{{1.5905534587643932`, -2.432377306359699}, {
         2.280413922387078, -2.6152121146920653`}}, 0.040081825033336876`], 
        ArrowBox[{{1.5905534587643932`, -2.432377306359699}, {
         1.7844692467548298`, -1.4955647190193857`}}, 0.040081825033336876`], 
        ArrowBox[{{1.187550605180886, -1.915574363692445}, {
         0.4299921900212669, -2.5543724498326412`}}, 0.040081825033336876`], 
        ArrowBox[{{1.187550605180886, -1.915574363692445}, {
         2.280413922387078, -2.6152121146920653`}}, 0.040081825033336876`], 
        ArrowBox[BezierCurveBox[{{1.187550605180886, -1.915574363692445}, {
         1.416943226173718, -1.6074117939287027`}, {
         1.7844692467548298`, -1.4955647190193857`}}], 0.040081825033336876`],
         ArrowBox[{{1.187550605180886, -1.915574363692445}, {
         0.9768735347821809, -1.0712562553341405`}}, 0.040081825033336876`], 
        ArrowBox[{{3.762532708903083, -2.452390603578773}, {
         2.280413922387078, -2.6152121146920653`}}, 0.040081825033336876`], 
        ArrowBox[{{3.762532708903083, -2.452390603578773}, {
         4.835493906255218, -2.3814980673777733`}}, 0.040081825033336876`], 
        ArrowBox[{{3.1478362240985813`, -3.210119730042544}, {
         2.280413922387078, -2.6152121146920653`}}, 0.040081825033336876`], 
        ArrowBox[{{3.1478362240985813`, -3.210119730042544}, {
         2.8235418343586454`, -3.5977058885236084`}}, 0.040081825033336876`], 
        ArrowBox[{{2.8235418343586454`, -3.5977058885236084`}, {
         2.280413922387078, -2.6152121146920653`}}, 0.040081825033336876`]}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1284533397533383`, -3.1795073223303825`}, 
           0.040081825033336876`],
          "\"MARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.34014085743889133`, -4.007928387155946}, 
           0.040081825033336876`],
          "\"FLORENCE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FLORENCE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.3401408574388909, -4.688210102033729}, 
           0.040081825033336876`],
          "\"NICOLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NICOLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.4299921900212669, -2.5543724498326412`}, 
           0.040081825033336876`],
          "\"BARBARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BARBARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.7768289240137447`, -3.5293860394538665`}, 
           0.040081825033336876`],
          "\"EILEEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EILEEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.280413922387078, -2.6152121146920653`}, 
           0.040081825033336876`],
          "\"SHIRLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHIRLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.5451428047575138`, -1.6728430292002545`}, 
           0.040081825033336876`],
          "\"PAULINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAULINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.7844692467548298`, -1.4955647190193857`}, 
           0.040081825033336876`],
          "\"ELAINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELAINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.5905534587643932`, -2.432377306359699}, 
           0.040081825033336876`],
          "\"HANNAH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HANNAH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8533818695745994`, -0.3401408574388909}, 
           0.040081825033336876`],
          "\"GWENDOLINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GWENDOLINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9768735347821809, -1.0712562553341405`}, 
           0.040081825033336876`],
          "\"KIRSTY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIRSTY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.187550605180886, -1.915574363692445}, 
           0.040081825033336876`],
          "\"NANCY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NANCY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9279582392859456`, -4.688210102033729}, 
           0.040081825033336876`],
          "\"CLAIR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLAIR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.762532708903083, -2.452390603578773}, 
           0.040081825033336876`],
          "\"STEVEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STEVEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.835493906255218, -2.3814980673777733`}, 
           0.040081825033336876`],
          "\"HERBERT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HERBERT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1478362240985813`, -3.210119730042544}, 
           0.040081825033336876`],
          "\"WAYNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WAYNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8235418343586454`, -3.5977058885236084`}, 
           0.040081825033336876`],
          "\"BEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BEN", "Tooltip"]& ]}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{{3.676267208278791*^9, 3.676267220714573*^9}, {
   3.6762673606492853`*^9, 3.676267375152782*^9}, 3.676267474741992*^9, 
   3.67627192747508*^9, 3.677821344823229*^9, 3.677822921850471*^9}]
}, Open  ]],

Cell[TextData[{
 "Select those rows from your list of associations where the \
\[OpenCurlyDoubleQuote]Secondary.Participant.Name\[CloseCurlyDoubleQuote] \
belongs to the output of step 3 (i.e. the value is a ",
 StyleBox["member",
  FontWeight->"Bold"],
 " of the list from step 3).\[LineSeparator]\[LineSeparator]Note that this \
will require a Query as you are operating on a list of Associations, store \
the output for use in Step 5."
}], "ItemNumbered",
 CellChangeTimes->{{3.676266226033101*^9, 3.676266229294284*^9}, {
  3.67626627854844*^9, 3.676266352764571*^9}, {3.676266498567348*^9, 
  3.676266540822094*^9}, {3.676267495305518*^9, 3.676267497364832*^9}}],

Cell[BoxData[
 RowBox[{"primaryAndSecondaryRows", "=", 
  RowBox[{
   RowBox[{"Query", "[", 
    RowBox[{"Select", "[", 
     RowBox[{
      RowBox[{"MemberQ", "[", 
       RowBox[{"zeroOutDegree", ",", 
        RowBox[{"Slot", "[", "\"\<Secondary.Participant.Name\>\"", "]"}]}], 
       "]"}], "&"}], "]"}], "]"}], "@", 
   "lifeevents$Associations"}]}]], "Input",
 CellChangeTimes->{{3.67626635431777*^9, 3.6762664393674383`*^9}, {
  3.676266471680746*^9, 3.676266477251255*^9}, {3.6762665501096888`*^9, 
  3.67626655191364*^9}, {3.6778213694041452`*^9, 3.6778213701497917`*^9}}],

Cell["\<\
Display this data in the form of a Grid, with appropriate column headings.\
\[LineSeparator]\[LineSeparator]Hint: Use ItemSize\[Rule]Full to ensure line \
breaks are not inserted.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676266560396649*^9, 3.6762666070076*^9}, {
  3.6762666537645073`*^9, 3.676266671548641*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"Prepend", "[", 
    RowBox[{
     RowBox[{"Values", "[", "primaryAndSecondaryRows", "]"}], ",", 
     RowBox[{"Keys", "[", 
      RowBox[{"primaryAndSecondaryRows", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}], ",", 
   RowBox[{"BaseStyle", "\[Rule]", "\"\<Text\>\""}], ",", 
   RowBox[{"ItemSize", "\[Rule]", "Full"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.6762666081370363`*^9, 3.676266638913844*^9}, {
  3.6762666879633503`*^9, 3.676266694893717*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"Category\"\>", "\<\"Primary.Participant.Emlo_ID\"\>", \
"\<\"Primary.Participant.Name\"\>", "\<\"Secondary.Participant.Emlo_ID\"\>", \
"\<\"Secondary.Participant.Name\"\>", "\<\"Secondary.Participant.Type\"\>"},
    {"\<\"BasicData\"\>", "1", "\<\"MARY\"\>", 
     "5", "\<\"FLORENCE\"\>", "\<\"Person\"\>"},
    {"\<\"SocialContacts\"\>", "1", "\<\"MARY\"\>", 
     "33", "\<\"BARBARA\"\>", "\<\"Person\"\>"},
    {"\<\"SocialContacts\"\>", "1", "\<\"MARY\"\>", 
     "49", "\<\"EILEEN\"\>", "\<\"Person\"\>"},
    {"\<\"SocialContacts\"\>", "1", "\<\"MARY\"\>", 
     "50", "\<\"SHIRLEY\"\>", "\<\"Person\"\>"},
    {"\<\"SocialContacts\"\>", "68", "\<\"PAULINE\"\>", 
     "50", "\<\"SHIRLEY\"\>", "\<\"Person\"\>"},
    {"\<\"SocialContacts\"\>", "68", "\<\"PAULINE\"\>", 
     "83", "\<\"ELAINE\"\>", "\<\"Person\"\>"},
    {"\<\"SocialContacts\"\>", "68", "\<\"PAULINE\"\>", 
     "50", "\<\"SHIRLEY\"\>", "\<\"Person\"\>"},
    {"\<\"SocialContacts\"\>", "68", "\<\"PAULINE\"\>", 
     "50", "\<\"SHIRLEY\"\>", "\<\"Person\"\>"},
    {"\<\"Education\"\>", "90", "\<\"HANNAH\"\>", 
     "1", "\<\"MARY\"\>", "\<\"Person\"\>"},
    {"\<\"SocialContacts\"\>", "90", "\<\"HANNAH\"\>", 
     "50", "\<\"SHIRLEY\"\>", "\<\"Person\"\>"},
    {"\<\"SocialContacts\"\>", "90", "\<\"HANNAH\"\>", 
     "50", "\<\"SHIRLEY\"\>", "\<\"Person\"\>"},
    {"\<\"SocialContacts\"\>", "90", "\<\"HANNAH\"\>", 
     "83", "\<\"ELAINE\"\>", "\<\"Person\"\>"},
    {"\<\"BasicData\"\>", "83", "\<\"ELAINE\"\>", 
     "147", "\<\"GWENDOLINE\"\>", "\<\"Person\"\>"},
    {"\<\"SocialContacts\"\>", "83", "\<\"ELAINE\"\>", 
     "50", "\<\"SHIRLEY\"\>", "\<\"Person\"\>"},
    {"\<\"SocialContacts\"\>", "83", "\<\"ELAINE\"\>", 
     "152", "\<\"KIRSTY\"\>", "\<\"Person\"\>"},
    {"\<\"SocialContacts\"\>", "83", "\<\"ELAINE\"\>", 
     "152", "\<\"KIRSTY\"\>", "\<\"Person\"\>"},
    {"\<\"BasicData\"\>", "83", "\<\"ELAINE\"\>", 
     "171", "\<\"NANCY\"\>", "\<\"Person\"\>"},
    {"\<\"SocialContacts\"\>", "83", "\<\"ELAINE\"\>", 
     "68", "\<\"PAULINE\"\>", "\<\"Person\"\>"},
    {"\<\"BasicData\"\>", "49", "\<\"EILEEN\"\>", 
     "50", "\<\"SHIRLEY\"\>", "\<\"Person\"\>"},
    {"\<\"BasicData\"\>", "171", "\<\"NANCY\"\>", 
     "83", "\<\"ELAINE\"\>", "\<\"Person\"\>"},
    {"\<\"SocialContacts\"\>", "171", "\<\"NANCY\"\>", 
     "33", "\<\"BARBARA\"\>", "\<\"Person\"\>"},
    {"\<\"SocialContacts\"\>", "171", "\<\"NANCY\"\>", 
     "50", "\<\"SHIRLEY\"\>", "\<\"Person\"\>"},
    {"\<\"SocialContacts\"\>", "171", "\<\"NANCY\"\>", 
     "152", "\<\"KIRSTY\"\>", "\<\"Person\"\>"},
    {"\<\"SocialContacts\"\>", "315", "\<\"STEVEN\"\>", 
     "50", "\<\"SHIRLEY\"\>", "\<\"Person\"\>"},
    {"\<\"BasicData\"\>", "315", "\<\"STEVEN\"\>", 
     "330", "\<\"HERBERT\"\>", "\<\"Person\"\>"},
    {"\<\"SocialContacts\"\>", "315", "\<\"STEVEN\"\>", 
     "50", "\<\"SHIRLEY\"\>", "\<\"Person\"\>"},
    {"\<\"SocialContacts\"\>", "315", "\<\"STEVEN\"\>", 
     "50", "\<\"SHIRLEY\"\>", "\<\"Person\"\>"},
    {"\<\"BasicData\"\>", "354", "\<\"WAYNE\"\>", 
     "370", "\<\"BEN\"\>", "\<\"Person\"\>"},
    {"\<\"HierarchicalRelationship\"\>", "354", "\<\"WAYNE\"\>", 
     "50", "\<\"SHIRLEY\"\>", "\<\"Person\"\>"},
    {"\<\"SocialContacts\"\>", "379", "\<\"BEN\"\>", 
     "50", "\<\"SHIRLEY\"\>", "\<\"Person\"\>"}
   },
   AutoDelete->False,
   BaseStyle->"Text",
   GridBoxItemSize->{"Columns" -> {{All}}, "Rows" -> {{All}}}],
  "Grid"]], "Output",
 CellChangeTimes->{
  3.67626647778323*^9, 3.676266552774918*^9, {3.676266618411418*^9, 
   3.676266639232176*^9}, 3.676266695776989*^9, 3.676271940135899*^9, 
   3.677821374604888*^9, 3.67782292868784*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["", "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],

Cell["Interactive Networks", "Title",
 CellChangeTimes->{{3.6761935218185587`*^9, 3.6761935242931232`*^9}, {
  3.676193721983591*^9, 3.676193724154065*^9}, {3.6762633942957077`*^9, 
  3.676263398703472*^9}, {3.676264468976424*^9, 3.676264476376086*^9}, {
  3.676265117060472*^9, 3.676265119130563*^9}, {3.676267603366243*^9, 
  3.676267605996387*^9}}],

Cell["When building a graph there are two choices:", "Text",
 CellChangeTimes->{{3.676267624716247*^9, 3.67626763648318*^9}}],

Cell[CellGroupData[{

Cell["\<\
Build a basic graph with edges and vertices only, and add properties \
afterwards\
\>", "Item",
 CellChangeTimes->{{3.676267643212533*^9, 3.6762676658308496`*^9}}],

Cell["Build a graph with multiple properties defined to begin with", "Item",
 CellChangeTimes->{{3.676267643212533*^9, 3.6762676841833363`*^9}}]
}, Open  ]],

Cell["\<\
Thus far we have only really considered the first method of graph \
construction, but that adds a lot of complications.\
\>", "Text",
 CellChangeTimes->{{3.676267686952236*^9, 3.676267728565609*^9}}],

Cell["Graph can be constructed as follows:", "Text",
 CellChangeTimes->{{3.676269064778693*^9, 3.6762690785369177`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Graph", "[", 
   RowBox[{"vertexlist", ",", "edgelist"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Graph", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "\[Rule]", "2"}], ",", 
     RowBox[{"2", "\[Rule]", "1"}]}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6762690794768467`*^9, 3.6762691126251717`*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 5}, {{{1, 2}, {2, 1}}, Null}]]}, 
    TagBox[GraphicsGroupBox[GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGBQBmIQXXQkqoaL4aO9tPuao8sZNuxXgNBwPpS2X5HVtOI3
w4n97HO+Mz+Z985eZXXkTYPynfuVF5Rt8zv01n5PU+fKyRt375+YUqrb++iN
/R5ZO+uyaXv38yl5PlFmeGPvwyFQvlNl//4X5/a9mCH92v6T7czjO3QP7I8y
2NNdbPrKfld2h+vnOQf2a8xXFLTxe2n/7IJs1Kn7B/Z7vJeOr057Yd/mY1Qk
9u3A/t8u81Rija/D+dZPJx24nXwVrv7modjTOVMvw83b0xohqHTyIty+gvvO
UjwMF+xdoO65suUaf3HZGfstUPf2Hbv4Ouf7CfstUP/8vnZ2q3jrUXsZqH/Z
r0P4CT2/j1dpzNo/E6qeQc+m/b3dxP33oeYxtFxuOBXWvL8Mah/DPoHOQ5Oy
9x+Cuochq/pbQ0eY/T2oexsmt/zO7yy2d4T6h8HSsC/oSbU9oyvEvwxrD0y4
urbO3hsaHjC+DjS8YOpjoeEJM+81NLxh9glC44NhP8Q9U6Dx5QB1rxo0PhWg
/uGCxncD1L8AhPEeqg==
       "], {
        {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[Medium], 
         ArrowBox[BezierCurveBox[{
          1, {0.5625100000000007, -0.2269507471831215}, 2}], 0.01273], 
         ArrowBox[BezierCurveBox[{
          2, {0.5625100000000005, 0.10193074718311719`}, 1}], 0.01273]}, 
        {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
         DiskBox[1, 0.01273], DiskBox[2, 0.01273], DiskBox[3, 0.01273]}}]],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{3.676269113056428*^9, 3.6778213885368347`*^9}]
}, Open  ]],

Cell["\<\
This allows for properties to be added to vertices and edges before the graph \
has been constructed:\
\>", "Text",
 CellChangeTimes->{{3.6762691224923477`*^9, 3.6762691389614897`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Graph", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Property", "[", 
     RowBox[{
      RowBox[{"1", "\[Rule]", "2"}], ",", 
      RowBox[{"EdgeStyle", "\[Rule]", "Red"}]}], "]"}], ",", 
    RowBox[{"2", "\[Rule]", "1"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.676269167892889*^9, 3.6762692267897463`*^9}, {
  3.676270411663514*^9, 3.676270414713463*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2}, {{{1, 2}, {2, 1}}, Null}, {
      EdgeStyle -> {DirectedEdge[1, 2] -> RGBColor[1, 0, 0]}}]]}, 
    TagBox[GraphicsGroupBox[GraphicsComplexBox[CompressedData["
1:eJxV0L1KA0EUBeDBZquFJYVVFDSQFIIEEdRCTyqxEPGnMdtoghbaWFhYKAhL
tBLWVhJ8g0CwiSjmuKAkeYJgIQRRxERlHkHD3C3mwjAzMMw93x0rHqzvDiml
xv/XYDeloazSjE+L6dLw9fwXvJafSfzc8GQyOD4sfSJ3dNfsFOr066d7+ukD
uWqqX5m458ZUpjOi3rEdNIuppQadi0TXmXlDa/q83fYf2Vtx0w/7XWxe7jwv
zEX08rVCZfYVNT/8/W5EDK8G9QK9djt61o9YNnfG96R5z/i9Nv8x/s81/Rj3
y5s8XJU8WyYvs5I3MB5mxbNsvFTiFT/FD/FT/BA/xQ/xU/xw7Dzo2Xnh2R6E
thdlex5I2vOCtucJ1543xA/xQ/wQP8QP8UP8ED/+ADqSCu8=
       "], {
        {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[Medium], 
         {RGBColor[1, 0, 0], 
          ArrowBox[BezierCurveBox[{1, {0., -0.32888149436623376`}, 2}], 
           0.02261146496815286]}, 
         ArrowBox[BezierCurveBox[{2, {0., 0.32888149436623376`}, 1}], 
          0.02261146496815286]}, 
        {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
         DiskBox[1, 0.02261146496815286], DiskBox[2, 0.02261146496815286]}}]],
     
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{{3.676269212362996*^9, 3.676269227153564*^9}, 
   3.676270415091167*^9, 3.6778213907945423`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Creating the Graph", "Section",
 CellChangeTimes->{{3.6762703834279633`*^9, 3.6762703922135973`*^9}}],

Cell["\<\
Contained within the data folder is another file \
\[OpenCurlyDoubleQuote]interaction_tallies\[CloseCurlyDoubleQuote] where the \
interactions between individuals have been tallied by the event category \
column:\
\>", "Text",
 CellChangeTimes->{{3.676268682038452*^9, 3.676268712153852*^9}, {
  3.676268743946643*^9, 3.676268784391241*^9}, {3.676269605223727*^9, 
  3.676269643123637*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"interactionTallies", "=", 
   RowBox[{"Import", "[", "\"\<interaction_tallies.csv\>\"", "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"interactionTallies$Associations", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"AssociationThread", "[", 
       RowBox[{
        RowBox[{"interactionTallies", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", "#"}], "]"}], "&"}], ",", 
     
     RowBox[{"interactionTallies", "[", 
      RowBox[{"[", 
       RowBox[{"2", ";;"}], "]"}], "]"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.676268286149037*^9, 3.67626831364515*^9}, {
   3.676268344714223*^9, 3.676268346603284*^9}, 3.676268790366938*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"interactionTallies$Associations", "//", "First"}]], "Input",
 CellChangeTimes->{{3.677822461115642*^9, 3.677822462914225*^9}}],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"\<\"BasicData\"\>", "\[Rule]", "0"}], ",", 
   RowBox[{"\<\"EcclesiasticActivity\"\>", "\[Rule]", "0"}], ",", 
   RowBox[{"\<\"Education\"\>", "\[Rule]", "1"}], ",", 
   RowBox[{"\<\"HierarchicalRelationship\"\>", "\[Rule]", "0"}], ",", 
   RowBox[{"\<\"LearnedActivity\"\>", "\[Rule]", "0"}], ",", 
   RowBox[{"\<\"LocationHistory\"\>", "\[Rule]", "0"}], ",", 
   RowBox[{"\<\"PoliticalActivity\"\>", "\[Rule]", "0"}], ",", 
   RowBox[{"\<\"ProfessionalActivity\"\>", "\[Rule]", "0"}], ",", 
   RowBox[{"\<\"SocialContacts\"\>", "\[Rule]", "0"}], ",", 
   RowBox[{"\<\"Primary.Emlo_ID\"\>", "\[Rule]", "1"}], ",", 
   RowBox[{"\<\"Secondary.Emlo_ID\"\>", "\[Rule]", "2"}], ",", 
   RowBox[{"\<\"Total.Connections\"\>", "\[Rule]", "1"}]}], 
  "\[RightAssociation]"}]], "Output",
 CellChangeTimes->{3.677822463129212*^9, 3.677822611972989*^9, 
  3.677822935220837*^9}]
}, Open  ]],

Cell["\<\
Unfortunately, the edges are detailed in terms of the EMLO_id rather than \
name of the individual - as the code for generating the tally was written in \
R where vertex indices are important. But we can fix that using the other \
datafile:\
\>", "Text",
 CellChangeTimes->{{3.67626965659134*^9, 3.67626971976099*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"people$info", "=", 
   RowBox[{"Import", "[", "\"\<people-info.csv\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"people$Associations", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"AssociationThread", "[", 
       RowBox[{
        RowBox[{"people$info", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", "#"}], "]"}], "&"}], ",", 
     
     RowBox[{"people$info", "[", 
      RowBox[{"[", 
       RowBox[{"2", ";;"}], "]"}], "]"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.676269758992466*^9, 3.676269770781001*^9}, {
  3.676269805408258*^9, 3.67626982108012*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"people$Associations", "//", "First"}]], "Input",
 CellChangeTimes->{{3.677822480842684*^9, 3.67782248421203*^9}}],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"\<\"Person.Name\"\>", "\[Rule]", "\<\"ONKXMB\"\>"}], ",", 
   RowBox[{"\<\"iperson_id\"\>", "\[Rule]", "1259"}]}], 
  "\[RightAssociation]"}]], "Output",
 CellChangeTimes->{3.6778224844239388`*^9, 3.677822938886319*^9}]
}, Open  ]],

Cell["\<\
Use ReplaceAll (/.) to replace the emlo ids in \
interactionTallies$Associations with the names from people$Associations. \
Consider how this might be achieved using Apply.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676269842095829*^9, 3.67626986944309*^9}, {
  3.6762699511436977`*^9, 3.676269996423822*^9}, {3.6762700268720837`*^9, 
  3.676270067884365*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"interactionTallies$Associations", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "\"\<Primary.Emlo_ID\>\""}], "]"}], "]"}], "=", 
   RowBox[{
    RowBox[{"interactionTallies$Associations", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "\"\<Primary.Emlo_ID\>\""}], "]"}], "]"}], "/.", 
    RowBox[{"Rule", "@@@", 
     RowBox[{"Values", "[", 
      RowBox[{"people$Associations", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", 
         RowBox[{"{", 
          RowBox[{"\"\<iperson_id\>\"", ",", "\"\<Person.Name\>\""}], "}"}]}],
         "]"}], "]"}], "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6778225054870996`*^9, 3.6778225764972982`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"interactionTallies$Associations", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "\"\<Secondary.Emlo_ID\>\""}], "]"}], "]"}], "=", 
   RowBox[{
    RowBox[{"interactionTallies$Associations", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "\"\<Secondary.Emlo_ID\>\""}], "]"}], "]"}], "/.", 
    RowBox[{"Rule", "@@@", 
     RowBox[{"Values", "[", 
      RowBox[{"people$Associations", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", 
         RowBox[{"{", 
          RowBox[{"\"\<iperson_id\>\"", ",", "\"\<Person.Name\>\""}], "}"}]}],
         "]"}], "]"}], "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.677822588456324*^9, 3.677822589918736*^9}}],

Cell["\<\
Use Map to construct a list of edges formed form the \
\[OpenCurlyDoubleQuote]Primary.Emlo_ID\[CloseCurlyDoubleQuote] and \
\[CloseCurlyDoubleQuote]Secondary.Emlo_ID\[CloseCurlyDoubleQuote] columns \
with the \[OpenCurlyDoubleQuote]Total.Connections\[CloseCurlyDoubleQuote] set \
as the EdgeWeight. The properties should look like this:\[LineSeparator]\
\[LineSeparator]Property[1\[DirectedEdge]2, EdgeWeight\[Rule]2]\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676270426458746*^9, 3.676270526867463*^9}}],

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Property", "[", 
     RowBox[{
      RowBox[{"DirectedEdge", "@@", 
       RowBox[{"#", "[", 
        RowBox[{"[", 
         RowBox[{"{", 
          RowBox[{
          "\"\<Primary.Emlo_ID\>\"", ",", "\"\<Secondary.Emlo_ID\>\""}], 
          "}"}], "]"}], "]"}]}], ",", 
      RowBox[{"EdgeWeight", "\[Rule]", 
       RowBox[{"#", "[", 
        RowBox[{"[", "\"\<Total.Connections\>\"", "]"}], "]"}]}]}], "]"}], 
    "&"}], ",", "interactionTallies$Associations"}], "]"}]], "Input"],

Cell["\<\
Provide these edges to Graph, and remember to display the vertex labels as \
tooltips, store the graph as a symbol for using in the next exercise.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676270426458746*^9, 3.6762704446512423`*^9}, {
  3.676270548100168*^9, 3.676270589270948*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tallyGraph", "=", 
  RowBox[{"Graph", "[", 
   RowBox[{
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Property", "[", 
        RowBox[{
         RowBox[{"DirectedEdge", "@@", 
          RowBox[{"#", "[", 
           RowBox[{"[", 
            RowBox[{"{", 
             RowBox[{
             "\"\<Primary.Emlo_ID\>\"", ",", "\"\<Secondary.Emlo_ID\>\""}], 
             "}"}], "]"}], "]"}]}], ",", 
         RowBox[{"EdgeWeight", "\[Rule]", 
          RowBox[{"#", "[", 
           RowBox[{"[", "\"\<Total.Connections\>\"", "]"}], "]"}]}]}], "]"}], 
       "&"}], ",", "interactionTallies$Associations"}], "]"}], ",", 
    RowBox[{"VertexLabels", "\[Rule]", 
     RowBox[{"Placed", "[", 
      RowBox[{"\"\<Name\>\"", ",", "Tooltip"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.676270150961307*^9, 3.676270196945557*^9}, {
  3.676270250407341*^9, 3.6762703290920143`*^9}, {3.676270716614808*^9, 
  3.6762707181538877`*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "MARY", 2, 3, "JEAN", "FLORENCE", 6, 7, "JULIE", "CLAIRE", "LAURA", 
       "DORIS", "JOAN", "JVGDNT", "KAREN", "URQUAX", "GEMMA", 17, "DOROTHY", 
       19, "JACQUELINE", "MFETPC", "KATHLEEN", "JANET", 24, "LISA", 26, 
       "ANNIE", 28, "ANN", 30, 31, "ELSIE", "BARBARA", "UQVRUY", "JANE", 
       "MICHELLE", "VICTORIA", "ALICE", "IRENE", "DOREEN", 41, "HELEN", 
       "SAMANTHA", "JUNE", "YAKZCN", "DIANE", "LBDVHJ", "WINIFRED", "EILEEN", 
       "SHIRLEY", "ANNE", "SHARON", "AMY", "AWWUMI", "CPYYFX", "VALERIE", 57, 
       "AMANDA", "JENNIFER", "ANGELA", "ETHEL", 62, "SANDRA", "LOUISE", 
       "KATIE", 66, "PHYLLIS", "PAULINE", 69, "LILIAN", "AUDREY", 72, "CLARE",
        "KELLY", "IVY", "VERA", "BRENDA", "LJNWXX", "NATALIE", "VIOLET", 
       "JUNMZV", "SYLVIA", "ELAINE", "LWHQYG", "LACFLA", "CATHERINE", 
       "HAYLEY", "LILY", "EDNA", "HANNAH", "NELLIE", "BERYL", 93, 94, 
       "SUCNHY", 96, "LUCY", "ADA", "DAWN", "LYNN", "BEATRICE", "ZLXPBT", 103,
        104, "CAROLE", "HFKAHK", "MAY", "EVELYN", "ROSE", "MAVIS", 111, 
       "SALLY", "KATHERINE", "IRIS", "CKYGWZ", "MARIA", "ZOE", "KERRY", 
       "DEBRA", "MELANIE", "STACEY", "GERTRUDE", "MURIEL", "PAULA", "LAUREN", 
       "MARION", "JOANNA", 129, 130, "MARINA", "JANICE", "LORRAINE", "JESSIE",
        "PEGGY", "ROSEMARY", "ANDREA", "FRANCES", "XFGSKJ", "GRACE", 
       "JOSEPHINE", "YVONNE", "SOPHIE", "LYNNE", "ANNA", "EVA", "GWENDOLINE", 
       "JESSICA", 149, "NORMA", "BEVERLEY", "KIRSTY", "KIMBERLEY", "HAZEL", 
       "FIONA", "KATE", "MARIE", "JENNA", "MARILYN", "DAISY", "NORA", 
       "NATASHA", "MINNIE", "FREDA", "MANDY", "RACHAEL", "TVKHRF", 
       "CHRISTOPHER", 169, "KATHRYN", "NANCY", "RUTH", "JAYNE", "DIANA", 
       "MARIAN", "ELEANOR", "VERONICA", "SARA", "ALEXANDRA", "LOUISA", 
       "MSRGUQ", "DORA", "DAPHNE", "TERESA", "JULIA", "NORAH", "HEATHER", 
       "KIM", "JEMMA", "THELMA", "CARLY", "IDA", "CLARA", "GLORIA", "HOLLY", 
       "HILARY", "MELISSA", "MARTHA", "CYNTHIA", "BERTHA", "LPYGMD", 
       "LILLIAN", "CHERYL", "IZRDSO", "NAOMI", 207, "BESSIE", "GAIL", "JADE", 
       "PENELOPE", "CHARLENE", 213, "CHRISTINA", "ANNETTE", 216, "QCBGCO", 
       "ESTHER", "CAROLYN", "HARRIET", "ANITA", "GERALDINE", "BRIDGET", 
       "GEORGINA", "LINDSEY", "KAY", 227, "STELLA", 229, 230, "NICHOLA", 232, 
       233, "AIMEE", "HEIDI", "MILLICENT", "MONICA", "THERESA", "MARGERY", 
       "MAXINE", "TANYA", "CARLA", "FANNY", "JOY", "LYDIA", "QSJBJN", 
       "GLENYS", "DEBBIE", "JENNY", "UQSBBO", "VIVIENNE", "TARA", "MIRIAM", 
       "YDYBEJ", "CLAIR", "LYNDSEY", "SONIA", "MOLLY", 259, 260, "ELLA", 
       "CHLOE", "SYBIL", "DAGTLQ", "TONI", "WILLIAM", "PZZJBB", 268, "PAUL", 
       270, "MARK", "JAMES", 273, "ZPINSB", "VYISWO", "ANDREW", 277, 278, 
       "DANIEL", "ARTHUR", "KKMNQK", "RICHARD", "ADLDLW", "ANTHONY", 
       "MATTHEW", "CHARLES", "FREDERICK", "KENNETH", "ALBERT", "ALAN", 291, 
       "SIMON", "ERNEST", "ALFRED", "EDWARD", "JOSEPH", "LEE", "ADAM", 
       "ROGER", "HAROLD", "QUQJHK", "KEITH", "FRANK", "ACVRVL", "RAYMOND", 
       "COLIN", "WRMHHQ", "DARREN", "HENRY", "PHILIP", "GARY", "BENJAMIN", 
       "STANLEY", 314, "STEVEN", 316, "ERIC", 318, 319, "MARTIN", 321, 322, 
       "WALTER", 324, "NUHUTJ", "NICHOLAS", 327, "LEONARD", "BARRY", "NKMUGR",
        "GORDON", "NORMAN", "NEIL", "NIGEL", "MALCOLM", "TIMOTHY", "STUART", 
       "GEOFFREY", "ALEXANDER", "CYRIL", "SIDNEY", "MBHDDP", "RYAN", "KCVFLP",
        "LUKE", "JACK", "TREVOR", "UNKPWV", "AJRODZ", "WILFRED", "PATRICK", 
       "KIRZZH", "SAMUEL", "WAYNE", "VRADXE", "GARETH", 357, "SEAN", "HORACE",
        "BERNARD", 361, 362, "FRED", "EDWIN", "FZCFTO", "SHAUN", "CLIFFORD", 
       "MAURICE", "CLIVE", "BEN", "ANTONY", "MXOUPI", 373, "JUSTIN", 375, 
       "JEFFREY", "OLIVER", "EDGAR", "CHRISTIAN", "ASHLEY", "KARL", "AARON", 
       "MARC", "MOHAMMED", "PEYHIE", "RUSSELL", "GAVIN", "VIVVLG", "LIAM", 
       "ROBIN", "PHILLIP", "NATHAN", "DENIS"}, {CompressedData["
1:eJxN1XWYFHUcBvClG47YBY48upZY6oijuzmOo7vr6G6OMBETAxVBRMVuxVbs
FgO7u1uxZh4/I/zxPp97f7/Z783OzO5mTF2YnVcwFosdKxCLhQb8b6EghRn2
IlJYL8piLM4SLMlSLM0yLBukHMOexvKswIqsxDgTrMwqrMp0VmN11mBN1mJt
ZrAO67Ie67MBGwZpZF7jk+Y2YVM2Y5LN2YIt2YoptmZ03duwLduxfZDMIB30
TImuZ0eJeid2Zha7sCu7sTt7sCfD994rSG/2YYJ92Y/9OYADmWSKgziYQziU
wziccWZzBHM4krkcxdEcE2RskHEczwmcyEmczCmcymmMczpncCZncTbncC7n
cT4XMI8LuYiLuYRLuYzLuYIruYqruYZruY7ruYEbuYnp3MwC3MJ8buU2bucO
ppjNU3gqEzyNp/MMnsmdPIsjuMvfZ/McOVdP43k8n+lM8QLu5oW8iBfzEu7h
pf7fZXo+L+dexnkF93E/r+QBJngVD/JqXsNrmcNDvI7X8wbeyJt4M2/hrUwy
m7fxdt4RO/GZDL2Td/Fu3sPDvJf38X4+wAfdg+h+PMSH+Yh79qh+hI/xcT7B
J/kUn+Yz5hxhuB5+Vz/LCUxj3HFx/Tk+b/0F/UW+xGj9ZR7lK3yVr/F1HuMb
fJPNOYpv8W2+w3eZ4nux/56V9/kB0/ghP+LH/ISfxk48a6Gf8XN+wTi/ZAaz
mcmvmOIufs1vmOROfsvv+D0TPMbd/IH5/JE/ObfofH9mLn/hXv7KHP7G372H
P/Tj+nH9zyB/Bfmb/zD8Qg0twIIsxMIswqIsxuLMMq+EXpKleNB+ab0My7Ic
01ieFViRlRhnIppjfmV9n15Frxodbz1dr8bqrMGarMXazGAd1mU91mcDNmQj
NmYTNmUzJtk86s63hd6SrZhia7ZhW7Zje2YGdgjSkZ0Y/g6F5jDJzvYTepbe
hSnrXfVu7M4e7Mle9nrrfdiX/difA7wmmj+QgziYQ7x2qB53Xoe5n8PsH9CH
67l6Ng9F3f4I7rG+kUej62Z/ZDSPoziaYziW4zieEziRk4JMDjKFUzmN0zmD
MzmLszmHczmP87mAeVzIRVzM8HMcukQfzKVcxuVcwZVcxSxzUgyfr0Un9dWO
W8O1XMf1TDp+g76R+dY36ZuZa32Lvl/P17dyG7dzR5B/AS5udwk=
       "], Null}, {
      VertexLabels -> {
         Placed["Name", Tooltip]}, EdgeWeight -> CompressedData["
1:eJyFUNsRgCAMIy3IHK7kCCzgvG4jFI8rtWI+aEhfue7lPApCCFd9oBFBLVAL
woRQp6KMBBQRbD0wHORWTUhezoC+VXoVKcXd+zvebuNZ5oWbivR0RIzjqHMt
TLD0zJZJGzDUN2H3zP8bwKAErA==
        "]}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[0.01778141633701648], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.532537510486784, 2.4864476516409706`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {2.56019190850827,
          2.1881187591285935`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.6809765476348346`, 2.132290583899925}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {2.80759955897226,
          2.0942859439459607`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         3.1709704115292134`, 2.969099785102592}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.6873696716808357`, 2.948736987448672}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.6281524226121875`, 3.0809666718565905`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.3767434589407133`, 2.2582050062738306`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.7784527363860168`, 1.7634443487195306`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         3.0430832156780405`, 1.7728453338247212`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.717475362572606, 1.9533471451421083`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         3.227868760502958, 2.045747407662254}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         1.8928874028487797`, 2.9295881308118688`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         4.717967172657957, 2.247008616963713}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         3.6932485238708868`, 2.1146740830214448`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.548930735926647, 2.031930272355649}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         3.179138326550807, 3.1336660226777266`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.9089174369494897`, 3.1923287499261903`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         4.8730050464711185`, 2.7284170627165594`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {4.1118989239318, 
         2.8528295234478325`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.9151966474947306`, 1.7523987031896178`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.7706292962715278`, 3.1807872856974755`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         3.0311280858836698`, 3.163854652020936}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         4.739075073848264, 3.3548619505669355`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.4265172000830804`, 2.3897307432303956`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.710851956395415, 2.3214497709697786`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         3.282460094273419, 1.8854927618004407`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.1919474683103948`, 1.862528536213921}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.5504199043905276`, 2.3278792957268686`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.350143074764466, 2.5213862884353406`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         4.431400475282976, 2.3735673939600495`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.631542683926015, 2.6228652267975625`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.869718419410847, 2.247653265447554}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.657101846398171, 1.8356837329190208`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.9402012569602656`, 2.4503125755134008`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.5535654947018784`, 1.9031066223704363`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         3.1088554968725317`, 2.241141153323576}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.4086147423427886`, 1.9944401577233473`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.8640278426132526`, 2.7719656382086657`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.525200803202172, 2.748930876369467}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.813585976152269, 2.6248978650498995`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         3.917790446940783, 2.640500949657646}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         3.9011281505152993`, 1.7332767461647987`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         3.0039600949850334`, 2.0781515674162447`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.852661010968112, 1.9142246350955632`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         4.683064068883834, 1.245810751888267}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         4.738003895465744, 2.438421916783211}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         3.0868081360430004`, 2.737394995088968}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.4564612296262527`, 2.861114506272823}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.460022018925988, 2.5888676204785144`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         3.176379186616198, 1.8015890862564126`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.554234589939101, 2.9473469241446786`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         4.2650064092992475`, 2.0466769646670513`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         3.4438257076629464`, 2.114094118210321}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.8279456451481755`, 2.8978482629102613`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.412615360157618, 2.147029466294559}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.280173282606988, 2.3473075059623456`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.643030825011694, 2.788931612883296}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.824022741644952, 3.0566821626084484`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.3910874562171807`, 2.6992451631574474`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         3.013525846634314, 1.9148642382863623`}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {
         2.982929118467082, 2.969410380332694}}, 0.05916923324627664], 
        ArrowBox[{{3.286229156506713, 2.5026766615150122`}, {2.69530438977898,
          2.460795651944117}}, 0.05916923324627664], 
        ArrowBox[{{2.6809765476348346`, 2.132290583899925}, {2.56019190850827,
          2.1881187591285935`}}, 0.05916923324627664], 
        ArrowBox[{{2.80759955897226, 2.0942859439459607`}, {
         2.6809765476348346`, 2.132290583899925}}, 0.05916923324627664], 
        ArrowBox[{{1.1828628935369445`, 2.6549765759498207`}, {
         1.8928874028487797`, 2.9295881308118688`}}, 0.05916923324627664], 
        ArrowBox[{{4.431400475282976, 2.3735673939600495`}, {
         4.8730050464711185`, 2.7284170627165594`}}, 0.05916923324627664], 
        ArrowBox[{{2.4086147423427886`, 1.9944401577233473`}, {
         2.1919474683103948`, 1.862528536213921}}, 0.05916923324627664], 
        ArrowBox[{{1.4519856831239868`, 1.4111927026543916`}, {
         2.1919474683103948`, 1.862528536213921}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {4.717967172657957, 
         2.247008616963713}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {
         4.8730050464711185`, 2.7284170627165594`}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {
         3.9011281505152993`, 1.7332767461647987`}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {4.738003895465744, 
         2.438421916783211}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {5.152538307205706, 
         1.0438055800527106`}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {5.259298654341054, 
         2.777645480904296}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {5.059365996060082, 
         0.37075160479062363`}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {4.751395620238616, 
         0.43836679935751155`}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {4.882558769893714, 
         0.2757595453499011}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {4.677534535749722, 
         1.692785352156783}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {4.867546262970022, 
         0.4175798005497957}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {5.156525278579793, 
         0.4473475461469816}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {4.749094808750387, 
         0.6036041263808407}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {4.501179195409648, 
         2.6272312670498783`}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {
         4.5018367737399005`, 0.43296188767322175`}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {4.976095744920696, 
         0.49310148766966844`}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {4.553740718797244, 
         0.6370907454908572}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {4.576166373359195, 
         0.3225585997065856}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {5.166709599763112, 
         1.4574285005419627`}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {4.890218388762008, 
         0.6408181466013585}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {4.693023262313079, 
         0.2963659686956861}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {4.440723677198861, 
         0.5366492928843987}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {5.001717125179382, 
         0.2804461046413729}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {4.779391042006912, 
         0.24546038590813302`}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {
         4.6228129245298035`, 0.510137681165586}}, 0.05916923324627664], 
        ArrowBox[{{4.683064068883834, 1.245810751888267}, {5.07854645191446, 
         0.5848141693643729}}, 0.05916923324627664], 
        ArrowBox[{{4.738003895465744, 2.438421916783211}, {
         4.8730050464711185`, 2.7284170627165594`}}, 0.05916923324627664], 
        ArrowBox[{{4.738003895465744, 2.438421916783211}, {4.534719413176031, 
         1.952455598198461}}, 0.05916923324627664], 
        ArrowBox[{{4.738003895465744, 2.438421916783211}, {
         5.3750504363538525`, 2.5558964858915947`}}, 0.05916923324627664], 
        ArrowBox[{{4.738003895465744, 2.438421916783211}, {5.351468760007008, 
         2.658552666100384}}, 0.05916923324627664], 
        ArrowBox[{{4.738003895465744, 2.438421916783211}, {4.677534535749722, 
         1.692785352156783}}, 0.05916923324627664], 
        ArrowBox[{{4.738003895465744, 2.438421916783211}, {4.73931348469306, 
         1.914419597546051}}, 0.05916923324627664], 
        ArrowBox[{{4.738003895465744, 2.438421916783211}, {5.107280804464408, 
         2.071066410750324}}, 0.05916923324627664], 
        ArrowBox[{{4.2650064092992475`, 2.0466769646670513`}, {
         3.6932485238708868`, 2.1146740830214448`}}, 0.05916923324627664], 
        ArrowBox[{{4.2650064092992475`, 2.0466769646670513`}, {
         4.168412863407633, 1.4049139205187118`}}, 0.05916923324627664], 
        ArrowBox[{{3.4438257076629464`, 2.114094118210321}, {
         3.6932485238708868`, 2.1146740830214448`}}, 0.05916923324627664], 
        ArrowBox[{{5.419493963755297, 1.6222849957142134`}, {
         4.8730050464711185`, 2.7284170627165594`}}, 0.05916923324627664], 
        ArrowBox[{{5.419493963755297, 1.6222849957142134`}, {4.1118989239318, 
         2.8528295234478325`}}, 0.05916923324627664], 
        ArrowBox[{{5.419493963755297, 1.6222849957142134`}, {
         3.917790446940783, 2.640500949657646}}, 0.05916923324627664], 
        ArrowBox[{{5.419493963755297, 1.6222849957142134`}, {
         4.738003895465744, 2.438421916783211}}, 0.05916923324627664], 
        ArrowBox[{{5.419493963755297, 1.6222849957142134`}, {
         5.9377463862521385`, 0.9720055643270571}}, 0.05916923324627664], 
        ArrowBox[{{5.419493963755297, 1.6222849957142134`}, {
         5.686950208161191, 0.7638897775283437}}, 0.05916923324627664], 
        ArrowBox[{{5.419493963755297, 1.6222849957142134`}, {
         6.156161164987801, 0.86083900335185}}, 0.05916923324627664], 
        ArrowBox[{{5.419493963755297, 1.6222849957142134`}, {
         5.812758568363123, 0.957357854555742}}, 0.05916923324627664], 
        ArrowBox[{{5.419493963755297, 1.6222849957142134`}, {6.05294384887973,
          0.9209257710599832}}, 0.05916923324627664], 
        ArrowBox[{{5.419493963755297, 1.6222849957142134`}, {5.52051259630225,
          0.836297074731303}}, 0.05916923324627664], 
        ArrowBox[{{5.419493963755297, 1.6222849957142134`}, {
         6.090720473590337, 1.0456179163499868`}}, 0.05916923324627664], 
        ArrowBox[{{5.419493963755297, 1.6222849957142134`}, {
         5.818936268714873, 0.7978438622700184}}, 0.05916923324627664], 
        ArrowBox[{{5.419493963755297, 1.6222849957142134`}, {
         5.9325015577573055`, 0.8079939351740921}}, 0.05916923324627664], 
        ArrowBox[{{5.419493963755297, 1.6222849957142134`}, {
         6.068545024683542, 0.7836970281843771}}, 0.05916923324627664], 
        ArrowBox[{{5.419493963755297, 1.6222849957142134`}, {
         6.243935992624913, 1.0654272107632627`}}, 0.05916923324627664], 
        ArrowBox[{{5.419493963755297, 1.6222849957142134`}, {
         5.661987102725427, 0.904726182831507}}, 0.05916923324627664], 
        ArrowBox[{{5.419493963755297, 1.6222849957142134`}, {
         5.932680377379178, 0.6916525803799898}}, 0.05916923324627664], 
        ArrowBox[{{5.419493963755297, 1.6222849957142134`}, {
         5.324371602114402, 3.0468036220992034`}}, 0.05916923324627664], 
        ArrowBox[BezierCurveBox[{{5.419493963755297, 1.6222849957142134`}, {
         5.418287175843297, 2.349984988163258}, {5.849250714402505, 
         2.9363459382553234`}}], 0.05916923324627664], 
        ArrowBox[{{5.419493963755297, 1.6222849957142134`}, {5.13638720706868,
          2.7686061356978193`}}, 0.05916923324627664], 
        ArrowBox[{{5.419493963755297, 1.6222849957142134`}, {
         5.7801488557272975`, 0.6632658391325665}}, 0.05916923324627664], 
        ArrowBox[{{5.419493963755297, 1.6222849957142134`}, {4.51422500603719,
          2.2529314493341337`}}, 0.05916923324627664], 
        ArrowBox[{{5.419493963755297, 1.6222849957142134`}, {
         5.152538307205706, 1.0438055800527106`}}, 0.05916923324627664], 
        ArrowBox[{{5.419493963755297, 1.6222849957142134`}, {
         6.2269496352947336`, 0.9599454331998611}}, 0.05916923324627664], 
        ArrowBox[{{5.419493963755297, 1.6222849957142134`}, {
         5.596085032650404, 0.6895372962563102}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         4.717967172657957, 2.247008616963713}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         4.8730050464711185`, 2.7284170627165594`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {4.1118989239318, 
         2.8528295234478325`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         4.739075073848264, 3.3548619505669355`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         3.917790446940783, 2.640500949657646}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         4.738003895465744, 2.438421916783211}}, 0.05916923324627664], 
        ArrowBox[BezierCurveBox[{{5.849250714402505, 2.9363459382553234`}, {
         5.850457502314506, 2.2086459457892116`}, {5.419493963755297, 
         1.6222849957142134`}}], 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         5.324371602114402, 3.0468036220992034`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {5.13638720706868,
          2.7686061356978193`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         4.911713811031306, 2.586261325112576}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.438954362554788, 2.667424179664479}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         7.434844543474231, 2.830484610999371}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.848253906173986, 2.8580306854243496`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.700487870694593, 2.4424766724498856`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {6.29388255075513,
          2.5678167858152916`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.0266510192185105`, 2.489165010141661}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.861886521067051, 2.6966910162865267`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.741402871473496, 3.3160197003524416`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.919091373624478, 3.1462622526861104`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.352226374323344, 3.248867088466713}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {5.20254894967904,
          3.6461575707622336`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.554306086344868, 2.672522066904943}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.049314292331256, 3.5117152657879362`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         5.950493588168063, 2.431134048938171}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.746644737080452, 2.6782890820337264`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         3.4515511696764003`, 3.342716500973031}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         4.449632454591704, 2.533045852598579}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.802663045555416, 3.175658584300045}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         5.109702040082671, 3.5568648829146956`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.804481533314103, 2.9696756153261017`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         3.4289017078547106`, 2.7365332138085625`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {6.9523360521308, 
         2.743928821700988}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.644391928447045, 3.244452126141589}}, 0.05916923324627664], 
        ArrowBox[BezierCurveBox[{{5.849250714402505, 2.9363459382553234`}, {
         5.814548709664946, 2.4737642518603424`}, {5.5120502218283844`, 
         2.1220815673911515`}}], 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         5.193981899820784, 3.5556287141883387`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.520042883951646, 3.5228866331337763`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.625686589218123, 2.381921734570134}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.616663838754043, 2.8089458941913774`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.402619766331258, 3.5518477056234867`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.459581670558542, 3.0550215260909916`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.481370801314781, 2.407378500888442}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.861738053447665, 2.5790176241241203`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.645903556697599, 2.931387344085481}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.216199441754197, 3.4542343355260443`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.862683117910904, 3.2922014813765266`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.534302206428681, 3.351992682829069}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {6.39303609848101,
          3.4127726304034165`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.507075072222268, 3.2123205142857305`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.743798349805475, 3.064108472214346}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.1901085703624865`, 3.325941375114658}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         5.087933691562657, 3.459534997474436}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.337965104662092, 2.7776768114723245`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.963802648567968, 2.886337006782308}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.291965012588083, 2.9874382292511314`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.5150465951610865`, 2.5293957182366364`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.191600025591699, 3.1618926718503135`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.621225799852331, 3.0903921872936064`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.655659937061612, 2.5973416307814463`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.928796847213739, 3.0236386651930554`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         5.3750504363538525`, 2.5558964858915947`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.790423052016454, 2.4922590663415978`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.221829943051231, 3.572673718568332}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.743906537485026, 2.7970307139966994`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.475909979942354, 2.884643793970506}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {6.63982893028647,
          3.4760810591037865`}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         5.351468760007008, 2.658552666100384}}, 0.05916923324627664], 
        ArrowBox[{{5.849250714402505, 2.9363459382553234`}, {
         6.7455750145556905`, 3.4267583612063}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {3.286229156506713, 
         2.5026766615150122`}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {
         4.8730050464711185`, 2.7284170627165594`}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {4.1118989239318, 
         2.8528295234478325`}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {4.739075073848264, 
         3.3548619505669355`}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {4.738003895465744, 
         2.438421916783211}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {5.324371602114402, 
         3.0468036220992034`}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {5.849250714402505, 
         2.9363459382553234`}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.365975010583998, 
         5.121678520977948}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {
         6.2297273099504284`, 4.590126385496445}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {5.259298654341054, 
         2.777645480904296}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.540086666110078, 
         4.4345259343806385`}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.357462682996364, 
         4.846279140828983}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.519824449473637, 
         4.921158425969408}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.509656438398307, 
         5.168314570841019}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {
         5.8548189364099805`, 5.156367667017251}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {5.983482673071006, 
         5.106738793360854}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.178773039899925, 
         5.207358622371585}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.410314567799693, 
         4.395771459935014}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.620749914373296, 
         4.826112101562465}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.051067702419588, 
         5.2549065971981275`}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.647929117593844, 
         4.703472562135655}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {5.719542160941998, 
         5.161927089156844}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {5.512713750415653, 
         5.065444456618279}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.361711882095648, 
         4.985612624663825}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.362910457949491, 
         4.7109469149736505`}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.490216765954272, 
         4.768828069593358}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {5.669934498013632, 
         4.892916760478343}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {5.630505524169648, 
         5.040121667874052}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {5.907130714175474, 
         5.258748453933963}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.251126858350011, 
         5.09674171621481}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.107409006547169, 
         5.077604921035324}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {5.713752879601781, 
         5.29106314533824}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.790958068512422, 
         4.497006781690249}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.407897163894246, 
         4.5610063093545135`}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.038479397516811, 
         4.708117174265966}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.745655007437586, 
         4.852728320216136}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {
         6.2188350986354735`, 4.933111608037214}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {
         6.6648733440522765`, 4.959535524313251}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {5.825763063611469, 
         5.342677687141828}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.777709740951684, 
         4.7240559177022625`}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.647357608062556, 
         4.517464066783505}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.064337687752802, 
         4.906687202802276}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.772579886658698, 
         4.61076776073411}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {5.100906852639415, 
         4.330120740246019}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.553334478641496, 
         4.619374414996618}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.727715887034952, 
         4.384252299443624}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.388415970003356, 
         5.2381358705537995`}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {4.911713811031306, 
         2.586261325112576}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.275801716041025, 
         5.278380987402617}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.609823235624464, 
         4.319267687680287}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {
         6.1572347298549275`, 5.346796452347017}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {5.926254550018793, 
         4.938054104736361}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {
         6.6109000996072975`, 5.067132635484567}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {6.171308591464613, 
         4.797669019461594}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {5.819437586060483, 
         4.8169133218931215`}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {5.808647205809958, 
         5.0076337273281055`}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {5.989293884659297, 
         5.3683563750493395`}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {5.598255128580069, 
         5.2089379424441535`}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {5.728968870792024, 
         3.2463608440239202`}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {
         6.4943391258594385`, 5.046727606371789}}, 0.05916923324627664], 
        ArrowBox[{{5.794178533001282, 4.295702963815212}, {
         5.6468107380787025`, 3.2559799988503073`}}, 0.05916923324627664], 
        ArrowBox[{{7.434844543474231, 2.830484610999371}, {8.318970790181242, 
         2.8487135386723215`}}, 0.05916923324627664], 
        ArrowBox[{{7.434844543474231, 2.830484610999371}, {8.308606538516361, 
         2.696822699860878}}, 0.05916923324627664], 
        ArrowBox[{{6.0266510192185105`, 2.489165010141661}, {6.29388255075513,
          2.5678167858152916`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         4.717967172657957, 2.247008616963713}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         4.8730050464711185`, 2.7284170627165594`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         4.1118989239318, 2.8528295234478325`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         4.431400475282976, 2.3735673939600495`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         3.917790446940783, 2.640500949657646}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         4.738003895465744, 2.438421916783211}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         4.2650064092992475`, 2.0466769646670513`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         5.324371602114402, 3.0468036220992034`}}, 0.05916923324627664], 
        ArrowBox[BezierCurveBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         5.546752226565943, 2.5846632537683405`}, {5.849250714402505, 
         2.9363459382553234`}}], 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         5.13638720706868, 2.7686061356978193`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         4.51422500603719, 2.2529314493341337`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         4.911713811031306, 2.586261325112576}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         5.728968870792024, 3.2463608440239202`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         5.6468107380787025`, 3.2559799988503073`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         6.0266510192185105`, 2.489165010141661}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         5.950493588168063, 2.431134048938171}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         5.166709599763112, 1.4574285005419627`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         6.193960451610545, 1.5269478908429592`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         5.550409226477074, 1.465518966322477}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         5.85293811720253, 1.4081016430179862`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         6.053924506648571, 1.4064740656287693`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         6.256127868513868, 1.7577321697835315`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         5.806463941406644, 1.7936709072161272`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         6.415714643899557, 1.6353841429849536`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         6.14743246172484, 1.9738856314389224`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         6.07011431406212, 1.7501701558579208`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         5.97322243091558, 2.140773218470946}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         5.962547303498972, 1.5033695238807598`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         6.093363973397614, 1.5946526822363933`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         5.860353399282597, 1.5844617459827466`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         5.687412558082926, 1.3857790014639133`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         5.707526552732934, 1.5388039487978071`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         5.765755057626299, 2.140440327512224}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         6.199912644534733, 2.0848858823262755`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         6.281486048750612, 1.641729667331575}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         6.332131459418241, 1.5255485588225783`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         5.686578552406644, 1.9927934606402578`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         5.97503823521391, 1.9367173334525603`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         6.44620085909332, 1.760990941222535}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         5.8865772531875304`, 2.240382044296952}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         6.213991454832093, 1.4325089835232951`}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         6.367683140125169, 1.857010964825938}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         5.107280804464408, 2.071066410750324}}, 0.05916923324627664], 
        ArrowBox[{{5.5120502218283844`, 2.1220815673911515`}, {
         6.06748899099226, 2.2317191355347825`}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         1.8928874028487797`, 2.9295881308118688`}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {4.1118989239318, 
         2.8528295234478325`}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         3.917790446940783, 2.640500949657646}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         2.280173282606988, 2.3473075059623456`}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         3.4515511696764003`, 3.342716500973031}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         3.4289017078547106`, 2.7365332138085625`}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.020256759784529343`, 3.4735795269987326`}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.0826226501711087, 3.28257117625992}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.8384795932604829, 4.382960998191306}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.47002687142130606`, 4.02361231817226}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.3455316442510563, 3.9457284863340076`}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.10019495055573646`, 3.391193800511799}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.8628061606871054, 4.215840146912527}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.2266097282668218, 3.296303602896672}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.2778798478622071, 3.598815882040535}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.2728552298655602, 4.190674292551935}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.2666624387443024, 3.099034648573936}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.3359305768021512, 3.7190141457881327`}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.1351775487440534, 4.167036378173184}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.9739711900014467, 4.092288086369532}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.7023486570287338, 4.04379657792637}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.6455719856229605, 3.393867512857955}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.5816967626346976, 4.111655454001608}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.48689835513946855`, 3.8688185853023205`}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.621678054853938, 3.0563172806705547`}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.9288571618726795, 4.495621532473739}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.4792941656123548, 3.413822520988866}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         1.094141518995297, 4.400939892089148}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.36498918097719235`, 3.009961797283954}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.013984822548024134`, 3.8648689535696077`}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.9738957790590748, 4.338549729456501}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.6660531974460646, 3.794063493093822}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.7850080077479396, 4.5118108893982285`}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.21028432425060162`, 4.078927266768108}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.5879960910085713, 4.358814316914354}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.4004756983281328, 4.152593702822263}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.4998340592441495, 3.708759848807689}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.4865384526698242, 4.2707850723480485`}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.5250052904325608, 4.476852081327943}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.43038070063343214`, 3.5686292697098745`}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.02090947534034271, 3.7256892163256667`}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.06439946292149568, 4.022103284904462}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.3496938809997454, 3.241445490212884}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.7346394252433464, 4.324109946210176}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.1530574776702478, 3.721652779097516}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.25276658799153706`, 4.30347809241438}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.1251833575576713, 3.599241613328986}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.6927639116138518, 3.195586154983091}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.32890128756848025`, 3.4205637988620516`}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.1717965436029445, 3.1746674290614196`}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.2002317462272356, 3.9669170263446887`}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.36039534892484415`, 4.318637917316683}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.5263982929225008, 3.2566235118511115`}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.6566468256533695, 4.501103360396075}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.6739143434348422, 3.5622701605454994`}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.26119808479500417`, 3.836932620838783}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.8099539871443642, 3.9244604710603515`}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.4050185839357128, 4.4162578926420695`}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.1864919583376019, 3.475705456635852}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.43325771683821523`, 3.1336260682470938`}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         1.1031491059783773`, 4.228620125485023}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.13223693987286378`, 3.866669109735546}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.659208335882389, 4.224769425045402}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {0., 
         3.6038272204377897`}}, 0.05916923324627664], 
        ArrowBox[{{1.0734862107930678`, 3.613056073998518}, {
         0.5043268835093695, 3.0083868217186223`}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.8730050464711185`, 2.7284170627165594`}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {4.1118989239318, 
         2.8528295234478325`}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.739075073848264, 3.3548619505669355`}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         3.917790446940783, 2.640500949657646}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.738003895465744, 2.438421916783211}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         5.324371602114402, 3.0468036220992034`}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {5.13638720706868,
          2.7686061356978193`}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {4.51422500603719,
          2.2529314493341337`}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         5.100906852639415, 4.330120740246019}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {5.20254894967904,
          3.6461575707622336`}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.449632454591704, 2.533045852598579}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         5.109702040082671, 3.5568648829146956`}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         5.193981899820784, 3.5556287141883387`}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         5.087933691562657, 3.459534997474436}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.501179195409648, 2.6272312670498783`}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         3.9650798522078916`, 4.859572498300617}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         3.866495451045463, 4.573211120916005}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         3.6618714804441472`, 4.532747337879211}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {4.2670442694893, 
         4.590968060802998}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.586342030190271, 4.816474522625021}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         3.7397618929152427`, 4.436780890613524}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.592074745646717, 4.64168110273655}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.252264472144632, 5.263771240942853}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         3.6519602806871108`, 4.322735884359272}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.553290220580485, 4.314380945337992}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         3.8141741510078577`, 4.332810816966502}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.733811831993701, 4.588401267414509}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.067113179235254, 4.764867207559504}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         3.8091001424806588`, 5.1066180502543235`}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.009995134107254, 4.595245989487468}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.333456413309544, 4.431790399919702}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.7109641489256475`, 4.424662329127981}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.105429117600194, 4.903162257192608}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         3.8873382518610824`, 2.499837056536484}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.154109941531763, 4.452963855795849}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.388828294149722, 4.893713401279151}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         3.805784079207106, 4.750538923208355}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         3.752570443096102, 4.633276363573887}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         3.751067705651491, 4.1707469464755125`}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         3.9287905006316017`, 4.73570138262282}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         3.923010962400469, 4.19371142607152}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.347280008290771, 4.749071332516304}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.691402835859663, 4.739952869752491}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.237349776480345, 4.934406972164576}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.453730714772374, 4.643912517733487}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.059652473401591, 4.296656776141832}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.492707951276989, 4.896648148573503}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         3.944950454902995, 4.425602575726703}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.140589529962889, 4.667639214265626}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.5285111978763775`, 4.487421507944514}}, 0.05916923324627664], 
        ArrowBox[{{4.363727400868515, 3.9526104740690053`}, {
         4.231675205140929, 4.8072629057601945`}}, 0.05916923324627664], 
        ArrowBox[{{4.252264472144632, 5.263771240942853}, {4.183547184247431, 
         6.14803314026841}}, 0.05916923324627664], 
        ArrowBox[{{3.8141741510078577`, 4.332810816966502}, {
         3.7397618929152427`, 4.436780890613524}}, 0.05916923324627664], 
        ArrowBox[{{3.8091001424806588`, 5.1066180502543235`}, {
         3.4055644221115013`, 5.84029279488464}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {4.1118989239318, 
         2.8528295234478325`}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.917790446940783, 2.640500949657646}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         4.738003895465744, 2.438421916783211}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         2.280173282606988, 2.3473075059623456`}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {4.51422500603719,
          2.2529314493341337`}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         4.911713811031306, 2.586261325112576}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         4.449632454591704, 2.533045852598579}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.4289017078547106`, 2.7365332138085625`}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.8873382518610824`, 2.499837056536484}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.5255199739139442`, 0.05174303618850207}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         2.6420482762243114`, 0.6290150585610736}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.6493143222330247`, 0.34064915040617505`}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.121712033947512, 0.3964524852024298}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.752218531478349, 0.17769316375478095`}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         2.9843696033409275`, 0.13100184161526895`}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.2801675544157414`, 0.5193212156788114}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         2.661175830438739, 0.38219852432715173`}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         2.796277751310369, 0.6088104962207552}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.0726593023825046`, 0.04930556501661565}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         2.797195901473659, 0.34726428110381136`}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.0765489469257834`, 0.23925186468339232`}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.251130396030764, 0.}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         2.953507178495718, 0.3145275015947706}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.688594766626704, 0.5005891336330199}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         4.115448299071365, 1.620007106324374}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.475521996974595, 0.2659173888793416}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.2884250885372586`, 0.11554905380577374`}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.7797472553650584`, 0.33329119534508544`}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         2.7470010633709054`, 0.24835769379540595`}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         2.7533818393188962`, 0.780184811378533}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         2.879530119235419, 0.43607224247584364`}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.516624760366616, 0.42439177816029616`}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         2.9800139427545327`, 0.5310157963922046}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.4472014553926247`, 0.5746455988651644}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         2.6283588858411955`, 0.7617314133332531}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.1666536801122662`, 0.12508884258070863`}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.6365626112710925`, 0.08889100986450593}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.1826878449766145`, 0.3061697602836726}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         2.606053970360506, 0.5177304130855807}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.4108025133548874`, 0.005575430578998564}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.6007316244648124`, 0.19992221862777493`}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         2.9016479866550813`, 0.7103177807793619}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         2.748423371670481, 0.4834964407555251}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.3179805820154353`, 0.26540948560116107`}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.4162437905953844`, 0.14854356729374407`}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         2.888254961342537, 0.19321857841527468`}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.116031938746251, 0.5780215589652817}}, 0.05916923324627664], 
        ArrowBox[{{3.451715780356415, 1.0568188462791823`}, {
         3.304582529863077, 0.40769940425153717`}}, 0.05916923324627664], 
        ArrowBox[{{4.115448299071365, 1.620007106324374}, {4.738003895465744, 
         2.438421916783211}}, 0.05916923324627664]}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
        TagBox[
         TooltipBox[
          DiskBox[{3.286229156506713, 2.5026766615150122`}, 
           0.05916923324627664],
          "\"MARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.532537510486784, 2.4864476516409706`}, 
           0.05916923324627664],
          "2"],
         Annotation[#, 2, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.56019190850827, 2.1881187591285935`}, 
           0.05916923324627664],
          "3"],
         Annotation[#, 3, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.6809765476348346`, 2.132290583899925}, 
           0.05916923324627664],
          "\"JEAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.80759955897226, 2.0942859439459607`}, 
           0.05916923324627664],
          "\"FLORENCE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FLORENCE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1709704115292134`, 2.969099785102592}, 
           0.05916923324627664],
          "6"],
         Annotation[#, 6, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.6873696716808357`, 2.948736987448672}, 
           0.05916923324627664],
          "7"],
         Annotation[#, 7, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.6281524226121875`, 3.0809666718565905`}, 
           0.05916923324627664],
          "\"JULIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JULIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3767434589407133`, 2.2582050062738306`}, 
           0.05916923324627664],
          "\"CLAIRE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLAIRE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.7784527363860168`, 1.7634443487195306`}, 
           0.05916923324627664],
          "\"LAURA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LAURA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.0430832156780405`, 1.7728453338247212`}, 
           0.05916923324627664],
          "\"DORIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DORIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.717475362572606, 1.9533471451421083`}, 
           0.05916923324627664],
          "\"JOAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.227868760502958, 2.045747407662254}, 0.05916923324627664],
          "\"JVGDNT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JVGDNT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8928874028487797`, 2.9295881308118688`}, 
           0.05916923324627664],
          "\"KAREN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KAREN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1828628935369445`, 2.6549765759498207`}, 
           0.05916923324627664],
          "\"URQUAX\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "URQUAX", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.717967172657957, 2.247008616963713}, 0.05916923324627664],
          "\"GEMMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GEMMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6932485238708868`, 2.1146740830214448`}, 
           0.05916923324627664],
          "17"],
         Annotation[#, 17, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.548930735926647, 2.031930272355649}, 0.05916923324627664],
          "\"DOROTHY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DOROTHY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.179138326550807, 3.1336660226777266`}, 
           0.05916923324627664],
          "19"],
         Annotation[#, 19, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9089174369494897`, 3.1923287499261903`}, 
           0.05916923324627664],
          "\"JACQUELINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JACQUELINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.8730050464711185`, 2.7284170627165594`}, 
           0.05916923324627664],
          "\"MFETPC\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MFETPC", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.1118989239318, 2.8528295234478325`}, 0.05916923324627664],
          "\"KATHLEEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATHLEEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9151966474947306`, 1.7523987031896178`}, 
           0.05916923324627664],
          "\"JANET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JANET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.7706292962715278`, 3.1807872856974755`}, 
           0.05916923324627664],
          "24"],
         Annotation[#, 24, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.0311280858836698`, 3.163854652020936}, 
           0.05916923324627664],
          "\"LISA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LISA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.739075073848264, 3.3548619505669355`}, 
           0.05916923324627664],
          "26"],
         Annotation[#, 26, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.4265172000830804`, 2.3897307432303956`}, 
           0.05916923324627664],
          "\"ANNIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.710851956395415, 2.3214497709697786`}, 
           0.05916923324627664],
          "28"],
         Annotation[#, 28, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.282460094273419, 1.8854927618004407`}, 
           0.05916923324627664],
          "\"ANN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.1919474683103948`, 1.862528536213921}, 
           0.05916923324627664],
          "30"],
         Annotation[#, 30, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.5504199043905276`, 2.3278792957268686`}, 
           0.05916923324627664],
          "31"],
         Annotation[#, 31, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.350143074764466, 2.5213862884353406`}, 
           0.05916923324627664],
          "\"ELSIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELSIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.431400475282976, 2.3735673939600495`}, 
           0.05916923324627664],
          "\"BARBARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BARBARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.631542683926015, 2.6228652267975625`}, 
           0.05916923324627664],
          "\"UQVRUY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "UQVRUY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.869718419410847, 2.247653265447554}, 0.05916923324627664],
          "\"JANE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JANE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.657101846398171, 1.8356837329190208`}, 
           0.05916923324627664],
          "\"MICHELLE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MICHELLE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9402012569602656`, 2.4503125755134008`}, 
           0.05916923324627664],
          "\"VICTORIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VICTORIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.5535654947018784`, 1.9031066223704363`}, 
           0.05916923324627664],
          "\"ALICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1088554968725317`, 2.241141153323576}, 
           0.05916923324627664],
          "\"IRENE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IRENE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.4086147423427886`, 1.9944401577233473`}, 
           0.05916923324627664],
          "\"DOREEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DOREEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.4519856831239868`, 1.4111927026543916`}, 
           0.05916923324627664],
          "41"],
         Annotation[#, 41, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8640278426132526`, 2.7719656382086657`}, 
           0.05916923324627664],
          "\"HELEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HELEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.525200803202172, 2.748930876369467}, 0.05916923324627664],
          "\"SAMANTHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SAMANTHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.813585976152269, 2.6248978650498995`}, 
           0.05916923324627664],
          "\"JUNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JUNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.917790446940783, 2.640500949657646}, 0.05916923324627664],
          "\"YAKZCN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "YAKZCN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.9011281505152993`, 1.7332767461647987`}, 
           0.05916923324627664],
          "\"DIANE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DIANE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.0039600949850334`, 2.0781515674162447`}, 
           0.05916923324627664],
          "\"LBDVHJ\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LBDVHJ", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.852661010968112, 1.9142246350955632`}, 
           0.05916923324627664],
          "\"WINIFRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WINIFRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.683064068883834, 1.245810751888267}, 0.05916923324627664],
          "\"EILEEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EILEEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.738003895465744, 2.438421916783211}, 0.05916923324627664],
          "\"SHIRLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHIRLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.0868081360430004`, 2.737394995088968}, 
           0.05916923324627664],
          "\"ANNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.4564612296262527`, 2.861114506272823}, 
           0.05916923324627664],
          "\"SHARON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHARON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.460022018925988, 2.5888676204785144`}, 
           0.05916923324627664],
          "\"AMY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AMY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.176379186616198, 1.8015890862564126`}, 
           0.05916923324627664],
          "\"AWWUMI\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AWWUMI", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.554234589939101, 2.9473469241446786`}, 
           0.05916923324627664],
          "\"CPYYFX\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CPYYFX", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.2650064092992475`, 2.0466769646670513`}, 
           0.05916923324627664],
          "\"VALERIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VALERIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.168412863407633, 1.4049139205187118`}, 
           0.05916923324627664],
          "57"],
         Annotation[#, 57, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4438257076629464`, 2.114094118210321}, 
           0.05916923324627664],
          "\"AMANDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AMANDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.8279456451481755`, 2.8978482629102613`}, 
           0.05916923324627664],
          "\"JENNIFER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JENNIFER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.412615360157618, 2.147029466294559}, 0.05916923324627664],
          "\"ANGELA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANGELA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.280173282606988, 2.3473075059623456`}, 
           0.05916923324627664],
          "\"ETHEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ETHEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.643030825011694, 2.788931612883296}, 0.05916923324627664],
          "62"],
         Annotation[#, 62, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.824022741644952, 3.0566821626084484`}, 
           0.05916923324627664],
          "\"SANDRA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SANDRA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.3910874562171807`, 2.6992451631574474`}, 
           0.05916923324627664],
          "\"LOUISE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LOUISE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.013525846634314, 1.9148642382863623`}, 
           0.05916923324627664],
          "\"KATIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.982929118467082, 2.969410380332694}, 0.05916923324627664],
          "66"],
         Annotation[#, 66, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.69530438977898, 2.460795651944117}, 0.05916923324627664],
          
          "\"PHYLLIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PHYLLIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.419493963755297, 1.6222849957142134`}, 
           0.05916923324627664],
          "\"PAULINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAULINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.9377463862521385`, 0.9720055643270571}, 
           0.05916923324627664],
          "69"],
         Annotation[#, 69, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.686950208161191, 0.7638897775283437}, 
           0.05916923324627664],
          "\"LILIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LILIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.156161164987801, 0.86083900335185}, 0.05916923324627664],
          
          "\"AUDREY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AUDREY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.812758568363123, 0.957357854555742}, 0.05916923324627664],
          "72"],
         Annotation[#, 72, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.05294384887973, 0.9209257710599832}, 0.05916923324627664],
          "\"CLARE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLARE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.52051259630225, 0.836297074731303}, 0.05916923324627664],
          
          "\"KELLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KELLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.090720473590337, 1.0456179163499868`}, 
           0.05916923324627664],
          "\"IVY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IVY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.818936268714873, 0.7978438622700184}, 
           0.05916923324627664],
          "\"VERA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VERA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.9325015577573055`, 0.8079939351740921}, 
           0.05916923324627664],
          "\"BRENDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BRENDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.068545024683542, 0.7836970281843771}, 
           0.05916923324627664],
          "\"LJNWXX\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LJNWXX", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.243935992624913, 1.0654272107632627`}, 
           0.05916923324627664],
          "\"NATALIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NATALIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.661987102725427, 0.904726182831507}, 0.05916923324627664],
          "\"VIOLET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VIOLET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.932680377379178, 0.6916525803799898}, 
           0.05916923324627664],
          "\"JUNMZV\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JUNMZV", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.324371602114402, 3.0468036220992034`}, 
           0.05916923324627664],
          "\"SYLVIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SYLVIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.849250714402505, 2.9363459382553234`}, 
           0.05916923324627664],
          "\"ELAINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELAINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.13638720706868, 2.7686061356978193`}, 
           0.05916923324627664],
          "\"LWHQYG\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LWHQYG", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.7801488557272975`, 0.6632658391325665}, 
           0.05916923324627664],
          "\"LACFLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LACFLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.51422500603719, 2.2529314493341337`}, 
           0.05916923324627664],
          "\"CATHERINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CATHERINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.152538307205706, 1.0438055800527106`}, 
           0.05916923324627664],
          "\"HAYLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HAYLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.2269496352947336`, 0.9599454331998611}, 
           0.05916923324627664],
          "\"LILY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LILY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.596085032650404, 0.6895372962563102}, 
           0.05916923324627664],
          "\"EDNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.794178533001282, 4.295702963815212}, 0.05916923324627664],
          "\"HANNAH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HANNAH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.365975010583998, 5.121678520977948}, 0.05916923324627664],
          "\"NELLIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NELLIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.2297273099504284`, 4.590126385496445}, 
           0.05916923324627664],
          "\"BERYL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BERYL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.259298654341054, 2.777645480904296}, 0.05916923324627664],
          "93"],
         Annotation[#, 93, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.540086666110078, 4.4345259343806385`}, 
           0.05916923324627664],
          "94"],
         Annotation[#, 94, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.357462682996364, 4.846279140828983}, 0.05916923324627664],
          "\"SUCNHY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SUCNHY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.519824449473637, 4.921158425969408}, 0.05916923324627664],
          "96"],
         Annotation[#, 96, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.509656438398307, 5.168314570841019}, 0.05916923324627664],
          "\"LUCY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LUCY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.8548189364099805`, 5.156367667017251}, 
           0.05916923324627664],
          "\"ADA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ADA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.983482673071006, 5.106738793360854}, 0.05916923324627664],
          "\"DAWN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DAWN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.178773039899925, 5.207358622371585}, 0.05916923324627664],
          "\"LYNN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYNN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.410314567799693, 4.395771459935014}, 0.05916923324627664],
          "\"BEATRICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BEATRICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.620749914373296, 4.826112101562465}, 0.05916923324627664],
          "\"ZLXPBT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ZLXPBT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.051067702419588, 5.2549065971981275`}, 
           0.05916923324627664],
          "103"],
         Annotation[#, 103, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.647929117593844, 4.703472562135655}, 0.05916923324627664],
          "104"],
         Annotation[#, 104, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.719542160941998, 5.161927089156844}, 0.05916923324627664],
          "\"CAROLE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CAROLE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.512713750415653, 5.065444456618279}, 0.05916923324627664],
          "\"HFKAHK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HFKAHK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.361711882095648, 4.985612624663825}, 0.05916923324627664],
          "\"MAY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.362910457949491, 4.7109469149736505`}, 
           0.05916923324627664],
          "\"EVELYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EVELYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.490216765954272, 4.768828069593358}, 0.05916923324627664],
          "\"ROSE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROSE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.669934498013632, 4.892916760478343}, 0.05916923324627664],
          "\"MAVIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAVIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.630505524169648, 5.040121667874052}, 0.05916923324627664],
          "111"],
         Annotation[#, 111, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.907130714175474, 5.258748453933963}, 0.05916923324627664],
          "\"SALLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SALLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.251126858350011, 5.09674171621481}, 0.05916923324627664],
          
          "\"KATHERINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATHERINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.107409006547169, 5.077604921035324}, 0.05916923324627664],
          "\"IRIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IRIS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.713752879601781, 5.29106314533824}, 0.05916923324627664],
          
          "\"CKYGWZ\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CKYGWZ", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.790958068512422, 4.497006781690249}, 0.05916923324627664],
          "\"MARIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.407897163894246, 4.5610063093545135`}, 
           0.05916923324627664],
          "\"ZOE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ZOE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.038479397516811, 4.708117174265966}, 0.05916923324627664],
          "\"KERRY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KERRY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.745655007437586, 4.852728320216136}, 0.05916923324627664],
          "\"DEBRA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DEBRA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.2188350986354735`, 4.933111608037214}, 
           0.05916923324627664],
          "\"MELANIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MELANIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.6648733440522765`, 4.959535524313251}, 
           0.05916923324627664],
          "\"STACEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STACEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.825763063611469, 5.342677687141828}, 0.05916923324627664],
          "\"GERTRUDE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GERTRUDE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.777709740951684, 4.7240559177022625`}, 
           0.05916923324627664],
          "\"MURIEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MURIEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.647357608062556, 4.517464066783505}, 0.05916923324627664],
          "\"PAULA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAULA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.064337687752802, 4.906687202802276}, 0.05916923324627664],
          "\"LAUREN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LAUREN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.772579886658698, 4.61076776073411}, 0.05916923324627664],
          
          "\"MARION\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARION", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.100906852639415, 4.330120740246019}, 0.05916923324627664],
          "\"JOANNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOANNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.553334478641496, 4.619374414996618}, 0.05916923324627664],
          "129"],
         Annotation[#, 129, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.727715887034952, 4.384252299443624}, 0.05916923324627664],
          "130"],
         Annotation[#, 130, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.388415970003356, 5.2381358705537995`}, 
           0.05916923324627664],
          "\"MARINA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARINA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.911713811031306, 2.586261325112576}, 0.05916923324627664],
          "\"JANICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JANICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.275801716041025, 5.278380987402617}, 0.05916923324627664],
          "\"LORRAINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LORRAINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.609823235624464, 4.319267687680287}, 0.05916923324627664],
          "\"JESSIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JESSIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.1572347298549275`, 5.346796452347017}, 
           0.05916923324627664],
          "\"PEGGY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PEGGY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.926254550018793, 4.938054104736361}, 0.05916923324627664],
          "\"ROSEMARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROSEMARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.6109000996072975`, 5.067132635484567}, 
           0.05916923324627664],
          "\"ANDREA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANDREA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.171308591464613, 4.797669019461594}, 0.05916923324627664],
          "\"FRANCES\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRANCES", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.819437586060483, 4.8169133218931215`}, 
           0.05916923324627664],
          "\"XFGSKJ\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "XFGSKJ", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.808647205809958, 5.0076337273281055`}, 
           0.05916923324627664],
          "\"GRACE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GRACE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.989293884659297, 5.3683563750493395`}, 
           0.05916923324627664],
          "\"JOSEPHINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOSEPHINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.598255128580069, 5.2089379424441535`}, 
           0.05916923324627664],
          "\"YVONNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "YVONNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.728968870792024, 3.2463608440239202`}, 
           0.05916923324627664],
          "\"SOPHIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SOPHIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.4943391258594385`, 5.046727606371789}, 
           0.05916923324627664],
          "\"LYNNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYNNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.6468107380787025`, 3.2559799988503073`}, 
           0.05916923324627664],
          "\"ANNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.438954362554788, 2.667424179664479}, 0.05916923324627664],
          "\"EVA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EVA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{7.434844543474231, 2.830484610999371}, 0.05916923324627664],
          "\"GWENDOLINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GWENDOLINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.318970790181242, 2.8487135386723215`}, 
           0.05916923324627664],
          "\"JESSICA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JESSICA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.848253906173986, 2.8580306854243496`}, 
           0.05916923324627664],
          "149"],
         Annotation[#, 149, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.700487870694593, 2.4424766724498856`}, 
           0.05916923324627664],
          "\"NORMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.29388255075513, 2.5678167858152916`}, 
           0.05916923324627664],
          "\"BEVERLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BEVERLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.0266510192185105`, 2.489165010141661}, 
           0.05916923324627664],
          "\"KIRSTY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIRSTY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.861886521067051, 2.6966910162865267`}, 
           0.05916923324627664],
          "\"KIMBERLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIMBERLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.741402871473496, 3.3160197003524416`}, 
           0.05916923324627664],
          "\"HAZEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HAZEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.919091373624478, 3.1462622526861104`}, 
           0.05916923324627664],
          "\"FIONA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FIONA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.352226374323344, 3.248867088466713}, 0.05916923324627664],
          "\"KATE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.20254894967904, 3.6461575707622336`}, 
           0.05916923324627664],
          "\"MARIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.554306086344868, 2.672522066904943}, 0.05916923324627664],
          "\"JENNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JENNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{8.308606538516361, 2.696822699860878}, 0.05916923324627664],
          "\"MARILYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARILYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.049314292331256, 3.5117152657879362`}, 
           0.05916923324627664],
          "\"DAISY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DAISY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.950493588168063, 2.431134048938171}, 0.05916923324627664],
          "\"NORA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.746644737080452, 2.6782890820337264`}, 
           0.05916923324627664],
          "\"NATASHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NATASHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4515511696764003`, 3.342716500973031}, 
           0.05916923324627664],
          "\"MINNIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MINNIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.449632454591704, 2.533045852598579}, 0.05916923324627664],
          "\"FREDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FREDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.802663045555416, 3.175658584300045}, 0.05916923324627664],
          "\"MANDY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MANDY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.109702040082671, 3.5568648829146956`}, 
           0.05916923324627664],
          "\"RACHAEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RACHAEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.804481533314103, 2.9696756153261017`}, 
           0.05916923324627664],
          "\"TVKHRF\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TVKHRF", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4289017078547106`, 2.7365332138085625`}, 
           0.05916923324627664],
          "\"CHRISTOPHER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHRISTOPHER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.9523360521308, 2.743928821700988}, 0.05916923324627664],
          "169"],
         Annotation[#, 169, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.644391928447045, 3.244452126141589}, 0.05916923324627664],
          "\"KATHRYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATHRYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.5120502218283844`, 2.1220815673911515`}, 
           0.05916923324627664],
          "\"NANCY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NANCY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.193981899820784, 3.5556287141883387`}, 
           0.05916923324627664],
          "\"RUTH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RUTH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.520042883951646, 3.5228866331337763`}, 
           0.05916923324627664],
          "\"JAYNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JAYNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.625686589218123, 2.381921734570134}, 0.05916923324627664],
          "\"DIANA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DIANA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.616663838754043, 2.8089458941913774`}, 
           0.05916923324627664],
          "\"MARIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.402619766331258, 3.5518477056234867`}, 
           0.05916923324627664],
          "\"ELEANOR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELEANOR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.459581670558542, 3.0550215260909916`}, 
           0.05916923324627664],
          "\"VERONICA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VERONICA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.481370801314781, 2.407378500888442}, 0.05916923324627664],
          "\"SARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.861738053447665, 2.5790176241241203`}, 
           0.05916923324627664],
          "\"ALEXANDRA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALEXANDRA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.645903556697599, 2.931387344085481}, 0.05916923324627664],
          "\"LOUISA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LOUISA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.216199441754197, 3.4542343355260443`}, 
           0.05916923324627664],
          "\"MSRGUQ\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MSRGUQ", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.862683117910904, 3.2922014813765266`}, 
           0.05916923324627664],
          "\"DORA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DORA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.534302206428681, 3.351992682829069}, 0.05916923324627664],
          "\"DAPHNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DAPHNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.39303609848101, 3.4127726304034165`}, 
           0.05916923324627664],
          "\"TERESA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TERESA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.507075072222268, 3.2123205142857305`}, 
           0.05916923324627664],
          "\"JULIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JULIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.743798349805475, 3.064108472214346}, 0.05916923324627664],
          "\"NORAH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORAH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.1901085703624865`, 3.325941375114658}, 
           0.05916923324627664],
          "\"HEATHER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HEATHER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.087933691562657, 3.459534997474436}, 0.05916923324627664],
          "\"KIM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.337965104662092, 2.7776768114723245`}, 
           0.05916923324627664],
          "\"JEMMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEMMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.963802648567968, 2.886337006782308}, 0.05916923324627664],
          "\"THELMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "THELMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.291965012588083, 2.9874382292511314`}, 
           0.05916923324627664],
          "\"CARLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CARLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.5150465951610865`, 2.5293957182366364`}, 
           0.05916923324627664],
          "\"IDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.191600025591699, 3.1618926718503135`}, 
           0.05916923324627664],
          "\"CLARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.621225799852331, 3.0903921872936064`}, 
           0.05916923324627664],
          "\"GLORIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLORIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.655659937061612, 2.5973416307814463`}, 
           0.05916923324627664],
          "\"HOLLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HOLLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.928796847213739, 3.0236386651930554`}, 
           0.05916923324627664],
          "\"HILARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HILARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.534719413176031, 1.952455598198461}, 0.05916923324627664],
          "\"MELISSA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MELISSA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.3750504363538525`, 2.5558964858915947`}, 
           0.05916923324627664],
          "\"MARTHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARTHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.790423052016454, 2.4922590663415978`}, 
           0.05916923324627664],
          "\"CYNTHIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CYNTHIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.221829943051231, 3.572673718568332}, 0.05916923324627664],
          "\"BERTHA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BERTHA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.743906537485026, 2.7970307139966994`}, 
           0.05916923324627664],
          "\"LPYGMD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LPYGMD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.475909979942354, 2.884643793970506}, 0.05916923324627664],
          "\"LILLIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LILLIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.63982893028647, 3.4760810591037865`}, 
           0.05916923324627664],
          "\"CHERYL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHERYL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.351468760007008, 2.658552666100384}, 0.05916923324627664],
          "\"IZRDSO\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "IZRDSO", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.7455750145556905`, 3.4267583612063}, 0.05916923324627664],
          "\"NAOMI\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NAOMI", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.059365996060082, 0.37075160479062363`}, 
           0.05916923324627664],
          "207"],
         Annotation[#, 207, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.751395620238616, 0.43836679935751155`}, 
           0.05916923324627664],
          "\"BESSIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BESSIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.882558769893714, 0.2757595453499011}, 
           0.05916923324627664],
          "\"GAIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GAIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.677534535749722, 1.692785352156783}, 0.05916923324627664],
          "\"JADE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JADE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.867546262970022, 0.4175798005497957}, 
           0.05916923324627664],
          "\"PENELOPE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PENELOPE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.156525278579793, 0.4473475461469816}, 
           0.05916923324627664],
          "\"CHARLENE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHARLENE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.749094808750387, 0.6036041263808407}, 
           0.05916923324627664],
          "213"],
         Annotation[#, 213, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.501179195409648, 2.6272312670498783`}, 
           0.05916923324627664],
          "\"CHRISTINA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHRISTINA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.5018367737399005`, 0.43296188767322175`}, 
           0.05916923324627664],
          "\"ANNETTE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNETTE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.976095744920696, 0.49310148766966844`}, 
           0.05916923324627664],
          "216"],
         Annotation[#, 216, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.553740718797244, 0.6370907454908572}, 
           0.05916923324627664],
          "\"QCBGCO\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "QCBGCO", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.576166373359195, 0.3225585997065856}, 
           0.05916923324627664],
          "\"ESTHER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ESTHER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.166709599763112, 1.4574285005419627`}, 
           0.05916923324627664],
          "\"CAROLYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CAROLYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.890218388762008, 0.6408181466013585}, 
           0.05916923324627664],
          "\"HARRIET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HARRIET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.693023262313079, 0.2963659686956861}, 
           0.05916923324627664],
          "\"ANITA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANITA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.440723677198861, 0.5366492928843987}, 
           0.05916923324627664],
          "\"GERALDINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GERALDINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.001717125179382, 0.2804461046413729}, 
           0.05916923324627664],
          "\"BRIDGET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BRIDGET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.779391042006912, 0.24546038590813302`}, 
           0.05916923324627664],
          "\"GEORGINA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GEORGINA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.6228129245298035`, 0.510137681165586}, 
           0.05916923324627664],
          "\"LINDSEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LINDSEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.07854645191446, 0.5848141693643729}, 0.05916923324627664],
          "\"KAY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KAY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.193960451610545, 1.5269478908429592`}, 
           0.05916923324627664],
          "227"],
         Annotation[#, 227, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.550409226477074, 1.465518966322477}, 0.05916923324627664],
          "\"STELLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STELLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.85293811720253, 1.4081016430179862`}, 
           0.05916923324627664],
          "229"],
         Annotation[#, 229, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.053924506648571, 1.4064740656287693`}, 
           0.05916923324627664],
          "230"],
         Annotation[#, 230, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.256127868513868, 1.7577321697835315`}, 
           0.05916923324627664],
          "\"NICHOLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NICHOLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.806463941406644, 1.7936709072161272`}, 
           0.05916923324627664],
          "232"],
         Annotation[#, 232, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.415714643899557, 1.6353841429849536`}, 
           0.05916923324627664],
          "233"],
         Annotation[#, 233, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.14743246172484, 1.9738856314389224`}, 
           0.05916923324627664],
          "\"AIMEE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AIMEE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.07011431406212, 1.7501701558579208`}, 
           0.05916923324627664],
          "\"HEIDI\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HEIDI", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.97322243091558, 2.140773218470946}, 0.05916923324627664],
          
          "\"MILLICENT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MILLICENT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.962547303498972, 1.5033695238807598`}, 
           0.05916923324627664],
          "\"MONICA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MONICA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.093363973397614, 1.5946526822363933`}, 
           0.05916923324627664],
          "\"THERESA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "THERESA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.860353399282597, 1.5844617459827466`}, 
           0.05916923324627664],
          "\"MARGERY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARGERY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.687412558082926, 1.3857790014639133`}, 
           0.05916923324627664],
          "\"MAXINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAXINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.707526552732934, 1.5388039487978071`}, 
           0.05916923324627664],
          "\"TANYA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TANYA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.765755057626299, 2.140440327512224}, 0.05916923324627664],
          "\"CARLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CARLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.199912644534733, 2.0848858823262755`}, 
           0.05916923324627664],
          "\"FANNY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FANNY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.281486048750612, 1.641729667331575}, 0.05916923324627664],
          "\"JOY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.332131459418241, 1.5255485588225783`}, 
           0.05916923324627664],
          "\"LYDIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYDIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.686578552406644, 1.9927934606402578`}, 
           0.05916923324627664],
          "\"QSJBJN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "QSJBJN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.97503823521391, 1.9367173334525603`}, 
           0.05916923324627664],
          "\"GLENYS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GLENYS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.44620085909332, 1.760990941222535}, 0.05916923324627664],
          
          "\"DEBBIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DEBBIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.8865772531875304`, 2.240382044296952}, 
           0.05916923324627664],
          "\"JENNY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JENNY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.213991454832093, 1.4325089835232951`}, 
           0.05916923324627664],
          "\"UQSBBO\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "UQSBBO", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.367683140125169, 1.857010964825938}, 0.05916923324627664],
          "\"VIVIENNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VIVIENNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.73931348469306, 1.914419597546051}, 0.05916923324627664],
          
          "\"TARA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TARA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.107280804464408, 2.071066410750324}, 0.05916923324627664],
          "\"MIRIAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MIRIAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{6.06748899099226, 2.2317191355347825`}, 
           0.05916923324627664],
          "\"YDYBEJ\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "YDYBEJ", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0734862107930678`, 3.613056073998518}, 
           0.05916923324627664],
          "\"CLAIR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLAIR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.020256759784529343`, 3.4735795269987326`}, 
           0.05916923324627664],
          "\"LYNDSEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYNDSEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.0826226501711087, 3.28257117625992}, 0.05916923324627664],
          "\"SONIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SONIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8384795932604829, 4.382960998191306}, 
           0.05916923324627664],
          "\"MOLLY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MOLLY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.47002687142130606`, 4.02361231817226}, 
           0.05916923324627664],
          "259"],
         Annotation[#, 259, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.3455316442510563, 3.9457284863340076`}, 
           0.05916923324627664],
          "260"],
         Annotation[#, 260, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.10019495055573646`, 3.391193800511799}, 
           0.05916923324627664],
          "\"ELLA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELLA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8628061606871054, 4.215840146912527}, 
           0.05916923324627664],
          "\"CHLOE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHLOE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.2266097282668218, 3.296303602896672}, 
           0.05916923324627664],
          "\"SYBIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SYBIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.2778798478622071, 3.598815882040535}, 
           0.05916923324627664],
          "\"DAGTLQ\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DAGTLQ", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.2728552298655602, 4.190674292551935}, 
           0.05916923324627664],
          "\"TONI\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TONI", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.2666624387443024, 3.099034648573936}, 
           0.05916923324627664],
          "\"WILLIAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WILLIAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.3359305768021512, 3.7190141457881327`}, 
           0.05916923324627664],
          "\"PZZJBB\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PZZJBB", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.1351775487440534, 4.167036378173184}, 
           0.05916923324627664],
          "268"],
         Annotation[#, 268, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9739711900014467, 4.092288086369532}, 
           0.05916923324627664],
          "\"PAUL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAUL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.7023486570287338, 4.04379657792637}, 0.05916923324627664],
          "270"],
         Annotation[#, 270, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6455719856229605, 3.393867512857955}, 
           0.05916923324627664],
          "\"MARK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5816967626346976, 4.111655454001608}, 
           0.05916923324627664],
          "\"JAMES\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JAMES", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.48689835513946855`, 3.8688185853023205`}, 
           0.05916923324627664],
          "273"],
         Annotation[#, 273, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.621678054853938, 3.0563172806705547`}, 
           0.05916923324627664],
          "\"ZPINSB\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ZPINSB", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9288571618726795, 4.495621532473739}, 
           0.05916923324627664],
          "\"VYISWO\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VYISWO", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.4792941656123548, 3.413822520988866}, 
           0.05916923324627664],
          "\"ANDREW\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANDREW", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.094141518995297, 4.400939892089148}, 0.05916923324627664],
          "277"],
         Annotation[#, 277, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.36498918097719235`, 3.009961797283954}, 
           0.05916923324627664],
          "278"],
         Annotation[#, 278, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.013984822548024134`, 3.8648689535696077`}, 
           0.05916923324627664],
          "\"DANIEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DANIEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.9738957790590748, 4.338549729456501}, 
           0.05916923324627664],
          "\"ARTHUR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ARTHUR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6660531974460646, 3.794063493093822}, 
           0.05916923324627664],
          "\"KKMNQK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KKMNQK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.7850080077479396, 4.5118108893982285`}, 
           0.05916923324627664],
          "\"RICHARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RICHARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.21028432425060162`, 4.078927266768108}, 
           0.05916923324627664],
          "\"ADLDLW\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ADLDLW", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5879960910085713, 4.358814316914354}, 
           0.05916923324627664],
          "\"ANTHONY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANTHONY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.4004756983281328, 4.152593702822263}, 
           0.05916923324627664],
          "\"MATTHEW\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MATTHEW", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.4998340592441495, 3.708759848807689}, 
           0.05916923324627664],
          "\"CHARLES\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHARLES", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.4865384526698242, 4.2707850723480485`}, 
           0.05916923324627664],
          "\"FREDERICK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FREDERICK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5250052904325608, 4.476852081327943}, 
           0.05916923324627664],
          "\"KENNETH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KENNETH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.43038070063343214`, 3.5686292697098745`}, 
           0.05916923324627664],
          "\"ALBERT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALBERT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.02090947534034271, 3.7256892163256667`}, 
           0.05916923324627664],
          "\"ALAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.06439946292149568, 4.022103284904462}, 
           0.05916923324627664],
          "291"],
         Annotation[#, 291, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.3496938809997454, 3.241445490212884}, 
           0.05916923324627664],
          "\"SIMON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SIMON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.7346394252433464, 4.324109946210176}, 
           0.05916923324627664],
          "\"ERNEST\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ERNEST", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.1530574776702478, 3.721652779097516}, 
           0.05916923324627664],
          "\"ALFRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALFRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.25276658799153706`, 4.30347809241438}, 
           0.05916923324627664],
          "\"EDWARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDWARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.1251833575576713, 3.599241613328986}, 
           0.05916923324627664],
          "\"JOSEPH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOSEPH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6927639116138518, 3.195586154983091}, 
           0.05916923324627664],
          "\"LEE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LEE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.32890128756848025`, 3.4205637988620516`}, 
           0.05916923324627664],
          "\"ADAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ADAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.1717965436029445, 3.1746674290614196`}, 
           0.05916923324627664],
          "\"ROGER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROGER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.2002317462272356, 3.9669170263446887`}, 
           0.05916923324627664],
          "\"HAROLD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HAROLD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.36039534892484415`, 4.318637917316683}, 
           0.05916923324627664],
          "\"QUQJHK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "QUQJHK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5263982929225008, 3.2566235118511115`}, 
           0.05916923324627664],
          "\"KEITH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KEITH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6566468256533695, 4.501103360396075}, 
           0.05916923324627664],
          "\"FRANK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRANK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6739143434348422, 3.5622701605454994`}, 
           0.05916923324627664],
          "\"ACVRVL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ACVRVL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.26119808479500417`, 3.836932620838783}, 
           0.05916923324627664],
          "\"RAYMOND\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RAYMOND", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.8099539871443642, 3.9244604710603515`}, 
           0.05916923324627664],
          "\"COLIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "COLIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.4050185839357128, 4.4162578926420695`}, 
           0.05916923324627664],
          "\"WRMHHQ\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WRMHHQ", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.1864919583376019, 3.475705456635852}, 
           0.05916923324627664],
          "\"DARREN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DARREN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.43325771683821523`, 3.1336260682470938`}, 
           0.05916923324627664],
          "\"HENRY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HENRY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1031491059783773`, 4.228620125485023}, 
           0.05916923324627664],
          "\"PHILIP\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PHILIP", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.13223693987286378`, 3.866669109735546}, 
           0.05916923324627664],
          "\"GARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.659208335882389, 4.224769425045402}, 0.05916923324627664],
          "\"BENJAMIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BENJAMIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[DiskBox[{0., 3.6038272204377897`}, 0.05916923324627664],
          "\"STANLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STANLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.5043268835093695, 3.0083868217186223`}, 
           0.05916923324627664],
          "314"],
         Annotation[#, 314, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.363727400868515, 3.9526104740690053`}, 
           0.05916923324627664],
          "\"STEVEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STEVEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.9650798522078916`, 4.859572498300617}, 
           0.05916923324627664],
          "316"],
         Annotation[#, 316, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.866495451045463, 4.573211120916005}, 0.05916923324627664],
          "\"ERIC\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ERIC", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6618714804441472`, 4.532747337879211}, 
           0.05916923324627664],
          "318"],
         Annotation[#, 318, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.2670442694893, 4.590968060802998}, 0.05916923324627664],
          "319"],
         Annotation[#, 319, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.586342030190271, 4.816474522625021}, 0.05916923324627664],
          "\"MARTIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARTIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.7397618929152427`, 4.436780890613524}, 
           0.05916923324627664],
          "321"],
         Annotation[#, 321, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.592074745646717, 4.64168110273655}, 0.05916923324627664],
          
          "322"],
         Annotation[#, 322, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.252264472144632, 5.263771240942853}, 0.05916923324627664],
          "\"WALTER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WALTER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6519602806871108`, 4.322735884359272}, 
           0.05916923324627664],
          "324"],
         Annotation[#, 324, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.553290220580485, 4.314380945337992}, 0.05916923324627664],
          "\"NUHUTJ\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NUHUTJ", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8141741510078577`, 4.332810816966502}, 
           0.05916923324627664],
          "\"NICHOLAS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NICHOLAS", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.183547184247431, 6.14803314026841}, 0.05916923324627664],
          
          "327"],
         Annotation[#, 327, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.733811831993701, 4.588401267414509}, 0.05916923324627664],
          "\"LEONARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LEONARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.067113179235254, 4.764867207559504}, 0.05916923324627664],
          "\"BARRY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BARRY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8091001424806588`, 5.1066180502543235`}, 
           0.05916923324627664],
          "\"NKMUGR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NKMUGR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.009995134107254, 4.595245989487468}, 0.05916923324627664],
          "\"GORDON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GORDON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.333456413309544, 4.431790399919702}, 0.05916923324627664],
          "\"NORMAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NORMAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.7109641489256475`, 4.424662329127981}, 
           0.05916923324627664],
          "\"NEIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NEIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.105429117600194, 4.903162257192608}, 0.05916923324627664],
          "\"NIGEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NIGEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.8873382518610824`, 2.499837056536484}, 
           0.05916923324627664],
          "\"MALCOLM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MALCOLM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.154109941531763, 4.452963855795849}, 0.05916923324627664],
          "\"TIMOTHY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TIMOTHY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4055644221115013`, 5.84029279488464}, 
           0.05916923324627664],
          "\"STUART\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STUART", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.388828294149722, 4.893713401279151}, 0.05916923324627664],
          "\"GEOFFREY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GEOFFREY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.805784079207106, 4.750538923208355}, 0.05916923324627664],
          "\"ALEXANDER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ALEXANDER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.752570443096102, 4.633276363573887}, 0.05916923324627664],
          "\"CYRIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CYRIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.751067705651491, 4.1707469464755125`}, 
           0.05916923324627664],
          "\"SIDNEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SIDNEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.9287905006316017`, 4.73570138262282}, 
           0.05916923324627664],
          "\"MBHDDP\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MBHDDP", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.923010962400469, 4.19371142607152}, 0.05916923324627664],
          
          "\"RYAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RYAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.347280008290771, 4.749071332516304}, 0.05916923324627664],
          "\"KCVFLP\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KCVFLP", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.691402835859663, 4.739952869752491}, 0.05916923324627664],
          "\"LUKE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LUKE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.237349776480345, 4.934406972164576}, 0.05916923324627664],
          "\"JACK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JACK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.453730714772374, 4.643912517733487}, 0.05916923324627664],
          "\"TREVOR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "TREVOR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.059652473401591, 4.296656776141832}, 0.05916923324627664],
          "\"UNKPWV\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "UNKPWV", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.492707951276989, 4.896648148573503}, 0.05916923324627664],
          "\"AJRODZ\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AJRODZ", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.944950454902995, 4.425602575726703}, 0.05916923324627664],
          "\"WILFRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WILFRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.140589529962889, 4.667639214265626}, 0.05916923324627664],
          "\"PATRICK\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PATRICK", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.5285111978763775`, 4.487421507944514}, 
           0.05916923324627664],
          "\"KIRZZH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIRZZH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.231675205140929, 4.8072629057601945`}, 
           0.05916923324627664],
          "\"SAMUEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SAMUEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.451715780356415, 1.0568188462791823`}, 
           0.05916923324627664],
          "\"WAYNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WAYNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5255199739139442`, 0.05174303618850207}, 
           0.05916923324627664],
          "\"VRADXE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VRADXE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.6420482762243114`, 0.6290150585610736}, 
           0.05916923324627664],
          "\"GARETH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GARETH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6493143222330247`, 0.34064915040617505`}, 
           0.05916923324627664],
          "357"],
         Annotation[#, 357, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.121712033947512, 0.3964524852024298}, 
           0.05916923324627664],
          "\"SEAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SEAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.752218531478349, 0.17769316375478095`}, 
           0.05916923324627664],
          "\"HORACE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HORACE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9843696033409275`, 0.13100184161526895`}, 
           0.05916923324627664],
          "\"BERNARD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BERNARD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2801675544157414`, 0.5193212156788114}, 
           0.05916923324627664],
          "361"],
         Annotation[#, 361, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.661175830438739, 0.38219852432715173`}, 
           0.05916923324627664],
          "362"],
         Annotation[#, 362, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.796277751310369, 0.6088104962207552}, 
           0.05916923324627664],
          "\"FRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.0726593023825046`, 0.04930556501661565}, 
           0.05916923324627664],
          "\"EDWIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDWIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.797195901473659, 0.34726428110381136`}, 
           0.05916923324627664],
          "\"FZCFTO\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "FZCFTO", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.0765489469257834`, 0.23925186468339232`}, 
           0.05916923324627664],
          "\"SHAUN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHAUN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[DiskBox[{3.251130396030764, 0.}, 0.05916923324627664],
          "\"CLIFFORD\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLIFFORD", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.953507178495718, 0.3145275015947706}, 
           0.05916923324627664],
          "\"MAURICE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MAURICE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.688594766626704, 0.5005891336330199}, 
           0.05916923324627664],
          "\"CLIVE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLIVE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.115448299071365, 1.620007106324374}, 0.05916923324627664],
          "\"BEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "BEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.475521996974595, 0.2659173888793416}, 
           0.05916923324627664],
          "\"ANTONY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANTONY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.2884250885372586`, 0.11554905380577374`}, 
           0.05916923324627664],
          "\"MXOUPI\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MXOUPI", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.7797472553650584`, 0.33329119534508544`}, 
           0.05916923324627664],
          "373"],
         Annotation[#, 373, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.7470010633709054`, 0.24835769379540595`}, 
           0.05916923324627664],
          "\"JUSTIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JUSTIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.7533818393188962`, 0.780184811378533}, 
           0.05916923324627664],
          "375"],
         Annotation[#, 375, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.879530119235419, 0.43607224247584364`}, 
           0.05916923324627664],
          "\"JEFFREY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JEFFREY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.516624760366616, 0.42439177816029616`}, 
           0.05916923324627664],
          "\"OLIVER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "OLIVER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9800139427545327`, 0.5310157963922046}, 
           0.05916923324627664],
          "\"EDGAR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EDGAR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4472014553926247`, 0.5746455988651644}, 
           0.05916923324627664],
          "\"CHRISTIAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHRISTIAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.6283588858411955`, 0.7617314133332531}, 
           0.05916923324627664],
          "\"ASHLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ASHLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1666536801122662`, 0.12508884258070863`}, 
           0.05916923324627664],
          "\"KARL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KARL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6365626112710925`, 0.08889100986450593}, 
           0.05916923324627664],
          "\"AARON\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AARON", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1826878449766145`, 0.3061697602836726}, 
           0.05916923324627664],
          "\"MARC\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARC", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.606053970360506, 0.5177304130855807}, 
           0.05916923324627664],
          "\"MOHAMMED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MOHAMMED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4108025133548874`, 0.005575430578998564}, 
           0.05916923324627664],
          "\"PEYHIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PEYHIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.6007316244648124`, 0.19992221862777493`}, 
           0.05916923324627664],
          "\"RUSSELL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "RUSSELL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.9016479866550813`, 0.7103177807793619}, 
           0.05916923324627664],
          "\"GAVIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GAVIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.748423371670481, 0.4834964407555251}, 
           0.05916923324627664],
          "\"VIVVLG\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VIVVLG", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3179805820154353`, 0.26540948560116107`}, 
           0.05916923324627664],
          "\"LIAM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LIAM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.4162437905953844`, 0.14854356729374407`}, 
           0.05916923324627664],
          "\"ROBIN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ROBIN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.888254961342537, 0.19321857841527468`}, 
           0.05916923324627664],
          "\"PHILLIP\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PHILLIP", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.116031938746251, 0.5780215589652817}, 
           0.05916923324627664],
          "\"NATHAN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NATHAN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.304582529863077, 0.40769940425153717`}, 
           0.05916923324627664],
          "\"DENIS\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "DENIS", "Tooltip"]& ]}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{{3.67627029334179*^9, 3.676270334040346*^9}, 
   3.676270723406953*^9, 3.676271973026086*^9, 3.6778223484233828`*^9, 
   3.6778226713051643`*^9, 3.677822737182002*^9, 
   3.677822950799683*^9},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Filtering Graph", "Section",
 CellChangeTimes->{{3.676270595978644*^9, 3.6762705980682783`*^9}}],

Cell["\<\
Return the list of EdgeWeights from the above graph using PropertyValue\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676270607333343*^9, 3.676270620230999*^9}, {
  3.6762709366877127`*^9, 3.6762709435157337`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"edgeWeights", "=", 
  RowBox[{"PropertyValue", "[", 
   RowBox[{"tallyGraph", ",", "EdgeWeight"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.676270914090187*^9, 3.676270930736466*^9}, {
  3.676270967637603*^9, 3.676270970021078*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "4", ",", "1", ",", 
   "2", ",", "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", "1", ",", "2", 
   ",", "1", ",", "1", ",", "2", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "2", ",", "1", ",", "1", ",", "2", ",", "2", ",", "2", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", "1", ",", 
   "1", ",", "1", ",", "2", ",", "1", ",", "1", ",", "2", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "6", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "3", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "7", ",", "1", ",", "1", ",", "1", ",", 
   "2", ",", "2", ",", "1", ",", "5", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "2", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "2", ",", "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "2", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "2", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", "3", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "3", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "2", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "3", ",", "2", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "2", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "5", ",", "1", ",", "1", ",", "1", ",", "3", ",", "1", ",", "1", 
   ",", "1", ",", "4", ",", "1", ",", "1", ",", "1", ",", "2", ",", "1", ",", 
   "1", ",", "1", ",", "2", ",", "1", ",", "1", ",", "1", ",", "1", ",", "2", 
   ",", "2", ",", "2", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", "3", ",", "1", ",", 
   "1", ",", "4", ",", "1", ",", "1", ",", "3", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "2", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "3", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "3", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "2", ",", "1", 
   ",", "2", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", 
   ",", "1", ",", "2", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
   "1"}], "}"}]], "Output",
 CellChangeTimes->{3.676270931113263*^9, 3.676270970643482*^9, 
  3.676271977344599*^9, 3.677822353913602*^9, 3.677822674176029*^9, 
  3.677822955312695*^9}]
}, Open  ]],

Cell["\<\
Use Subgraph to view only those edges where the EdgeWeight is greater than 1:\
\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676270978853116*^9, 3.676271038838369*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sub1", "=", 
  RowBox[{"Subgraph", "[", 
   RowBox[{"tallyGraph", ",", 
    RowBox[{"Pick", "[", 
     RowBox[{
      RowBox[{"EdgeList", "[", "tallyGraph", "]"}], ",", "edgeWeights", ",", 
      RowBox[{"q_", "/;", 
       RowBox[{"q", ">", "1"}]}]}], "]"}], ",", 
    RowBox[{"VertexLabels", "\[Rule]", 
     RowBox[{"Placed", "[", 
      RowBox[{"\"\<Name\>\"", ",", "Tooltip"}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.676271070998399*^9, 3.676271086504744*^9}, {
  3.676271208153985*^9, 3.6762712146460733`*^9}, {3.676271331241371*^9, 
  3.676271350872201*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{
      "MARY", "KAREN", "GEMMA", "MFETPC", "JANET", 26, "ELSIE", "JANE", 
       "MICHELLE", "VICTORIA", "JUNE", "WINIFRED", "ANNE", "AMANDA", 
       "PAULINE", "KATHLEEN", "SHIRLEY", "HANNAH", 96, "LYNN", "ZLXPBT", 
       "ELAINE", "KIRSTY", "MARIE", "MANDY", "LWHQYG", "YAKZCN", "SYLVIA", 
       "EILEEN", "CHARLENE", "GEORGINA", "NANCY", "ANNA", "CAROLYN", "CLAIR", 
       259, "ETHEL", "CHRISTOPHER", 273, 277, "ANTHONY", "MATTHEW", "STEVEN", 
       "NEIL", "KIM", "JOANNA", "WAYNE", "MALCOLM"}, {{{1, 2}, {1, 3}, {1, 
       4}, {1, 5}, {1, 6}, {1, 7}, {1, 8}, {1, 9}, {1, 10}, {1, 11}, {1, 
       12}, {1, 13}, {1, 14}, {15, 4}, {1, 16}, {15, 16}, {17, 4}, {1, 17}, {
       15, 17}, {18, 4}, {18, 6}, {18, 1}, {18, 17}, {18, 16}, {18, 19}, {18, 
       20}, {18, 21}, {22, 3}, {22, 6}, {22, 17}, {22, 4}, {22, 16}, {22, 
       15}, {15, 22}, {18, 22}, {22, 23}, {22, 24}, {22, 25}, {15, 26}, {22, 
       26}, {1, 27}, {15, 27}, {22, 27}, {15, 28}, {18, 28}, {22, 28}, {29, 
       3}, {29, 4}, {29, 17}, {1, 29}, {29, 30}, {29, 31}, {32, 3}, {32, 
       22}, {32, 4}, {32, 28}, {32, 17}, {32, 27}, {32, 16}, {32, 23}, {32, 
       26}, {22, 32}, {18, 33}, {32, 33}, {29, 34}, {32, 34}, {35, 2}, {35, 
       16}, {35, 27}, {35, 36}, {1, 37}, {35, 37}, {22, 38}, {35, 38}, {35, 
       39}, {35, 40}, {35, 41}, {35, 42}, {43, 6}, {43, 26}, {43, 27}, {43, 
       16}, {43, 17}, {43, 4}, {43, 28}, {43, 24}, {43, 44}, {22, 45}, {43, 
       45}, {18, 46}, {43, 46}, {47, 38}, {47, 37}, {47, 17}, {47, 16}, {47, 
       27}, {43, 48}, {47, 48}}, Null}, {VertexLabels -> {
         Placed["Name", Tooltip]}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[0.020874074764142287`], 
        ArrowBox[{{2.574505805048765, 3.355560284765596}, {3.821808524866075, 
         2.935002924607719}}, 0.045666279220597045`], 
        ArrowBox[{{2.574505805048765, 3.355560284765596}, {
         1.8004919395367953`, 2.8333308771479735`}}, 0.045666279220597045`], 
        ArrowBox[{{2.574505805048765, 3.355560284765596}, {
         1.8402663531778711`, 2.4432625175764}}, 0.045666279220597045`], 
        ArrowBox[{{2.574505805048765, 3.355560284765596}, {
         1.9299414657441607`, 4.2231313903886285`}}, 0.045666279220597045`], 
        ArrowBox[{{2.574505805048765, 3.355560284765596}, {2.176523273182099, 
         2.2232708835530115`}}, 0.045666279220597045`], 
        ArrowBox[{{2.574505805048765, 3.355560284765596}, {2.919533917350072, 
         4.607264239175569}}, 0.045666279220597045`], 
        ArrowBox[{{2.574505805048765, 3.355560284765596}, {
         2.1440502575243423`, 4.517076753262203}}, 0.045666279220597045`], 
        ArrowBox[{{2.574505805048765, 3.355560284765596}, {
         3.0914848441148166`, 4.107203954376572}}, 0.045666279220597045`], 
        ArrowBox[{{2.574505805048765, 3.355560284765596}, {3.585756554753272, 
         3.771379243743429}}, 0.045666279220597045`], 
        ArrowBox[{{2.574505805048765, 3.355560284765596}, {
         2.5531527504376337`, 4.271289087732374}}, 0.045666279220597045`], 
        ArrowBox[{{2.574505805048765, 3.355560284765596}, {2.523342837356128, 
         4.691872610342888}}, 0.045666279220597045`], 
        ArrowBox[{{2.574505805048765, 3.355560284765596}, {3.564631471184913, 
         4.153172780410161}}, 0.045666279220597045`], 
        ArrowBox[{{2.574505805048765, 3.355560284765596}, {3.289564197851116, 
         4.480569833401649}}, 0.045666279220597045`], 
        ArrowBox[{{2.574505805048765, 3.355560284765596}, {
         2.5850621624617074`, 2.097795105821197}}, 0.045666279220597045`], 
        ArrowBox[{{2.574505805048765, 3.355560284765596}, {2.097850597127875, 
         2.4022486633626183`}}, 0.045666279220597045`], 
        ArrowBox[{{2.574505805048765, 3.355560284765596}, {2.798044628832711, 
         2.0938951153540484`}}, 0.045666279220597045`], 
        ArrowBox[{{2.574505805048765, 3.355560284765596}, {
         1.3778689734457545`, 3.4073491633032837`}}, 0.045666279220597045`], 
        ArrowBox[{{2.574505805048765, 3.355560284765596}, {
         3.5524543793480055`, 2.5494054277940745`}}, 0.045666279220597045`], 
        ArrowBox[{{2.1688556846576237`, 1.827597121274505}, {
         1.8402663531778711`, 2.4432625175764}}, 0.045666279220597045`], 
        ArrowBox[{{2.1688556846576237`, 1.827597121274505}, {
         2.5850621624617074`, 2.097795105821197}}, 0.045666279220597045`], 
        ArrowBox[{{2.1688556846576237`, 1.827597121274505}, {
         2.097850597127875, 2.4022486633626183`}}, 0.045666279220597045`], 
        ArrowBox[BezierCurveBox[{{2.1688556846576237`, 1.827597121274505}, {
         2.107378668605844, 1.695082865459602}, {1.9792472985317382`, 
         1.6249272989703822`}}], 0.045666279220597045`], 
        ArrowBox[{{2.1688556846576237`, 1.827597121274505}, {
         1.7676894915219474`, 1.2475540283303435`}}, 0.045666279220597045`], 
        ArrowBox[{{2.1688556846576237`, 1.827597121274505}, {
         2.798044628832711, 2.0938951153540484`}}, 0.045666279220597045`], 
        ArrowBox[{{2.1688556846576237`, 1.827597121274505}, {
         1.549139820702139, 1.5601602847583633`}}, 0.045666279220597045`], 
        ArrowBox[{{2.097850597127875, 2.4022486633626183`}, {
         1.8402663531778711`, 2.4432625175764}}, 0.045666279220597045`], 
        ArrowBox[{{1.2913131469342947`, 2.0891512694336645`}, {
         2.574505805048765, 3.355560284765596}}, 0.045666279220597045`], 
        ArrowBox[{{1.2913131469342947`, 2.0891512694336645`}, {
         1.8402663531778711`, 2.4432625175764}}, 0.045666279220597045`], 
        ArrowBox[{{1.2913131469342947`, 2.0891512694336645`}, {
         2.176523273182099, 2.2232708835530115`}}, 0.045666279220597045`], 
        ArrowBox[{{1.2913131469342947`, 2.0891512694336645`}, {
         2.5850621624617074`, 2.097795105821197}}, 0.045666279220597045`], 
        ArrowBox[{{1.2913131469342947`, 2.0891512694336645`}, {
         2.097850597127875, 2.4022486633626183`}}, 0.045666279220597045`], 
        ArrowBox[{{1.2913131469342947`, 2.0891512694336645`}, {
         0.05910974040339001, 1.700235328763744}}, 0.045666279220597045`], 
        ArrowBox[{{1.2913131469342947`, 2.0891512694336645`}, {
         0.25587204722294743`, 1.2940306553622902`}}, 0.045666279220597045`], 
        ArrowBox[{{1.2913131469342947`, 2.0891512694336645`}, {0., 
         2.170353652270008}}, 0.045666279220597045`], 
        ArrowBox[{{1.2913131469342947`, 2.0891512694336645`}, {
         1.9792472985317382`, 1.6249272989703822`}}, 0.045666279220597045`], 
        ArrowBox[{{1.2913131469342947`, 2.0891512694336645`}, {
         1.549139820702139, 1.5601602847583633`}}, 0.045666279220597045`], 
        ArrowBox[{{1.2913131469342947`, 2.0891512694336645`}, {
         0.6349941973844722, 2.2481855521834713`}}, 0.045666279220597045`], 
        ArrowBox[{{1.2913131469342947`, 2.0891512694336645`}, {
         1.2034973633529076`, 1.089777697847379}}, 0.045666279220597045`], 
        ArrowBox[{{1.9792472985317382`, 1.6249272989703822`}, {
         1.8004919395367953`, 2.8333308771479735`}}, 0.045666279220597045`], 
        ArrowBox[{{1.9792472985317382`, 1.6249272989703822`}, {
         1.8402663531778711`, 2.4432625175764}}, 0.045666279220597045`], 
        ArrowBox[{{1.9792472985317382`, 1.6249272989703822`}, {
         2.176523273182099, 2.2232708835530115`}}, 0.045666279220597045`], 
        ArrowBox[BezierCurveBox[{{1.9792472985317382`, 1.6249272989703822`}, {
         2.0407243145835245`, 1.75744155477071}, {2.1688556846576237`, 
         1.827597121274505}}], 0.045666279220597045`], 
        ArrowBox[{{1.9792472985317382`, 1.6249272989703822`}, {
         2.5850621624617074`, 2.097795105821197}}, 0.045666279220597045`], 
        ArrowBox[{{1.9792472985317382`, 1.6249272989703822`}, {
         2.097850597127875, 2.4022486633626183`}}, 0.045666279220597045`], 
        ArrowBox[{{1.9792472985317382`, 1.6249272989703822`}, {
         1.0239976860837299`, 1.5950051829625829`}}, 0.045666279220597045`], 
        ArrowBox[{{1.9792472985317382`, 1.6249272989703822`}, {
         2.289618375509897, 0.6260308797416947}}, 0.045666279220597045`], 
        ArrowBox[{{1.9792472985317382`, 1.6249272989703822`}, {
         1.1090206510826126`, 0.6019191404557653}}, 0.045666279220597045`], 
        ArrowBox[{{1.9792472985317382`, 1.6249272989703822`}, {
         1.7676894915219474`, 1.2475540283303435`}}, 0.045666279220597045`], 
        ArrowBox[{{1.9792472985317382`, 1.6249272989703822`}, {
         2.798044628832711, 2.0938951153540484`}}, 0.045666279220597045`], 
        ArrowBox[{{1.9792472985317382`, 1.6249272989703822`}, {
         1.549139820702139, 1.5601602847583633`}}, 0.045666279220597045`], 
        ArrowBox[BezierCurveBox[{{1.9792472985317382`, 1.6249272989703822`}, {
         1.7142140768604206`, 1.8168714135868433`}, {1.6148490148553272`, 
         2.128659380294913}}], 0.045666279220597045`], 
        ArrowBox[{{1.9792472985317382`, 1.6249272989703822`}, {
         3.3748849608363107`, 1.4764785864560102`}}, 0.045666279220597045`], 
        ArrowBox[{{1.9792472985317382`, 1.6249272989703822`}, {
         1.8729112357117237`, 0.5857357137582138}}, 0.045666279220597045`], 
        ArrowBox[{{1.3778689734457545`, 3.4073491633032837`}, {
         1.8004919395367953`, 2.8333308771479735`}}, 0.045666279220597045`], 
        ArrowBox[{{1.3778689734457545`, 3.4073491633032837`}, {
         1.8402663531778711`, 2.4432625175764}}, 0.045666279220597045`], 
        ArrowBox[{{1.3778689734457545`, 3.4073491633032837`}, {
         2.097850597127875, 2.4022486633626183`}}, 0.045666279220597045`], 
        ArrowBox[{{1.3778689734457545`, 3.4073491633032837`}, {
         0.3850267572921564, 4.0847894453149785`}}, 0.045666279220597045`], 
        ArrowBox[{{1.3778689734457545`, 3.4073491633032837`}, {
         0.7270670137408601, 4.408798511864399}}, 0.045666279220597045`], 
        ArrowBox[{{1.3778689734457545`, 3.4073491633032837`}, {
         0.841984295805746, 2.989648881740341}}, 0.045666279220597045`], 
        ArrowBox[{{1.6148490148553272`, 2.128659380294913}, {
         1.8004919395367953`, 2.8333308771479735`}}, 0.045666279220597045`], 
        ArrowBox[{{1.6148490148553272`, 2.128659380294913}, {
         1.8402663531778711`, 2.4432625175764}}, 0.045666279220597045`], 
        ArrowBox[{{1.6148490148553272`, 2.128659380294913}, {
         2.5850621624617074`, 2.097795105821197}}, 0.045666279220597045`], 
        ArrowBox[{{1.6148490148553272`, 2.128659380294913}, {
         2.097850597127875, 2.4022486633626183`}}, 0.045666279220597045`], 
        ArrowBox[BezierCurveBox[{{1.6148490148553272`, 2.128659380294913}, {
         1.8798822365266428`, 1.9367152656712037`}, {1.9792472985317382`, 
         1.6249272989703822`}}], 0.045666279220597045`], 
        ArrowBox[{{1.6148490148553272`, 2.128659380294913}, {
         1.0239976860837299`, 1.5950051829625829`}}, 0.045666279220597045`], 
        ArrowBox[{{1.6148490148553272`, 2.128659380294913}, {
         1.7676894915219474`, 1.2475540283303435`}}, 0.045666279220597045`], 
        ArrowBox[{{1.6148490148553272`, 2.128659380294913}, {
         2.798044628832711, 2.0938951153540484`}}, 0.045666279220597045`], 
        ArrowBox[{{1.6148490148553272`, 2.128659380294913}, {
         1.549139820702139, 1.5601602847583633`}}, 0.045666279220597045`], 
        ArrowBox[{{1.6148490148553272`, 2.128659380294913}, {
         0.6349941973844722, 2.2481855521834713`}}, 0.045666279220597045`], 
        ArrowBox[{{1.6148490148553272`, 2.128659380294913}, {
         0.841984295805746, 2.989648881740341}}, 0.045666279220597045`], 
        ArrowBox[{{4.2566239408701065`, 1.9495431944837078`}, {
         3.821808524866075, 2.935002924607719}}, 0.045666279220597045`], 
        ArrowBox[{{4.2566239408701065`, 1.9495431944837078`}, {
         2.5850621624617074`, 2.097795105821197}}, 0.045666279220597045`], 
        ArrowBox[{{4.2566239408701065`, 1.9495431944837078`}, {
         2.798044628832711, 2.0938951153540484`}}, 0.045666279220597045`], 
        ArrowBox[{{4.2566239408701065`, 1.9495431944837078`}, {
         5.469257887664927, 2.0329675300455308`}}, 0.045666279220597045`], 
        ArrowBox[{{4.2566239408701065`, 1.9495431944837078`}, {
         3.5524543793480055`, 2.5494054277940745`}}, 0.045666279220597045`], 
        ArrowBox[{{4.2566239408701065`, 1.9495431944837078`}, {
         3.3748849608363107`, 1.4764785864560102`}}, 0.045666279220597045`], 
        ArrowBox[{{4.2566239408701065`, 1.9495431944837078`}, {
         5.312399120897634, 1.704242181259683}}, 0.045666279220597045`], 
        ArrowBox[{{4.2566239408701065`, 1.9495431944837078`}, {
         5.280276546387174, 2.3846048889498923`}}, 0.045666279220597045`], 
        ArrowBox[{{4.2566239408701065`, 1.9495431944837078`}, {
         5.3172865611460285`, 1.342872391410806}}, 0.045666279220597045`], 
        ArrowBox[{{4.2566239408701065`, 1.9495431944837078`}, {
         4.984965146444981, 1.1007659278372426`}}, 0.045666279220597045`], 
        ArrowBox[{{2.203484289448593, 1.3238369336642366`}, {
         1.8402663531778711`, 2.4432625175764}}, 0.045666279220597045`], 
        ArrowBox[{{2.203484289448593, 1.3238369336642366`}, {
         2.176523273182099, 2.2232708835530115`}}, 0.045666279220597045`], 
        ArrowBox[{{2.203484289448593, 1.3238369336642366`}, {
         2.5850621624617074`, 2.097795105821197}}, 0.045666279220597045`], 
        ArrowBox[{{2.203484289448593, 1.3238369336642366`}, {
         2.097850597127875, 2.4022486633626183`}}, 0.045666279220597045`], 
        ArrowBox[{{2.203484289448593, 1.3238369336642366`}, {
         2.289618375509897, 0.6260308797416947}}, 0.045666279220597045`], 
        ArrowBox[{{2.203484289448593, 1.3238369336642366`}, {
         1.7676894915219474`, 1.2475540283303435`}}, 0.045666279220597045`], 
        ArrowBox[{{2.203484289448593, 1.3238369336642366`}, {
         2.798044628832711, 2.0938951153540484`}}, 0.045666279220597045`], 
        ArrowBox[{{2.203484289448593, 1.3238369336642366`}, {
         1.549139820702139, 1.5601602847583633`}}, 0.045666279220597045`], 
        ArrowBox[{{2.203484289448593, 1.3238369336642366`}, {
         2.3247939040523353`, 0.}}, 0.045666279220597045`], 
        ArrowBox[{{2.203484289448593, 1.3238369336642366`}, {
         1.8729112357117237`, 0.5857357137582138}}, 0.045666279220597045`], 
        ArrowBox[{{2.203484289448593, 1.3238369336642366`}, {
         1.2034973633529076`, 1.089777697847379}}, 0.045666279220597045`], 
        ArrowBox[{{2.203484289448593, 1.3238369336642366`}, {
         3.084147466725331, 0.8765895228193847}}, 0.045666279220597045`], 
        ArrowBox[{{3.1038168417238925`, 1.8302829194393802`}, {
         2.5850621624617074`, 2.097795105821197}}, 0.045666279220597045`], 
        ArrowBox[{{3.1038168417238925`, 1.8302829194393802`}, {
         2.097850597127875, 2.4022486633626183`}}, 0.045666279220597045`], 
        ArrowBox[{{3.1038168417238925`, 1.8302829194393802`}, {
         2.798044628832711, 2.0938951153540484`}}, 0.045666279220597045`], 
        ArrowBox[{{3.1038168417238925`, 1.8302829194393802`}, {
         3.5524543793480055`, 2.5494054277940745`}}, 0.045666279220597045`], 
        ArrowBox[{{3.1038168417238925`, 1.8302829194393802`}, {
         3.3748849608363107`, 1.4764785864560102`}}, 0.045666279220597045`], 
        ArrowBox[{{3.1038168417238925`, 1.8302829194393802`}, {
         3.084147466725331, 0.8765895228193847}}, 0.045666279220597045`]}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
        TagBox[
         TooltipBox[
          DiskBox[{2.574505805048765, 3.355560284765596}, 
           0.045666279220597045`],
          "\"MARY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.821808524866075, 2.935002924607719}, 
           0.045666279220597045`],
          "\"KAREN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KAREN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8004919395367953`, 2.8333308771479735`}, 
           0.045666279220597045`],
          "\"GEMMA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GEMMA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8402663531778711`, 2.4432625175764}, 
           0.045666279220597045`],
          "\"MFETPC\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MFETPC", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9299414657441607`, 4.2231313903886285`}, 
           0.045666279220597045`],
          "\"JANET\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JANET", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.176523273182099, 2.2232708835530115`}, 
           0.045666279220597045`],
          "26"],
         Annotation[#, 26, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.919533917350072, 4.607264239175569}, 
           0.045666279220597045`],
          "\"ELSIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELSIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.1440502575243423`, 4.517076753262203}, 
           0.045666279220597045`],
          "\"JANE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JANE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.0914848441148166`, 4.107203954376572}, 
           0.045666279220597045`],
          "\"MICHELLE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MICHELLE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.585756554753272, 3.771379243743429}, 
           0.045666279220597045`],
          "\"VICTORIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "VICTORIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.5531527504376337`, 4.271289087732374}, 
           0.045666279220597045`],
          "\"JUNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JUNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.523342837356128, 4.691872610342888}, 
           0.045666279220597045`],
          "\"WINIFRED\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WINIFRED", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.564631471184913, 4.153172780410161}, 
           0.045666279220597045`],
          "\"ANNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.289564197851116, 4.480569833401649}, 
           0.045666279220597045`],
          "\"AMANDA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "AMANDA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.1688556846576237`, 1.827597121274505}, 
           0.045666279220597045`],
          "\"PAULINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "PAULINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.5850621624617074`, 2.097795105821197}, 
           0.045666279220597045`],
          "\"KATHLEEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KATHLEEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.097850597127875, 2.4022486633626183`}, 
           0.045666279220597045`],
          "\"SHIRLEY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SHIRLEY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2913131469342947`, 2.0891512694336645`}, 
           0.045666279220597045`],
          "\"HANNAH\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "HANNAH", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.05910974040339001, 1.700235328763744}, 
           0.045666279220597045`],
          "96"],
         Annotation[#, 96, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.25587204722294743`, 1.2940306553622902`}, 
           0.045666279220597045`],
          "\"LYNN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LYNN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[DiskBox[{0., 2.170353652270008}, 0.045666279220597045`],
          "\"ZLXPBT\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ZLXPBT", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.9792472985317382`, 1.6249272989703822`}, 
           0.045666279220597045`],
          "\"ELAINE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ELAINE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.0239976860837299`, 1.5950051829625829`}, 
           0.045666279220597045`],
          "\"KIRSTY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIRSTY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.289618375509897, 0.6260308797416947}, 
           0.045666279220597045`],
          "\"MARIE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MARIE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.1090206510826126`, 0.6019191404557653}, 
           0.045666279220597045`],
          "\"MANDY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MANDY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.7676894915219474`, 1.2475540283303435`}, 
           0.045666279220597045`],
          "\"LWHQYG\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "LWHQYG", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.798044628832711, 2.0938951153540484`}, 
           0.045666279220597045`],
          "\"YAKZCN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "YAKZCN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.549139820702139, 1.5601602847583633`}, 
           0.045666279220597045`],
          "\"SYLVIA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "SYLVIA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.3778689734457545`, 3.4073491633032837`}, 
           0.045666279220597045`],
          "\"EILEEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "EILEEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.3850267572921564, 4.0847894453149785`}, 
           0.045666279220597045`],
          "\"CHARLENE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHARLENE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.7270670137408601, 4.408798511864399}, 
           0.045666279220597045`],
          "\"GEORGINA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "GEORGINA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.6148490148553272`, 2.128659380294913}, 
           0.045666279220597045`],
          "\"NANCY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NANCY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.6349941973844722, 2.2481855521834713`}, 
           0.045666279220597045`],
          "\"ANNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{0.841984295805746, 2.989648881740341}, 
           0.045666279220597045`],
          "\"CAROLYN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CAROLYN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.2566239408701065`, 1.9495431944837078`}, 
           0.045666279220597045`],
          "\"CLAIR\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CLAIR", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.469257887664927, 2.0329675300455308`}, 
           0.045666279220597045`],
          "259"],
         Annotation[#, 259, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.5524543793480055`, 2.5494054277940745`}, 
           0.045666279220597045`],
          "\"ETHEL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ETHEL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.3748849608363107`, 1.4764785864560102`}, 
           0.045666279220597045`],
          "\"CHRISTOPHER\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "CHRISTOPHER", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.312399120897634, 1.704242181259683}, 
           0.045666279220597045`],
          "273"],
         Annotation[#, 273, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.280276546387174, 2.3846048889498923`}, 
           0.045666279220597045`],
          "277"],
         Annotation[#, 277, "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{5.3172865611460285`, 1.342872391410806}, 
           0.045666279220597045`],
          "\"ANTHONY\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "ANTHONY", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{4.984965146444981, 1.1007659278372426`}, 
           0.045666279220597045`],
          "\"MATTHEW\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MATTHEW", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{2.203484289448593, 1.3238369336642366`}, 
           0.045666279220597045`],
          "\"STEVEN\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "STEVEN", "Tooltip"]& ], 
        TagBox[
         TooltipBox[DiskBox[{2.3247939040523353`, 0.}, 0.045666279220597045`],
          
          "\"NEIL\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "NEIL", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.8729112357117237`, 0.5857357137582138}, 
           0.045666279220597045`],
          "\"KIM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "KIM", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{1.2034973633529076`, 1.089777697847379}, 
           0.045666279220597045`],
          "\"JOANNA\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "JOANNA", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.1038168417238925`, 1.8302829194393802`}, 
           0.045666279220597045`],
          "\"WAYNE\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "WAYNE", "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          DiskBox[{3.084147466725331, 0.8765895228193847}, 
           0.045666279220597045`],
          "\"MALCOLM\"",
          TooltipStyle->"TextStyling"],
         Annotation[#, "MALCOLM", "Tooltip"]& ]}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{{3.6762713318622026`*^9, 3.676271351290493*^9}, 
   3.676271978922358*^9, 3.677822677953236*^9, 3.67782274670725*^9, 
   3.6778229572342377`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Note that the EdgeWeights have been removed from the Subgraph - in order to \
retain them you would need to follow a more complicated route - \
http://mathematica.stackexchange.com/a/26223/1952.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676271180658208*^9, 3.676271204001034*^9}, {
  3.676271392645278*^9, 3.676271422343728*^9}, {3.676271452574134*^9, 
  3.676271458681254*^9}}],

Cell["\<\
Build a Manipulate that allows you to filter the graph according to the edge \
weights:\
\>", "ItemNumbered",
 CellChangeTimes->{{3.67627146799815*^9, 3.67627151176016*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Subgraph", "[", 
    RowBox[{"tallyGraph", ",", 
     RowBox[{"Pick", "[", 
      RowBox[{
       RowBox[{"EdgeList", "[", "tallyGraph", "]"}], ",", "edgeWeights", ",", 
       
       RowBox[{"q_", "/;", 
        RowBox[{"q", ">=", "minWeight"}]}]}], "]"}], ",", 
     RowBox[{"VertexLabels", "\[Rule]", 
      RowBox[{"Placed", "[", 
       RowBox[{"\"\<Name\>\"", ",", "Tooltip"}], "]"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "minWeight", ",", "1", ",", "\"\<Minimum Number of Interactions\>\""}], 
      "}"}], ",", 
     RowBox[{"Range", "[", 
      RowBox[{"Max", "[", "edgeWeights", "]"}], "]"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "Setter"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",
 CellChangeTimes->{{3.676271513222766*^9, 3.676271643692251*^9}, {
  3.676271991353635*^9, 3.676272006217389*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`minWeight$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`minWeight$$], 1, "Minimum Number of Interactions"}, {
      1, 2, 3, 4, 5, 6, 7}}}, Typeset`size$$ = {360., {133., 138.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`minWeight$1128$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`minWeight$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`minWeight$$, $CellContext`minWeight$1128$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Subgraph[$CellContext`tallyGraph, 
        Pick[
         EdgeList[$CellContext`tallyGraph], $CellContext`edgeWeights, 
         Condition[
          Pattern[$CellContext`q$, 
           Blank[]], $CellContext`q$ >= $CellContext`minWeight$$]], 
        VertexLabels -> Placed["Name", Tooltip]], 
      "Specifications" :> {{{$CellContext`minWeight$$, 1, 
          "Minimum Number of Interactions"}, {1, 2, 3, 4, 5, 6, 7}, 
         ControlType -> Setter}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{405., {176., 181.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`tallyGraph = 
       Graph[{"MARY", 2, 3, "JEAN", "FLORENCE", 6, 7, "JULIE", "CLAIRE", 
          "LAURA", "DORIS", "JOAN", "JVGDNT", "KAREN", "URQUAX", "GEMMA", 17, 
          "DOROTHY", 19, "JACQUELINE", "MFETPC", "KATHLEEN", "JANET", 24, 
          "LISA", 26, "ANNIE", 28, "ANN", 30, 31, "ELSIE", "BARBARA", 
          "UQVRUY", "JANE", "MICHELLE", "VICTORIA", "ALICE", "IRENE", 
          "DOREEN", 41, "HELEN", "SAMANTHA", "JUNE", "YAKZCN", "DIANE", 
          "LBDVHJ", "WINIFRED", "EILEEN", "SHIRLEY", "ANNE", "SHARON", "AMY", 
          "AWWUMI", "CPYYFX", "VALERIE", 57, "AMANDA", "JENNIFER", "ANGELA", 
          "ETHEL", 62, "SANDRA", "LOUISE", "KATIE", 66, "PHYLLIS", "PAULINE", 
          69, "LILIAN", "AUDREY", 72, "CLARE", "KELLY", "IVY", "VERA", 
          "BRENDA", "LJNWXX", "NATALIE", "VIOLET", "JUNMZV", "SYLVIA", 
          "ELAINE", "LWHQYG", "LACFLA", "CATHERINE", "HAYLEY", "LILY", "EDNA",
           "HANNAH", "NELLIE", "BERYL", 93, 94, "SUCNHY", 96, "LUCY", "ADA", 
          "DAWN", "LYNN", "BEATRICE", "ZLXPBT", 103, 104, "CAROLE", "HFKAHK", 
          "MAY", "EVELYN", "ROSE", "MAVIS", 111, "SALLY", "KATHERINE", "IRIS",
           "CKYGWZ", "MARIA", "ZOE", "KERRY", "DEBRA", "MELANIE", "STACEY", 
          "GERTRUDE", "MURIEL", "PAULA", "LAUREN", "MARION", "JOANNA", 129, 
          130, "MARINA", "JANICE", "LORRAINE", "JESSIE", "PEGGY", "ROSEMARY", 
          "ANDREA", "FRANCES", "XFGSKJ", "GRACE", "JOSEPHINE", "YVONNE", 
          "SOPHIE", "LYNNE", "ANNA", "EVA", "GWENDOLINE", "JESSICA", 149, 
          "NORMA", "BEVERLEY", "KIRSTY", "KIMBERLEY", "HAZEL", "FIONA", 
          "KATE", "MARIE", "JENNA", "MARILYN", "DAISY", "NORA", "NATASHA", 
          "MINNIE", "FREDA", "MANDY", "RACHAEL", "TVKHRF", "CHRISTOPHER", 169,
           "KATHRYN", "NANCY", "RUTH", "JAYNE", "DIANA", "MARIAN", "ELEANOR", 
          "VERONICA", "SARA", "ALEXANDRA", "LOUISA", "MSRGUQ", "DORA", 
          "DAPHNE", "TERESA", "JULIA", "NORAH", "HEATHER", "KIM", "JEMMA", 
          "THELMA", "CARLY", "IDA", "CLARA", "GLORIA", "HOLLY", "HILARY", 
          "MELISSA", "MARTHA", "CYNTHIA", "BERTHA", "LPYGMD", "LILLIAN", 
          "CHERYL", "IZRDSO", "NAOMI", 207, "BESSIE", "GAIL", "JADE", 
          "PENELOPE", "CHARLENE", 213, "CHRISTINA", "ANNETTE", 216, "QCBGCO", 
          "ESTHER", "CAROLYN", "HARRIET", "ANITA", "GERALDINE", "BRIDGET", 
          "GEORGINA", "LINDSEY", "KAY", 227, "STELLA", 229, 230, "NICHOLA", 
          232, 233, "AIMEE", "HEIDI", "MILLICENT", "MONICA", "THERESA", 
          "MARGERY", "MAXINE", "TANYA", "CARLA", "FANNY", "JOY", "LYDIA", 
          "QSJBJN", "GLENYS", "DEBBIE", "JENNY", "UQSBBO", "VIVIENNE", "TARA",
           "MIRIAM", "YDYBEJ", "CLAIR", "LYNDSEY", "SONIA", "MOLLY", 259, 260,
           "ELLA", "CHLOE", "SYBIL", "DAGTLQ", "TONI", "WILLIAM", "PZZJBB", 
          268, "PAUL", 270, "MARK", "JAMES", 273, "ZPINSB", "VYISWO", 
          "ANDREW", 277, 278, "DANIEL", "ARTHUR", "KKMNQK", "RICHARD", 
          "ADLDLW", "ANTHONY", "MATTHEW", "CHARLES", "FREDERICK", "KENNETH", 
          "ALBERT", "ALAN", 291, "SIMON", "ERNEST", "ALFRED", "EDWARD", 
          "JOSEPH", "LEE", "ADAM", "ROGER", "HAROLD", "QUQJHK", "KEITH", 
          "FRANK", "ACVRVL", "RAYMOND", "COLIN", "WRMHHQ", "DARREN", "HENRY", 
          "PHILIP", "GARY", "BENJAMIN", "STANLEY", 314, "STEVEN", 316, "ERIC",
           318, 319, "MARTIN", 321, 322, "WALTER", 324, "NUHUTJ", "NICHOLAS", 
          327, "LEONARD", "BARRY", "NKMUGR", "GORDON", "NORMAN", "NEIL", 
          "NIGEL", "MALCOLM", "TIMOTHY", "STUART", "GEOFFREY", "ALEXANDER", 
          "CYRIL", "SIDNEY", "MBHDDP", "RYAN", "KCVFLP", "LUKE", "JACK", 
          "TREVOR", "UNKPWV", "AJRODZ", "WILFRED", "PATRICK", "KIRZZH", 
          "SAMUEL", "WAYNE", "VRADXE", "GARETH", 357, "SEAN", "HORACE", 
          "BERNARD", 361, 362, "FRED", "EDWIN", "FZCFTO", "SHAUN", "CLIFFORD",
           "MAURICE", "CLIVE", "BEN", "ANTONY", "MXOUPI", 373, "JUSTIN", 375, 
          "JEFFREY", "OLIVER", "EDGAR", "CHRISTIAN", "ASHLEY", "KARL", 
          "AARON", "MARC", "MOHAMMED", "PEYHIE", "RUSSELL", "GAVIN", "VIVVLG",
           "LIAM", "ROBIN", "PHILLIP", "NATHAN", "DENIS"}, {
          DirectedEdge["MARY", 2], 
          DirectedEdge["MARY", 3], 
          DirectedEdge["JEAN", 3], 
          DirectedEdge["MARY", "FLORENCE"], 
          DirectedEdge["FLORENCE", "JEAN"], 
          DirectedEdge["MARY", 6], 
          DirectedEdge["MARY", 7], 
          DirectedEdge["MARY", "JULIE"], 
          DirectedEdge["MARY", "CLAIRE"], 
          DirectedEdge["MARY", "LAURA"], 
          DirectedEdge["MARY", "DORIS"], 
          DirectedEdge["MARY", "JOAN"], 
          DirectedEdge["MARY", "JVGDNT"], 
          DirectedEdge["MARY", "KAREN"], 
          DirectedEdge["URQUAX", "KAREN"], 
          DirectedEdge["MARY", "GEMMA"], 
          DirectedEdge["MARY", 17], 
          DirectedEdge["MARY", "DOROTHY"], 
          DirectedEdge["MARY", 19], 
          DirectedEdge["MARY", "JACQUELINE"], 
          DirectedEdge["MARY", "MFETPC"], 
          DirectedEdge["MARY", "KATHLEEN"], 
          DirectedEdge["MARY", "JANET"], 
          DirectedEdge["MARY", 24], 
          DirectedEdge["MARY", "LISA"], 
          DirectedEdge["MARY", 26], 
          DirectedEdge["MARY", "ANNIE"], 
          DirectedEdge["MARY", 28], 
          DirectedEdge["MARY", "ANN"], 
          DirectedEdge["MARY", 30], 
          DirectedEdge["MARY", 31], 
          DirectedEdge["MARY", "ELSIE"], 
          DirectedEdge["MARY", "BARBARA"], 
          DirectedEdge["MARY", "UQVRUY"], 
          DirectedEdge["MARY", "JANE"], 
          DirectedEdge["MARY", "MICHELLE"], 
          DirectedEdge["MARY", "VICTORIA"], 
          DirectedEdge["MARY", "ALICE"], 
          DirectedEdge["MARY", "IRENE"], 
          DirectedEdge["DOREEN", 30], 
          DirectedEdge[41, 30], 
          DirectedEdge["MARY", "HELEN"], 
          DirectedEdge["MARY", "SAMANTHA"], 
          DirectedEdge["MARY", "JUNE"], 
          DirectedEdge["MARY", "YAKZCN"], 
          DirectedEdge["MARY", "DIANE"], 
          DirectedEdge["MARY", "LBDVHJ"], 
          DirectedEdge["MARY", "WINIFRED"], 
          DirectedEdge["MARY", "EILEEN"], 
          DirectedEdge["MARY", "SHIRLEY"], 
          DirectedEdge["MARY", "ANNE"], 
          DirectedEdge["MARY", "JEAN"], 
          DirectedEdge["MARY", "SHARON"], 
          DirectedEdge["MARY", "AMY"], 
          DirectedEdge["MARY", "AWWUMI"], 
          DirectedEdge["MARY", "CPYYFX"], 
          DirectedEdge["VALERIE", 57], 
          DirectedEdge["MARY", "VALERIE"], 
          DirectedEdge["VALERIE", 17], 
          DirectedEdge["MARY", "AMANDA"], 
          DirectedEdge["AMANDA", 17], 
          DirectedEdge["MARY", "JENNIFER"], 
          DirectedEdge["MARY", "ANGELA"], 
          DirectedEdge["MARY", "ETHEL"], 
          DirectedEdge["MARY", 62], 
          DirectedEdge["MARY", "SANDRA"], 
          DirectedEdge["MARY", "LOUISE"], 
          DirectedEdge["MARY", "KATIE"], 
          DirectedEdge["MARY", 66], 
          DirectedEdge["MARY", "PHYLLIS"], 
          DirectedEdge["MARY", "DOREEN"], 
          DirectedEdge["PAULINE", 69], 
          DirectedEdge["PAULINE", "LILIAN"], 
          DirectedEdge["PAULINE", "KATHLEEN"], 
          DirectedEdge["PAULINE", "AUDREY"], 
          DirectedEdge["PAULINE", 72], 
          DirectedEdge["PAULINE", "CLARE"], 
          DirectedEdge["PAULINE", "KELLY"], 
          DirectedEdge["PAULINE", "IVY"], 
          DirectedEdge["PAULINE", "YAKZCN"], 
          DirectedEdge["PAULINE", "SHIRLEY"], 
          DirectedEdge["PAULINE", "VERA"], 
          DirectedEdge["PAULINE", "BRENDA"], 
          DirectedEdge["PAULINE", "LJNWXX"], 
          DirectedEdge["PAULINE", "NATALIE"], 
          DirectedEdge["PAULINE", "VIOLET"], 
          DirectedEdge["PAULINE", "JUNMZV"], 
          DirectedEdge["PAULINE", "MFETPC"], 
          DirectedEdge["PAULINE", "SYLVIA"], 
          DirectedEdge["PAULINE", "ELAINE"], 
          DirectedEdge["PAULINE", "LWHQYG"], 
          DirectedEdge["PAULINE", "LACFLA"], 
          DirectedEdge["PAULINE", "CATHERINE"], 
          DirectedEdge["PAULINE", "HAYLEY"], 
          DirectedEdge["PAULINE", "LILY"], 
          DirectedEdge["PAULINE", "EDNA"], 
          DirectedEdge["HANNAH", "NELLIE"], 
          DirectedEdge["HANNAH", "BERYL"], 
          DirectedEdge["HANNAH", 93], 
          DirectedEdge["HANNAH", 94], 
          DirectedEdge["HANNAH", "SUCNHY"], 
          DirectedEdge["HANNAH", 96], 
          DirectedEdge["HANNAH", "LUCY"], 
          DirectedEdge["HANNAH", "ADA"], 
          DirectedEdge["HANNAH", "DAWN"], 
          DirectedEdge["HANNAH", "MFETPC"], 
          DirectedEdge["HANNAH", "LYNN"], 
          DirectedEdge["HANNAH", "BEATRICE"], 
          DirectedEdge["HANNAH", "ZLXPBT"], 
          DirectedEdge["HANNAH", 103], 
          DirectedEdge["HANNAH", 104], 
          DirectedEdge["HANNAH", "CAROLE"], 
          DirectedEdge["HANNAH", "HFKAHK"], 
          DirectedEdge["HANNAH", "MAY"], 
          DirectedEdge["HANNAH", "EVELYN"], 
          DirectedEdge["HANNAH", "ROSE"], 
          DirectedEdge["HANNAH", "MAVIS"], 
          DirectedEdge["HANNAH", 111], 
          DirectedEdge["HANNAH", "SALLY"], 
          DirectedEdge["HANNAH", "KATHERINE"], 
          DirectedEdge["HANNAH", "IRIS"], 
          DirectedEdge["HANNAH", "CKYGWZ"], 
          DirectedEdge["HANNAH", "MARIA"], 
          DirectedEdge["HANNAH", "ZOE"], 
          DirectedEdge["HANNAH", "KERRY"], 
          DirectedEdge["HANNAH", "DEBRA"], 
          DirectedEdge["HANNAH", "MELANIE"], 
          DirectedEdge["HANNAH", "STACEY"], 
          DirectedEdge["HANNAH", "GERTRUDE"], 
          DirectedEdge["HANNAH", "MURIEL"], 
          DirectedEdge["HANNAH", "PAULA"], 
          DirectedEdge["HANNAH", "LAUREN"], 
          DirectedEdge["HANNAH", "MARION"], 
          DirectedEdge["HANNAH", "JOANNA"], 
          DirectedEdge["HANNAH", 129], 
          DirectedEdge["HANNAH", 26], 
          DirectedEdge["HANNAH", 130], 
          DirectedEdge["HANNAH", "MARY"], 
          DirectedEdge["HANNAH", "MARINA"], 
          DirectedEdge["HANNAH", "JANICE"], 
          DirectedEdge["HANNAH", "LORRAINE"], 
          DirectedEdge["HANNAH", "JESSIE"], 
          DirectedEdge["HANNAH", "PEGGY"], 
          DirectedEdge["HANNAH", "ROSEMARY"], 
          DirectedEdge["HANNAH", "SHIRLEY"], 
          DirectedEdge["HANNAH", "SYLVIA"], 
          DirectedEdge["HANNAH", "ANDREA"], 
          DirectedEdge["HANNAH", "FRANCES"], 
          DirectedEdge["HANNAH", "KATHLEEN"], 
          DirectedEdge["HANNAH", "XFGSKJ"], 
          DirectedEdge["HANNAH", "GRACE"], 
          DirectedEdge["HANNAH", "JOSEPHINE"], 
          DirectedEdge["HANNAH", "YVONNE"], 
          DirectedEdge["HANNAH", "SOPHIE"], 
          DirectedEdge["HANNAH", "LYNNE"], 
          DirectedEdge["HANNAH", "ELAINE"], 
          DirectedEdge["HANNAH", "ANNA"], 
          DirectedEdge["ELAINE", "EVA"], 
          DirectedEdge["ELAINE", "GWENDOLINE"], 
          DirectedEdge["GWENDOLINE", "JESSICA"], 
          DirectedEdge["ELAINE", "GEMMA"], 
          DirectedEdge["ELAINE", 149], 
          DirectedEdge["ELAINE", "NORMA"], 
          DirectedEdge["ELAINE", 26], 
          DirectedEdge["ELAINE", "SHIRLEY"], 
          DirectedEdge["ELAINE", "BEVERLEY"], 
          DirectedEdge["ELAINE", "KIRSTY"], 
          DirectedEdge["ELAINE", "KIMBERLEY"], 
          DirectedEdge["ELAINE", "HAZEL"], 
          DirectedEdge["ELAINE", "FIONA"], 
          DirectedEdge["ELAINE", "KATE"], 
          DirectedEdge["ELAINE", "MARIE"], 
          DirectedEdge["ELAINE", "JENNA"], 
          DirectedEdge["GWENDOLINE", "MARILYN"], 
          DirectedEdge["ELAINE", "JANICE"], 
          DirectedEdge["ELAINE", "DAISY"], 
          DirectedEdge["ELAINE", "NORA"], 
          DirectedEdge["ELAINE", "MFETPC"], 
          DirectedEdge["ELAINE", "NATASHA"], 
          DirectedEdge["ELAINE", "MINNIE"], 
          DirectedEdge["ELAINE", "FREDA"], 
          DirectedEdge["ELAINE", "MANDY"], 
          DirectedEdge["ELAINE", "RACHAEL"], 
          DirectedEdge["ELAINE", "KATHLEEN"], 
          DirectedEdge["ELAINE", "TVKHRF"], 
          DirectedEdge["ELAINE", "CHRISTOPHER"], 
          DirectedEdge["ELAINE", 169], 
          DirectedEdge["ELAINE", "KATHRYN"], 
          DirectedEdge["ELAINE", "NANCY"], 
          DirectedEdge["ELAINE", "LWHQYG"], 
          DirectedEdge["ELAINE", "RUTH"], 
          DirectedEdge["ELAINE", "JAYNE"], 
          DirectedEdge["ELAINE", "DIANA"], 
          DirectedEdge["ELAINE", "MARIAN"], 
          DirectedEdge["ELAINE", "ELEANOR"], 
          DirectedEdge["ELAINE", "VERONICA"], 
          DirectedEdge["ELAINE", "SARA"], 
          DirectedEdge["ELAINE", "ALEXANDRA"], 
          DirectedEdge["ELAINE", "LOUISA"], 
          DirectedEdge["ELAINE", "YAKZCN"], 
          DirectedEdge["ELAINE", "SYLVIA"], 
          DirectedEdge["ELAINE", "MSRGUQ"], 
          DirectedEdge["ELAINE", "DORA"], 
          DirectedEdge["ELAINE", "DAPHNE"], 
          DirectedEdge["ELAINE", "PAULINE"], 
          DirectedEdge["ELAINE", "TERESA"], 
          DirectedEdge["ELAINE", "JULIA"], 
          DirectedEdge["ELAINE", "NORAH"], 
          DirectedEdge["ELAINE", "HEATHER"], 
          DirectedEdge["ELAINE", "KIM"], 
          DirectedEdge["ELAINE", "JEMMA"], 
          DirectedEdge["ELAINE", "THELMA"], 
          DirectedEdge["ELAINE", "CARLY"], 
          DirectedEdge["ELAINE", "IDA"], 
          DirectedEdge["ELAINE", "CLARA"], 
          DirectedEdge["KIRSTY", "BEVERLEY"], 
          DirectedEdge["ELAINE", "GLORIA"], 
          DirectedEdge["ELAINE", "HOLLY"], 
          DirectedEdge["ELAINE", "HILARY"], 
          DirectedEdge["SHIRLEY", "MELISSA"], 
          DirectedEdge["ELAINE", "MARTHA"], 
          DirectedEdge["ELAINE", "CYNTHIA"], 
          DirectedEdge["ELAINE", "BERTHA"], 
          DirectedEdge["ELAINE", "LPYGMD"], 
          DirectedEdge["ELAINE", "LILLIAN"], 
          DirectedEdge["ELAINE", "CHERYL"], 
          DirectedEdge["ELAINE", "IZRDSO"], 
          DirectedEdge["ELAINE", "NAOMI"], 
          DirectedEdge["SHIRLEY", "MARTHA"], 
          DirectedEdge["SHIRLEY", "IZRDSO"], 
          DirectedEdge["EILEEN", 207], 
          DirectedEdge["EILEEN", 93], 
          DirectedEdge["EILEEN", "GEMMA"], 
          DirectedEdge["EILEEN", "MFETPC"], 
          DirectedEdge["SHIRLEY", "MFETPC"], 
          DirectedEdge["EILEEN", "BESSIE"], 
          DirectedEdge["EILEEN", "GAIL"], 
          DirectedEdge["SHIRLEY", "JADE"], 
          DirectedEdge["EILEEN", "PENELOPE"], 
          DirectedEdge["EILEEN", "CHARLENE"], 
          DirectedEdge["EILEEN", "JADE"], 
          DirectedEdge["EILEEN", 213], 
          DirectedEdge["EILEEN", "CHRISTINA"], 
          DirectedEdge["EILEEN", "ANNETTE"], 
          DirectedEdge["EILEEN", 216], 
          DirectedEdge["EILEEN", "QCBGCO"], 
          DirectedEdge["EILEEN", "ESTHER"], 
          DirectedEdge["EILEEN", "CAROLYN"], 
          DirectedEdge["EILEEN", "HARRIET"], 
          DirectedEdge["EILEEN", "ANITA"], 
          DirectedEdge["EILEEN", "DIANE"], 
          DirectedEdge["EILEEN", "HAYLEY"], 
          DirectedEdge["EILEEN", "GERALDINE"], 
          DirectedEdge["EILEEN", "BRIDGET"], 
          DirectedEdge["EILEEN", "GEORGINA"], 
          DirectedEdge["EILEEN", "LINDSEY"], 
          DirectedEdge["EILEEN", "SHIRLEY"], 
          DirectedEdge["EILEEN", "KAY"], 
          DirectedEdge["NANCY", 227], 
          DirectedEdge["NANCY", "STELLA"], 
          DirectedEdge["NANCY", "GEMMA"], 
          DirectedEdge["NANCY", 229], 
          DirectedEdge["NANCY", 230], 
          DirectedEdge["NANCY", "NICHOLA"], 
          DirectedEdge["NANCY", 232], 
          DirectedEdge["NANCY", 233], 
          DirectedEdge["NANCY", "ELAINE"], 
          DirectedEdge["NANCY", "AIMEE"], 
          DirectedEdge["NANCY", "HEIDI"], 
          DirectedEdge["NANCY", "MILLICENT"], 
          DirectedEdge["NANCY", "MFETPC"], 
          DirectedEdge["NANCY", "MONICA"], 
          DirectedEdge["NANCY", "BARBARA"], 
          DirectedEdge["NANCY", "SYLVIA"], 
          DirectedEdge["NANCY", "VALERIE"], 
          DirectedEdge["NANCY", "THERESA"], 
          DirectedEdge["NANCY", "SHIRLEY"], 
          DirectedEdge["NANCY", "ANNA"], 
          DirectedEdge["NANCY", "MARGERY"], 
          DirectedEdge["NANCY", "MAXINE"], 
          DirectedEdge["NANCY", "YAKZCN"], 
          DirectedEdge["NANCY", "SOPHIE"], 
          DirectedEdge["NANCY", "TANYA"], 
          DirectedEdge["NANCY", "CARLA"], 
          DirectedEdge["NANCY", "FANNY"], 
          DirectedEdge["NANCY", "KATHLEEN"], 
          DirectedEdge["NANCY", "CAROLYN"], 
          DirectedEdge["NANCY", "KIRSTY"], 
          DirectedEdge["NANCY", "JOY"], 
          DirectedEdge["NANCY", "JANICE"], 
          DirectedEdge["NANCY", "LYDIA"], 
          DirectedEdge["NANCY", "QSJBJN"], 
          DirectedEdge["BARBARA", "MFETPC"], 
          DirectedEdge["NANCY", "GLENYS"], 
          DirectedEdge["NANCY", "CATHERINE"], 
          DirectedEdge["NANCY", "DEBBIE"], 
          DirectedEdge["NANCY", "NORA"], 
          DirectedEdge["NANCY", "JENNY"], 
          DirectedEdge["NANCY", "LWHQYG"], 
          DirectedEdge["NANCY", "UQSBBO"], 
          DirectedEdge["NANCY", "VIVIENNE"], 
          DirectedEdge["SHIRLEY", "TARA"], 
          DirectedEdge["NANCY", "MIRIAM"], 
          DirectedEdge["SHIRLEY", "MIRIAM"], 
          DirectedEdge["NANCY", "YDYBEJ"], 
          DirectedEdge["CLAIR", "LYNDSEY"], 
          DirectedEdge["CLAIR", "SONIA"], 
          DirectedEdge["CLAIR", "MOLLY"], 
          DirectedEdge["CLAIR", 259], 
          DirectedEdge["CLAIR", 260], 
          DirectedEdge["CLAIR", "ELLA"], 
          DirectedEdge["CLAIR", "CHLOE"], 
          DirectedEdge["CLAIR", "SYBIL"], 
          DirectedEdge["CLAIR", "DAGTLQ"], 
          DirectedEdge["CLAIR", "TONI"], 
          DirectedEdge["CLAIR", "WILLIAM"], 
          DirectedEdge["CLAIR", "ETHEL"], 
          DirectedEdge["CLAIR", "PZZJBB"], 
          DirectedEdge["CLAIR", 268], 
          DirectedEdge["CLAIR", "PAUL"], 
          DirectedEdge["CLAIR", "CHRISTOPHER"], 
          DirectedEdge["CLAIR", 270], 
          DirectedEdge["CLAIR", "MARK"], 
          DirectedEdge["CLAIR", "JAMES"], 
          DirectedEdge["CLAIR", 273], 
          DirectedEdge["CLAIR", "ZPINSB"], 
          DirectedEdge["CLAIR", "VYISWO"], 
          DirectedEdge["CLAIR", "ANDREW"], 
          DirectedEdge["CLAIR", 277], 
          DirectedEdge["CLAIR", 278], 
          DirectedEdge["CLAIR", "DANIEL"], 
          DirectedEdge["CLAIR", "ARTHUR"], 
          DirectedEdge["CLAIR", "KAREN"], 
          DirectedEdge["CLAIR", "KKMNQK"], 
          DirectedEdge["CLAIR", "MINNIE"], 
          DirectedEdge["CLAIR", "RICHARD"], 
          DirectedEdge["CLAIR", "ADLDLW"], 
          DirectedEdge["CLAIR", "KATHLEEN"], 
          DirectedEdge["CLAIR", "ANTHONY"], 
          DirectedEdge["CLAIR", "MATTHEW"], 
          DirectedEdge["CLAIR", "CHARLES"], 
          DirectedEdge["CLAIR", "FREDERICK"], 
          DirectedEdge["CLAIR", "KENNETH"], 
          DirectedEdge["CLAIR", "ALBERT"], 
          DirectedEdge["CLAIR", "ALAN"], 
          DirectedEdge["CLAIR", 291], 
          DirectedEdge["CLAIR", "SIMON"], 
          DirectedEdge["CLAIR", "ERNEST"], 
          DirectedEdge["CLAIR", "ALFRED"], 
          DirectedEdge["CLAIR", "EDWARD"], 
          DirectedEdge["CLAIR", "JOSEPH"], 
          DirectedEdge["CLAIR", "LEE"], 
          DirectedEdge["CLAIR", "ADAM"], 
          DirectedEdge["CLAIR", "ROGER"], 
          DirectedEdge["CLAIR", "HAROLD"], 
          DirectedEdge["CLAIR", "QUQJHK"], 
          DirectedEdge["CLAIR", "KEITH"], 
          DirectedEdge["CLAIR", "FRANK"], 
          DirectedEdge["CLAIR", "ACVRVL"], 
          DirectedEdge["CLAIR", "YAKZCN"], 
          DirectedEdge["CLAIR", "RAYMOND"], 
          DirectedEdge["CLAIR", "COLIN"], 
          DirectedEdge["CLAIR", "WRMHHQ"], 
          DirectedEdge["CLAIR", "DARREN"], 
          DirectedEdge["CLAIR", "HENRY"], 
          DirectedEdge["CLAIR", "PHILIP"], 
          DirectedEdge["CLAIR", "GARY"], 
          DirectedEdge["CLAIR", "BENJAMIN"], 
          DirectedEdge["CLAIR", "STANLEY"], 
          DirectedEdge["CLAIR", 314], 
          DirectedEdge["STEVEN", 316], 
          DirectedEdge["STEVEN", "ERIC"], 
          DirectedEdge["STEVEN", 26], 
          DirectedEdge["STEVEN", "LWHQYG"], 
          DirectedEdge["STEVEN", "YAKZCN"], 
          DirectedEdge["STEVEN", 318], 
          DirectedEdge["STEVEN", "KATHLEEN"], 
          DirectedEdge["STEVEN", 319], 
          DirectedEdge["STEVEN", "MARTIN"], 
          DirectedEdge["STEVEN", "SHIRLEY"], 
          DirectedEdge["STEVEN", 321], 
          DirectedEdge["STEVEN", 322], 
          DirectedEdge["STEVEN", "WALTER"], 
          DirectedEdge["STEVEN", 324], 
          DirectedEdge["STEVEN", "NUHUTJ"], 
          DirectedEdge["STEVEN", "NICHOLAS"], 
          DirectedEdge["WALTER", 327], 
          DirectedEdge["STEVEN", "LEONARD"], 
          DirectedEdge["STEVEN", "BARRY"], 
          DirectedEdge["STEVEN", "NKMUGR"], 
          DirectedEdge["STEVEN", "GORDON"], 
          DirectedEdge["STEVEN", "NORMAN"], 
          DirectedEdge["NICHOLAS", 321], 
          DirectedEdge["STEVEN", "NEIL"], 
          DirectedEdge["STEVEN", "NIGEL"], 
          DirectedEdge["STEVEN", "MALCOLM"], 
          DirectedEdge["STEVEN", "TIMOTHY"], 
          DirectedEdge["NKMUGR", "STUART"], 
          DirectedEdge["STEVEN", "MFETPC"], 
          DirectedEdge["STEVEN", "KIM"], 
          DirectedEdge["STEVEN", "FREDA"], 
          DirectedEdge["STEVEN", "GEOFFREY"], 
          DirectedEdge["STEVEN", "RACHAEL"], 
          DirectedEdge["STEVEN", "ALEXANDER"], 
          DirectedEdge["STEVEN", "CATHERINE"], 
          DirectedEdge["STEVEN", "SYLVIA"], 
          DirectedEdge["STEVEN", "RUTH"], 
          DirectedEdge["STEVEN", "CYRIL"], 
          DirectedEdge["STEVEN", "SIDNEY"], 
          DirectedEdge["STEVEN", "MARIE"], 
          DirectedEdge["STEVEN", "JOANNA"], 
          DirectedEdge["STEVEN", "CHRISTINA"], 
          DirectedEdge["STEVEN", "MBHDDP"], 
          DirectedEdge["STEVEN", "RYAN"], 
          DirectedEdge["STEVEN", "KCVFLP"], 
          DirectedEdge["STEVEN", "LUKE"], 
          DirectedEdge["STEVEN", "JACK"], 
          DirectedEdge["STEVEN", "TREVOR"], 
          DirectedEdge["STEVEN", "UNKPWV"], 
          DirectedEdge["STEVEN", "AJRODZ"], 
          DirectedEdge["STEVEN", "WILFRED"], 
          DirectedEdge["STEVEN", "PATRICK"], 
          DirectedEdge["STEVEN", "KIRZZH"], 
          DirectedEdge["STEVEN", "SAMUEL"], 
          DirectedEdge["WAYNE", "VRADXE"], 
          DirectedEdge["WAYNE", "GARETH"], 
          DirectedEdge["WAYNE", 357], 
          DirectedEdge["WAYNE", "SEAN"], 
          DirectedEdge["WAYNE", "HORACE"], 
          DirectedEdge["WAYNE", "BERNARD"], 
          DirectedEdge["WAYNE", 361], 
          DirectedEdge["WAYNE", 362], 
          DirectedEdge["WAYNE", "FRED"], 
          DirectedEdge["WAYNE", "EDWIN"], 
          DirectedEdge["WAYNE", "FZCFTO"], 
          DirectedEdge["WAYNE", "SHAUN"], 
          DirectedEdge["WAYNE", "CLIFFORD"], 
          DirectedEdge["WAYNE", "MAURICE"], 
          DirectedEdge["WAYNE", "CLIVE"], 
          DirectedEdge["WAYNE", "BEN"], 
          DirectedEdge["WAYNE", "ANTONY"], 
          DirectedEdge["WAYNE", "CHRISTOPHER"], 
          DirectedEdge["WAYNE", "MXOUPI"], 
          DirectedEdge["WAYNE", "MALCOLM"], 
          DirectedEdge["WAYNE", 373], 
          DirectedEdge["WAYNE", "JUSTIN"], 
          DirectedEdge["WAYNE", 375], 
          DirectedEdge["WAYNE", "JEFFREY"], 
          DirectedEdge["WAYNE", "OLIVER"], 
          DirectedEdge["WAYNE", "EDGAR"], 
          DirectedEdge["WAYNE", "ETHEL"], 
          DirectedEdge["WAYNE", "SHIRLEY"], 
          DirectedEdge["WAYNE", "KATHLEEN"], 
          DirectedEdge["BEN", "SHIRLEY"], 
          DirectedEdge["WAYNE", "CHRISTIAN"], 
          DirectedEdge["WAYNE", "ASHLEY"], 
          DirectedEdge["WAYNE", "KARL"], 
          DirectedEdge["WAYNE", "AARON"], 
          DirectedEdge["WAYNE", "MARC"], 
          DirectedEdge["WAYNE", "YAKZCN"], 
          DirectedEdge["WAYNE", "MOHAMMED"], 
          DirectedEdge["WAYNE", "PEYHIE"], 
          DirectedEdge["WAYNE", "JANICE"], 
          DirectedEdge["WAYNE", "RUSSELL"], 
          DirectedEdge["WAYNE", "GAVIN"], 
          DirectedEdge["WAYNE", "CATHERINE"], 
          DirectedEdge["WAYNE", "VIVVLG"], 
          DirectedEdge["WAYNE", "FREDA"], 
          DirectedEdge["WAYNE", "LIAM"], 
          DirectedEdge["WAYNE", "ROBIN"], 
          DirectedEdge["WAYNE", "PHILLIP"], 
          DirectedEdge["WAYNE", "NATHAN"], 
          DirectedEdge["WAYNE", "DENIS"]}, {VertexLabels -> {
            Placed["Name", Tooltip]}, EdgeWeight -> CompressedData["
1:eJyFUNsRgCAMIy3IHK7kCCzgvG4jFI8rtWI+aEhfue7lPApCCFd9oBFBLVAL
woRQp6KMBBQRbD0wHORWTUhezoC+VXoVKcXd+zvebuNZ5oWbivR0RIzjqHMt
TLD0zJZJGzDUN2H3zP8bwKAErA==
           
           "]}], $CellContext`edgeWeights = CompressedData["
1:eJyFUNsRgCAMIy3IHK7kCCzgvG4jFI8rtWI+aEhfue7lPApCCFd9oBFBLVAL
woRQp6KMBBQRbD0wHORWTUhezoC+VXoVKcXd+zvebuNZ5oWbivR0RIzjqHMt
TLD0zJZJGzDUN2H3zP8bwKAErA==
        "]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.676271572623253*^9, 3.6762716111958437`*^9}, 
   3.6762716452272882`*^9, {3.676271981486299*^9, 3.676272007077566*^9}, 
   3.6778227620033693`*^9, 3.677822959314481*^9}]
}, Open  ]],

Cell["\<\
There were some EMLO ids included in the tallies file that were not detailed \
included in the people-info.csv file, remove these from the dataset and \
update your manipulate.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.67627146799815*^9, 3.67627151176016*^9}, {
  3.677822785379602*^9, 3.6778228559495897`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Advanced Questions", "Section",
 CellChangeTimes->{{3.6762714912388487`*^9, 3.6762714940183067`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Modify your code so that you can filter out edges by the different \
interaction types, for instance display only those connections where at least \
interaction is due to PoliticalActivity\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676271691223072*^9, 3.6762717544237843`*^9}}],

Cell["\<\
Allow the user to switch between subsetting the graph and instead just \
highlighting the interactions of interest.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.676271691223072*^9, 3.676271781954151*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1069, 1031},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"10.4 for Mac OS X x86 (32-bit, 64-bit Kernel) (April 11, \
2016)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData["Comments"], CellMargins -> {{66, 210}, {7, 7}}, 
    LineSpacing -> {1, 3}, CounterIncrements -> "Text", MenuSortingValue -> 
    1400, FontFamily -> "Arial", FontSize -> 14, FontColor -> 
    RGBColor[0, 0, 1]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Section"], CellFrame -> {{0, 0}, {0, 1}}, 
       CellMargins -> {{27, Inherited}, {8, 18}}, 
       StyleKeyMapping -> {"Tab" -> "Subsection"}, 
       CellGroupingRules -> {"SectionGrouping", 30}, PageBreakBelow -> False, 
       CellFrameMargins -> 4, CellFrameColor -> GrayLevel[0.7], 
       LineSpacing -> {1, 2}, LanguageCategory -> "NaturalLanguage", 
       CounterIncrements -> "Section", 
       CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
         "Item", 0}, {"Subitem", 0}, {"Subsubitem", 0}, {"ItemNumbered", 0}, {
         "SubitemNumbered", 0}, {"SubsubitemNumbered", 0}}, MenuSortingValue -> 
       1250, MenuCommandKey -> "4", FontFamily -> "Gill Sans", FontSize -> 28,
        FontColor -> RGBColor[0, 0, 0]], 
      Cell[
       StyleData["Section", "Presentation"], CellFrame -> {{0, 0}, {0, 2}}, 
       CellMargins -> {{67, Inherited}, {12, 24}}, CellFrameMargins -> 8, 
       LineSpacing -> {1, 10}, FontSize -> 40], 
      Cell[
       StyleData["Section", "SlideShow"], 
       CellMargins -> {{
         0.06 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}], 0.04 
          FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]}, {
         12, 0.06 FrontEnd`AbsoluteCurrentValue[{WindowSize, 2}]}}, 
       LineSpacing -> {1, 2}, FontSize -> 40], 
      Cell[
       StyleData["Section", "Condensed"], 
       CellMargins -> {{18, Inherited}, {6, 12}}, FontSize -> 12], 
      Cell[
       StyleData["Section", "Printout"], 
       CellMargins -> {{10, Inherited}, {8, 18}}], 
      Cell[
       StyleData["Section", "PrintoutGray"], 
       CellMargins -> {{10, Inherited}, {8, 18}}, FontColor -> 
       GrayLevel[0.2]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Subsection"], CellMargins -> {{50.34765625, 3.}, {8., 12.}},
        StyleKeyMapping -> {
        "Tab" -> "Subsubsection", "Backspace" -> "Section", 
         KeyEvent["Tab", Modifiers -> {Shift}] -> "Section"}, 
       CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> False, 
       LanguageCategory -> "NaturalLanguage", CounterIncrements -> 
       "Subsection", 
       CounterAssignments -> {{"Subsubsection", 0}, {"Item", 0}, {
         "Subitem", 0}, {"Subsubitem", 0}, {"ItemNumbered", 0}, {
         "SubitemNumbered", 0}, {"SubsubitemNumbered", 0}}, MenuSortingValue -> 
       1300, MenuCommandKey -> "5", FontFamily -> "Gill Sans", FontSize -> 20,
        FontColor -> RGBColor[0, 0, 0]], 
      Cell[
       StyleData["Subsection", "Presentation"], 
       CellMargins -> {{100, Inherited}, {12, 18}}, LineSpacing -> {1, 10}, 
       FontSize -> 28], 
      Cell[
       StyleData["Subsection", "SlideShow"], 
       CellMargins -> {{
         0.1 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}], 0.02 
          FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]}, {
         12, 0.046 FrontEnd`AbsoluteCurrentValue[{WindowSize, 2}]}}, 
       LineSpacing -> {1, 2}, FontSize -> 32], 
      Cell[
       StyleData["Subsection", "Condensed"], 
       CellMargins -> {{18, Inherited}, {6, 12}}, FontSize -> 11], 
      Cell[
       StyleData["Subsection", "Printout"], 
       CellMargins -> {{30, Inherited}, {8., 16}}], 
      Cell[
       StyleData["Subsection", "PrintoutGray"], 
       CellMargins -> {{30, Inherited}, {8., 16}}, FontColor -> 
       GrayLevel[0.3]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Subsubsection"], CellMargins -> {{66, Inherited}, {2, 10}}, 
       StyleKeyMapping -> {
        "Tab" -> "Subsubsubsection", "Backspace" -> "Subsection", 
         KeyEvent["Tab", Modifiers -> {Shift}] -> "Subsection"}, 
       CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> False, 
       LanguageCategory -> "NaturalLanguage", CounterIncrements -> 
       "Subsubsection", 
       CounterAssignments -> {{"Subsubsubsection", 0}, {"Item", 0}, {
         "Subitem", 0}, {"Subsubitem", 0}, {"ItemNumbered", 0}, {
         "SubitemNumbered", 0}, {"SubsubitemNumbered", 0}}, MenuSortingValue -> 
       1350, MenuCommandKey -> "6", FontFamily -> "Gill Sans", FontSize -> 19,
        FontColor -> RGBColor[0, 0, 0]], 
      Cell[
       StyleData["Subsubsection", "Presentation"], 
       CellMargins -> {{100, Inherited}, {3, 15}}, LineSpacing -> {1, 6}, 
       FontSize -> 24], 
      Cell[
       StyleData["Subsubsection", "SlideShow"], 
       CellMargins -> {{
         0.135 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}], 0.03 
          FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]}, {3, 15}}, 
       LineSpacing -> {1, 2}, FontSize -> 28], 
      Cell[
       StyleData["Subsubsection", "Condensed"], 
       CellMargins -> {{18, Inherited}, {6, 12}}, FontSize -> 11], 
      Cell[
       StyleData["Subsubsection", "Printout"], 
       CellMargins -> {{49, Inherited}, {6, 16}}], 
      Cell[
       StyleData["Subsubsection", "PrintoutGray"], 
       CellMargins -> {{49, Inherited}, {6, 16}}, FontColor -> 
       GrayLevel[0.3]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Subsubsubsection"], 
       CellMargins -> {{66, Inherited}, {2, 10}}, 
       StyleKeyMapping -> {
        "Tab" -> "Subsubsubsubsection", "Backspace" -> "Subsubsection", 
         KeyEvent["Tab", Modifiers -> {Shift}] -> "Subsubsection"}, 
       CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> False, 
       LanguageCategory -> "NaturalLanguage", CounterIncrements -> 
       "Subsubsubsection", 
       CounterAssignments -> {{"Subsubsubsubsection", 0}, {"Item", 0}, {
         "Subitem", 0}, {"Subsubitem", 0}, {"ItemNumbered", 0}, {
         "SubitemNumbered", 0}, {"SubsubitemNumbered", 0}}, MenuSortingValue -> 
       None, FontFamily -> "Arial", FontSize -> 14, FontWeight -> "Bold", 
       FontColor -> RGBColor[0, 0, 0]], 
      Cell[
       StyleData["Subsubsubsection", "Presentation"], 
       CellMargins -> {{100, Inherited}, {3, 15}}, LineSpacing -> {1, 7}, 
       FontSize -> 24], 
      Cell[
       StyleData["Subsubsubsection", "SlideShow"], 
       CellMargins -> {{
         0.135 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}], 0.03 
          FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]}, {3, 15}}, 
       LineSpacing -> {1, 2}, FontFamily -> "Arial", FontSize -> 22], 
      Cell[
       StyleData["Subsubsubsection", "Condensed"], 
       CellMargins -> {{18, Inherited}, {6, 12}}, FontSize -> 10], 
      Cell[
       StyleData["Subsubsubsection", "Printout"], 
       CellMargins -> {{49, Inherited}, {6, 14}}], 
      Cell[
       StyleData["Subsubsubsection", "PrintoutGray"], 
       CellMargins -> {{49, Inherited}, {6, 14}}, FontColor -> 
       GrayLevel[0.4]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
       StyleData["Subsubsubsubsection"], 
       CellMargins -> {{66, Inherited}, {2, 10}}, 
       StyleKeyMapping -> {
        "Backspace" -> "Subsubsubsection", 
         KeyEvent["Tab", Modifiers -> {Shift}] -> "Subsubsubsection"}, 
       CellGroupingRules -> {"SectionGrouping", 70}, PageBreakBelow -> False, 
       LanguageCategory -> "NaturalLanguage", CounterIncrements -> 
       "Subsubsubsubsection", 
       CounterAssignments -> {{"Item", 0}, {"Subitem", 0}, {
         "Subsubitem", 0}, {"ItemNumbered", 0}, {"SubitemNumbered", 0}, {
         "SubsubitemNumbered", 0}}, MenuSortingValue -> None, FontFamily -> 
       "Arial", FontSize -> 14, FontColor -> RGBColor[0, 0, 0]], 
      Cell[
       StyleData["Subsubsubsubsection", "Presentation"], 
       CellMargins -> {{100, Inherited}, {3, 15}}, LineSpacing -> {1, 7}, 
       FontSize -> 24], 
      Cell[
       StyleData["Subsubsubsubsection", "SlideShow"], 
       CellMargins -> {{
         0.135 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}], 0.03 
          FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]}, {3, 15}}, 
       LineSpacing -> {1, 2}, FontSize -> 22], 
      Cell[
       StyleData["Subsubsubsubsection", "Condensed"], 
       CellMargins -> {{18, Inherited}, {6, 12}}, FontSize -> 10], 
      Cell[
       StyleData["Subsubsubsubsection", "Printout"], 
       CellMargins -> {{49, Inherited}, {6, 14}}], 
      Cell[
       StyleData["Subsubsubsubsection", "PrintoutGray"], 
       CellMargins -> {{49, Inherited}, {6, 14}}, FontColor -> 
       GrayLevel[0.3]]}, Closed]]}, Visible -> False, FrontEndVersion -> 
  "10.4 for Mac OS X x86 (32-bit, 64-bit Kernel) (April 11, 2016)", 
  StyleDefinitions -> "PrivateStylesheetFormatting.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "SlideShowHeader"->{
  Cell[936, 29, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[5620, 116, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[8098, 185, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[34337, 902, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[870844, 18012, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[872838, 18063, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"],
  Cell[899746, 18643, 64, 1, 74, "SlideShowNavigationBar",
   CellTags->"SlideShowHeader"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"SlideShowHeader", 1214464, 25257}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 353, 5, 92, "Title"],
Cell[CellGroupData[{
Cell[936, 29, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[1003, 32, 84, 1, 92, "Title"],
Cell[1090, 35, 512, 11, 49, "Text"],
Cell[1605, 48, 790, 16, 49, "Text"],
Cell[2398, 66, 155, 2, 30, "Text"],
Cell[2556, 70, 3027, 41, 619, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5620, 116, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[5687, 119, 140, 2, 92, "Title"],
Cell[5830, 123, 371, 6, 49, "Text"],
Cell[6204, 131, 346, 7, 68, "Text"],
Cell[CellGroupData[{
Cell[6575, 142, 96, 1, 28, "Item"],
Cell[6674, 145, 230, 4, 28, "Item"]
}, Open  ]],
Cell[6919, 152, 748, 19, 80, "Input"],
Cell[7670, 173, 391, 7, 45, "Item"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8098, 185, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[8165, 188, 93, 1, 92, "Title"],
Cell[8261, 191, 363, 10, 125, "Text"],
Cell[8627, 203, 267, 5, 30, "Text"],
Cell[8897, 210, 342, 6, 30, "ItemNumbered"],
Cell[9242, 218, 193, 2, 30, "Text"],
Cell[CellGroupData[{
Cell[9460, 224, 272, 6, 28, "Input"],
Cell[9735, 232, 353, 6, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10125, 243, 368, 9, 28, "Input"],
Cell[10496, 254, 163, 2, 28, "Output"]
}, Open  ]],
Cell[10674, 259, 133, 1, 30, "Text"],
Cell[10810, 262, 193, 4, 30, "ItemNumbered"],
Cell[11006, 268, 155, 4, 28, "Input"],
Cell[CellGroupData[{
Cell[11186, 276, 214, 5, 28, "Input"],
Cell[11403, 283, 858, 18, 117, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12298, 306, 93, 1, 64, "Section"],
Cell[12394, 309, 254, 5, 30, "ItemNumbered"],
Cell[12651, 316, 432, 13, 28, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13120, 334, 101, 1, 64, "Section"],
Cell[13224, 337, 192, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[13441, 345, 287, 7, 28, "Input"],
Cell[13731, 354, 261, 6, 28, "Output"]
}, Open  ]],
Cell[14007, 363, 319, 6, 30, "ItemNumbered"],
Cell[14329, 371, 132, 1, 30, "Text"],
Cell[14464, 374, 709, 15, 63, "Input"],
Cell[15176, 391, 221, 5, 30, "Text"],
Cell[15400, 398, 405, 11, 28, "Input"],
Cell[15808, 411, 697, 11, 106, "ItemNumbered"],
Cell[16508, 424, 220, 5, 28, "Input"],
Cell[16731, 431, 290, 5, 24, "SubitemNumbered"],
Cell[17024, 438, 405, 7, 49, "ItemNumbered"],
Cell[17432, 447, 360, 11, 28, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17829, 463, 106, 1, 64, "Section"],
Cell[17938, 466, 201, 4, 30, "Text"],
Cell[18142, 472, 237, 4, 30, "ItemNumbered"],
Cell[CellGroupData[{
Cell[18404, 480, 234, 5, 28, "Input"],
Cell[18641, 487, 819, 20, 46, "Output"]
}, Open  ]],
Cell[19475, 510, 247, 5, 30, "ItemNumbered"],
Cell[CellGroupData[{
Cell[19747, 519, 861, 23, 63, "Input"],
Cell[20611, 544, 13665, 351, 184, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[34337, 902, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[34404, 905, 210, 3, 92, "Title"],
Cell[34617, 910, 344, 6, 30, "Text"],
Cell[34964, 918, 231998, 4634, 311, 157127, 3405, "CachedBoxData", "BoxData", \
"Input"],
Cell[266965, 5554, 404, 8, 30, "ItemNumbered"],
Cell[267372, 5564, 486, 13, 28, "Input"],
Cell[267861, 5579, 446, 8, 49, "ItemNumbered"],
Cell[268310, 5589, 157192, 3406, 311, "Input"],
Cell[425505, 8997, 400, 7, 49, "ItemNumbered"],
Cell[CellGroupData[{
Cell[425930, 9008, 447, 10, 28, "Input"],
Cell[426380, 9020, 232090, 4635, 311, 157128, 3405, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[658485, 13658, 389, 7, 49, "Text"],
Cell[658877, 13667, 355, 7, 49, "ItemNumbered"],
Cell[CellGroupData[{
Cell[659257, 13678, 366, 8, 28, "Input"],
Cell[659626, 13688, 211169, 4318, 311, 142318, 3187, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[870844, 18012, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[870911, 18015, 211, 3, 92, "Title"],
Cell[871125, 18020, 232, 4, 30, "Text"],
Cell[871360, 18026, 164, 3, 30, "ItemNumbered"],
Cell[871527, 18031, 242, 4, 47, "Input"],
Cell[871772, 18037, 205, 4, 30, "Text"],
Cell[871980, 18043, 530, 8, 68, "ItemNumbered"],
Cell[872513, 18053, 288, 5, 49, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[872838, 18063, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[872905, 18066, 205, 3, 92, "Title"],
Cell[873113, 18071, 435, 7, 49, "Text"],
Cell[873551, 18080, 243, 5, 30, "Text"],
Cell[873797, 18087, 306, 5, 30, "ItemNumbered"],
Cell[CellGroupData[{
Cell[874128, 18096, 265, 5, 28, "Input"],
Cell[874396, 18103, 3777, 50, 165, "Output"]
}, Open  ]],
Cell[878188, 18156, 575, 9, 106, "ItemNumbered"],
Cell[CellGroupData[{
Cell[878788, 18169, 610, 17, 63, "Input"],
Cell[879401, 18188, 2328, 51, 329, "Output"]
}, Open  ]],
Cell[881744, 18242, 659, 12, 68, "Text"],
Cell[882406, 18256, 317, 5, 30, "ItemNumbered"],
Cell[CellGroupData[{
Cell[882748, 18265, 441, 10, 28, "Input"],
Cell[883192, 18277, 696, 11, 46, "Output"]
}, Open  ]],
Cell[883903, 18291, 401, 7, 49, "ItemNumbered"],
Cell[CellGroupData[{
Cell[884329, 18302, 353, 7, 28, "Input"],
Cell[884685, 18311, 9155, 197, 363, "Output"]
}, Open  ]],
Cell[893855, 18511, 667, 12, 87, "ItemNumbered"],
Cell[894525, 18525, 581, 13, 46, "Input"],
Cell[895109, 18540, 326, 6, 68, "ItemNumbered"],
Cell[CellGroupData[{
Cell[895460, 18550, 532, 12, 46, "Input"],
Cell[895995, 18564, 3702, 73, 629, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[899746, 18643, 64, 1, 74, "SlideShowNavigationBar",
 CellTags->"SlideShowHeader"],
Cell[899813, 18646, 351, 5, 92, "Title"],
Cell[900167, 18653, 125, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[900317, 18658, 173, 4, 28, "Item"],
Cell[900493, 18664, 144, 1, 28, "Item"]
}, Open  ]],
Cell[900652, 18668, 209, 4, 30, "Text"],
Cell[900864, 18674, 120, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[901009, 18679, 445, 13, 46, "Input"],
Cell[901457, 18694, 1552, 30, 140, "Output"]
}, Open  ]],
Cell[903024, 18727, 195, 4, 30, "Text"],
Cell[CellGroupData[{
Cell[903244, 18735, 392, 10, 28, "Input"],
Cell[903639, 18747, 1545, 31, 141, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[905221, 18783, 107, 1, 64, "Section"],
Cell[905331, 18786, 400, 8, 49, "Text"],
Cell[905734, 18796, 716, 19, 46, "Input"],
Cell[CellGroupData[{
Cell[906475, 18819, 150, 2, 28, "Input"],
Cell[906628, 18823, 936, 17, 63, "Output"]
}, Open  ]],
Cell[907579, 18843, 328, 6, 49, "Text"],
Cell[907910, 18851, 669, 19, 46, "Input"],
Cell[CellGroupData[{
Cell[908604, 18874, 137, 2, 28, "Input"],
Cell[908744, 18878, 288, 6, 28, "Output"]
}, Open  ]],
Cell[909047, 18887, 371, 7, 49, "ItemNumbered"],
Cell[909421, 18896, 713, 18, 63, "Input"],
Cell[910137, 18916, 713, 18, 63, "Input"],
Cell[910853, 18936, 515, 8, 87, "ItemNumbered"],
Cell[911371, 18946, 554, 16, 46, "Input"],
Cell[911928, 18964, 295, 5, 49, "ItemNumbered"],
Cell[CellGroupData[{
Cell[912248, 18973, 979, 25, 80, "Input"],
Cell[913230, 19000, 227459, 4703, 286, 161192, 3616, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1140738, 23709, 102, 1, 64, "Section"],
Cell[1140843, 23712, 222, 4, 30, "ItemNumbered"],
Cell[CellGroupData[{
Cell[1141090, 23720, 256, 5, 28, "Input"],
Cell[1141349, 23727, 5196, 69, 216, "Output"]
}, Open  ]],
Cell[1146560, 23799, 177, 4, 30, "ItemNumbered"],
Cell[CellGroupData[{
Cell[1146762, 23807, 602, 14, 28, "Input"],
Cell[1147367, 23823, 27656, 566, 326, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1175060, 24394, 390, 7, 49, "ItemNumbered"],
Cell[1175453, 24403, 183, 4, 30, "ItemNumbered"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1175673, 24412, 1079, 28, 114, "Input"],
Cell[1176755, 24442, 27550, 582, 374, "Output"]
}, Open  ]],
Cell[1204320, 25027, 323, 6, 49, "ItemNumbered"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1204680, 25038, 107, 1, 64, "Section"],
Cell[CellGroupData[{
Cell[1204812, 25043, 288, 5, 49, "ItemNumbered"],
Cell[1205103, 25050, 213, 4, 30, "ItemNumbered"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

